Class: Google::Apis::YoutubeV3::ActivityContentDetailsComment
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivityContentDetailsComment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Information about a resource that received a comment.
Instance Attribute Summary collapse
-
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityContentDetailsComment
constructor
A new instance of ActivityContentDetailsComment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityContentDetailsComment
Returns a new instance of ActivityContentDetailsComment.
290 291 292 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property resourceId
288 289 290 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 288 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
295 296 297 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 295 def update!(**args) @resource_id = args[:resource_id] if args.key?(:resource_id) end |