Class: Google::Apis::YoutubeV3::ActivityContentDetailsPlaylistItem
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivityContentDetailsPlaylistItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Information about a new playlist item.
Instance Attribute Summary collapse
-
#playlist_id ⇒ String
The value that YouTube uses to uniquely identify the playlist.
-
#playlist_item_id ⇒ String
ID of the item within the playlist.
-
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityContentDetailsPlaylistItem
constructor
A new instance of ActivityContentDetailsPlaylistItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityContentDetailsPlaylistItem
Returns a new instance of ActivityContentDetailsPlaylistItem.
359 360 361 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#playlist_id ⇒ String
The value that YouTube uses to uniquely identify the playlist.
Corresponds to the JSON property playlistId
347 348 349 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 347 def playlist_id @playlist_id end |
#playlist_item_id ⇒ String
ID of the item within the playlist.
Corresponds to the JSON property playlistItemId
352 353 354 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 352 def playlist_item_id @playlist_item_id end |
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property resourceId
357 358 359 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 357 def resource_id @resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
364 365 366 367 368 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 364 def update!(**args) @playlist_id = args[:playlist_id] if args.key?(:playlist_id) @playlist_item_id = args[:playlist_item_id] if args.key?(:playlist_item_id) @resource_id = args[:resource_id] if args.key?(:resource_id) end |