Class: Google::Apis::YoutubeV3::ActivityContentDetailsPromotedItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about a resource which is being promoted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActivityContentDetailsPromotedItem

Returns a new instance of ActivityContentDetailsPromotedItem.



433
434
435
# File 'lib/google/apis/youtube_v3/classes.rb', line 433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_tagString

The URL the client should fetch to request a promoted item. Corresponds to the JSON property adTag

Returns:

  • (String)


378
379
380
# File 'lib/google/apis/youtube_v3/classes.rb', line 378

def ad_tag
  @ad_tag
end

#click_tracking_urlString

The URL the client should ping to indicate that the user clicked through on this promoted item. Corresponds to the JSON property clickTrackingUrl

Returns:

  • (String)


384
385
386
# File 'lib/google/apis/youtube_v3/classes.rb', line 384

def click_tracking_url
  @click_tracking_url
end

#creative_view_urlString

The URL the client should ping to indicate that the user was shown this promoted item. Corresponds to the JSON property creativeViewUrl

Returns:

  • (String)


390
391
392
# File 'lib/google/apis/youtube_v3/classes.rb', line 390

def creative_view_url
  @creative_view_url
end

#cta_typeString

The type of call-to-action, a message to the user indicating action that can be taken. Corresponds to the JSON property ctaType

Returns:

  • (String)


396
397
398
# File 'lib/google/apis/youtube_v3/classes.rb', line 396

def cta_type
  @cta_type
end

#custom_cta_button_textString

The custom call-to-action button text. If specified, it will override the default button text for the cta_type. Corresponds to the JSON property customCtaButtonText

Returns:

  • (String)


402
403
404
# File 'lib/google/apis/youtube_v3/classes.rb', line 402

def custom_cta_button_text
  @custom_cta_button_text
end

#description_textString

The text description to accompany the promoted item. Corresponds to the JSON property descriptionText

Returns:

  • (String)


407
408
409
# File 'lib/google/apis/youtube_v3/classes.rb', line 407

def description_text
  @description_text
end

#destination_urlString

The URL the client should direct the user to, if the user chooses to visit the advertiser's website. Corresponds to the JSON property destinationUrl

Returns:

  • (String)


413
414
415
# File 'lib/google/apis/youtube_v3/classes.rb', line 413

def destination_url
  @destination_url
end

#forecasting_urlArray<String>

The list of forecasting URLs. The client should ping all of these URLs when a promoted item is not available, to indicate that a promoted item could have been shown. Corresponds to the JSON property forecastingUrl

Returns:

  • (Array<String>)


420
421
422
# File 'lib/google/apis/youtube_v3/classes.rb', line 420

def forecasting_url
  @forecasting_url
end

#impression_urlArray<String>

The list of impression URLs. The client should ping all of these URLs to indicate that the user was shown this promoted item. Corresponds to the JSON property impressionUrl

Returns:

  • (Array<String>)


426
427
428
# File 'lib/google/apis/youtube_v3/classes.rb', line 426

def impression_url
  @impression_url
end

#video_idString

The ID that YouTube uses to uniquely identify the promoted video. Corresponds to the JSON property videoId

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/youtube_v3/classes.rb', line 431

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/google/apis/youtube_v3/classes.rb', line 438

def update!(**args)
  @ad_tag = args[:ad_tag] if args.key?(:ad_tag)
  @click_tracking_url = args[:click_tracking_url] if args.key?(:click_tracking_url)
  @creative_view_url = args[:creative_view_url] if args.key?(:creative_view_url)
  @cta_type = args[:cta_type] if args.key?(:cta_type)
  @custom_cta_button_text = args[:custom_cta_button_text] if args.key?(:custom_cta_button_text)
  @description_text = args[:description_text] if args.key?(:description_text)
  @destination_url = args[:destination_url] if args.key?(:destination_url)
  @forecasting_url = args[:forecasting_url] if args.key?(:forecasting_url)
  @impression_url = args[:impression_url] if args.key?(:impression_url)
  @video_id = args[:video_id] if args.key?(:video_id)
end