Class: Google::Apis::YoutubeV3::ActivityContentDetailsRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information that identifies the recommended resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActivityContentDetailsRecommendation

Returns a new instance of ActivityContentDetailsRecommendation.



471
472
473
# File 'lib/google/apis/youtube_v3/classes.rb', line 471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reasonString

The reason that the resource is recommended to the user. Corresponds to the JSON property reason

Returns:

  • (String)


459
460
461
# File 'lib/google/apis/youtube_v3/classes.rb', line 459

def reason
  @reason
end

#resource_idGoogle::Apis::YoutubeV3::ResourceId

A resource id is a generic reference that points to another YouTube resource. Corresponds to the JSON property resourceId



464
465
466
# File 'lib/google/apis/youtube_v3/classes.rb', line 464

def resource_id
  @resource_id
end

#seed_resource_idGoogle::Apis::YoutubeV3::ResourceId

A resource id is a generic reference that points to another YouTube resource. Corresponds to the JSON property seedResourceId



469
470
471
# File 'lib/google/apis/youtube_v3/classes.rb', line 469

def seed_resource_id
  @seed_resource_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



476
477
478
479
480
# File 'lib/google/apis/youtube_v3/classes.rb', line 476

def update!(**args)
  @reason = args[:reason] if args.key?(:reason)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @seed_resource_id = args[:seed_resource_id] if args.key?(:seed_resource_id)
end