Class: Google::Apis::YoutubeV3::ActivityContentDetailsSocial
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivityContentDetailsSocial
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Details about a social network post.
Instance Attribute Summary collapse
-
#author ⇒ String
The author of the social network post.
-
#image_url ⇒ String
An image of the post's author.
-
#reference_url ⇒ String
The URL of the social network post.
-
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
-
#type ⇒ String
The name of the social network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityContentDetailsSocial
constructor
A new instance of ActivityContentDetailsSocial.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityContentDetailsSocial
Returns a new instance of ActivityContentDetailsSocial.
512 513 514 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author ⇒ String
The author of the social network post.
Corresponds to the JSON property author
490 491 492 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 490 def @author end |
#image_url ⇒ String
An image of the post's author.
Corresponds to the JSON property imageUrl
495 496 497 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 495 def image_url @image_url end |
#reference_url ⇒ String
The URL of the social network post.
Corresponds to the JSON property referenceUrl
500 501 502 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 500 def reference_url @reference_url end |
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property resourceId
505 506 507 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 505 def resource_id @resource_id end |
#type ⇒ String
The name of the social network.
Corresponds to the JSON property type
510 511 512 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 510 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
517 518 519 520 521 522 523 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 517 def update!(**args) @author = args[:author] if args.key?(:author) @image_url = args[:image_url] if args.key?(:image_url) @reference_url = args[:reference_url] if args.key?(:reference_url) @resource_id = args[:resource_id] if args.key?(:resource_id) @type = args[:type] if args.key?(:type) end |