Class: Google::Apis::YoutubeV3::AvailabilityConfigRegionsConfigRegionInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Region and time window where video is available for the region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AvailabilityConfigRegionsConfigRegionInterval

Returns a new instance of AvailabilityConfigRegionsConfigRegionInterval.



796
797
798
# File 'lib/google/apis/youtube_v3/classes.rb', line 796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::YoutubeV3::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



789
790
791
# File 'lib/google/apis/youtube_v3/classes.rb', line 789

def interval
  @interval
end

#region_codeString

Required. Region where video is available Corresponds to the JSON property regionCode

Returns:

  • (String)


794
795
796
# File 'lib/google/apis/youtube_v3/classes.rb', line 794

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



801
802
803
804
# File 'lib/google/apis/youtube_v3/classes.rb', line 801

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @region_code = args[:region_code] if args.key?(:region_code)
end