Class: Google::Apis::YoutubeV3::BatchGetStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Response for the Videos.stats API. Returns VideoStat information about a batch of videos. VideoStat contains a subset of the information in Video that is relevant to statistics and content details. BatchGetStats is intentionally not atomic to provide a better user experience. BatchGetStatsResponse returns a summary to help users understand the outcome of the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchGetStatsResponse

Returns a new instance of BatchGetStatsResponse.



827
828
829
# File 'lib/google/apis/youtube_v3/classes.rb', line 827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


814
815
816
# File 'lib/google/apis/youtube_v3/classes.rb', line 814

def etag
  @etag
end

#itemsArray<Google::Apis::YoutubeV3::VideoStat>

The videos' stats information. Corresponds to the JSON property items



819
820
821
# File 'lib/google/apis/youtube_v3/classes.rb', line 819

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# batchGetStatsResponse". Corresponds to the JSON property kind

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/youtube_v3/classes.rb', line 825

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



832
833
834
835
836
# File 'lib/google/apis/youtube_v3/classes.rb', line 832

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end