Class: Google::Apis::YoutubeV3::Caption

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A caption resource represents a YouTube caption track. A caption track is associated with exactly one YouTube video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Caption

Returns a new instance of Caption.



891
892
893
# File 'lib/google/apis/youtube_v3/classes.rb', line 891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


873
874
875
# File 'lib/google/apis/youtube_v3/classes.rb', line 873

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the caption track. Corresponds to the JSON property id

Returns:

  • (String)


878
879
880
# File 'lib/google/apis/youtube_v3/classes.rb', line 878

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# caption". Corresponds to the JSON property kind

Returns:

  • (String)


884
885
886
# File 'lib/google/apis/youtube_v3/classes.rb', line 884

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::CaptionSnippet

Basic details about a caption track, such as its language and name. Corresponds to the JSON property snippet



889
890
891
# File 'lib/google/apis/youtube_v3/classes.rb', line 889

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



896
897
898
899
900
901
# File 'lib/google/apis/youtube_v3/classes.rb', line 896

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end