Class: Google::Apis::YoutubeV3::CdnSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Brief description of the live stream cdn settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CdnSettings

Returns a new instance of CdnSettings.



1087
1088
1089
# File 'lib/google/apis/youtube_v3/classes.rb', line 1087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#formatString

The format of the video stream that you are sending to Youtube. Corresponds to the JSON property format

Returns:

  • (String)


1065
1066
1067
# File 'lib/google/apis/youtube_v3/classes.rb', line 1065

def format
  @format
end

#frame_rateString

The frame rate of the inbound video data. Corresponds to the JSON property frameRate

Returns:

  • (String)


1070
1071
1072
# File 'lib/google/apis/youtube_v3/classes.rb', line 1070

def frame_rate
  @frame_rate
end

#ingestion_infoGoogle::Apis::YoutubeV3::IngestionInfo

Describes information necessary for ingesting an RTMP, HTTP, or SRT stream. Corresponds to the JSON property ingestionInfo



1075
1076
1077
# File 'lib/google/apis/youtube_v3/classes.rb', line 1075

def ingestion_info
  @ingestion_info
end

#ingestion_typeString

The method or protocol used to transmit the video stream. Corresponds to the JSON property ingestionType

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/youtube_v3/classes.rb', line 1080

def ingestion_type
  @ingestion_type
end

#resolutionString

The resolution of the inbound video data. Corresponds to the JSON property resolution

Returns:

  • (String)


1085
1086
1087
# File 'lib/google/apis/youtube_v3/classes.rb', line 1085

def resolution
  @resolution
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1092
1093
1094
1095
1096
1097
1098
# File 'lib/google/apis/youtube_v3/classes.rb', line 1092

def update!(**args)
  @format = args[:format] if args.key?(:format)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @ingestion_info = args[:ingestion_info] if args.key?(:ingestion_info)
  @ingestion_type = args[:ingestion_type] if args.key?(:ingestion_type)
  @resolution = args[:resolution] if args.key?(:resolution)
end