Class: Google::Apis::YoutubeV3::Channel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A channel resource contains information about a YouTube channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Channel

Returns a new instance of Channel.



1179
1180
1181
# File 'lib/google/apis/youtube_v3/classes.rb', line 1179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_detailsGoogle::Apis::YoutubeV3::ChannelAuditDetails

The auditDetails object encapsulates channel data that is relevant for YouTube Partners during the audit process. Corresponds to the JSON property auditDetails



1113
1114
1115
# File 'lib/google/apis/youtube_v3/classes.rb', line 1113

def audit_details
  @audit_details
end

#branding_settingsGoogle::Apis::YoutubeV3::ChannelBrandingSettings

Branding properties of a YouTube channel. Corresponds to the JSON property brandingSettings



1118
1119
1120
# File 'lib/google/apis/youtube_v3/classes.rb', line 1118

def branding_settings
  @branding_settings
end

#content_detailsGoogle::Apis::YoutubeV3::ChannelContentDetails

Details about the content of a channel. Corresponds to the JSON property contentDetails



1123
1124
1125
# File 'lib/google/apis/youtube_v3/classes.rb', line 1123

def content_details
  @content_details
end

#content_owner_detailsGoogle::Apis::YoutubeV3::ChannelContentOwnerDetails

The contentOwnerDetails object encapsulates channel data that is relevant for YouTube Partners linked with the channel. Corresponds to the JSON property contentOwnerDetails



1129
1130
1131
# File 'lib/google/apis/youtube_v3/classes.rb', line 1129

def content_owner_details
  @content_owner_details
end

#conversion_pingsGoogle::Apis::YoutubeV3::ChannelConversionPings

The conversionPings object encapsulates information about conversion pings that need to be respected by the channel. Corresponds to the JSON property conversionPings



1135
1136
1137
# File 'lib/google/apis/youtube_v3/classes.rb', line 1135

def conversion_pings
  @conversion_pings
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


1140
1141
1142
# File 'lib/google/apis/youtube_v3/classes.rb', line 1140

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the channel. Corresponds to the JSON property id

Returns:

  • (String)


1145
1146
1147
# File 'lib/google/apis/youtube_v3/classes.rb', line 1145

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# channel". Corresponds to the JSON property kind

Returns:

  • (String)


1151
1152
1153
# File 'lib/google/apis/youtube_v3/classes.rb', line 1151

def kind
  @kind
end

#localizationsHash<String,Google::Apis::YoutubeV3::ChannelLocalization>

Localizations for different languages Corresponds to the JSON property localizations



1156
1157
1158
# File 'lib/google/apis/youtube_v3/classes.rb', line 1156

def localizations
  @localizations
end

#snippetGoogle::Apis::YoutubeV3::ChannelSnippet

Basic details about a channel, including title, description and thumbnails. Corresponds to the JSON property snippet



1161
1162
1163
# File 'lib/google/apis/youtube_v3/classes.rb', line 1161

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::ChannelStatistics

Statistics about a channel: number of subscribers, number of videos in the channel, etc. Corresponds to the JSON property statistics



1167
1168
1169
# File 'lib/google/apis/youtube_v3/classes.rb', line 1167

def statistics
  @statistics
end

#statusGoogle::Apis::YoutubeV3::ChannelStatus

JSON template for the status part of a channel. Corresponds to the JSON property status



1172
1173
1174
# File 'lib/google/apis/youtube_v3/classes.rb', line 1172

def status
  @status
end

#topic_detailsGoogle::Apis::YoutubeV3::ChannelTopicDetails

Freebase topic information related to the channel. Corresponds to the JSON property topicDetails



1177
1178
1179
# File 'lib/google/apis/youtube_v3/classes.rb', line 1177

def topic_details
  @topic_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
# File 'lib/google/apis/youtube_v3/classes.rb', line 1184

def update!(**args)
  @audit_details = args[:audit_details] if args.key?(:audit_details)
  @branding_settings = args[:branding_settings] if args.key?(:branding_settings)
  @content_details = args[:content_details] if args.key?(:content_details)
  @content_owner_details = args[:content_owner_details] if args.key?(:content_owner_details)
  @conversion_pings = args[:conversion_pings] if args.key?(:conversion_pings)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @localizations = args[:localizations] if args.key?(:localizations)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
  @status = args[:status] if args.key?(:status)
  @topic_details = args[:topic_details] if args.key?(:topic_details)
end