Class: Google::Apis::YoutubeV3::ChannelContentDetails::RelatedPlaylists

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelatedPlaylists

Returns a new instance of RelatedPlaylists.



1362
1363
1364
# File 'lib/google/apis/youtube_v3/classes.rb', line 1362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#favoritesString

The ID of the playlist that contains the channel"s favorite videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property favorites

Returns:

  • (String)


1332
1333
1334
# File 'lib/google/apis/youtube_v3/classes.rb', line 1332

def favorites
  @favorites
end

#likesString

The ID of the playlist that contains the channel"s liked videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property likes

Returns:

  • (String)


1339
1340
1341
# File 'lib/google/apis/youtube_v3/classes.rb', line 1339

def likes
  @likes
end

#uploadsString

The ID of the playlist that contains the channel"s uploaded videos. Use the videos.insert method to upload new videos and the videos.delete method to delete previously uploaded videos. Corresponds to the JSON property uploads

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/youtube_v3/classes.rb', line 1346

def uploads
  @uploads
end

#watch_historyString

The ID of the playlist that contains the channel"s watch history. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchHistory

Returns:

  • (String)


1353
1354
1355
# File 'lib/google/apis/youtube_v3/classes.rb', line 1353

def watch_history
  @watch_history
end

#watch_laterString

The ID of the playlist that contains the channel"s watch later playlist. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchLater

Returns:

  • (String)


1360
1361
1362
# File 'lib/google/apis/youtube_v3/classes.rb', line 1360

def watch_later
  @watch_later
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1367
1368
1369
1370
1371
1372
1373
# File 'lib/google/apis/youtube_v3/classes.rb', line 1367

def update!(**args)
  @favorites = args[:favorites] if args.key?(:favorites)
  @likes = args[:likes] if args.key?(:likes)
  @uploads = args[:uploads] if args.key?(:uploads)
  @watch_history = args[:watch_history] if args.key?(:watch_history)
  @watch_later = args[:watch_later] if args.key?(:watch_later)
end