Class: Google::Apis::YoutubeV3::ChannelConversionPings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelConversionPings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
The conversionPings object encapsulates information about conversion pings that need to be respected by the channel.
Instance Attribute Summary collapse
-
#pings ⇒ Array<Google::Apis::YoutubeV3::ChannelConversionPing>
Pings that the app shall fire (authenticated by biscotti cookie).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelConversionPings
constructor
A new instance of ChannelConversionPings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelConversionPings
Returns a new instance of ChannelConversionPings.
1312 1313 1314 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1312 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pings ⇒ Array<Google::Apis::YoutubeV3::ChannelConversionPing>
Pings that the app shall fire (authenticated by biscotti cookie). Each ping
has a context, in which the app must fire the ping, and a url identifying the
ping.
Corresponds to the JSON property pings
1310 1311 1312 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1310 def pings @pings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1317 1318 1319 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1317 def update!(**args) @pings = args[:pings] if args.key?(:pings) end |