Class: Google::Apis::YoutubeV3::ChannelSection
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelSection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#content_details ⇒ Google::Apis::YoutubeV3::ChannelSectionContentDetails
Details about a channelsection, including playlists and channels.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the channel section.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::ChannelSectionLocalization>
Localizations for different languages Corresponds to the JSON property
localizations. -
#snippet ⇒ Google::Apis::YoutubeV3::ChannelSectionSnippet
Basic details about a channel section, including title, style and position.
-
#targeting ⇒ Google::Apis::YoutubeV3::ChannelSectionTargeting
ChannelSection targeting setting.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelSection
constructor
A new instance of ChannelSection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelSection
Returns a new instance of ChannelSection.
1497 1498 1499 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_details ⇒ Google::Apis::YoutubeV3::ChannelSectionContentDetails
Details about a channelsection, including playlists and channels.
Corresponds to the JSON property contentDetails
1464 1465 1466 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1464 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
1469 1470 1471 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1469 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the channel section.
Corresponds to the JSON property id
1474 1475 1476 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1474 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
channelSection".
Corresponds to the JSON property kind
1480 1481 1482 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1480 def kind @kind end |
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::ChannelSectionLocalization>
Localizations for different languages
Corresponds to the JSON property localizations
1485 1486 1487 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1485 def localizations @localizations end |
#snippet ⇒ Google::Apis::YoutubeV3::ChannelSectionSnippet
Basic details about a channel section, including title, style and position.
Corresponds to the JSON property snippet
1490 1491 1492 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1490 def snippet @snippet end |
#targeting ⇒ Google::Apis::YoutubeV3::ChannelSectionTargeting
ChannelSection targeting setting.
Corresponds to the JSON property targeting
1495 1496 1497 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1495 def targeting @targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1502 1503 1504 1505 1506 1507 1508 1509 1510 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1502 def update!(**args) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @localizations = args[:localizations] if args.key?(:localizations) @snippet = args[:snippet] if args.key?(:snippet) @targeting = args[:targeting] if args.key?(:targeting) end |