Class: Google::Apis::YoutubeV3::ChannelSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a channel, including title, description and thumbnails.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSnippet

Returns a new instance of ChannelSnippet.



1968
1969
1970
# File 'lib/google/apis/youtube_v3/classes.rb', line 1968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The country of the channel. Corresponds to the JSON property country

Returns:

  • (String)


1931
1932
1933
# File 'lib/google/apis/youtube_v3/classes.rb', line 1931

def country
  @country
end

#custom_urlString

The custom url of the channel. Corresponds to the JSON property customUrl

Returns:

  • (String)


1936
1937
1938
# File 'lib/google/apis/youtube_v3/classes.rb', line 1936

def custom_url
  @custom_url
end

#default_languageString

The language of the channel's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1941
1942
1943
# File 'lib/google/apis/youtube_v3/classes.rb', line 1941

def default_language
  @default_language
end

#descriptionString

The description of the channel. Corresponds to the JSON property description

Returns:

  • (String)


1946
1947
1948
# File 'lib/google/apis/youtube_v3/classes.rb', line 1946

def description
  @description
end

#localizedGoogle::Apis::YoutubeV3::ChannelLocalization

Channel localization setting Corresponds to the JSON property localized



1951
1952
1953
# File 'lib/google/apis/youtube_v3/classes.rb', line 1951

def localized
  @localized
end

#published_atDateTime

The date and time that the channel was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


1956
1957
1958
# File 'lib/google/apis/youtube_v3/classes.rb', line 1956

def published_at
  @published_at
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



1961
1962
1963
# File 'lib/google/apis/youtube_v3/classes.rb', line 1961

def thumbnails
  @thumbnails
end

#titleString

The channel's title. Corresponds to the JSON property title

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/youtube_v3/classes.rb', line 1966

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
# File 'lib/google/apis/youtube_v3/classes.rb', line 1973

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @custom_url = args[:custom_url] if args.key?(:custom_url)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end