Class: Google::Apis::YoutubeV3::ChannelStatistics
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Statistics about a channel: number of subscribers, number of videos in the channel, etc.
Instance Attribute Summary collapse
-
#comment_count ⇒ Fixnum
The number of comments for the channel.
-
#hidden_subscriber_count ⇒ Boolean
(also: #hidden_subscriber_count?)
Whether or not the number of subscribers is shown for this user.
-
#subscriber_count ⇒ Fixnum
The number of subscribers that the channel has.
-
#video_count ⇒ Fixnum
The number of videos uploaded to the channel.
-
#view_count ⇒ Fixnum
The number of times the channel has been viewed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelStatistics
constructor
A new instance of ChannelStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelStatistics
Returns a new instance of ChannelStatistics.
2016 2017 2018 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment_count ⇒ Fixnum
The number of comments for the channel.
Corresponds to the JSON property commentCount
1993 1994 1995 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1993 def comment_count @comment_count end |
#hidden_subscriber_count ⇒ Boolean Also known as:
Whether or not the number of subscribers is shown for this user.
Corresponds to the JSON property hiddenSubscriberCount
1998 1999 2000 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1998 def hidden_subscriber_count @hidden_subscriber_count end |
#subscriber_count ⇒ Fixnum
The number of subscribers that the channel has.
Corresponds to the JSON property subscriberCount
2004 2005 2006 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2004 def subscriber_count @subscriber_count end |
#video_count ⇒ Fixnum
The number of videos uploaded to the channel.
Corresponds to the JSON property videoCount
2009 2010 2011 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2009 def video_count @video_count end |
#view_count ⇒ Fixnum
The number of times the channel has been viewed.
Corresponds to the JSON property viewCount
2014 2015 2016 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2014 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2021 def update!(**args) @comment_count = args[:comment_count] if args.key?(:comment_count) @hidden_subscriber_count = args[:hidden_subscriber_count] if args.key?(:hidden_subscriber_count) @subscriber_count = args[:subscriber_count] if args.key?(:subscriber_count) @video_count = args[:video_count] if args.key?(:video_count) @view_count = args[:view_count] if args.key?(:view_count) end |