Class: Google::Apis::YoutubeV3::ChannelToAffiliateProgramLinkDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information specific to a creator in an affiliate program linked to a YouTube channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelToAffiliateProgramLinkDetails

Returns a new instance of ChannelToAffiliateProgramLinkDetails.



2107
2108
2109
# File 'lib/google/apis/youtube_v3/classes.rb', line 2107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_idFixnum

Required. Google Merchant Center ID of the partner. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


2090
2091
2092
# File 'lib/google/apis/youtube_v3/classes.rb', line 2090

def merchant_id
  @merchant_id
end

#program_statusString

Required. Affiliate program status. Corresponds to the JSON property programStatus

Returns:

  • (String)


2095
2096
2097
# File 'lib/google/apis/youtube_v3/classes.rb', line 2095

def program_status
  @program_status
end

#status_update_reasonString

Optional. Reason for the last update of the affiliate program status. Corresponds to the JSON property statusUpdateReason

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/youtube_v3/classes.rb', line 2100

def status_update_reason
  @status_update_reason
end

#status_update_timeString

Optional. Timestamp when the affiliate program status was last updated. Corresponds to the JSON property statusUpdateTime

Returns:

  • (String)


2105
2106
2107
# File 'lib/google/apis/youtube_v3/classes.rb', line 2105

def status_update_time
  @status_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2112
2113
2114
2115
2116
2117
# File 'lib/google/apis/youtube_v3/classes.rb', line 2112

def update!(**args)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @program_status = args[:program_status] if args.key?(:program_status)
  @status_update_reason = args[:status_update_reason] if args.key?(:status_update_reason)
  @status_update_time = args[:status_update_time] if args.key?(:status_update_time)
end