Class: Google::Apis::YoutubeV3::Comment
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Comment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A comment represents a single YouTube comment.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the comment.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::CommentSnippet
Basic details about a comment, such as its author and text.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Comment
constructor
A new instance of Comment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Comment
Returns a new instance of Comment.
2150 2151 2152 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2132 2133 2134 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2132 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the comment.
Corresponds to the JSON property id
2137 2138 2139 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2137 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
comment".
Corresponds to the JSON property kind
2143 2144 2145 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2143 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::CommentSnippet
Basic details about a comment, such as its author and text.
Corresponds to the JSON property snippet
2148 2149 2150 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2148 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2155 2156 2157 2158 2159 2160 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2155 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |