Class: Google::Apis::YoutubeV3::CommentThreadSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::CommentThreadSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a comment thread.
Instance Attribute Summary collapse
-
#can_reply ⇒ Boolean
(also: #can_reply?)
Whether the current viewer of the thread can reply to it.
-
#channel_id ⇒ String
The YouTube channel the comments in the thread refer to or the channel with the video the comments refer to.
-
#is_public ⇒ Boolean
(also: #is_public?)
Whether the thread (and therefore all its comments) is visible to all YouTube users.
-
#post_id ⇒ String
The ID of the post the comments refer to, if any.
-
#top_level_comment ⇒ Google::Apis::YoutubeV3::Comment
A comment represents a single YouTube comment.
-
#total_reply_count ⇒ Fixnum
The total number of replies (not including the top level comment).
-
#video_id ⇒ String
The ID of the video the comments refer to, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommentThreadSnippet
constructor
A new instance of CommentThreadSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommentThreadSnippet
Returns a new instance of CommentThreadSnippet.
2649 2650 2651 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reply ⇒ Boolean Also known as: can_reply?
Whether the current viewer of the thread can reply to it. This is viewer
specific - other viewers may see a different value for this field.
Corresponds to the JSON property canReply
2612 2613 2614 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2612 def can_reply @can_reply end |
#channel_id ⇒ String
The YouTube channel the comments in the thread refer to or the channel with
the video the comments refer to. If neither video_id nor post_id is set the
comments refer to the channel itself.
Corresponds to the JSON property channelId
2620 2621 2622 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2620 def channel_id @channel_id end |
#is_public ⇒ Boolean Also known as: is_public?
Whether the thread (and therefore all its comments) is visible to all YouTube
users.
Corresponds to the JSON property isPublic
2626 2627 2628 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2626 def is_public @is_public end |
#post_id ⇒ String
The ID of the post the comments refer to, if any.
Corresponds to the JSON property postId
2632 2633 2634 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2632 def post_id @post_id end |
#top_level_comment ⇒ Google::Apis::YoutubeV3::Comment
A comment represents a single YouTube comment.
Corresponds to the JSON property topLevelComment
2637 2638 2639 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2637 def top_level_comment @top_level_comment end |
#total_reply_count ⇒ Fixnum
The total number of replies (not including the top level comment).
Corresponds to the JSON property totalReplyCount
2642 2643 2644 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2642 def total_reply_count @total_reply_count end |
#video_id ⇒ String
The ID of the video the comments refer to, if any.
Corresponds to the JSON property videoId
2647 2648 2649 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2647 def video_id @video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2654 2655 2656 2657 2658 2659 2660 2661 2662 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2654 def update!(**args) @can_reply = args[:can_reply] if args.key?(:can_reply) @channel_id = args[:channel_id] if args.key?(:channel_id) @is_public = args[:is_public] if args.key?(:is_public) @post_id = args[:post_id] if args.key?(:post_id) @top_level_comment = args[:top_level_comment] if args.key?(:top_level_comment) @total_reply_count = args[:total_reply_count] if args.key?(:total_reply_count) @video_id = args[:video_id] if args.key?(:video_id) end |