Class: Google::Apis::YoutubeV3::Cuepoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Note that there may be a 5-second end-point resolution issue. For instance, if a cuepoint comes in for 22:03:27, we may stuff the cuepoint into 22:03:25 or 22:03:30, depending. This is an artifact of HLS.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cuepoint

Returns a new instance of Cuepoint.



3174
3175
3176
# File 'lib/google/apis/youtube_v3/classes.rb', line 3174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cue_typeString

Corresponds to the JSON property cueType

Returns:

  • (String)


3145
3146
3147
# File 'lib/google/apis/youtube_v3/classes.rb', line 3145

def cue_type
  @cue_type
end

#duration_secsFixnum

The duration of this cuepoint. Corresponds to the JSON property durationSecs

Returns:

  • (Fixnum)


3150
3151
3152
# File 'lib/google/apis/youtube_v3/classes.rb', line 3150

def duration_secs
  @duration_secs
end

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


3155
3156
3157
# File 'lib/google/apis/youtube_v3/classes.rb', line 3155

def etag
  @etag
end

#idString

The identifier for cuepoint resource. Corresponds to the JSON property id

Returns:

  • (String)


3160
3161
3162
# File 'lib/google/apis/youtube_v3/classes.rb', line 3160

def id
  @id
end

#insertion_offset_time_msFixnum

The time when the cuepoint should be inserted by offset to the broadcast actual start time. Corresponds to the JSON property insertionOffsetTimeMs

Returns:

  • (Fixnum)


3166
3167
3168
# File 'lib/google/apis/youtube_v3/classes.rb', line 3166

def insertion_offset_time_ms
  @insertion_offset_time_ms
end

#walltime_msFixnum

The wall clock time at which the cuepoint should be inserted. Only one of insertion_offset_time_ms and walltime_ms may be set at a time. Corresponds to the JSON property walltimeMs

Returns:

  • (Fixnum)


3172
3173
3174
# File 'lib/google/apis/youtube_v3/classes.rb', line 3172

def walltime_ms
  @walltime_ms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3179
3180
3181
3182
3183
3184
3185
3186
# File 'lib/google/apis/youtube_v3/classes.rb', line 3179

def update!(**args)
  @cue_type = args[:cue_type] if args.key?(:cue_type)
  @duration_secs = args[:duration_secs] if args.key?(:duration_secs)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @insertion_offset_time_ms = args[:insertion_offset_time_ms] if args.key?(:insertion_offset_time_ms)
  @walltime_ms = args[:walltime_ms] if args.key?(:walltime_ms)
end