Class: Google::Apis::YoutubeV3::GetVideoRatingResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::GetVideoRatingResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::VideoRating>
A list of ratings that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetVideoRatingResponse
constructor
A new instance of GetVideoRatingResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetVideoRatingResponse
Returns a new instance of GetVideoRatingResponse.
8558 8559 8560 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
8535 8536 8537 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8535 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
8540 8541 8542 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8540 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::VideoRating>
A list of ratings that match the request criteria.
Corresponds to the JSON property items
8545 8546 8547 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8545 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoGetRatingResponse".
Corresponds to the JSON property kind
8551 8552 8553 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8551 def kind @kind end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
8556 8557 8558 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8556 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8563 8564 8565 8566 8567 8568 8569 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8563 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |