Class: Google::Apis::YoutubeV3::InvideoBranding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes an invideo branding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InvideoBranding

Returns a new instance of InvideoBranding.



3777
3778
3779
# File 'lib/google/apis/youtube_v3/classes.rb', line 3777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_bytesString

The bytes the uploaded image. Only used in api to youtube communication. Corresponds to the JSON property imageBytes NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3753
3754
3755
# File 'lib/google/apis/youtube_v3/classes.rb', line 3753

def image_bytes
  @image_bytes
end

#image_urlString

The url of the uploaded image. Only used in apiary to api communication. Corresponds to the JSON property imageUrl

Returns:

  • (String)


3758
3759
3760
# File 'lib/google/apis/youtube_v3/classes.rb', line 3758

def image_url
  @image_url
end

#positionGoogle::Apis::YoutubeV3::InvideoPosition

Describes the spatial position of a visual widget inside a video. It is a union of various position types, out of which only will be set one. Corresponds to the JSON property position



3764
3765
3766
# File 'lib/google/apis/youtube_v3/classes.rb', line 3764

def position
  @position
end

#target_channel_idString

The channel to which this branding links. If not present it defaults to the current channel. Corresponds to the JSON property targetChannelId

Returns:

  • (String)


3770
3771
3772
# File 'lib/google/apis/youtube_v3/classes.rb', line 3770

def target_channel_id
  @target_channel_id
end

#timingGoogle::Apis::YoutubeV3::InvideoTiming

Describes a temporal position of a visual widget inside a video. Corresponds to the JSON property timing



3775
3776
3777
# File 'lib/google/apis/youtube_v3/classes.rb', line 3775

def timing
  @timing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3782
3783
3784
3785
3786
3787
3788
# File 'lib/google/apis/youtube_v3/classes.rb', line 3782

def update!(**args)
  @image_bytes = args[:image_bytes] if args.key?(:image_bytes)
  @image_url = args[:image_url] if args.key?(:image_url)
  @position = args[:position] if args.key?(:position)
  @target_channel_id = args[:target_channel_id] if args.key?(:target_channel_id)
  @timing = args[:timing] if args.key?(:timing)
end