Class: Google::Apis::YoutubeV3::InvideoPosition
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::InvideoPosition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Describes the spatial position of a visual widget inside a video. It is a union of various position types, out of which only will be set one.
Instance Attribute Summary collapse
-
#corner_position ⇒ String
Describes in which corner of the video the visual widget will appear.
-
#type ⇒ String
Defines the position type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InvideoPosition
constructor
A new instance of InvideoPosition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InvideoPosition
Returns a new instance of InvideoPosition.
3806 3807 3808 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corner_position ⇒ String
Describes in which corner of the video the visual widget will appear.
Corresponds to the JSON property cornerPosition
3799 3800 3801 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3799 def corner_position @corner_position end |
#type ⇒ String
Defines the position type.
Corresponds to the JSON property type
3804 3805 3806 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3804 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3811 3812 3813 3814 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3811 def update!(**args) @corner_position = args[:corner_position] if args.key?(:corner_position) @type = args[:type] if args.key?(:type) end |