Class: Google::Apis::YoutubeV3::InvideoTiming

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes a temporal position of a visual widget inside a video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InvideoTiming

Returns a new instance of InvideoTiming.



3846
3847
3848
# File 'lib/google/apis/youtube_v3/classes.rb', line 3846

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#duration_msFixnum

Defines the duration in milliseconds for which the promotion should be displayed. If missing, the client should use the default. Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


3829
3830
3831
# File 'lib/google/apis/youtube_v3/classes.rb', line 3829

def duration_ms
  @duration_ms
end

#offset_msFixnum

Defines the time at which the promotion will appear. Depending on the value of type the value of the offsetMs field will represent a time offset from the start or from the end of the video, expressed in milliseconds. Corresponds to the JSON property offsetMs

Returns:

  • (Fixnum)


3836
3837
3838
# File 'lib/google/apis/youtube_v3/classes.rb', line 3836

def offset_ms
  @offset_ms
end

#typeString

Describes a timing type. If the value is offsetFromStart, then the offsetMs field represents an offset from the start of the video. If the value is offsetFromEnd, then the offsetMs field represents an offset from the end of the video. Corresponds to the JSON property type

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/youtube_v3/classes.rb', line 3844

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3851
3852
3853
3854
3855
# File 'lib/google/apis/youtube_v3/classes.rb', line 3851

def update!(**args)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @offset_ms = args[:offset_ms] if args.key?(:offset_ms)
  @type = args[:type] if args.key?(:type)
end