Class: Google::Apis::YoutubeV3::ListActivitiesResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListActivitiesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Activity>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListActivitiesResponse
constructor
A new instance of ListActivitiesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListActivitiesResponse
Returns a new instance of ListActivitiesResponse.
618 619 620 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
572 573 574 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 572 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
577 578 579 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 577 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Activity>
Corresponds to the JSON property items
582 583 584 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 582 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
activityListResponse".
Corresponds to the JSON property kind
588 589 590 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 588 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
594 595 596 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 594 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
600 601 602 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 600 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
606 607 608 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 606 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
611 612 613 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 611 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
616 617 618 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 616 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
623 624 625 626 627 628 629 630 631 632 633 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 623 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |