Class: Google::Apis::YoutubeV3::ListCaptionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCaptionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Caption>
A list of captions that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCaptionsResponse
constructor
A new instance of ListCaptionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCaptionsResponse
Returns a new instance of ListCaptionsResponse.
938 939 940 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
915 916 917 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 915 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
920 921 922 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 920 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Caption>
A list of captions that match the request criteria.
Corresponds to the JSON property items
925 926 927 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 925 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
captionListResponse".
Corresponds to the JSON property kind
931 932 933 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 931 def kind @kind end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
936 937 938 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 936 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
943 944 945 946 947 948 949 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 943 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |