Class: Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCommentThreadsResponse
constructor
A new instance of ListCommentThreadsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCommentThreadsResponse
Returns a new instance of ListCommentThreadsResponse.
2566 2567 2568 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2526 2527 2528 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2526 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
2531 2532 2533 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2531 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
Corresponds to the JSON property items
2536 2537 2538 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2536 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
commentThreadListResponse".
Corresponds to the JSON property kind
2542 2543 2544 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2542 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
2548 2549 2550 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2548 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
2554 2555 2556 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2554 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
2559 2560 2561 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2559 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
2564 2565 2566 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2564 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2571 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |