Class: Google::Apis::YoutubeV3::ListCommentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCommentsResponse

Returns a new instance of ListCommentsResponse.



2317
2318
2319
# File 'lib/google/apis/youtube_v3/classes.rb', line 2317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


2277
2278
2279
# File 'lib/google/apis/youtube_v3/classes.rb', line 2277

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


2282
2283
2284
# File 'lib/google/apis/youtube_v3/classes.rb', line 2282

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Comment>

A list of comments that match the request criteria. Corresponds to the JSON property items



2287
2288
2289
# File 'lib/google/apis/youtube_v3/classes.rb', line 2287

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# commentListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


2293
2294
2295
# File 'lib/google/apis/youtube_v3/classes.rb', line 2293

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2299
2300
2301
# File 'lib/google/apis/youtube_v3/classes.rb', line 2299

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



2305
2306
2307
# File 'lib/google/apis/youtube_v3/classes.rb', line 2305

def page_info
  @page_info
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



2310
2311
2312
# File 'lib/google/apis/youtube_v3/classes.rb', line 2310

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


2315
2316
2317
# File 'lib/google/apis/youtube_v3/classes.rb', line 2315

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/google/apis/youtube_v3/classes.rb', line 2322

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end