Class: Google::Apis::YoutubeV3::ListLiveBroadcastsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListLiveBroadcastsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveBroadcast>
A list of broadcasts that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLiveBroadcastsResponse
constructor
A new instance of ListLiveBroadcastsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLiveBroadcastsResponse
Returns a new instance of ListLiveBroadcastsResponse.
4034 4035 4036 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
3988 3989 3990 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3988 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
3993 3994 3995 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3993 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveBroadcast>
A list of broadcasts that match the request criteria.
Corresponds to the JSON property items
3998 3999 4000 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3998 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveBroadcastListResponse".
Corresponds to the JSON property kind
4004 4005 4006 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4004 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
4010 4011 4012 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4010 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4016 4017 4018 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4016 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
4022 4023 4024 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4022 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4027 4028 4029 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4027 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4032 4033 4034 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4032 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 4049 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4039 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |