Class: Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLiveStreamsResponse
constructor
A new instance of ListLiveStreamsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLiveStreamsResponse
Returns a new instance of ListLiveStreamsResponse.
5626 5627 5628 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5580 5581 5582 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5580 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5585 5586 5587 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5585 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
Corresponds to the JSON property items
5590 5591 5592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5590 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveStreamListResponse".
Corresponds to the JSON property kind
5596 5597 5598 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5596 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5602 5603 5604 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5602 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5608 5609 5610 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5608 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
5614 5615 5616 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5614 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5619 5620 5621 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5619 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5624 5625 5626 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5624 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5631 5632 5633 5634 5635 5636 5637 5638 5639 5640 5641 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5631 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |