Class: Google::Apis::YoutubeV3::ListSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Subscription>
A list of subscriptions that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSubscriptionResponse
constructor
A new instance of ListSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSubscriptionResponse
Returns a new instance of ListSubscriptionResponse.
7337 7338 7339 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7291 7292 7293 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7291 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7296 7297 7298 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7296 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Subscription>
A list of subscriptions that match the request criteria.
Corresponds to the JSON property items
7301 7302 7303 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7301 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
subscriptionListResponse".
Corresponds to the JSON property kind
7307 7308 7309 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7307 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7313 7314 7315 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7313 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7319 7320 7321 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7319 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
7325 7326 7327 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7325 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7330 7331 7332 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7330 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
7335 7336 7337 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7335 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7342 7343 7344 7345 7346 7347 7348 7349 7350 7351 7352 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7342 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |