Class: Google::Apis::YoutubeV3::ListVideoAbuseReportReasonResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListVideoAbuseReportReasonResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportReason>
A list of valid abuse reasons that are used with
video.ReportAbuse. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#visitor_id ⇒ String
The
visitorIdidentifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVideoAbuseReportReasonResponse
constructor
A new instance of ListVideoAbuseReportReasonResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVideoAbuseReportReasonResponse
Returns a new instance of ListVideoAbuseReportReasonResponse.
8238 8239 8240 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
8215 8216 8217 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8215 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
8220 8221 8222 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8220 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportReason>
A list of valid abuse reasons that are used with video.ReportAbuse.
Corresponds to the JSON property items
8225 8226 8227 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8225 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoAbuseReportReasonListResponse".
Corresponds to the JSON property kind
8231 8232 8233 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8231 def kind @kind end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
8236 8237 8238 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8236 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8243 8244 8245 8246 8247 8248 8249 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8243 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |