Class: Google::Apis::YoutubeV3::LiveBroadcastMonetizationDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastMonetizationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Monetization settings of a broadcast.
Instance Attribute Summary collapse
-
#cuepoint_schedule ⇒ Google::Apis::YoutubeV3::CuepointSchedule
Schedule to insert cuepoints into a broadcast by ads automator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastMonetizationDetails
constructor
A new instance of LiveBroadcastMonetizationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastMonetizationDetails
Returns a new instance of LiveBroadcastMonetizationDetails.
4061 4062 4063 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cuepoint_schedule ⇒ Google::Apis::YoutubeV3::CuepointSchedule
Schedule to insert cuepoints into a broadcast by ads automator.
Corresponds to the JSON property cuepointSchedule
4059 4060 4061 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4059 def cuepoint_schedule @cuepoint_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4066 4067 4068 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4066 def update!(**args) @cuepoint_schedule = args[:cuepoint_schedule] if args.key?(:cuepoint_schedule) end |