Class: Google::Apis::YoutubeV3::LiveBroadcastSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic broadcast information.
Instance Attribute Summary collapse
-
#actual_end_time ⇒ DateTime
The date and time that the broadcast actually ended.
-
#actual_start_time ⇒ DateTime
The date and time that the broadcast actually started.
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast.
-
#description ⇒ String
The broadcast's description.
-
#is_default_broadcast ⇒ Boolean
(also: #is_default_broadcast?)
Indicates whether this broadcast is the default broadcast.
-
#live_chat_id ⇒ String
The id of the live chat for this broadcast.
-
#published_at ⇒ DateTime
The date and time that the broadcast was added to YouTube's live broadcast schedule.
-
#scheduled_end_time ⇒ DateTime
The date and time that the broadcast is scheduled to end.
-
#scheduled_start_time ⇒ DateTime
The date and time that the broadcast is scheduled to start.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The broadcast's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastSnippet
constructor
A new instance of LiveBroadcastSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastSnippet
Returns a new instance of LiveBroadcastSnippet.
4278 4279 4280 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4278 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_end_time ⇒ DateTime
The date and time that the broadcast actually ended. This information is only
available once the broadcast's state is complete.
Corresponds to the JSON property actualEndTime
4218 4219 4220 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4218 def actual_end_time @actual_end_time end |
#actual_start_time ⇒ DateTime
The date and time that the broadcast actually started. This information is
only available once the broadcast's state is live.
Corresponds to the JSON property actualStartTime
4224 4225 4226 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4224 def actual_start_time @actual_start_time end |
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is publishing
the broadcast.
Corresponds to the JSON property channelId
4230 4231 4232 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4230 def channel_id @channel_id end |
#description ⇒ String
The broadcast's description. As with the title, you can set this field by
modifying the broadcast resource or by setting the description field of the
corresponding video resource.
Corresponds to the JSON property description
4237 4238 4239 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4237 def description @description end |
#is_default_broadcast ⇒ Boolean Also known as: is_default_broadcast?
Indicates whether this broadcast is the default broadcast. Internal only.
Corresponds to the JSON property isDefaultBroadcast
4242 4243 4244 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4242 def is_default_broadcast @is_default_broadcast end |
#live_chat_id ⇒ String
The id of the live chat for this broadcast.
Corresponds to the JSON property liveChatId
4248 4249 4250 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4248 def live_chat_id @live_chat_id end |
#published_at ⇒ DateTime
The date and time that the broadcast was added to YouTube's live broadcast
schedule.
Corresponds to the JSON property publishedAt
4254 4255 4256 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4254 def published_at @published_at end |
#scheduled_end_time ⇒ DateTime
The date and time that the broadcast is scheduled to end.
Corresponds to the JSON property scheduledEndTime
4259 4260 4261 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4259 def scheduled_end_time @scheduled_end_time end |
#scheduled_start_time ⇒ DateTime
The date and time that the broadcast is scheduled to start.
Corresponds to the JSON property scheduledStartTime
4264 4265 4266 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4264 def scheduled_start_time @scheduled_start_time end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
4269 4270 4271 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4269 def thumbnails @thumbnails end |
#title ⇒ String
The broadcast's title. Note that the broadcast represents exactly one YouTube
video. You can set this field by modifying the broadcast resource or by
setting the title field of the corresponding video resource.
Corresponds to the JSON property title
4276 4277 4278 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4276 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4283 def update!(**args) @actual_end_time = args[:actual_end_time] if args.key?(:actual_end_time) @actual_start_time = args[:actual_start_time] if args.key?(:actual_start_time) @channel_id = args[:channel_id] if args.key?(:channel_id) @description = args[:description] if args.key?(:description) @is_default_broadcast = args[:is_default_broadcast] if args.key?(:is_default_broadcast) @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id) @published_at = args[:published_at] if args.key?(:published_at) @scheduled_end_time = args[:scheduled_end_time] if args.key?(:scheduled_end_time) @scheduled_start_time = args[:scheduled_start_time] if args.key?(:scheduled_start_time) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |