Class: Google::Apis::YoutubeV3::LiveBroadcastStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about the live broadcast. These represent a snapshot of the values at the time of the request. Statistics are only returned for live broadcasts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveBroadcastStatistics

Returns a new instance of LiveBroadcastStatistics.



4317
4318
4319
# File 'lib/google/apis/youtube_v3/classes.rb', line 4317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrent_viewersFixnum

The number of viewers currently watching the broadcast. The property and its value will be present if the broadcast has current viewers and the broadcast owner has not hidden the viewcount for the video. Note that YouTube stops tracking the number of concurrent viewers for a broadcast when the broadcast ends. So, this property would not identify the number of viewers watching an archived video of a live broadcast that already ended. Corresponds to the JSON property concurrentViewers

Returns:

  • (Fixnum)


4315
4316
4317
# File 'lib/google/apis/youtube_v3/classes.rb', line 4315

def concurrent_viewers
  @concurrent_viewers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4322
4323
4324
# File 'lib/google/apis/youtube_v3/classes.rb', line 4322

def update!(**args)
  @concurrent_viewers = args[:concurrent_viewers] if args.key?(:concurrent_viewers)
end