Class: Google::Apis::YoutubeV3::LiveChatFanFundingEventDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatFanFundingEventDetails

Returns a new instance of LiveChatFanFundingEventDetails.



4341
4342
4343
# File 'lib/google/apis/youtube_v3/classes.rb', line 4341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_display_stringString

A rendered string that displays the fund amount and currency to the user. Corresponds to the JSON property amountDisplayString

Returns:

  • (String)


4324
4325
4326
# File 'lib/google/apis/youtube_v3/classes.rb', line 4324

def amount_display_string
  @amount_display_string
end

#amount_microsFixnum

The amount of the fund. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


4329
4330
4331
# File 'lib/google/apis/youtube_v3/classes.rb', line 4329

def amount_micros
  @amount_micros
end

#currencyString

The currency in which the fund was made. Corresponds to the JSON property currency

Returns:

  • (String)


4334
4335
4336
# File 'lib/google/apis/youtube_v3/classes.rb', line 4334

def currency
  @currency
end

#user_commentString

The comment added by the user to this fan funding event. Corresponds to the JSON property userComment

Returns:

  • (String)


4339
4340
4341
# File 'lib/google/apis/youtube_v3/classes.rb', line 4339

def user_comment
  @user_comment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4346
4347
4348
4349
4350
4351
# File 'lib/google/apis/youtube_v3/classes.rb', line 4346

def update!(**args)
  @amount_display_string = args[:amount_display_string] if args.key?(:amount_display_string)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @currency = args[:currency] if args.key?(:currency)
  @user_comment = args[:user_comment] if args.key?(:user_comment)
end