Class: Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMemberMilestoneChatDetails

Returns a new instance of LiveChatMemberMilestoneChatDetails.



4620
4621
4622
# File 'lib/google/apis/youtube_v3/classes.rb', line 4620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#member_level_nameString

The name of the Level at which the viever is a member. The Level names are defined by the YouTube channel offering the Membership. In some situations this field isn't filled. Corresponds to the JSON property memberLevelName

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/youtube_v3/classes.rb', line 4605

def member_level_name
  @member_level_name
end

#member_monthFixnum

The total amount of months (rounded up) the viewer has been a member that granted them this Member Milestone Chat. This is the same number of months as is being displayed to YouTube users. Corresponds to the JSON property memberMonth

Returns:

  • (Fixnum)


4612
4613
4614
# File 'lib/google/apis/youtube_v3/classes.rb', line 4612

def member_month
  @member_month
end

#user_commentString

The comment added by the member to this Member Milestone Chat. This field is empty for messages without a comment from the member. Corresponds to the JSON property userComment

Returns:

  • (String)


4618
4619
4620
# File 'lib/google/apis/youtube_v3/classes.rb', line 4618

def user_comment
  @user_comment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4625
4626
4627
4628
4629
# File 'lib/google/apis/youtube_v3/classes.rb', line 4625

def update!(**args)
  @member_level_name = args[:member_level_name] if args.key?(:member_level_name)
  @member_month = args[:member_month] if args.key?(:member_month)
  @user_comment = args[:user_comment] if args.key?(:user_comment)
end