Class: Google::Apis::YoutubeV3::LiveChatMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A liveChatMessage resource represents a chat message in a YouTube Live Chat.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMessage

Returns a new instance of LiveChatMessage.



4696
4697
4698
# File 'lib/google/apis/youtube_v3/classes.rb', line 4696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_detailsGoogle::Apis::YoutubeV3::LiveChatMessageAuthorDetails

The authorDetails object contains basic details about the user that posted this message. Corresponds to the JSON property authorDetails



4673
4674
4675
# File 'lib/google/apis/youtube_v3/classes.rb', line 4673

def author_details
  @author_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


4678
4679
4680
# File 'lib/google/apis/youtube_v3/classes.rb', line 4678

def etag
  @etag
end

#idString

The ID that YouTube assigns to uniquely identify the message. Corresponds to the JSON property id

Returns:

  • (String)


4683
4684
4685
# File 'lib/google/apis/youtube_v3/classes.rb', line 4683

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# liveChatMessage". Corresponds to the JSON property kind

Returns:

  • (String)


4689
4690
4691
# File 'lib/google/apis/youtube_v3/classes.rb', line 4689

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::LiveChatMessageSnippet

Next ID: 35 Corresponds to the JSON property snippet



4694
4695
4696
# File 'lib/google/apis/youtube_v3/classes.rb', line 4694

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4701
4702
4703
4704
4705
4706
4707
# File 'lib/google/apis/youtube_v3/classes.rb', line 4701

def update!(**args)
  @author_details = args[:author_details] if args.key?(:author_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end