Class: Google::Apis::YoutubeV3::LiveChatMessageAuthorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMessageAuthorDetails

Returns a new instance of LiveChatMessageAuthorDetails.



4752
4753
4754
# File 'lib/google/apis/youtube_v3/classes.rb', line 4752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The YouTube channel ID. Corresponds to the JSON property channelId

Returns:

  • (String)


4711
4712
4713
# File 'lib/google/apis/youtube_v3/classes.rb', line 4711

def channel_id
  @channel_id
end

#channel_urlString

The channel's URL. Corresponds to the JSON property channelUrl

Returns:

  • (String)


4716
4717
4718
# File 'lib/google/apis/youtube_v3/classes.rb', line 4716

def channel_url
  @channel_url
end

#display_nameString

The channel's display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4721
4722
4723
# File 'lib/google/apis/youtube_v3/classes.rb', line 4721

def display_name
  @display_name
end

#is_chat_moderatorBoolean Also known as: is_chat_moderator?

Whether the author is a moderator of the live chat. Corresponds to the JSON property isChatModerator

Returns:

  • (Boolean)


4726
4727
4728
# File 'lib/google/apis/youtube_v3/classes.rb', line 4726

def is_chat_moderator
  @is_chat_moderator
end

#is_chat_ownerBoolean Also known as: is_chat_owner?

Whether the author is the owner of the live chat. Corresponds to the JSON property isChatOwner

Returns:

  • (Boolean)


4732
4733
4734
# File 'lib/google/apis/youtube_v3/classes.rb', line 4732

def is_chat_owner
  @is_chat_owner
end

#is_chat_sponsorBoolean Also known as: is_chat_sponsor?

Whether the author is a sponsor of the live chat. Corresponds to the JSON property isChatSponsor

Returns:

  • (Boolean)


4738
4739
4740
# File 'lib/google/apis/youtube_v3/classes.rb', line 4738

def is_chat_sponsor
  @is_chat_sponsor
end

#is_verifiedBoolean Also known as: is_verified?

Whether the author's identity has been verified by YouTube. Corresponds to the JSON property isVerified

Returns:

  • (Boolean)


4744
4745
4746
# File 'lib/google/apis/youtube_v3/classes.rb', line 4744

def is_verified
  @is_verified
end

#profile_image_urlString

The channels's avatar URL. Corresponds to the JSON property profileImageUrl

Returns:

  • (String)


4750
4751
4752
# File 'lib/google/apis/youtube_v3/classes.rb', line 4750

def profile_image_url
  @profile_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4757
4758
4759
4760
4761
4762
4763
4764
4765
4766
# File 'lib/google/apis/youtube_v3/classes.rb', line 4757

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_url = args[:channel_url] if args.key?(:channel_url)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_chat_moderator = args[:is_chat_moderator] if args.key?(:is_chat_moderator)
  @is_chat_owner = args[:is_chat_owner] if args.key?(:is_chat_owner)
  @is_chat_sponsor = args[:is_chat_sponsor] if args.key?(:is_chat_sponsor)
  @is_verified = args[:is_verified] if args.key?(:is_verified)
  @profile_image_url = args[:profile_image_url] if args.key?(:profile_image_url)
end