Class: Google::Apis::YoutubeV3::LiveChatMessageListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMessageListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#active_poll_item ⇒ Google::Apis::YoutubeV3::LiveChatMessage
A liveChatMessage resource represents a chat message in a YouTube Live Chat.
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatMessage>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Corresponds to the JSON property
nextPageToken. -
#offline_at ⇒ DateTime
The date and time when the underlying stream went offline.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#polling_interval_millis ⇒ Fixnum
The amount of time the client should wait before polling again.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMessageListResponse
constructor
A new instance of LiveChatMessageListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMessageListResponse
Returns a new instance of LiveChatMessageListResponse.
4849 4850 4851 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_poll_item ⇒ Google::Apis::YoutubeV3::LiveChatMessage
A liveChatMessage resource represents a chat message in a YouTube Live Chat.
Corresponds to the JSON property activePollItem
4795 4796 4797 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4795 def active_poll_item @active_poll_item end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4800 4801 4802 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4800 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
4805 4806 4807 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4805 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatMessage>
Corresponds to the JSON property items
4810 4811 4812 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4810 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatMessageListResponse".
Corresponds to the JSON property kind
4816 4817 4818 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4816 def kind @kind end |
#next_page_token ⇒ String
Corresponds to the JSON property nextPageToken
4821 4822 4823 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4821 def next_page_token @next_page_token end |
#offline_at ⇒ DateTime
The date and time when the underlying stream went offline.
Corresponds to the JSON property offlineAt
4826 4827 4828 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4826 def offline_at @offline_at end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4832 4833 4834 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4832 def page_info @page_info end |
#polling_interval_millis ⇒ Fixnum
The amount of time the client should wait before polling again.
Corresponds to the JSON property pollingIntervalMillis
4837 4838 4839 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4837 def polling_interval_millis @polling_interval_millis end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4842 4843 4844 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4842 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4847 4848 4849 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4847 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4854 4855 4856 4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4854 def update!(**args) @active_poll_item = args[:active_poll_item] if args.key?(:active_poll_item) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @offline_at = args[:offline_at] if args.key?(:offline_at) @page_info = args[:page_info] if args.key?(:page_info) @polling_interval_millis = args[:polling_interval_millis] if args.key?(:polling_interval_millis) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |