Class: Google::Apis::YoutubeV3::LiveChatMessageSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMessageSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Next ID: 35
Instance Attribute Summary collapse
-
#author_channel_id ⇒ String
The ID of the user that authored this message, this field is not always filled.
-
#display_message ⇒ String
Contains a string that can be displayed to the user.
-
#fan_funding_event_details ⇒ Google::Apis::YoutubeV3::LiveChatFanFundingEventDetails
Details about the funding event, this is only set if the type is ' fanFundingEvent'.
-
#gift_details ⇒ Google::Apis::YoutubeV3::LiveChatGiftDetails
Details about the gift event, this is only set if the type is 'giftEvent'.
-
#gift_membership_received_details ⇒ Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
Details about the Gift Membership Received event, this is only set if the type is 'giftMembershipReceivedEvent'.
-
#has_display_content ⇒ Boolean
(also: #has_display_content?)
Whether the message has display content that should be displayed to users.
-
#live_chat_id ⇒ String
Corresponds to the JSON property
liveChatId. -
#member_milestone_chat_details ⇒ Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails
Details about the Member Milestone Chat event, this is only set if the type is 'memberMilestoneChatEvent'.
-
#membership_gifting_details ⇒ Google::Apis::YoutubeV3::LiveChatMembershipGiftingDetails
Details about the Membership Gifting event, this is only set if the type is ' membershipGiftingEvent'.
-
#message_deleted_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageDeletedDetails
Corresponds to the JSON property
messageDeletedDetails. -
#message_retracted_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageRetractedDetails
Corresponds to the JSON property
messageRetractedDetails. -
#new_sponsor_details ⇒ Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
Details about the New Member Announcement event, this is only set if the type is 'newSponsorEvent'.
-
#poll_details ⇒ Google::Apis::YoutubeV3::LiveChatPollDetails
Details about the poll event, this is only set if the type is 'pollEvent'.
-
#published_at ⇒ DateTime
The date and time when the message was orignally published.
-
#super_chat_details ⇒ Google::Apis::YoutubeV3::LiveChatSuperChatDetails
Details about the Super Chat event, this is only set if the type is ' superChatEvent'.
-
#super_sticker_details ⇒ Google::Apis::YoutubeV3::LiveChatSuperStickerDetails
Details about the Super Sticker event, this is only set if the type is ' superStickerEvent'.
-
#text_message_details ⇒ Google::Apis::YoutubeV3::LiveChatTextMessageDetails
Details about the text message, this is only set if the type is ' textMessageEvent'.
-
#type ⇒ String
The type of message, this will always be present, it determines the contents of the message as well as which fields will be present.
-
#user_banned_details ⇒ Google::Apis::YoutubeV3::LiveChatUserBannedMessageDetails
Corresponds to the JSON property
userBannedDetails.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMessageSnippet
constructor
A new instance of LiveChatMessageSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMessageSnippet
Returns a new instance of LiveChatMessageSnippet.
5015 5016 5017 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author_channel_id ⇒ String
The ID of the user that authored this message, this field is not always filled.
textMessageEvent - the user that wrote the message fanFundingEvent - the user
that funded the broadcast newSponsorEvent - the user that just became a
sponsor memberMilestoneChatEvent - the member that sent the message
membershipGiftingEvent - the user that made the purchase
giftMembershipReceivedEvent - the user that received the gift membership
messageDeletedEvent - the moderator that took the action. Unused.
messageRetractedEvent - the author that retracted their message. Unused.
userBannedEvent - the moderator that took the action superChatEvent - the user
that made the purchase superStickerEvent - the user that made the purchase
pollEvent - the user that created the poll
Corresponds to the JSON property authorChannelId
4911 4912 4913 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4911 def @author_channel_id end |
#display_message ⇒ String
Contains a string that can be displayed to the user. If this field is not
present the message is silent, at the moment only messages of type TOMBSTONE
and CHAT_ENDED_EVENT are silent.
Corresponds to the JSON property displayMessage
4918 4919 4920 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4918 def @display_message end |
#fan_funding_event_details ⇒ Google::Apis::YoutubeV3::LiveChatFanFundingEventDetails
Details about the funding event, this is only set if the type is '
fanFundingEvent'.
Corresponds to the JSON property fanFundingEventDetails
4924 4925 4926 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4924 def fan_funding_event_details @fan_funding_event_details end |
#gift_details ⇒ Google::Apis::YoutubeV3::LiveChatGiftDetails
Details about the gift event, this is only set if the type is 'giftEvent'.
Corresponds to the JSON property giftDetails
4929 4930 4931 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4929 def gift_details @gift_details end |
#gift_membership_received_details ⇒ Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
Details about the Gift Membership Received event, this is only set if the type
is 'giftMembershipReceivedEvent'.
Corresponds to the JSON property giftMembershipReceivedDetails
4935 4936 4937 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4935 def gift_membership_received_details @gift_membership_received_details end |
#has_display_content ⇒ Boolean Also known as: has_display_content?
Whether the message has display content that should be displayed to users.
Corresponds to the JSON property hasDisplayContent
4940 4941 4942 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4940 def has_display_content @has_display_content end |
#live_chat_id ⇒ String
Corresponds to the JSON property liveChatId
4946 4947 4948 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4946 def live_chat_id @live_chat_id end |
#member_milestone_chat_details ⇒ Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails
Details about the Member Milestone Chat event, this is only set if the type is
'memberMilestoneChatEvent'.
Corresponds to the JSON property memberMilestoneChatDetails
4952 4953 4954 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4952 def member_milestone_chat_details @member_milestone_chat_details end |
#membership_gifting_details ⇒ Google::Apis::YoutubeV3::LiveChatMembershipGiftingDetails
Details about the Membership Gifting event, this is only set if the type is '
membershipGiftingEvent'.
Corresponds to the JSON property membershipGiftingDetails
4958 4959 4960 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4958 def membership_gifting_details @membership_gifting_details end |
#message_deleted_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageDeletedDetails
Corresponds to the JSON property messageDeletedDetails
4963 4964 4965 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4963 def @message_deleted_details end |
#message_retracted_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageRetractedDetails
Corresponds to the JSON property messageRetractedDetails
4968 4969 4970 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4968 def @message_retracted_details end |
#new_sponsor_details ⇒ Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
Details about the New Member Announcement event, this is only set if the type
is 'newSponsorEvent'. Please note that "member" is the new term for "sponsor".
Corresponds to the JSON property newSponsorDetails
4974 4975 4976 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4974 def new_sponsor_details @new_sponsor_details end |
#poll_details ⇒ Google::Apis::YoutubeV3::LiveChatPollDetails
Details about the poll event, this is only set if the type is 'pollEvent'.
Corresponds to the JSON property pollDetails
4979 4980 4981 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4979 def poll_details @poll_details end |
#published_at ⇒ DateTime
The date and time when the message was orignally published.
Corresponds to the JSON property publishedAt
4984 4985 4986 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4984 def published_at @published_at end |
#super_chat_details ⇒ Google::Apis::YoutubeV3::LiveChatSuperChatDetails
Details about the Super Chat event, this is only set if the type is '
superChatEvent'.
Corresponds to the JSON property superChatDetails
4990 4991 4992 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4990 def super_chat_details @super_chat_details end |
#super_sticker_details ⇒ Google::Apis::YoutubeV3::LiveChatSuperStickerDetails
Details about the Super Sticker event, this is only set if the type is '
superStickerEvent'.
Corresponds to the JSON property superStickerDetails
4996 4997 4998 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4996 def super_sticker_details @super_sticker_details end |
#text_message_details ⇒ Google::Apis::YoutubeV3::LiveChatTextMessageDetails
Details about the text message, this is only set if the type is '
textMessageEvent'.
Corresponds to the JSON property textMessageDetails
5002 5003 5004 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5002 def @text_message_details end |
#type ⇒ String
The type of message, this will always be present, it determines the contents
of the message as well as which fields will be present.
Corresponds to the JSON property type
5008 5009 5010 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5008 def type @type end |
#user_banned_details ⇒ Google::Apis::YoutubeV3::LiveChatUserBannedMessageDetails
Corresponds to the JSON property userBannedDetails
5013 5014 5015 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5013 def user_banned_details @user_banned_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5020 def update!(**args) @author_channel_id = args[:author_channel_id] if args.key?(:author_channel_id) @display_message = args[:display_message] if args.key?(:display_message) @fan_funding_event_details = args[:fan_funding_event_details] if args.key?(:fan_funding_event_details) @gift_details = args[:gift_details] if args.key?(:gift_details) @gift_membership_received_details = args[:gift_membership_received_details] if args.key?(:gift_membership_received_details) @has_display_content = args[:has_display_content] if args.key?(:has_display_content) @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id) @member_milestone_chat_details = args[:member_milestone_chat_details] if args.key?(:member_milestone_chat_details) @membership_gifting_details = args[:membership_gifting_details] if args.key?(:membership_gifting_details) @message_deleted_details = args[:message_deleted_details] if args.key?(:message_deleted_details) @message_retracted_details = args[:message_retracted_details] if args.key?(:message_retracted_details) @new_sponsor_details = args[:new_sponsor_details] if args.key?(:new_sponsor_details) @poll_details = args[:poll_details] if args.key?(:poll_details) @published_at = args[:published_at] if args.key?(:published_at) @super_chat_details = args[:super_chat_details] if args.key?(:super_chat_details) @super_sticker_details = args[:super_sticker_details] if args.key?(:super_sticker_details) @text_message_details = args[:text_message_details] if args.key?(:text_message_details) @type = args[:type] if args.key?(:type) @user_banned_details = args[:user_banned_details] if args.key?(:user_banned_details) end |