Class: Google::Apis::YoutubeV3::LiveChatModerator
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModerator
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A liveChatModerator resource represents a moderator for a YouTube live chat. A chat moderator has the ability to ban/unban users from a chat, remove message, etc.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the moderator.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::LiveChatModeratorSnippet
The snippet object contains basic details about the moderator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModerator
constructor
A new instance of LiveChatModerator.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModerator
Returns a new instance of LiveChatModerator.
4895 4896 4897 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4877 4878 4879 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4877 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the moderator.
Corresponds to the JSON property id
4882 4883 4884 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4882 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatModerator".
Corresponds to the JSON property kind
4888 4889 4890 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4888 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::LiveChatModeratorSnippet
The snippet object contains basic details about the moderator.
Corresponds to the JSON property snippet
4893 4894 4895 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4893 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4900 4901 4902 4903 4904 4905 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4900 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |