Class: Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModeratorListResponse
constructor
A new instance of LiveChatModeratorListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModeratorListResponse
Returns a new instance of LiveChatModeratorListResponse.
5130 5131 5132 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5084 5085 5086 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5084 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5089 5090 5091 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5089 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
Corresponds to the JSON property items
5094 5095 5096 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5094 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatModeratorListResponse".
Corresponds to the JSON property kind
5100 5101 5102 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5100 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5106 5107 5108 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5106 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5112 5113 5114 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5112 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
5118 5119 5120 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5118 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5123 5124 5125 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5123 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5128 5129 5130 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5128 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5135 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |