Class: Google::Apis::YoutubeV3::LiveChatModeratorSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModeratorSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#live_chat_id ⇒ String
The ID of the live chat this moderator can act on.
-
#moderator_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the moderator.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModeratorSnippet
constructor
A new instance of LiveChatModeratorSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModeratorSnippet
Returns a new instance of LiveChatModeratorSnippet.
4919 4920 4921 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#live_chat_id ⇒ String
The ID of the live chat this moderator can act on.
Corresponds to the JSON property liveChatId
4912 4913 4914 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4912 def live_chat_id @live_chat_id end |
#moderator_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the moderator.
Corresponds to the JSON property moderatorDetails
4917 4918 4919 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4917 def moderator_details @moderator_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4924 4925 4926 4927 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4924 def update!(**args) @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id) @moderator_details = args[:moderator_details] if args.key?(:moderator_details) end |