Class: Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadata
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#options ⇒ Array<Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadataPollOption>
The options will be returned in the order that is displayed in 1P Corresponds to the JSON property
options. -
#question_text ⇒ String
Corresponds to the JSON property
questionText.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatPollDetailsPollMetadata
constructor
A new instance of LiveChatPollDetailsPollMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatPollDetailsPollMetadata
Returns a new instance of LiveChatPollDetailsPollMetadata.
5098 5099 5100 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#options ⇒ Array<Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadataPollOption>
The options will be returned in the order that is displayed in 1P
Corresponds to the JSON property options
5091 5092 5093 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5091 def @options end |
#question_text ⇒ String
Corresponds to the JSON property questionText
5096 5097 5098 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5096 def question_text @question_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5103 5104 5105 5106 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5103 def update!(**args) @options = args[:options] if args.key?(:options) @question_text = args[:question_text] if args.key?(:question_text) end |