Class: Google::Apis::YoutubeV3::LiveChatSuperChatDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatSuperChatDetails

Returns a new instance of LiveChatSuperChatDetails.



5303
5304
5305
# File 'lib/google/apis/youtube_v3/classes.rb', line 5303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_display_stringString

A rendered string that displays the fund amount and currency to the user. Corresponds to the JSON property amountDisplayString

Returns:

  • (String)


5280
5281
5282
# File 'lib/google/apis/youtube_v3/classes.rb', line 5280

def amount_display_string
  @amount_display_string
end

#amount_microsFixnum

The amount purchased by the user, in micros (1,750,000 micros = 1.75). Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


5285
5286
5287
# File 'lib/google/apis/youtube_v3/classes.rb', line 5285

def amount_micros
  @amount_micros
end

#currencyString

The currency in which the purchase was made. Corresponds to the JSON property currency

Returns:

  • (String)


5290
5291
5292
# File 'lib/google/apis/youtube_v3/classes.rb', line 5290

def currency
  @currency
end

#tierFixnum

The tier in which the amount belongs. Lower amounts belong to lower tiers. The lowest tier is 1. Corresponds to the JSON property tier

Returns:

  • (Fixnum)


5296
5297
5298
# File 'lib/google/apis/youtube_v3/classes.rb', line 5296

def tier
  @tier
end

#user_commentString

The comment added by the user to this Super Chat event. Corresponds to the JSON property userComment

Returns:

  • (String)


5301
5302
5303
# File 'lib/google/apis/youtube_v3/classes.rb', line 5301

def user_comment
  @user_comment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5308
5309
5310
5311
5312
5313
5314
# File 'lib/google/apis/youtube_v3/classes.rb', line 5308

def update!(**args)
  @amount_display_string = args[:amount_display_string] if args.key?(:amount_display_string)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @currency = args[:currency] if args.key?(:currency)
  @tier = args[:tier] if args.key?(:tier)
  @user_comment = args[:user_comment] if args.key?(:user_comment)
end