Class: Google::Apis::YoutubeV3::LiveChatSuperStickerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatSuperStickerDetails

Returns a new instance of LiveChatSuperStickerDetails.



5347
5348
5349
# File 'lib/google/apis/youtube_v3/classes.rb', line 5347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_display_stringString

A rendered string that displays the fund amount and currency to the user. Corresponds to the JSON property amountDisplayString

Returns:

  • (String)


5324
5325
5326
# File 'lib/google/apis/youtube_v3/classes.rb', line 5324

def amount_display_string
  @amount_display_string
end

#amount_microsFixnum

The amount purchased by the user, in micros (1,750,000 micros = 1.75). Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


5329
5330
5331
# File 'lib/google/apis/youtube_v3/classes.rb', line 5329

def amount_micros
  @amount_micros
end

#currencyString

The currency in which the purchase was made. Corresponds to the JSON property currency

Returns:

  • (String)


5334
5335
5336
# File 'lib/google/apis/youtube_v3/classes.rb', line 5334

def currency
  @currency
end

#super_sticker_metadataGoogle::Apis::YoutubeV3::SuperStickerMetadata

Information about the Super Sticker. Corresponds to the JSON property superStickerMetadata



5339
5340
5341
# File 'lib/google/apis/youtube_v3/classes.rb', line 5339

def 
  @super_sticker_metadata
end

#tierFixnum

The tier in which the amount belongs. Lower amounts belong to lower tiers. The lowest tier is 1. Corresponds to the JSON property tier

Returns:

  • (Fixnum)


5345
5346
5347
# File 'lib/google/apis/youtube_v3/classes.rb', line 5345

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5352
5353
5354
5355
5356
5357
5358
# File 'lib/google/apis/youtube_v3/classes.rb', line 5352

def update!(**args)
  @amount_display_string = args[:amount_display_string] if args.key?(:amount_display_string)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @currency = args[:currency] if args.key?(:currency)
  @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata)
  @tier = args[:tier] if args.key?(:tier)
end