Class: Google::Apis::YoutubeV3::LiveStream
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A live stream describes a live ingestion point.
Instance Attribute Summary collapse
-
#cdn ⇒ Google::Apis::YoutubeV3::CdnSettings
Brief description of the live stream cdn settings.
-
#content_details ⇒ Google::Apis::YoutubeV3::LiveStreamContentDetails
Detailed settings of a stream.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the stream.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::LiveStreamSnippet
The snippet object contains basic details about the stream, including its channel, title, and description.
-
#status ⇒ Google::Apis::YoutubeV3::LiveStreamStatus
Brief description of the live stream status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStream
constructor
A new instance of LiveStream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStream
Returns a new instance of LiveStream.
5457 5458 5459 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5457 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cdn ⇒ Google::Apis::YoutubeV3::CdnSettings
Brief description of the live stream cdn settings.
Corresponds to the JSON property cdn
5423 5424 5425 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5423 def cdn @cdn end |
#content_details ⇒ Google::Apis::YoutubeV3::LiveStreamContentDetails
Detailed settings of a stream.
Corresponds to the JSON property contentDetails
5428 5429 5430 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5428 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5433 5434 5435 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5433 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the stream.
Corresponds to the JSON property id
5438 5439 5440 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5438 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveStream".
Corresponds to the JSON property kind
5444 5445 5446 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5444 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::LiveStreamSnippet
The snippet object contains basic details about the stream, including its
channel, title, and description.
Corresponds to the JSON property snippet
5450 5451 5452 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5450 def snippet @snippet end |
#status ⇒ Google::Apis::YoutubeV3::LiveStreamStatus
Brief description of the live stream status.
Corresponds to the JSON property status
5455 5456 5457 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5455 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5462 5463 5464 5465 5466 5467 5468 5469 5470 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5462 def update!(**args) @cdn = args[:cdn] if args.key?(:cdn) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) @status = args[:status] if args.key?(:status) end |