Class: Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
The long-form description of the issue and how to resolve it.
-
#reason ⇒ String
The short-form reason for this issue.
-
#severity ⇒ String
How severe this issue is to the stream.
-
#type ⇒ String
The kind of error happening.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStreamConfigurationIssue
constructor
A new instance of LiveStreamConfigurationIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStreamConfigurationIssue
Returns a new instance of LiveStreamConfigurationIssue.
5497 5498 5499 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The long-form description of the issue and how to resolve it.
Corresponds to the JSON property description
5480 5481 5482 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5480 def description @description end |
#reason ⇒ String
The short-form reason for this issue.
Corresponds to the JSON property reason
5485 5486 5487 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5485 def reason @reason end |
#severity ⇒ String
How severe this issue is to the stream.
Corresponds to the JSON property severity
5490 5491 5492 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5490 def severity @severity end |
#type ⇒ String
The kind of error happening.
Corresponds to the JSON property type
5495 5496 5497 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5495 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5502 5503 5504 5505 5506 5507 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5502 def update!(**args) @description = args[:description] if args.key?(:description) @reason = args[:reason] if args.key?(:reason) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |