Class: Google::Apis::YoutubeV3::LiveStreamSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveStreamSnippet

Returns a new instance of LiveStreamSnippet.



5675
5676
5677
# File 'lib/google/apis/youtube_v3/classes.rb', line 5675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the channel that is transmitting the stream. Corresponds to the JSON property channelId

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/youtube_v3/classes.rb', line 5652

def channel_id
  @channel_id
end

#descriptionString

The stream's description. The value cannot be longer than 10000 characters. Corresponds to the JSON property description

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/youtube_v3/classes.rb', line 5657

def description
  @description
end

#is_default_streamBoolean Also known as: is_default_stream?

Corresponds to the JSON property isDefaultStream

Returns:

  • (Boolean)


5662
5663
5664
# File 'lib/google/apis/youtube_v3/classes.rb', line 5662

def is_default_stream
  @is_default_stream
end

#published_atDateTime

The date and time that the stream was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


5668
5669
5670
# File 'lib/google/apis/youtube_v3/classes.rb', line 5668

def published_at
  @published_at
end

#titleString

The stream's title. The value must be between 1 and 128 characters long. Corresponds to the JSON property title

Returns:

  • (String)


5673
5674
5675
# File 'lib/google/apis/youtube_v3/classes.rb', line 5673

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5680
5681
5682
5683
5684
5685
5686
# File 'lib/google/apis/youtube_v3/classes.rb', line 5680

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @description = args[:description] if args.key?(:description)
  @is_default_stream = args[:is_default_stream] if args.key?(:is_default_stream)
  @published_at = args[:published_at] if args.key?(:published_at)
  @title = args[:title] if args.key?(:title)
end