Class: Google::Apis::YoutubeV3::MemberListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MemberListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemberListResponse
constructor
A new instance of MemberListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemberListResponse
Returns a new instance of MemberListResponse.
5860 5861 5862 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5860 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5820 5821 5822 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5820 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5825 5826 5827 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5825 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
Corresponds to the JSON property items
5830 5831 5832 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5830 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
memberListResponse".
Corresponds to the JSON property kind
5836 5837 5838 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5836 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5842 5843 5844 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5842 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5848 5849 5850 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5848 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5853 5854 5855 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5853 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5858 5859 5860 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5858 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5865 5866 5867 5868 5869 5870 5871 5872 5873 5874 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5865 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |