Class: Google::Apis::YoutubeV3::MembershipsDurationAtLevel
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MembershipsDurationAtLevel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#level ⇒ String
Pricing level ID.
-
#member_since ⇒ String
The date and time when the user became a continuous member for the given level.
-
#member_total_duration_months ⇒ Fixnum
The cumulative time the user has been a member for the given level in complete months (the time is rounded down to the nearest integer).
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipsDurationAtLevel
constructor
A new instance of MembershipsDurationAtLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipsDurationAtLevel
Returns a new instance of MembershipsDurationAtLevel.
5825 5826 5827 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#level ⇒ String
Pricing level ID.
Corresponds to the JSON property level
5812 5813 5814 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5812 def level @level end |
#member_since ⇒ String
The date and time when the user became a continuous member for the given level.
Corresponds to the JSON property memberSince
5817 5818 5819 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5817 def member_since @member_since end |
#member_total_duration_months ⇒ Fixnum
The cumulative time the user has been a member for the given level in complete
months (the time is rounded down to the nearest integer).
Corresponds to the JSON property memberTotalDurationMonths
5823 5824 5825 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5823 def member_total_duration_months @member_total_duration_months end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5830 5831 5832 5833 5834 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5830 def update!(**args) @level = args[:level] if args.key?(:level) @member_since = args[:member_since] if args.key?(:member_since) @member_total_duration_months = args[:member_total_duration_months] if args.key?(:member_total_duration_months) end |