Class: Google::Apis::YoutubeV3::MembershipsLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A membershipsLevel resource represents an offer made by YouTube creators for their fans. Users can become members of the channel by joining one of the available levels. They will provide recurring monetary support and receives special benefits.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsLevel

Returns a new instance of MembershipsLevel.



6040
6041
6042
# File 'lib/google/apis/youtube_v3/classes.rb', line 6040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


6022
6023
6024
# File 'lib/google/apis/youtube_v3/classes.rb', line 6022

def etag
  @etag
end

#idString

The ID that YouTube assigns to uniquely identify the memberships level. Corresponds to the JSON property id

Returns:

  • (String)


6027
6028
6029
# File 'lib/google/apis/youtube_v3/classes.rb', line 6027

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# membershipsLevelListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


6033
6034
6035
# File 'lib/google/apis/youtube_v3/classes.rb', line 6033

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::MembershipsLevelSnippet

The snippet object contains basic details about the level. Corresponds to the JSON property snippet



6038
6039
6040
# File 'lib/google/apis/youtube_v3/classes.rb', line 6038

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6045
6046
6047
6048
6049
6050
# File 'lib/google/apis/youtube_v3/classes.rb', line 6045

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end