Class: Google::Apis::YoutubeV3::MonitorStreamInfo
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MonitorStreamInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Settings and Info of the monitor stream
Instance Attribute Summary collapse
-
#broadcast_stream_delay_ms ⇒ Fixnum
If you have set the enableMonitorStream property to true, then this property determines the length of the live broadcast delay.
-
#embed_html ⇒ String
HTML code that embeds a player that plays the monitor stream.
-
#enable_monitor_stream ⇒ Boolean
(also: #enable_monitor_stream?)
This value determines whether the monitor stream is enabled for the broadcast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonitorStreamInfo
constructor
A new instance of MonitorStreamInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonitorStreamInfo
Returns a new instance of MonitorStreamInfo.
6149 6150 6151 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#broadcast_stream_delay_ms ⇒ Fixnum
If you have set the enableMonitorStream property to true, then this property
determines the length of the live broadcast delay.
Corresponds to the JSON property broadcastStreamDelayMs
6130 6131 6132 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6130 def broadcast_stream_delay_ms @broadcast_stream_delay_ms end |
#embed_html ⇒ String
HTML code that embeds a player that plays the monitor stream.
Corresponds to the JSON property embedHtml
6135 6136 6137 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6135 def @embed_html end |
#enable_monitor_stream ⇒ Boolean Also known as: enable_monitor_stream?
This value determines whether the monitor stream is enabled for the broadcast.
If the monitor stream is enabled, then YouTube will broadcast the event
content on a special stream intended only for the broadcaster's consumption.
The broadcaster can use the stream to review the event content and also to
identify the optimal times to insert cuepoints. You need to set this value to
true if you intend to have a broadcast delay for your event. Note: This
property cannot be updated once the broadcast is in the testing or live state.
Corresponds to the JSON property enableMonitorStream
6146 6147 6148 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6146 def enable_monitor_stream @enable_monitor_stream end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6154 6155 6156 6157 6158 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6154 def update!(**args) @broadcast_stream_delay_ms = args[:broadcast_stream_delay_ms] if args.key?(:broadcast_stream_delay_ms) @embed_html = args[:embed_html] if args.key?(:embed_html) @enable_monitor_stream = args[:enable_monitor_stream] if args.key?(:enable_monitor_stream) end |