Class: Google::Apis::YoutubeV3::PageInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Paging details for lists of resources, including total number of items available and number of resources returned in a single page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PageInfo

Returns a new instance of PageInfo.



6027
6028
6029
# File 'lib/google/apis/youtube_v3/classes.rb', line 6027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#results_per_pageFixnum

The number of results included in the API response. Corresponds to the JSON property resultsPerPage

Returns:

  • (Fixnum)


6020
6021
6022
# File 'lib/google/apis/youtube_v3/classes.rb', line 6020

def results_per_page
  @results_per_page
end

#total_resultsFixnum

The total number of results in the result set. Corresponds to the JSON property totalResults

Returns:

  • (Fixnum)


6025
6026
6027
# File 'lib/google/apis/youtube_v3/classes.rb', line 6025

def total_results
  @total_results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6032
6033
6034
6035
# File 'lib/google/apis/youtube_v3/classes.rb', line 6032

def update!(**args)
  @results_per_page = args[:results_per_page] if args.key?(:results_per_page)
  @total_results = args[:total_results] if args.key?(:total_results)
end