Class: Google::Apis::YoutubeV3::PlaylistImageListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistImageListResponse

Returns a new instance of PlaylistImageListResponse.



6359
6360
6361
# File 'lib/google/apis/youtube_v3/classes.rb', line 6359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::YoutubeV3::PlaylistImage>

Corresponds to the JSON property items



6333
6334
6335
# File 'lib/google/apis/youtube_v3/classes.rb', line 6333

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# playlistImageListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


6339
6340
6341
# File 'lib/google/apis/youtube_v3/classes.rb', line 6339

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6345
6346
6347
# File 'lib/google/apis/youtube_v3/classes.rb', line 6345

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



6351
6352
6353
# File 'lib/google/apis/youtube_v3/classes.rb', line 6351

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


6357
6358
6359
# File 'lib/google/apis/youtube_v3/classes.rb', line 6357

def prev_page_token
  @prev_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6364
6365
6366
6367
6368
6369
6370
# File 'lib/google/apis/youtube_v3/classes.rb', line 6364

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
end