Class: Google::Apis::YoutubeV3::PlaylistItem
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A playlistItem resource identifies another resource, such as a video, that is included in a playlist. In addition, the playlistItem resource contains details about the included resource that pertain specifically to how that resource is used in that playlist. YouTube uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history - watch later To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistItems.list method to retrieve any of those lists. You can also add or remove items from those lists by calling the playlistItems.insert and playlistItems.delete methods. For example, if a user gives a positive rating to a video, you would insert that video into the liked videos playlist for that user's channel.
Instance Attribute Summary collapse
-
#content_details ⇒ Google::Apis::YoutubeV3::PlaylistItemContentDetails
The contentDetails object is included in the resource if the included item is a YouTube video.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the playlist item.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistItemSnippet
Basic details about a playlist, including title, description and thumbnails.
-
#status ⇒ Google::Apis::YoutubeV3::PlaylistItemStatus
Information about the playlist item's privacy status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistItem
constructor
A new instance of PlaylistItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistItem
Returns a new instance of PlaylistItem.
6473 6474 6475 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6473 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_details ⇒ Google::Apis::YoutubeV3::PlaylistItemContentDetails
The contentDetails object is included in the resource if the included item is
a YouTube video. The object contains additional information about the video.
Corresponds to the JSON property contentDetails
6444 6445 6446 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6444 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6449 6450 6451 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6449 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the playlist item.
Corresponds to the JSON property id
6454 6455 6456 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6454 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistItem".
Corresponds to the JSON property kind
6460 6461 6462 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6460 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistItemSnippet
Basic details about a playlist, including title, description and thumbnails.
Basic details of a YouTube Playlist item provided by the author. Next ID: 15
Corresponds to the JSON property snippet
6466 6467 6468 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6466 def snippet @snippet end |
#status ⇒ Google::Apis::YoutubeV3::PlaylistItemStatus
Information about the playlist item's privacy status.
Corresponds to the JSON property status
6471 6472 6473 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6471 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6478 6479 6480 6481 6482 6483 6484 6485 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6478 def update!(**args) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) @status = args[:status] if args.key?(:status) end |