Class: Google::Apis::YoutubeV3::PlaylistItemSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistItemSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a playlist, including title, description and thumbnails. Basic details of a YouTube Playlist item provided by the author. Next ID: 15
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the user that added the item to the playlist.
-
#channel_title ⇒ String
Channel title for the channel that the playlist item belongs to.
-
#description ⇒ String
The item's description.
-
#playlist_id ⇒ String
The ID that YouTube uses to uniquely identify thGe playlist that the playlist item is in.
-
#position ⇒ Fixnum
The order in which the item appears in the playlist.
-
#published_at ⇒ DateTime
The date and time that the item was added to the playlist.
-
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The item's title.
-
#video_owner_channel_id ⇒ String
Channel id for the channel this video belongs to.
-
#video_owner_channel_title ⇒ String
Channel title for the channel this video belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistItemSnippet
constructor
A new instance of PlaylistItemSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistItemSnippet
Returns a new instance of PlaylistItemSnippet.
6663 6664 6665 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6663 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the user that added the item to
the playlist.
Corresponds to the JSON property channelId
6608 6609 6610 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6608 def channel_id @channel_id end |
#channel_title ⇒ String
Channel title for the channel that the playlist item belongs to.
Corresponds to the JSON property channelTitle
6613 6614 6615 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6613 def channel_title @channel_title end |
#description ⇒ String
The item's description.
Corresponds to the JSON property description
6618 6619 6620 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6618 def description @description end |
#playlist_id ⇒ String
The ID that YouTube uses to uniquely identify thGe playlist that the playlist
item is in.
Corresponds to the JSON property playlistId
6624 6625 6626 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6624 def playlist_id @playlist_id end |
#position ⇒ Fixnum
The order in which the item appears in the playlist. The value uses a zero-
based index, so the first item has a position of 0, the second item has a
position of 1, and so forth.
Corresponds to the JSON property position
6631 6632 6633 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6631 def position @position end |
#published_at ⇒ DateTime
The date and time that the item was added to the playlist.
Corresponds to the JSON property publishedAt
6636 6637 6638 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6636 def published_at @published_at end |
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property resourceId
6641 6642 6643 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6641 def resource_id @resource_id end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
6646 6647 6648 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6646 def thumbnails @thumbnails end |
#title ⇒ String
The item's title.
Corresponds to the JSON property title
6651 6652 6653 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6651 def title @title end |
#video_owner_channel_id ⇒ String
Channel id for the channel this video belongs to.
Corresponds to the JSON property videoOwnerChannelId
6656 6657 6658 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6656 def video_owner_channel_id @video_owner_channel_id end |
#video_owner_channel_title ⇒ String
Channel title for the channel this video belongs to.
Corresponds to the JSON property videoOwnerChannelTitle
6661 6662 6663 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6661 def video_owner_channel_title @video_owner_channel_title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6668 6669 6670 6671 6672 6673 6674 6675 6676 6677 6678 6679 6680 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6668 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @channel_title = args[:channel_title] if args.key?(:channel_title) @description = args[:description] if args.key?(:description) @playlist_id = args[:playlist_id] if args.key?(:playlist_id) @position = args[:position] if args.key?(:position) @published_at = args[:published_at] if args.key?(:published_at) @resource_id = args[:resource_id] if args.key?(:resource_id) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) @video_owner_channel_id = args[:video_owner_channel_id] if args.key?(:video_owner_channel_id) @video_owner_channel_title = args[:video_owner_channel_title] if args.key?(:video_owner_channel_title) end |