Class: Google::Apis::YoutubeV3::ResourceId
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ResourceId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A resource id is a generic reference that points to another YouTube resource.
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that resource is a channel.
-
#kind ⇒ String
The type of the API resource.
-
#playlist_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that resource is a playlist.
-
#video_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that resource is a video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceId
constructor
A new instance of ResourceId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceId
Returns a new instance of ResourceId.
6857 6858 6859 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that
resource is a channel. This property is only present if the resourceId.kind
value is youtube#channel.
Corresponds to the JSON property channelId
6836 6837 6838 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6836 def channel_id @channel_id end |
#kind ⇒ String
The type of the API resource.
Corresponds to the JSON property kind
6841 6842 6843 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6841 def kind @kind end |
#playlist_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that
resource is a playlist. This property is only present if the resourceId.kind
value is youtube#playlist.
Corresponds to the JSON property playlistId
6848 6849 6850 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6848 def playlist_id @playlist_id end |
#video_id ⇒ String
The ID that YouTube uses to uniquely identify the referred resource, if that
resource is a video. This property is only present if the resourceId.kind
value is youtube#video.
Corresponds to the JSON property videoId
6855 6856 6857 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6855 def video_id @video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6862 6863 6864 6865 6866 6867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6862 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @kind = args[:kind] if args.key?(:kind) @playlist_id = args[:playlist_id] if args.key?(:playlist_id) @video_id = args[:video_id] if args.key?(:video_id) end |