Class: Google::Apis::YoutubeV3::SearchListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SearchListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#region_code ⇒ String
Corresponds to the JSON property
regionCode. -
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchListsResponse
constructor
A new instance of SearchListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchListsResponse
Returns a new instance of SearchListsResponse.
7077 7078 7079 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7026 7027 7028 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7026 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7031 7032 7033 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7031 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
Corresponds to the JSON property items
7036 7037 7038 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7036 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
searchListResponse".
Corresponds to the JSON property kind
7042 7043 7044 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7042 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7048 7049 7050 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7048 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7054 7055 7056 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7054 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
7060 7061 7062 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7060 def prev_page_token @prev_page_token end |
#region_code ⇒ String
Corresponds to the JSON property regionCode
7065 7066 7067 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7065 def region_code @region_code end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7070 7071 7072 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7070 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Corresponds to the JSON property visitorId
7075 7076 7077 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7075 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7082 7083 7084 7085 7086 7087 7088 7089 7090 7091 7092 7093 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7082 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @region_code = args[:region_code] if args.key?(:region_code) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |