Class: Google::Apis::YoutubeV3::SearchResult
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SearchResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A search result contains information about a YouTube video, channel, or playlist that matches the search parameters specified in an API request. While a search result points to a uniquely identifiable resource, like a video, it does not have its own persistent data.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::SearchResultSnippet
Basic details about a search result, including title, description and thumbnails of the item referenced by the search result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchResult
constructor
A new instance of SearchResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchResult
Returns a new instance of SearchResult.
6976 6977 6978 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6976 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6957 6958 6959 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6957 def etag @etag end |
#id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property id
6962 6963 6964 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6962 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
searchResult".
Corresponds to the JSON property kind
6968 6969 6970 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6968 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::SearchResultSnippet
Basic details about a search result, including title, description and
thumbnails of the item referenced by the search result.
Corresponds to the JSON property snippet
6974 6975 6976 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6974 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6981 6982 6983 6984 6985 6986 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6981 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |