Class: Google::Apis::YoutubeV3::Subscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A subscription resource contains information about a YouTube user subscription. A subscription notifies a user when new videos are added to a channel or when another user takes one of several actions on YouTube, such as uploading a video, rating a video, or commenting on a video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subscription

Returns a new instance of Subscription.



7089
7090
7091
# File 'lib/google/apis/youtube_v3/classes.rb', line 7089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_detailsGoogle::Apis::YoutubeV3::SubscriptionContentDetails

Details about the content to witch a subscription refers. Corresponds to the JSON property contentDetails



7059
7060
7061
# File 'lib/google/apis/youtube_v3/classes.rb', line 7059

def content_details
  @content_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7064
7065
7066
# File 'lib/google/apis/youtube_v3/classes.rb', line 7064

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the subscription. Corresponds to the JSON property id

Returns:

  • (String)


7069
7070
7071
# File 'lib/google/apis/youtube_v3/classes.rb', line 7069

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# subscription". Corresponds to the JSON property kind

Returns:

  • (String)


7075
7076
7077
# File 'lib/google/apis/youtube_v3/classes.rb', line 7075

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::SubscriptionSnippet

Basic details about a subscription, including title, description and thumbnails of the subscribed item. Corresponds to the JSON property snippet



7081
7082
7083
# File 'lib/google/apis/youtube_v3/classes.rb', line 7081

def snippet
  @snippet
end

#subscriber_snippetGoogle::Apis::YoutubeV3::SubscriptionSubscriberSnippet

Basic details about a subscription's subscriber including title, description, channel ID and thumbnails. Corresponds to the JSON property subscriberSnippet



7087
7088
7089
# File 'lib/google/apis/youtube_v3/classes.rb', line 7087

def subscriber_snippet
  @subscriber_snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7094
7095
7096
7097
7098
7099
7100
7101
# File 'lib/google/apis/youtube_v3/classes.rb', line 7094

def update!(**args)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
  @subscriber_snippet = args[:subscriber_snippet] if args.key?(:subscriber_snippet)
end