Class: Google::Apis::YoutubeV3::SubscriptionContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about the content to witch a subscription refers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionContentDetails

Returns a new instance of SubscriptionContentDetails.



6989
6990
6991
# File 'lib/google/apis/youtube_v3/classes.rb', line 6989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activity_typeString

The type of activity this subscription is for (only uploads, everything). Corresponds to the JSON property activityType

Returns:

  • (String)


6977
6978
6979
# File 'lib/google/apis/youtube_v3/classes.rb', line 6977

def activity_type
  @activity_type
end

#new_item_countFixnum

The number of new items in the subscription since its content was last read. Corresponds to the JSON property newItemCount

Returns:

  • (Fixnum)


6982
6983
6984
# File 'lib/google/apis/youtube_v3/classes.rb', line 6982

def new_item_count
  @new_item_count
end

#total_item_countFixnum

The approximate number of items that the subscription points to. Corresponds to the JSON property totalItemCount

Returns:

  • (Fixnum)


6987
6988
6989
# File 'lib/google/apis/youtube_v3/classes.rb', line 6987

def total_item_count
  @total_item_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6994
6995
6996
6997
6998
# File 'lib/google/apis/youtube_v3/classes.rb', line 6994

def update!(**args)
  @activity_type = args[:activity_type] if args.key?(:activity_type)
  @new_item_count = args[:new_item_count] if args.key?(:new_item_count)
  @total_item_count = args[:total_item_count] if args.key?(:total_item_count)
end