Class: Google::Apis::YoutubeV3::SuperStickerMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperStickerMetadata

Returns a new instance of SuperStickerMetadata.



7645
7646
7647
# File 'lib/google/apis/youtube_v3/classes.rb', line 7645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

Internationalized alt text that describes the sticker image and any animation associated with it. Corresponds to the JSON property altText

Returns:

  • (String)


7632
7633
7634
# File 'lib/google/apis/youtube_v3/classes.rb', line 7632

def alt_text
  @alt_text
end

#alt_text_languageString

Specifies the localization language in which the alt text is returned. Corresponds to the JSON property altTextLanguage

Returns:

  • (String)


7637
7638
7639
# File 'lib/google/apis/youtube_v3/classes.rb', line 7637

def alt_text_language
  @alt_text_language
end

#sticker_idString

Unique identifier of the Super Sticker. This is a shorter form of the alt_text that includes pack name and a recognizable characteristic of the sticker. Corresponds to the JSON property stickerId

Returns:

  • (String)


7643
7644
7645
# File 'lib/google/apis/youtube_v3/classes.rb', line 7643

def sticker_id
  @sticker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7650
7651
7652
7653
7654
# File 'lib/google/apis/youtube_v3/classes.rb', line 7650

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @alt_text_language = args[:alt_text_language] if args.key?(:alt_text_language)
  @sticker_id = args[:sticker_id] if args.key?(:sticker_id)
end