Class: Google::Apis::YoutubeV3::ThirdPartyLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A third party account link resource represents a link between a YouTube account or a channel and an account on a third-party service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyLink

Returns a new instance of ThirdPartyLink.



7738
7739
7740
# File 'lib/google/apis/youtube_v3/classes.rb', line 7738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource Corresponds to the JSON property etag

Returns:

  • (String)


7712
7713
7714
# File 'lib/google/apis/youtube_v3/classes.rb', line 7712

def etag
  @etag
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# thirdPartyLink". Corresponds to the JSON property kind

Returns:

  • (String)


7718
7719
7720
# File 'lib/google/apis/youtube_v3/classes.rb', line 7718

def kind
  @kind
end

#linking_tokenString

The linking_token identifies a YouTube account and channel with which the third party account is linked. Corresponds to the JSON property linkingToken

Returns:

  • (String)


7724
7725
7726
# File 'lib/google/apis/youtube_v3/classes.rb', line 7724

def linking_token
  @linking_token
end

#snippetGoogle::Apis::YoutubeV3::ThirdPartyLinkSnippet

Basic information about a third party account link, including its type and type-specific information. Corresponds to the JSON property snippet



7730
7731
7732
# File 'lib/google/apis/youtube_v3/classes.rb', line 7730

def snippet
  @snippet
end

#statusGoogle::Apis::YoutubeV3::ThirdPartyLinkStatus

The third-party link status object contains information about the status of the link. Corresponds to the JSON property status



7736
7737
7738
# File 'lib/google/apis/youtube_v3/classes.rb', line 7736

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7743
7744
7745
7746
7747
7748
7749
# File 'lib/google/apis/youtube_v3/classes.rb', line 7743

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @linking_token = args[:linking_token] if args.key?(:linking_token)
  @snippet = args[:snippet] if args.key?(:snippet)
  @status = args[:status] if args.key?(:status)
end