Class: Google::Apis::YoutubeV3::ThirdPartyLinkSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic information about a third party account link, including its type and type-specific information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyLinkSnippet

Returns a new instance of ThirdPartyLinkSnippet.



7810
7811
7812
# File 'lib/google/apis/youtube_v3/classes.rb', line 7810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Information specific to a creator in an affiliate program linked to a YouTube channel. Corresponds to the JSON property channelToAffiliateProgramLink



7797
7798
7799
# File 'lib/google/apis/youtube_v3/classes.rb', line 7797

def channel_to_affiliate_program_link
  @channel_to_affiliate_program_link
end

Information specific to a store on a merchandising platform linked to a YouTube channel. Corresponds to the JSON property channelToStoreLink



7803
7804
7805
# File 'lib/google/apis/youtube_v3/classes.rb', line 7803

def channel_to_store_link
  @channel_to_store_link
end

#typeString

Type of the link named after the entities that are being linked. Corresponds to the JSON property type

Returns:

  • (String)


7808
7809
7810
# File 'lib/google/apis/youtube_v3/classes.rb', line 7808

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7815
7816
7817
7818
7819
# File 'lib/google/apis/youtube_v3/classes.rb', line 7815

def update!(**args)
  @channel_to_affiliate_program_link = args[:channel_to_affiliate_program_link] if args.key?(:channel_to_affiliate_program_link)
  @channel_to_store_link = args[:channel_to_store_link] if args.key?(:channel_to_store_link)
  @type = args[:type] if args.key?(:type)
end