Class: Google::Apis::YoutubeV3::VideoAbuseReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAbuseReport

Returns a new instance of VideoAbuseReport.



8154
8155
8156
# File 'lib/google/apis/youtube_v3/classes.rb', line 8154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentsString

Additional comments regarding the abuse report. Corresponds to the JSON property comments

Returns:

  • (String)


8129
8130
8131
# File 'lib/google/apis/youtube_v3/classes.rb', line 8129

def comments
  @comments
end

#languageString

The language that the content was viewed in. Corresponds to the JSON property language

Returns:

  • (String)


8134
8135
8136
# File 'lib/google/apis/youtube_v3/classes.rb', line 8134

def language
  @language
end

#reason_idString

The high-level, or primary, reason that the content is abusive. The value is an abuse report reason ID. Corresponds to the JSON property reasonId

Returns:

  • (String)


8140
8141
8142
# File 'lib/google/apis/youtube_v3/classes.rb', line 8140

def reason_id
  @reason_id
end

#secondary_reason_idString

The specific, or secondary, reason that this content is abusive (if available). The value is an abuse report reason ID that is a valid secondary reason for the primary reason. Corresponds to the JSON property secondaryReasonId

Returns:

  • (String)


8147
8148
8149
# File 'lib/google/apis/youtube_v3/classes.rb', line 8147

def secondary_reason_id
  @secondary_reason_id
end

#video_idString

The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property videoId

Returns:

  • (String)


8152
8153
8154
# File 'lib/google/apis/youtube_v3/classes.rb', line 8152

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8159
8160
8161
8162
8163
8164
8165
# File 'lib/google/apis/youtube_v3/classes.rb', line 8159

def update!(**args)
  @comments = args[:comments] if args.key?(:comments)
  @language = args[:language] if args.key?(:language)
  @reason_id = args[:reason_id] if args.key?(:reason_id)
  @secondary_reason_id = args[:secondary_reason_id] if args.key?(:secondary_reason_id)
  @video_id = args[:video_id] if args.key?(:video_id)
end