Class: Google::Apis::YoutubeV3::VideoAbuseReportReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A __videoAbuseReportReason__ resource identifies a reason that a video could be reported as abusive. Video abuse report reasons are used with video. ReportAbuse.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAbuseReportReason

Returns a new instance of VideoAbuseReportReason.



8056
8057
8058
# File 'lib/google/apis/youtube_v3/classes.rb', line 8056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


8038
8039
8040
# File 'lib/google/apis/youtube_v3/classes.rb', line 8038

def etag
  @etag
end

#idString

The ID of this abuse report reason. Corresponds to the JSON property id

Returns:

  • (String)


8043
8044
8045
# File 'lib/google/apis/youtube_v3/classes.rb', line 8043

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# videoAbuseReportReason". Corresponds to the JSON property kind

Returns:

  • (String)


8049
8050
8051
# File 'lib/google/apis/youtube_v3/classes.rb', line 8049

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::VideoAbuseReportReasonSnippet

Basic details about a video category, such as its localized title. Corresponds to the JSON property snippet



8054
8055
8056
# File 'lib/google/apis/youtube_v3/classes.rb', line 8054

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8061
8062
8063
8064
8065
8066
# File 'lib/google/apis/youtube_v3/classes.rb', line 8061

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end