Class: Google::Apis::YoutubeV3::VideoAbuseReportReasonSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video category, such as its localized title.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAbuseReportReasonSnippet

Returns a new instance of VideoAbuseReportReasonSnippet.



8128
8129
8130
# File 'lib/google/apis/youtube_v3/classes.rb', line 8128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

The localized label belonging to this abuse report reason. Corresponds to the JSON property label

Returns:

  • (String)


8120
8121
8122
# File 'lib/google/apis/youtube_v3/classes.rb', line 8120

def label
  @label
end

#secondary_reasonsArray<Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason>

The secondary reasons associated with this reason, if any are available. ( There might be 0 or more.) Corresponds to the JSON property secondaryReasons



8126
8127
8128
# File 'lib/google/apis/youtube_v3/classes.rb', line 8126

def secondary_reasons
  @secondary_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8133
8134
8135
8136
# File 'lib/google/apis/youtube_v3/classes.rb', line 8133

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @secondary_reasons = args[:secondary_reasons] if args.key?(:secondary_reasons)
end