Class: Google::Apis::YoutubeV3::VideoContentDetailsRegionRestriction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

DEPRECATED Region restriction of the video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoContentDetailsRegionRestriction

Returns a new instance of VideoContentDetailsRegionRestriction.



8616
8617
8618
# File 'lib/google/apis/youtube_v3/classes.rb', line 8616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowedArray<String>

A list of region codes that identify countries where the video is viewable. If this property is present and a country is not listed in its value, then the video is blocked from appearing in that country. If this property is present and contains an empty list, the video is blocked in all countries. Corresponds to the JSON property allowed

Returns:

  • (Array<String>)


8606
8607
8608
# File 'lib/google/apis/youtube_v3/classes.rb', line 8606

def allowed
  @allowed
end

#blockedArray<String>

A list of region codes that identify countries where the video is blocked. If this property is present and a country is not listed in its value, then the video is viewable in that country. If this property is present and contains an empty list, the video is viewable in all countries. Corresponds to the JSON property blocked

Returns:

  • (Array<String>)


8614
8615
8616
# File 'lib/google/apis/youtube_v3/classes.rb', line 8614

def blocked
  @blocked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8621
8622
8623
8624
# File 'lib/google/apis/youtube_v3/classes.rb', line 8621

def update!(**args)
  @allowed = args[:allowed] if args.key?(:allowed)
  @blocked = args[:blocked] if args.key?(:blocked)
end