Class: Google::Apis::YoutubeV3::VideoFileDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoFileDetails

Returns a new instance of VideoFileDetails.



8688
8689
8690
# File 'lib/google/apis/youtube_v3/classes.rb', line 8688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>

A list of audio streams contained in the uploaded video file. Each item in the list contains detailed metadata about an audio stream. Corresponds to the JSON property audioStreams



8637
8638
8639
# File 'lib/google/apis/youtube_v3/classes.rb', line 8637

def audio_streams
  @audio_streams
end

#bitrate_bpsFixnum

The uploaded video file's combined (video and audio) bitrate in bits per second. Corresponds to the JSON property bitrateBps

Returns:

  • (Fixnum)


8643
8644
8645
# File 'lib/google/apis/youtube_v3/classes.rb', line 8643

def bitrate_bps
  @bitrate_bps
end

#containerString

The uploaded video file's container format. Corresponds to the JSON property container

Returns:

  • (String)


8648
8649
8650
# File 'lib/google/apis/youtube_v3/classes.rb', line 8648

def container
  @container
end

#creation_timeString

The date and time when the uploaded video file was created. The value is specified in ISO 8601 format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD - Naive time: YYYY-MM-DDTHH:MM:SS - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM Corresponds to the JSON property creationTime

Returns:

  • (String)


8656
8657
8658
# File 'lib/google/apis/youtube_v3/classes.rb', line 8656

def creation_time
  @creation_time
end

#duration_msFixnum

The length of the uploaded video in milliseconds. Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


8661
8662
8663
# File 'lib/google/apis/youtube_v3/classes.rb', line 8661

def duration_ms
  @duration_ms
end

#file_nameString

The uploaded file's name. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileName

Returns:

  • (String)


8667
8668
8669
# File 'lib/google/apis/youtube_v3/classes.rb', line 8667

def file_name
  @file_name
end

#file_sizeFixnum

The uploaded file's size in bytes. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


8673
8674
8675
# File 'lib/google/apis/youtube_v3/classes.rb', line 8673

def file_size
  @file_size
end

#file_typeString

The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube only processes video files, but this field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileType

Returns:

  • (String)


8680
8681
8682
# File 'lib/google/apis/youtube_v3/classes.rb', line 8680

def file_type
  @file_type
end

#video_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>

A list of video streams contained in the uploaded video file. Each item in the list contains detailed metadata about a video stream. Corresponds to the JSON property videoStreams



8686
8687
8688
# File 'lib/google/apis/youtube_v3/classes.rb', line 8686

def video_streams
  @video_streams
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8693
8694
8695
8696
8697
8698
8699
8700
8701
8702
8703
# File 'lib/google/apis/youtube_v3/classes.rb', line 8693

def update!(**args)
  @audio_streams = args[:audio_streams] if args.key?(:audio_streams)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @container = args[:container] if args.key?(:container)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @file_name = args[:file_name] if args.key?(:file_name)
  @file_size = args[:file_size] if args.key?(:file_size)
  @file_type = args[:file_type] if args.key?(:file_type)
  @video_streams = args[:video_streams] if args.key?(:video_streams)
end