Class: Google::Apis::YoutubeV3::VideoFileDetailsAudioStream
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoFileDetailsAudioStream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Information about an audio stream.
Instance Attribute Summary collapse
-
#bitrate_bps ⇒ Fixnum
The audio stream's bitrate, in bits per second.
-
#channel_count ⇒ Fixnum
The number of audio channels that the stream contains.
-
#codec ⇒ String
The audio codec that the stream uses.
-
#vendor ⇒ String
A value that uniquely identifies a video vendor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFileDetailsAudioStream
constructor
A new instance of VideoFileDetailsAudioStream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFileDetailsAudioStream
Returns a new instance of VideoFileDetailsAudioStream.
8707 8708 8709 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8707 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bitrate_bps ⇒ Fixnum
The audio stream's bitrate, in bits per second.
Corresponds to the JSON property bitrateBps
8689 8690 8691 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8689 def bitrate_bps @bitrate_bps end |
#channel_count ⇒ Fixnum
The number of audio channels that the stream contains.
Corresponds to the JSON property channelCount
8694 8695 8696 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8694 def channel_count @channel_count end |
#codec ⇒ String
The audio codec that the stream uses.
Corresponds to the JSON property codec
8699 8700 8701 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8699 def codec @codec end |
#vendor ⇒ String
A value that uniquely identifies a video vendor. Typically, the value is a
four-letter vendor code.
Corresponds to the JSON property vendor
8705 8706 8707 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8705 def vendor @vendor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8712 8713 8714 8715 8716 8717 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8712 def update!(**args) @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps) @channel_count = args[:channel_count] if args.key?(:channel_count) @codec = args[:codec] if args.key?(:codec) @vendor = args[:vendor] if args.key?(:vendor) end |