Class: Google::Apis::YoutubeV3::VideoFileDetailsVideoStream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information about a video stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoFileDetailsVideoStream

Returns a new instance of VideoFileDetailsVideoStream.



8768
8769
8770
# File 'lib/google/apis/youtube_v3/classes.rb', line 8768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioFloat

The video content's display aspect ratio, which specifies the aspect ratio in which the video should be displayed. Corresponds to the JSON property aspectRatio

Returns:

  • (Float)


8728
8729
8730
# File 'lib/google/apis/youtube_v3/classes.rb', line 8728

def aspect_ratio
  @aspect_ratio
end

#bitrate_bpsFixnum

The video stream's bitrate, in bits per second. Corresponds to the JSON property bitrateBps

Returns:

  • (Fixnum)


8733
8734
8735
# File 'lib/google/apis/youtube_v3/classes.rb', line 8733

def bitrate_bps
  @bitrate_bps
end

#codecString

The video codec that the stream uses. Corresponds to the JSON property codec

Returns:

  • (String)


8738
8739
8740
# File 'lib/google/apis/youtube_v3/classes.rb', line 8738

def codec
  @codec
end

#frame_rate_fpsFloat

The video stream's frame rate, in frames per second. Corresponds to the JSON property frameRateFps

Returns:

  • (Float)


8743
8744
8745
# File 'lib/google/apis/youtube_v3/classes.rb', line 8743

def frame_rate_fps
  @frame_rate_fps
end

#height_pixelsFixnum

The encoded video content's height in pixels. Corresponds to the JSON property heightPixels

Returns:

  • (Fixnum)


8748
8749
8750
# File 'lib/google/apis/youtube_v3/classes.rb', line 8748

def height_pixels
  @height_pixels
end

#rotationString

The amount that YouTube needs to rotate the original source content to properly display the video. Corresponds to the JSON property rotation

Returns:

  • (String)


8754
8755
8756
# File 'lib/google/apis/youtube_v3/classes.rb', line 8754

def rotation
  @rotation
end

#vendorString

A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor code. Corresponds to the JSON property vendor

Returns:

  • (String)


8760
8761
8762
# File 'lib/google/apis/youtube_v3/classes.rb', line 8760

def vendor
  @vendor
end

#width_pixelsFixnum

The encoded video content's width in pixels. You can calculate the video's encoding aspect ratio as width_pixels / height_pixels. Corresponds to the JSON property widthPixels

Returns:

  • (Fixnum)


8766
8767
8768
# File 'lib/google/apis/youtube_v3/classes.rb', line 8766

def width_pixels
  @width_pixels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8773
8774
8775
8776
8777
8778
8779
8780
8781
8782
# File 'lib/google/apis/youtube_v3/classes.rb', line 8773

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @codec = args[:codec] if args.key?(:codec)
  @frame_rate_fps = args[:frame_rate_fps] if args.key?(:frame_rate_fps)
  @height_pixels = args[:height_pixels] if args.key?(:height_pixels)
  @rotation = args[:rotation] if args.key?(:rotation)
  @vendor = args[:vendor] if args.key?(:vendor)
  @width_pixels = args[:width_pixels] if args.key?(:width_pixels)
end