Class: Google::Apis::YoutubeV3::VideoRecordingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Recording information associated with the video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoRecordingDetails

Returns a new instance of VideoRecordingDetails.



9066
9067
9068
# File 'lib/google/apis/youtube_v3/classes.rb', line 9066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::YoutubeV3::GeoPoint

Geographical coordinates of a point, in WGS84. Corresponds to the JSON property location



9054
9055
9056
# File 'lib/google/apis/youtube_v3/classes.rb', line 9054

def location
  @location
end

#location_descriptionString

The text description of the location where the video was recorded. Corresponds to the JSON property locationDescription

Returns:

  • (String)


9059
9060
9061
# File 'lib/google/apis/youtube_v3/classes.rb', line 9059

def location_description
  @location_description
end

#recording_dateDateTime

The date and time when the video was recorded. Corresponds to the JSON property recordingDate

Returns:

  • (DateTime)


9064
9065
9066
# File 'lib/google/apis/youtube_v3/classes.rb', line 9064

def recording_date
  @recording_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9071
9072
9073
9074
9075
# File 'lib/google/apis/youtube_v3/classes.rb', line 9071

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @location_description = args[:location_description] if args.key?(:location_description)
  @recording_date = args[:recording_date] if args.key?(:recording_date)
end