Class: Google::Apis::YoutubeV3::VideoStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about the video, such as the number of times the video was viewed or liked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatistics

Returns a new instance of VideoStatistics.



9428
9429
9430
# File 'lib/google/apis/youtube_v3/classes.rb', line 9428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comment_countFixnum

The number of comments for the video. Corresponds to the JSON property commentCount

Returns:

  • (Fixnum)


9404
9405
9406
# File 'lib/google/apis/youtube_v3/classes.rb', line 9404

def comment_count
  @comment_count
end

#dislike_countFixnum

The number of users who have indicated that they disliked the video by giving it a negative rating. Corresponds to the JSON property dislikeCount

Returns:

  • (Fixnum)


9410
9411
9412
# File 'lib/google/apis/youtube_v3/classes.rb', line 9410

def dislike_count
  @dislike_count
end

#favorite_countFixnum

The number of users who currently have the video marked as a favorite video. Corresponds to the JSON property favoriteCount

Returns:

  • (Fixnum)


9415
9416
9417
# File 'lib/google/apis/youtube_v3/classes.rb', line 9415

def favorite_count
  @favorite_count
end

#like_countFixnum

The number of users who have indicated that they liked the video by giving it a positive rating. Corresponds to the JSON property likeCount

Returns:

  • (Fixnum)


9421
9422
9423
# File 'lib/google/apis/youtube_v3/classes.rb', line 9421

def like_count
  @like_count
end

#view_countFixnum

The number of times the video has been viewed. Corresponds to the JSON property viewCount

Returns:

  • (Fixnum)


9426
9427
9428
# File 'lib/google/apis/youtube_v3/classes.rb', line 9426

def view_count
  @view_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9433
9434
9435
9436
9437
9438
9439
# File 'lib/google/apis/youtube_v3/classes.rb', line 9433

def update!(**args)
  @comment_count = args[:comment_count] if args.key?(:comment_count)
  @dislike_count = args[:dislike_count] if args.key?(:dislike_count)
  @favorite_count = args[:favorite_count] if args.key?(:favorite_count)
  @like_count = args[:like_count] if args.key?(:like_count)
  @view_count = args[:view_count] if args.key?(:view_count)
end