Class: Google::Apis::YoutubeV3::VideoStatsStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about the video, such as the number of times the video was viewed or liked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatsStatistics

Returns a new instance of VideoStatsStatistics.



9507
9508
9509
# File 'lib/google/apis/youtube_v3/classes.rb', line 9507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comment_countFixnum

Output only. The number of comments for the video. Corresponds to the JSON property commentCount

Returns:

  • (Fixnum)


9494
9495
9496
# File 'lib/google/apis/youtube_v3/classes.rb', line 9494

def comment_count
  @comment_count
end

#like_countFixnum

Output only. The number of users who have indicated that they liked the video by giving it a positive rating. Corresponds to the JSON property likeCount

Returns:

  • (Fixnum)


9500
9501
9502
# File 'lib/google/apis/youtube_v3/classes.rb', line 9500

def like_count
  @like_count
end

#view_countFixnum

Output only. The number of times the video has been viewed. Corresponds to the JSON property viewCount

Returns:

  • (Fixnum)


9505
9506
9507
# File 'lib/google/apis/youtube_v3/classes.rb', line 9505

def view_count
  @view_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9512
9513
9514
9515
9516
# File 'lib/google/apis/youtube_v3/classes.rb', line 9512

def update!(**args)
  @comment_count = args[:comment_count] if args.key?(:comment_count)
  @like_count = args[:like_count] if args.key?(:like_count)
  @view_count = args[:view_count] if args.key?(:view_count)
end