Class: Google::Apis::YoutubeV3::VideoTrainability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Specifies who is allowed to train on the video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoTrainability

Returns a new instance of VideoTrainability.



9782
9783
9784
# File 'lib/google/apis/youtube_v3/classes.rb', line 9782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


9763
9764
9765
# File 'lib/google/apis/youtube_v3/classes.rb', line 9763

def etag
  @etag
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# videoTrainability". Corresponds to the JSON property kind

Returns:

  • (String)


9769
9770
9771
# File 'lib/google/apis/youtube_v3/classes.rb', line 9769

def kind
  @kind
end

#permittedArray<String>

Specifies who is allowed to train on the video. Valid values are: - a single string "all" - a single string "none" - a list of allowed parties Corresponds to the JSON property permitted

Returns:

  • (Array<String>)


9775
9776
9777
# File 'lib/google/apis/youtube_v3/classes.rb', line 9775

def permitted
  @permitted
end

#video_idString

The ID of the video. Corresponds to the JSON property videoId

Returns:

  • (String)


9780
9781
9782
# File 'lib/google/apis/youtube_v3/classes.rb', line 9780

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9787
9788
9789
9790
9791
9792
# File 'lib/google/apis/youtube_v3/classes.rb', line 9787

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @permitted = args[:permitted] if args.key?(:permitted)
  @video_id = args[:video_id] if args.key?(:video_id)
end