Class: Google::Apis::YoutubeV3::Activity
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Activity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
An activity resource contains information about an action that a particular
channel, or user, has taken on YouTube. The actions reported in activity feeds
include sharing a video, uploading a video, and so forth. Each activity
resource identifies the type of action, the channel associated with the action,
and the resource(s) associated with the action, such as the video that was
rated or uploaded.
Instance Attribute Summary collapse
-
#content_details ⇒ Google::Apis::YoutubeV3::ActivityContentDetails
Details about the content of an activity: the video that was shared, the channel that was subscribed to, etc.
-
#etag ⇒ String
Etag of this resource Corresponds to the JSON property
etag. -
#id ⇒ String
The ID that YouTube uses to uniquely identify the activity.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::ActivitySnippet
Basic details about an activity, including title, description, thumbnails, activity type and group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Activity
constructor
A new instance of Activity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Activity
Returns a new instance of Activity.
146 147 148 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_details ⇒ Google::Apis::YoutubeV3::ActivityContentDetails
Details about the content of an activity: the video that was shared, the
channel that was subscribed to, etc.
Corresponds to the JSON property contentDetails
122 123 124 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 122 def content_details @content_details end |
#etag ⇒ String
Etag of this resource
Corresponds to the JSON property etag
127 128 129 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 127 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the activity.
Corresponds to the JSON property id
132 133 134 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 132 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: The fixed string "youtube#
activity".
Corresponds to the JSON property kind
138 139 140 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 138 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::ActivitySnippet
Basic details about an activity, including title, description, thumbnails,
activity type and group. Next ID: 12
Corresponds to the JSON property snippet
144 145 146 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 144 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
151 152 153 154 155 156 157 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 151 def update!(**args) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |