Class: Google::Apis::YoutubeV3::ActivityContentDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivityContentDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Details about the content of an activity: the video that was shared, the channel that was subscribed to, etc.
Instance Attribute Summary collapse
-
#bulletin ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsBulletin
Details about a channel bulletin post.
-
#channel_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsChannelItem
Details about a resource which was added to a channel.
-
#comment ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsComment
Information about a resource that received a comment.
-
#favorite ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsFavorite
Information about a video that was marked as a favorite video.
-
#like ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsLike
Information about a resource that received a positive (like) rating.
-
#playlist_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsPlaylistItem
Information about a new playlist item.
-
#promoted_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsPromotedItem
Details about a resource which is being promoted.
-
#recommendation ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsRecommendation
Information that identifies the recommended resource.
-
#social ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsSocial
Details about a social network post.
-
#subscription ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsSubscription
Information about a channel that a user subscribed to.
-
#upload ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsUpload
Information about the uploaded video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityContentDetails
constructor
A new instance of ActivityContentDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityContentDetails
Returns a new instance of ActivityContentDetails.
223 224 225 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bulletin ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsBulletin
Details about a channel bulletin post.
Corresponds to the JSON property bulletin
168 169 170 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 168 def bulletin @bulletin end |
#channel_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsChannelItem
Details about a resource which was added to a channel.
Corresponds to the JSON property channelItem
173 174 175 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 173 def channel_item @channel_item end |
#comment ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsComment
Information about a resource that received a comment.
Corresponds to the JSON property comment
178 179 180 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 178 def comment @comment end |
#favorite ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsFavorite
Information about a video that was marked as a favorite video. Deprecated:
This resource is no longer returned.
Corresponds to the JSON property favorite
184 185 186 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 184 def favorite @favorite end |
#like ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsLike
Information about a resource that received a positive (like) rating.
Deprecated: This resource is no longer returned.
Corresponds to the JSON property like
190 191 192 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 190 def like @like end |
#playlist_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsPlaylistItem
Information about a new playlist item.
Corresponds to the JSON property playlistItem
195 196 197 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 195 def playlist_item @playlist_item end |
#promoted_item ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsPromotedItem
Details about a resource which is being promoted.
Corresponds to the JSON property promotedItem
200 201 202 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 200 def promoted_item @promoted_item end |
#recommendation ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsRecommendation
Information that identifies the recommended resource.
Corresponds to the JSON property recommendation
205 206 207 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 205 def recommendation @recommendation end |
#social ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsSocial
Details about a social network post.
Corresponds to the JSON property social
210 211 212 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 210 def @social end |
#subscription ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsSubscription
Information about a channel that a user subscribed to. Deprecated: This
resource is no longer returned.
Corresponds to the JSON property subscription
216 217 218 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 216 def subscription @subscription end |
#upload ⇒ Google::Apis::YoutubeV3::ActivityContentDetailsUpload
Information about the uploaded video.
Corresponds to the JSON property upload
221 222 223 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 221 def upload @upload end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 228 def update!(**args) @bulletin = args[:bulletin] if args.key?(:bulletin) @channel_item = args[:channel_item] if args.key?(:channel_item) @comment = args[:comment] if args.key?(:comment) @favorite = args[:favorite] if args.key?(:favorite) @like = args[:like] if args.key?(:like) @playlist_item = args[:playlist_item] if args.key?(:playlist_item) @promoted_item = args[:promoted_item] if args.key?(:promoted_item) @recommendation = args[:recommendation] if args.key?(:recommendation) @social = args[:social] if args.key?(:social) @subscription = args[:subscription] if args.key?(:subscription) @upload = args[:upload] if args.key?(:upload) end |