Class: Google::Apis::YoutubeV3::ActivityContentDetailsRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivityContentDetailsRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Information that identifies the recommended resource.
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason that the resource is recommended to the user.
-
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
-
#seed_resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivityContentDetailsRecommendation
constructor
A new instance of ActivityContentDetailsRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivityContentDetailsRecommendation
Returns a new instance of ActivityContentDetailsRecommendation.
471 472 473 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reason ⇒ String
The reason that the resource is recommended to the user.
Corresponds to the JSON property reason
459 460 461 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 459 def reason @reason end |
#resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property resourceId
464 465 466 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 464 def resource_id @resource_id end |
#seed_resource_id ⇒ Google::Apis::YoutubeV3::ResourceId
A resource id is a generic reference that points to another YouTube resource.
Corresponds to the JSON property seedResourceId
469 470 471 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 469 def seed_resource_id @seed_resource_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
476 477 478 479 480 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 476 def update!(**args) @reason = args[:reason] if args.key?(:reason) @resource_id = args[:resource_id] if args.key?(:resource_id) @seed_resource_id = args[:seed_resource_id] if args.key?(:seed_resource_id) end |