Class: Google::Apis::YoutubeV3::ActivitySnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ActivitySnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about an activity, including title, description, thumbnails, activity type and group. Next ID: 12
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel associated with the activity.
-
#channel_title ⇒ String
Channel title for the channel responsible for this activity Corresponds to the JSON property
channelTitle. -
#description ⇒ String
The description of the resource primarily associated with the activity.
-
#group_id ⇒ String
The group ID associated with the activity.
-
#published_at ⇒ DateTime
The date and time that the video was uploaded.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The title of the resource primarily associated with the activity.
-
#type ⇒ String
The type of activity that the resource describes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActivitySnippet
constructor
A new instance of ActivitySnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActivitySnippet
Returns a new instance of ActivitySnippet.
687 688 689 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel associated with the
activity.
Corresponds to the JSON property channelId
645 646 647 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 645 def channel_id @channel_id end |
#channel_title ⇒ String
Channel title for the channel responsible for this activity
Corresponds to the JSON property channelTitle
650 651 652 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 650 def channel_title @channel_title end |
#description ⇒ String
The description of the resource primarily associated with the activity. @
mutable youtube.activities.insert
Corresponds to the JSON property description
656 657 658 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 656 def description @description end |
#group_id ⇒ String
The group ID associated with the activity. A group ID identifies user events
that are associated with the same user and resource. For example, if a user
uploads a video and watches the same video, the entries for those events would
have the same group ID in the user's activity feed. In your user interface,
you can avoid repetition by grouping events with the same groupId value.
Corresponds to the JSON property groupId
665 666 667 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 665 def group_id @group_id end |
#published_at ⇒ DateTime
The date and time that the video was uploaded.
Corresponds to the JSON property publishedAt
670 671 672 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 670 def published_at @published_at end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
675 676 677 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 675 def thumbnails @thumbnails end |
#title ⇒ String
The title of the resource primarily associated with the activity.
Corresponds to the JSON property title
680 681 682 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 680 def title @title end |
#type ⇒ String
The type of activity that the resource describes.
Corresponds to the JSON property type
685 686 687 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 685 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
692 693 694 695 696 697 698 699 700 701 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 692 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @channel_title = args[:channel_title] if args.key?(:channel_title) @description = args[:description] if args.key?(:description) @group_id = args[:group_id] if args.key?(:group_id) @published_at = args[:published_at] if args.key?(:published_at) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |