Class: Google::Apis::YoutubeV3::AvailabilityConfig
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::AvailabilityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Common proto for Live and VOD geo-restrictions
Instance Attribute Summary collapse
-
#global_config ⇒ Google::Apis::YoutubeV3::AvailabilityConfigGlobalConfig
Video is available in all regions except the ones specified in the excluded_region_codes list.
-
#regions_config ⇒ Google::Apis::YoutubeV3::AvailabilityConfigRegionsConfig
Video is available in the specified regions only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AvailabilityConfig
constructor
A new instance of AvailabilityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AvailabilityConfig
Returns a new instance of AvailabilityConfig.
715 716 717 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#global_config ⇒ Google::Apis::YoutubeV3::AvailabilityConfigGlobalConfig
Video is available in all regions except the ones specified in the
excluded_region_codes list.
Corresponds to the JSON property globalConfig
708 709 710 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 708 def global_config @global_config end |
#regions_config ⇒ Google::Apis::YoutubeV3::AvailabilityConfigRegionsConfig
Video is available in the specified regions only.
Corresponds to the JSON property regionsConfig
713 714 715 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 713 def regions_config @regions_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
720 721 722 723 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 720 def update!(**args) @global_config = args[:global_config] if args.key?(:global_config) @regions_config = args[:regions_config] if args.key?(:regions_config) end |