Class: Google::Apis::YoutubeV3::AvailabilityConfigGlobalConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Video is available in all regions except the ones specified in the excluded_region_codes list.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AvailabilityConfigGlobalConfig

Returns a new instance of AvailabilityConfigGlobalConfig.



744
745
746
# File 'lib/google/apis/youtube_v3/classes.rb', line 744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_region_codesArray<String>

Optional. Regions where video is blocked Corresponds to the JSON property excludedRegionCodes

Returns:

  • (Array<String>)


734
735
736
# File 'lib/google/apis/youtube_v3/classes.rb', line 734

def excluded_region_codes
  @excluded_region_codes
end

#intervalGoogle::Apis::YoutubeV3::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



742
743
744
# File 'lib/google/apis/youtube_v3/classes.rb', line 742

def interval
  @interval
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



749
750
751
752
# File 'lib/google/apis/youtube_v3/classes.rb', line 749

def update!(**args)
  @excluded_region_codes = args[:excluded_region_codes] if args.key?(:excluded_region_codes)
  @interval = args[:interval] if args.key?(:interval)
end