Class: Google::Apis::YoutubeV3::AvailabilityConfigRegionsConfigRegionInterval
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::AvailabilityConfigRegionsConfigRegionInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Region and time window where video is available for the region.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::YoutubeV3::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#region_code ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AvailabilityConfigRegionsConfigRegionInterval
constructor
A new instance of AvailabilityConfigRegionsConfigRegionInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AvailabilityConfigRegionsConfigRegionInterval
Returns a new instance of AvailabilityConfigRegionsConfigRegionInterval.
792 793 794 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::YoutubeV3::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
785 786 787 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 785 def interval @interval end |
#region_code ⇒ String
Required. Region where video is available
Corresponds to the JSON property regionCode
790 791 792 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 790 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
797 798 799 800 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 797 def update!(**args) @interval = args[:interval] if args.key?(:interval) @region_code = args[:region_code] if args.key?(:region_code) end |