Class: Google::Apis::YoutubeV3::BatchGetStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Response for the Videos.stats API. Returns VideoStat information about a batch of videos. VideoStat contains a subset of the information in Video that is relevant to statistics and content details. BatchGetStats is intentionally not atomic to provide a better user experience. BatchGetStatsResponse returns a summary to help users understand the outcome of the operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchGetStatsResponse

Returns a new instance of BatchGetStatsResponse.



724
725
726
# File 'lib/google/apis/youtube_v3/classes.rb', line 724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


711
712
713
# File 'lib/google/apis/youtube_v3/classes.rb', line 711

def etag
  @etag
end

#itemsArray<Google::Apis::YoutubeV3::VideoStat>

The videos' stats information. Corresponds to the JSON property items



716
717
718
# File 'lib/google/apis/youtube_v3/classes.rb', line 716

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# batchGetStatsResponse". Corresponds to the JSON property kind

Returns:

  • (String)


722
723
724
# File 'lib/google/apis/youtube_v3/classes.rb', line 722

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



729
730
731
732
733
# File 'lib/google/apis/youtube_v3/classes.rb', line 729

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end