Class: Google::Apis::YoutubeV3::BatchGetStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Response for the Videos.stats API. Returns VideoStat information about a batch of videos. VideoStat contains a subset of the information in Video that is relevant to statistics and content details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchGetStatsResponse

Returns a new instance of BatchGetStatsResponse.



722
723
724
# File 'lib/google/apis/youtube_v3/classes.rb', line 722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


709
710
711
# File 'lib/google/apis/youtube_v3/classes.rb', line 709

def etag
  @etag
end

#itemsArray<Google::Apis::YoutubeV3::VideoStat>

Output only. The videos' stats information. Corresponds to the JSON property items



714
715
716
# File 'lib/google/apis/youtube_v3/classes.rb', line 714

def items
  @items
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "youtube#batchGetStatsResponse". Corresponds to the JSON property kind

Returns:

  • (String)


720
721
722
# File 'lib/google/apis/youtube_v3/classes.rb', line 720

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



727
728
729
730
731
# File 'lib/google/apis/youtube_v3/classes.rb', line 727

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
end