Class: Google::Apis::YoutubeV3::CaptionSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a caption track, such as its language and name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CaptionSnippet

Returns a new instance of CaptionSnippet.



905
906
907
# File 'lib/google/apis/youtube_v3/classes.rb', line 905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_track_typeString

The type of audio track associated with the caption track. Corresponds to the JSON property audioTrackType

Returns:

  • (String)


824
825
826
# File 'lib/google/apis/youtube_v3/classes.rb', line 824

def audio_track_type
  @audio_track_type
end

#failure_reasonString

The reason that YouTube failed to process the caption track. This property is only present if the state property's value is failed. Corresponds to the JSON property failureReason

Returns:

  • (String)


830
831
832
# File 'lib/google/apis/youtube_v3/classes.rb', line 830

def failure_reason
  @failure_reason
end

#is_auto_syncedBoolean Also known as: is_auto_synced?

Indicates whether YouTube synchronized the caption track to the audio track in the video. The value will be true if a sync was explicitly requested when the caption track was uploaded. For example, when calling the captions.insert or captions.update methods, you can set the sync parameter to true to instruct YouTube to sync the uploaded track to the video. If the value is false, YouTube uses the time codes in the uploaded caption track to determine when to display captions. Corresponds to the JSON property isAutoSynced

Returns:

  • (Boolean)


841
842
843
# File 'lib/google/apis/youtube_v3/classes.rb', line 841

def is_auto_synced
  @is_auto_synced
end

#is_ccBoolean Also known as: is_cc?

Indicates whether the track contains closed captions for the deaf and hard of hearing. The default value is false. Corresponds to the JSON property isCC

Returns:

  • (Boolean)


848
849
850
# File 'lib/google/apis/youtube_v3/classes.rb', line 848

def is_cc
  @is_cc
end

#is_draftBoolean Also known as: is_draft?

Indicates whether the caption track is a draft. If the value is true, then the track is not publicly visible. The default value is false. @mutable youtube. captions.insert youtube.captions.update Corresponds to the JSON property isDraft

Returns:

  • (Boolean)


856
857
858
# File 'lib/google/apis/youtube_v3/classes.rb', line 856

def is_draft
  @is_draft
end

#is_easy_readerBoolean Also known as: is_easy_reader?

Indicates whether caption track is formatted for "easy reader," meaning it is at a third-grade level for language learners. The default value is false. Corresponds to the JSON property isEasyReader

Returns:

  • (Boolean)


863
864
865
# File 'lib/google/apis/youtube_v3/classes.rb', line 863

def is_easy_reader
  @is_easy_reader
end

#is_largeBoolean Also known as: is_large?

Indicates whether the caption track uses large text for the vision-impaired. The default value is false. Corresponds to the JSON property isLarge

Returns:

  • (Boolean)


870
871
872
# File 'lib/google/apis/youtube_v3/classes.rb', line 870

def is_large
  @is_large
end

#languageString

The language of the caption track. The property value is a BCP-47 language tag. Corresponds to the JSON property language

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/youtube_v3/classes.rb', line 876

def language
  @language
end

#last_updatedDateTime

The date and time when the caption track was last updated. Corresponds to the JSON property lastUpdated

Returns:

  • (DateTime)


881
882
883
# File 'lib/google/apis/youtube_v3/classes.rb', line 881

def last_updated
  @last_updated
end

#nameString

The name of the caption track. The name is intended to be visible to the user as an option during playback. Corresponds to the JSON property name

Returns:

  • (String)


887
888
889
# File 'lib/google/apis/youtube_v3/classes.rb', line 887

def name
  @name
end

#statusString

The caption track's status. Corresponds to the JSON property status

Returns:

  • (String)


892
893
894
# File 'lib/google/apis/youtube_v3/classes.rb', line 892

def status
  @status
end

#track_kindString

The caption track's type. Corresponds to the JSON property trackKind

Returns:

  • (String)


897
898
899
# File 'lib/google/apis/youtube_v3/classes.rb', line 897

def track_kind
  @track_kind
end

#video_idString

The ID that YouTube uses to uniquely identify the video associated with the caption track. @mutable youtube.captions.insert Corresponds to the JSON property videoId

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/youtube_v3/classes.rb', line 903

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
# File 'lib/google/apis/youtube_v3/classes.rb', line 910

def update!(**args)
  @audio_track_type = args[:audio_track_type] if args.key?(:audio_track_type)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @is_auto_synced = args[:is_auto_synced] if args.key?(:is_auto_synced)
  @is_cc = args[:is_cc] if args.key?(:is_cc)
  @is_draft = args[:is_draft] if args.key?(:is_draft)
  @is_easy_reader = args[:is_easy_reader] if args.key?(:is_easy_reader)
  @is_large = args[:is_large] if args.key?(:is_large)
  @language = args[:language] if args.key?(:language)
  @last_updated = args[:last_updated] if args.key?(:last_updated)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @track_kind = args[:track_kind] if args.key?(:track_kind)
  @video_id = args[:video_id] if args.key?(:video_id)
end