Class: Google::Apis::YoutubeV3::CdnSettings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::CdnSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Brief description of the live stream cdn settings.
Instance Attribute Summary collapse
-
#format ⇒ String
The format of the video stream that you are sending to Youtube.
-
#frame_rate ⇒ String
The frame rate of the inbound video data.
-
#ingestion_info ⇒ Google::Apis::YoutubeV3::IngestionInfo
Describes information necessary for ingesting an RTMP, HTTP, or SRT stream.
-
#ingestion_type ⇒ String
The method or protocol used to transmit the video stream.
-
#resolution ⇒ String
The resolution of the inbound video data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CdnSettings
constructor
A new instance of CdnSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CdnSettings
Returns a new instance of CdnSettings.
956 957 958 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#format ⇒ String
The format of the video stream that you are sending to Youtube.
Corresponds to the JSON property format
934 935 936 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 934 def format @format end |
#frame_rate ⇒ String
The frame rate of the inbound video data.
Corresponds to the JSON property frameRate
939 940 941 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 939 def frame_rate @frame_rate end |
#ingestion_info ⇒ Google::Apis::YoutubeV3::IngestionInfo
Describes information necessary for ingesting an RTMP, HTTP, or SRT stream.
Corresponds to the JSON property ingestionInfo
944 945 946 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 944 def ingestion_info @ingestion_info end |
#ingestion_type ⇒ String
The method or protocol used to transmit the video stream.
Corresponds to the JSON property ingestionType
949 950 951 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 949 def ingestion_type @ingestion_type end |
#resolution ⇒ String
The resolution of the inbound video data.
Corresponds to the JSON property resolution
954 955 956 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 954 def resolution @resolution end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
961 962 963 964 965 966 967 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 961 def update!(**args) @format = args[:format] if args.key?(:format) @frame_rate = args[:frame_rate] if args.key?(:frame_rate) @ingestion_info = args[:ingestion_info] if args.key?(:ingestion_info) @ingestion_type = args[:ingestion_type] if args.key?(:ingestion_type) @resolution = args[:resolution] if args.key?(:resolution) end |