Class: Google::Apis::YoutubeV3::Channel
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Channel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A channel resource contains information about a YouTube channel.
Instance Attribute Summary collapse
-
#audit_details ⇒ Google::Apis::YoutubeV3::ChannelAuditDetails
The auditDetails object encapsulates channel data that is relevant for YouTube Partners during the audit process.
-
#branding_settings ⇒ Google::Apis::YoutubeV3::ChannelBrandingSettings
Branding properties of a YouTube channel.
-
#content_details ⇒ Google::Apis::YoutubeV3::ChannelContentDetails
Details about the content of a channel.
-
#content_owner_details ⇒ Google::Apis::YoutubeV3::ChannelContentOwnerDetails
The contentOwnerDetails object encapsulates channel data that is relevant for YouTube Partners linked with the channel.
-
#conversion_pings ⇒ Google::Apis::YoutubeV3::ChannelConversionPings
The conversionPings object encapsulates information about conversion pings that need to be respected by the channel.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the channel.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::ChannelLocalization>
Localizations for different languages Corresponds to the JSON property
localizations. -
#snippet ⇒ Google::Apis::YoutubeV3::ChannelSnippet
Basic details about a channel, including title, description and thumbnails.
-
#statistics ⇒ Google::Apis::YoutubeV3::ChannelStatistics
Statistics about a channel: number of subscribers, number of videos in the channel, etc.
-
#status ⇒ Google::Apis::YoutubeV3::ChannelStatus
JSON template for the status part of a channel.
-
#topic_details ⇒ Google::Apis::YoutubeV3::ChannelTopicDetails
Freebase topic information related to the channel.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Channel
constructor
A new instance of Channel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Channel
Returns a new instance of Channel.
1046 1047 1048 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_details ⇒ Google::Apis::YoutubeV3::ChannelAuditDetails
The auditDetails object encapsulates channel data that is relevant for YouTube
Partners during the audit process.
Corresponds to the JSON property auditDetails
980 981 982 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 980 def audit_details @audit_details end |
#branding_settings ⇒ Google::Apis::YoutubeV3::ChannelBrandingSettings
Branding properties of a YouTube channel.
Corresponds to the JSON property brandingSettings
985 986 987 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 985 def branding_settings @branding_settings end |
#content_details ⇒ Google::Apis::YoutubeV3::ChannelContentDetails
Details about the content of a channel.
Corresponds to the JSON property contentDetails
990 991 992 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 990 def content_details @content_details end |
#content_owner_details ⇒ Google::Apis::YoutubeV3::ChannelContentOwnerDetails
The contentOwnerDetails object encapsulates channel data that is relevant for
YouTube Partners linked with the channel.
Corresponds to the JSON property contentOwnerDetails
996 997 998 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 996 def content_owner_details @content_owner_details end |
#conversion_pings ⇒ Google::Apis::YoutubeV3::ChannelConversionPings
The conversionPings object encapsulates information about conversion pings
that need to be respected by the channel.
Corresponds to the JSON property conversionPings
1002 1003 1004 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1002 def conversion_pings @conversion_pings end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
1007 1008 1009 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1007 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the channel.
Corresponds to the JSON property id
1012 1013 1014 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1012 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
channel".
Corresponds to the JSON property kind
1018 1019 1020 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1018 def kind @kind end |
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::ChannelLocalization>
Localizations for different languages
Corresponds to the JSON property localizations
1023 1024 1025 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1023 def localizations @localizations end |
#snippet ⇒ Google::Apis::YoutubeV3::ChannelSnippet
Basic details about a channel, including title, description and thumbnails.
Corresponds to the JSON property snippet
1028 1029 1030 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1028 def snippet @snippet end |
#statistics ⇒ Google::Apis::YoutubeV3::ChannelStatistics
Statistics about a channel: number of subscribers, number of videos in the
channel, etc.
Corresponds to the JSON property statistics
1034 1035 1036 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1034 def statistics @statistics end |
#status ⇒ Google::Apis::YoutubeV3::ChannelStatus
JSON template for the status part of a channel.
Corresponds to the JSON property status
1039 1040 1041 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1039 def status @status end |
#topic_details ⇒ Google::Apis::YoutubeV3::ChannelTopicDetails
Freebase topic information related to the channel.
Corresponds to the JSON property topicDetails
1044 1045 1046 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1044 def topic_details @topic_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1051 def update!(**args) @audit_details = args[:audit_details] if args.key?(:audit_details) @branding_settings = args[:branding_settings] if args.key?(:branding_settings) @content_details = args[:content_details] if args.key?(:content_details) @content_owner_details = args[:content_owner_details] if args.key?(:content_owner_details) @conversion_pings = args[:conversion_pings] if args.key?(:conversion_pings) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @localizations = args[:localizations] if args.key?(:localizations) @snippet = args[:snippet] if args.key?(:snippet) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @topic_details = args[:topic_details] if args.key?(:topic_details) end |