Class: Google::Apis::YoutubeV3::ChannelAuditDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelAuditDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
The auditDetails object encapsulates channel data that is relevant for YouTube Partners during the audit process.
Instance Attribute Summary collapse
-
#community_guidelines_good_standing ⇒ Boolean
(also: #community_guidelines_good_standing?)
Whether or not the channel respects the community guidelines.
-
#content_id_claims_good_standing ⇒ Boolean
(also: #content_id_claims_good_standing?)
Whether or not the channel has any unresolved claims.
-
#copyright_strikes_good_standing ⇒ Boolean
(also: #copyright_strikes_good_standing?)
Whether or not the channel has any copyright strikes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelAuditDetails
constructor
A new instance of ChannelAuditDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelAuditDetails
Returns a new instance of ChannelAuditDetails.
1224 1225 1226 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#community_guidelines_good_standing ⇒ Boolean Also known as: community_guidelines_good_standing?
Whether or not the channel respects the community guidelines.
Corresponds to the JSON property communityGuidelinesGoodStanding
1209 1210 1211 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1209 def community_guidelines_good_standing @community_guidelines_good_standing end |
#content_id_claims_good_standing ⇒ Boolean Also known as: content_id_claims_good_standing?
Whether or not the channel has any unresolved claims.
Corresponds to the JSON property contentIdClaimsGoodStanding
1215 1216 1217 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1215 def content_id_claims_good_standing @content_id_claims_good_standing end |
#copyright_strikes_good_standing ⇒ Boolean Also known as: copyright_strikes_good_standing?
Whether or not the channel has any copyright strikes.
Corresponds to the JSON property copyrightStrikesGoodStanding
1221 1222 1223 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1221 def copyright_strikes_good_standing @copyright_strikes_good_standing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1229 1230 1231 1232 1233 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1229 def update!(**args) @community_guidelines_good_standing = args[:community_guidelines_good_standing] if args.key?(:community_guidelines_good_standing) @content_id_claims_good_standing = args[:content_id_claims_good_standing] if args.key?(:content_id_claims_good_standing) @copyright_strikes_good_standing = args[:copyright_strikes_good_standing] if args.key?(:copyright_strikes_good_standing) end |