Class: Google::Apis::YoutubeV3::ChannelAuditDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

The auditDetails object encapsulates channel data that is relevant for YouTube Partners during the audit process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelAuditDetails

Returns a new instance of ChannelAuditDetails.



1220
1221
1222
# File 'lib/google/apis/youtube_v3/classes.rb', line 1220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#community_guidelines_good_standingBoolean Also known as: community_guidelines_good_standing?

Whether or not the channel respects the community guidelines. Corresponds to the JSON property communityGuidelinesGoodStanding

Returns:

  • (Boolean)


1205
1206
1207
# File 'lib/google/apis/youtube_v3/classes.rb', line 1205

def community_guidelines_good_standing
  @community_guidelines_good_standing
end

#content_id_claims_good_standingBoolean Also known as: content_id_claims_good_standing?

Whether or not the channel has any unresolved claims. Corresponds to the JSON property contentIdClaimsGoodStanding

Returns:

  • (Boolean)


1211
1212
1213
# File 'lib/google/apis/youtube_v3/classes.rb', line 1211

def content_id_claims_good_standing
  @content_id_claims_good_standing
end

Whether or not the channel has any copyright strikes. Corresponds to the JSON property copyrightStrikesGoodStanding

Returns:

  • (Boolean)


1217
1218
1219
# File 'lib/google/apis/youtube_v3/classes.rb', line 1217

def copyright_strikes_good_standing
  @copyright_strikes_good_standing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1225
1226
1227
1228
1229
# File 'lib/google/apis/youtube_v3/classes.rb', line 1225

def update!(**args)
  @community_guidelines_good_standing = args[:community_guidelines_good_standing] if args.key?(:community_guidelines_good_standing)
  @content_id_claims_good_standing = args[:content_id_claims_good_standing] if args.key?(:content_id_claims_good_standing)
  @copyright_strikes_good_standing = args[:copyright_strikes_good_standing] if args.key?(:copyright_strikes_good_standing)
end