Class: Google::Apis::YoutubeV3::ChannelAuditDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

The auditDetails object encapsulates channel data that is relevant for YouTube Partners during the audit process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelAuditDetails

Returns a new instance of ChannelAuditDetails.



1089
1090
1091
# File 'lib/google/apis/youtube_v3/classes.rb', line 1089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#community_guidelines_good_standingBoolean Also known as: community_guidelines_good_standing?

Whether or not the channel respects the community guidelines. Corresponds to the JSON property communityGuidelinesGoodStanding

Returns:

  • (Boolean)


1074
1075
1076
# File 'lib/google/apis/youtube_v3/classes.rb', line 1074

def community_guidelines_good_standing
  @community_guidelines_good_standing
end

#content_id_claims_good_standingBoolean Also known as: content_id_claims_good_standing?

Whether or not the channel has any unresolved claims. Corresponds to the JSON property contentIdClaimsGoodStanding

Returns:

  • (Boolean)


1080
1081
1082
# File 'lib/google/apis/youtube_v3/classes.rb', line 1080

def content_id_claims_good_standing
  @content_id_claims_good_standing
end

Whether or not the channel has any copyright strikes. Corresponds to the JSON property copyrightStrikesGoodStanding

Returns:

  • (Boolean)


1086
1087
1088
# File 'lib/google/apis/youtube_v3/classes.rb', line 1086

def copyright_strikes_good_standing
  @copyright_strikes_good_standing
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1094
1095
1096
1097
1098
# File 'lib/google/apis/youtube_v3/classes.rb', line 1094

def update!(**args)
  @community_guidelines_good_standing = args[:community_guidelines_good_standing] if args.key?(:community_guidelines_good_standing)
  @content_id_claims_good_standing = args[:content_id_claims_good_standing] if args.key?(:content_id_claims_good_standing)
  @copyright_strikes_good_standing = args[:copyright_strikes_good_standing] if args.key?(:copyright_strikes_good_standing)
end