Class: Google::Apis::YoutubeV3::ChannelContentDetails::RelatedPlaylists

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelatedPlaylists

Returns a new instance of RelatedPlaylists.



1255
1256
1257
# File 'lib/google/apis/youtube_v3/classes.rb', line 1255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#favoritesString

The ID of the playlist that contains the channel"s favorite videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property favorites

Returns:

  • (String)


1225
1226
1227
# File 'lib/google/apis/youtube_v3/classes.rb', line 1225

def favorites
  @favorites
end

#likesString

The ID of the playlist that contains the channel"s liked videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property likes

Returns:

  • (String)


1232
1233
1234
# File 'lib/google/apis/youtube_v3/classes.rb', line 1232

def likes
  @likes
end

#uploadsString

The ID of the playlist that contains the channel"s uploaded videos. Use the videos.insert method to upload new videos and the videos.delete method to delete previously uploaded videos. Corresponds to the JSON property uploads

Returns:

  • (String)


1239
1240
1241
# File 'lib/google/apis/youtube_v3/classes.rb', line 1239

def uploads
  @uploads
end

#watch_historyString

The ID of the playlist that contains the channel"s watch history. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchHistory

Returns:

  • (String)


1246
1247
1248
# File 'lib/google/apis/youtube_v3/classes.rb', line 1246

def watch_history
  @watch_history
end

#watch_laterString

The ID of the playlist that contains the channel"s watch later playlist. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchLater

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/youtube_v3/classes.rb', line 1253

def watch_later
  @watch_later
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1260
1261
1262
1263
1264
1265
1266
# File 'lib/google/apis/youtube_v3/classes.rb', line 1260

def update!(**args)
  @favorites = args[:favorites] if args.key?(:favorites)
  @likes = args[:likes] if args.key?(:likes)
  @uploads = args[:uploads] if args.key?(:uploads)
  @watch_history = args[:watch_history] if args.key?(:watch_history)
  @watch_later = args[:watch_later] if args.key?(:watch_later)
end