Class: Google::Apis::YoutubeV3::ChannelContentDetails::RelatedPlaylists

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RelatedPlaylists

Returns a new instance of RelatedPlaylists.



1227
1228
1229
# File 'lib/google/apis/youtube_v3/classes.rb', line 1227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#favoritesString

The ID of the playlist that contains the channel"s favorite videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property favorites

Returns:

  • (String)


1197
1198
1199
# File 'lib/google/apis/youtube_v3/classes.rb', line 1197

def favorites
  @favorites
end

#likesString

The ID of the playlist that contains the channel"s liked videos. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property likes

Returns:

  • (String)


1204
1205
1206
# File 'lib/google/apis/youtube_v3/classes.rb', line 1204

def likes
  @likes
end

#uploadsString

The ID of the playlist that contains the channel"s uploaded videos. Use the videos.insert method to upload new videos and the videos.delete method to delete previously uploaded videos. Corresponds to the JSON property uploads

Returns:

  • (String)


1211
1212
1213
# File 'lib/google/apis/youtube_v3/classes.rb', line 1211

def uploads
  @uploads
end

#watch_historyString

The ID of the playlist that contains the channel"s watch history. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchHistory

Returns:

  • (String)


1218
1219
1220
# File 'lib/google/apis/youtube_v3/classes.rb', line 1218

def watch_history
  @watch_history
end

#watch_laterString

The ID of the playlist that contains the channel"s watch later playlist. Use the playlistItems.insert and playlistItems.delete to add or remove items from that list. Corresponds to the JSON property watchLater

Returns:

  • (String)


1225
1226
1227
# File 'lib/google/apis/youtube_v3/classes.rb', line 1225

def watch_later
  @watch_later
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1232
1233
1234
1235
1236
1237
1238
# File 'lib/google/apis/youtube_v3/classes.rb', line 1232

def update!(**args)
  @favorites = args[:favorites] if args.key?(:favorites)
  @likes = args[:likes] if args.key?(:likes)
  @uploads = args[:uploads] if args.key?(:uploads)
  @watch_history = args[:watch_history] if args.key?(:watch_history)
  @watch_later = args[:watch_later] if args.key?(:watch_later)
end