Class: Google::Apis::YoutubeV3::ChannelContentOwnerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

The contentOwnerDetails object encapsulates channel data that is relevant for YouTube Partners linked with the channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelContentOwnerDetails

Returns a new instance of ChannelContentOwnerDetails.



1257
1258
1259
# File 'lib/google/apis/youtube_v3/classes.rb', line 1257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_ownerString

The ID of the content owner linked to the channel. Corresponds to the JSON property contentOwner

Returns:

  • (String)


1250
1251
1252
# File 'lib/google/apis/youtube_v3/classes.rb', line 1250

def content_owner
  @content_owner
end

#time_linkedDateTime

The date and time when the channel was linked to the content owner. Corresponds to the JSON property timeLinked

Returns:

  • (DateTime)


1255
1256
1257
# File 'lib/google/apis/youtube_v3/classes.rb', line 1255

def time_linked
  @time_linked
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1262
1263
1264
1265
# File 'lib/google/apis/youtube_v3/classes.rb', line 1262

def update!(**args)
  @content_owner = args[:content_owner] if args.key?(:content_owner)
  @time_linked = args[:time_linked] if args.key?(:time_linked)
end