Class: Google::Apis::YoutubeV3::ChannelConversionPing

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Pings that the app shall fire (authenticated by biscotti cookie). Each ping has a context, in which the app must fire the ping, and a url identifying the ping.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelConversionPing

Returns a new instance of ChannelConversionPing.



1289
1290
1291
# File 'lib/google/apis/youtube_v3/classes.rb', line 1289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextString

Defines the context of the ping. Corresponds to the JSON property context

Returns:

  • (String)


1277
1278
1279
# File 'lib/google/apis/youtube_v3/classes.rb', line 1277

def context
  @context
end

#conversion_urlString

The url (without the schema) that the player shall send the ping to. It's at caller's descretion to decide which schema to use (http vs https) Example of a returned url: //googleads.g.doubleclick.net/pagead/ viewthroughconversion/ 962985656/?data=path%3DtHe_path%3Btype%3D cview%3Butuid% 3DGISQtTNGYqaYl4sKxoVvKA&labe=default The caller must append biscotti authentication (ms param in case of mobile, for example) to this ping. Corresponds to the JSON property conversionUrl

Returns:

  • (String)


1287
1288
1289
# File 'lib/google/apis/youtube_v3/classes.rb', line 1287

def conversion_url
  @conversion_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1294
1295
1296
1297
# File 'lib/google/apis/youtube_v3/classes.rb', line 1294

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @conversion_url = args[:conversion_url] if args.key?(:conversion_url)
end