Class: Google::Apis::YoutubeV3::ChannelSectionSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelSectionSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a channel section, including title, style and position.
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that published the channel section.
-
#default_language ⇒ String
The language of the channel section's default title and description.
-
#localized ⇒ Google::Apis::YoutubeV3::ChannelSectionLocalization
ChannelSection localization setting Corresponds to the JSON property
localized. -
#position ⇒ Fixnum
The position of the channel section in the channel.
-
#style ⇒ String
The style of the channel section.
-
#title ⇒ String
The channel section's title for multiple_playlists and multiple_channels.
-
#type ⇒ String
The type of the channel section.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelSectionSnippet
constructor
A new instance of ChannelSectionSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelSectionSnippet
Returns a new instance of ChannelSectionSnippet.
1775 1776 1777 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1775 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that published the
channel section.
Corresponds to the JSON property channelId
1743 1744 1745 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1743 def channel_id @channel_id end |
#default_language ⇒ String
The language of the channel section's default title and description.
Corresponds to the JSON property defaultLanguage
1748 1749 1750 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1748 def default_language @default_language end |
#localized ⇒ Google::Apis::YoutubeV3::ChannelSectionLocalization
ChannelSection localization setting
Corresponds to the JSON property localized
1753 1754 1755 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1753 def localized @localized end |
#position ⇒ Fixnum
The position of the channel section in the channel.
Corresponds to the JSON property position
1758 1759 1760 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1758 def position @position end |
#style ⇒ String
The style of the channel section.
Corresponds to the JSON property style
1763 1764 1765 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1763 def style @style end |
#title ⇒ String
The channel section's title for multiple_playlists and multiple_channels.
Corresponds to the JSON property title
1768 1769 1770 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1768 def title @title end |
#type ⇒ String
The type of the channel section.
Corresponds to the JSON property type
1773 1774 1775 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1773 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1780 1781 1782 1783 1784 1785 1786 1787 1788 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1780 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @default_language = args[:default_language] if args.key?(:default_language) @localized = args[:localized] if args.key?(:localized) @position = args[:position] if args.key?(:position) @style = args[:style] if args.key?(:style) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |