Class: Google::Apis::YoutubeV3::ChannelSectionSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a channel section, including title, style and position.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSectionSnippet

Returns a new instance of ChannelSectionSnippet.



1640
1641
1642
# File 'lib/google/apis/youtube_v3/classes.rb', line 1640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the channel that published the channel section. Corresponds to the JSON property channelId

Returns:

  • (String)


1608
1609
1610
# File 'lib/google/apis/youtube_v3/classes.rb', line 1608

def channel_id
  @channel_id
end

#default_languageString

The language of the channel section's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1613
1614
1615
# File 'lib/google/apis/youtube_v3/classes.rb', line 1613

def default_language
  @default_language
end

#localizedGoogle::Apis::YoutubeV3::ChannelSectionLocalization

ChannelSection localization setting Corresponds to the JSON property localized



1618
1619
1620
# File 'lib/google/apis/youtube_v3/classes.rb', line 1618

def localized
  @localized
end

#positionFixnum

The position of the channel section in the channel. Corresponds to the JSON property position

Returns:

  • (Fixnum)


1623
1624
1625
# File 'lib/google/apis/youtube_v3/classes.rb', line 1623

def position
  @position
end

#styleString

The style of the channel section. Corresponds to the JSON property style

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/youtube_v3/classes.rb', line 1628

def style
  @style
end

#titleString

The channel section's title for multiple_playlists and multiple_channels. Corresponds to the JSON property title

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/youtube_v3/classes.rb', line 1633

def title
  @title
end

#typeString

The type of the channel section. Corresponds to the JSON property type

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/youtube_v3/classes.rb', line 1638

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1645
1646
1647
1648
1649
1650
1651
1652
1653
# File 'lib/google/apis/youtube_v3/classes.rb', line 1645

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @default_language = args[:default_language] if args.key?(:default_language)
  @localized = args[:localized] if args.key?(:localized)
  @position = args[:position] if args.key?(:position)
  @style = args[:style] if args.key?(:style)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
end