Class: Google::Apis::YoutubeV3::ChannelSettings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Branding properties for the channel view.
Instance Attribute Summary collapse
-
#country ⇒ String
The country of the channel.
-
#default_language ⇒ String
Corresponds to the JSON property
defaultLanguage. -
#default_tab ⇒ String
Which content tab users should see when viewing the channel.
-
#description ⇒ String
Specifies the channel description.
-
#featured_channels_title ⇒ String
Title for the featured channels tab.
-
#featured_channels_urls ⇒ Array<String>
The list of featured channels.
-
#keywords ⇒ String
Lists keywords associated with the channel, comma-separated.
-
#moderate_comments ⇒ Boolean
(also: #moderate_comments?)
Whether user-submitted comments left on the channel page need to be approved by the channel owner to be publicly visible.
-
#profile_color ⇒ String
A prominent color that can be rendered on this channel page.
-
#show_browse_view ⇒ Boolean
(also: #show_browse_view?)
Whether the tab to browse the videos should be displayed.
-
#show_related_channels ⇒ Boolean
(also: #show_related_channels?)
Whether related channels should be proposed.
-
#title ⇒ String
Specifies the channel title.
-
#tracking_analytics_account_id ⇒ String
The ID for a Google Analytics account to track and measure traffic to the channels.
-
#unsubscribed_trailer ⇒ String
The trailer of the channel, for users that are not subscribers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelSettings
constructor
A new instance of ChannelSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelSettings
Returns a new instance of ChannelSettings.
1901 1902 1903 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
The country of the channel.
Corresponds to the JSON property country
1829 1830 1831 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1829 def country @country end |
#default_language ⇒ String
Corresponds to the JSON property defaultLanguage
1834 1835 1836 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1834 def default_language @default_language end |
#default_tab ⇒ String
Which content tab users should see when viewing the channel.
Corresponds to the JSON property defaultTab
1839 1840 1841 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1839 def default_tab @default_tab end |
#description ⇒ String
Specifies the channel description.
Corresponds to the JSON property description
1844 1845 1846 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1844 def description @description end |
#featured_channels_title ⇒ String
Title for the featured channels tab.
Corresponds to the JSON property featuredChannelsTitle
1849 1850 1851 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1849 def featured_channels_title @featured_channels_title end |
#featured_channels_urls ⇒ Array<String>
The list of featured channels.
Corresponds to the JSON property featuredChannelsUrls
1854 1855 1856 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1854 def featured_channels_urls @featured_channels_urls end |
#keywords ⇒ String
Lists keywords associated with the channel, comma-separated.
Corresponds to the JSON property keywords
1859 1860 1861 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1859 def keywords @keywords end |
#moderate_comments ⇒ Boolean Also known as: moderate_comments?
Whether user-submitted comments left on the channel page need to be approved
by the channel owner to be publicly visible.
Corresponds to the JSON property moderateComments
1865 1866 1867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1865 def moderate_comments @moderate_comments end |
#profile_color ⇒ String
A prominent color that can be rendered on this channel page.
Corresponds to the JSON property profileColor
1871 1872 1873 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1871 def profile_color @profile_color end |
#show_browse_view ⇒ Boolean Also known as: show_browse_view?
Whether the tab to browse the videos should be displayed.
Corresponds to the JSON property showBrowseView
1876 1877 1878 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1876 def show_browse_view @show_browse_view end |
#show_related_channels ⇒ Boolean Also known as:
Whether related channels should be proposed.
Corresponds to the JSON property showRelatedChannels
1882 1883 1884 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1882 def @show_related_channels end |
#title ⇒ String
Specifies the channel title.
Corresponds to the JSON property title
1888 1889 1890 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1888 def title @title end |
#tracking_analytics_account_id ⇒ String
The ID for a Google Analytics account to track and measure traffic to the
channels.
Corresponds to the JSON property trackingAnalyticsAccountId
1894 1895 1896 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1894 def tracking_analytics_account_id @tracking_analytics_account_id end |
#unsubscribed_trailer ⇒ String
The trailer of the channel, for users that are not subscribers.
Corresponds to the JSON property unsubscribedTrailer
1899 1900 1901 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1899 def unsubscribed_trailer @unsubscribed_trailer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1906 def update!(**args) @country = args[:country] if args.key?(:country) @default_language = args[:default_language] if args.key?(:default_language) @default_tab = args[:default_tab] if args.key?(:default_tab) @description = args[:description] if args.key?(:description) @featured_channels_title = args[:featured_channels_title] if args.key?(:featured_channels_title) @featured_channels_urls = args[:featured_channels_urls] if args.key?(:featured_channels_urls) @keywords = args[:keywords] if args.key?(:keywords) @moderate_comments = args[:moderate_comments] if args.key?(:moderate_comments) @profile_color = args[:profile_color] if args.key?(:profile_color) @show_browse_view = args[:show_browse_view] if args.key?(:show_browse_view) @show_related_channels = args[:show_related_channels] if args.key?(:show_related_channels) @title = args[:title] if args.key?(:title) @tracking_analytics_account_id = args[:tracking_analytics_account_id] if args.key?(:tracking_analytics_account_id) @unsubscribed_trailer = args[:unsubscribed_trailer] if args.key?(:unsubscribed_trailer) end |