Class: Google::Apis::YoutubeV3::ChannelSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Branding properties for the channel view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSettings

Returns a new instance of ChannelSettings.



1897
1898
1899
# File 'lib/google/apis/youtube_v3/classes.rb', line 1897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The country of the channel. Corresponds to the JSON property country

Returns:

  • (String)


1825
1826
1827
# File 'lib/google/apis/youtube_v3/classes.rb', line 1825

def country
  @country
end

#default_languageString

Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1830
1831
1832
# File 'lib/google/apis/youtube_v3/classes.rb', line 1830

def default_language
  @default_language
end

#default_tabString

Which content tab users should see when viewing the channel. Corresponds to the JSON property defaultTab

Returns:

  • (String)


1835
1836
1837
# File 'lib/google/apis/youtube_v3/classes.rb', line 1835

def default_tab
  @default_tab
end

#descriptionString

Specifies the channel description. Corresponds to the JSON property description

Returns:

  • (String)


1840
1841
1842
# File 'lib/google/apis/youtube_v3/classes.rb', line 1840

def description
  @description
end

Title for the featured channels tab. Corresponds to the JSON property featuredChannelsTitle

Returns:

  • (String)


1845
1846
1847
# File 'lib/google/apis/youtube_v3/classes.rb', line 1845

def featured_channels_title
  @featured_channels_title
end

The list of featured channels. Corresponds to the JSON property featuredChannelsUrls

Returns:

  • (Array<String>)


1850
1851
1852
# File 'lib/google/apis/youtube_v3/classes.rb', line 1850

def featured_channels_urls
  @featured_channels_urls
end

#keywordsString

Lists keywords associated with the channel, comma-separated. Corresponds to the JSON property keywords

Returns:

  • (String)


1855
1856
1857
# File 'lib/google/apis/youtube_v3/classes.rb', line 1855

def keywords
  @keywords
end

#moderate_commentsBoolean Also known as: moderate_comments?

Whether user-submitted comments left on the channel page need to be approved by the channel owner to be publicly visible. Corresponds to the JSON property moderateComments

Returns:

  • (Boolean)


1861
1862
1863
# File 'lib/google/apis/youtube_v3/classes.rb', line 1861

def moderate_comments
  @moderate_comments
end

#profile_colorString

A prominent color that can be rendered on this channel page. Corresponds to the JSON property profileColor

Returns:

  • (String)


1867
1868
1869
# File 'lib/google/apis/youtube_v3/classes.rb', line 1867

def profile_color
  @profile_color
end

#show_browse_viewBoolean Also known as: show_browse_view?

Whether the tab to browse the videos should be displayed. Corresponds to the JSON property showBrowseView

Returns:

  • (Boolean)


1872
1873
1874
# File 'lib/google/apis/youtube_v3/classes.rb', line 1872

def show_browse_view
  @show_browse_view
end

Whether related channels should be proposed. Corresponds to the JSON property showRelatedChannels

Returns:

  • (Boolean)


1878
1879
1880
# File 'lib/google/apis/youtube_v3/classes.rb', line 1878

def show_related_channels
  @show_related_channels
end

#titleString

Specifies the channel title. Corresponds to the JSON property title

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/youtube_v3/classes.rb', line 1884

def title
  @title
end

#tracking_analytics_account_idString

The ID for a Google Analytics account to track and measure traffic to the channels. Corresponds to the JSON property trackingAnalyticsAccountId

Returns:

  • (String)


1890
1891
1892
# File 'lib/google/apis/youtube_v3/classes.rb', line 1890

def 
  @tracking_analytics_account_id
end

#unsubscribed_trailerString

The trailer of the channel, for users that are not subscribers. Corresponds to the JSON property unsubscribedTrailer

Returns:

  • (String)


1895
1896
1897
# File 'lib/google/apis/youtube_v3/classes.rb', line 1895

def unsubscribed_trailer
  @unsubscribed_trailer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
1912
1913
1914
1915
1916
1917
# File 'lib/google/apis/youtube_v3/classes.rb', line 1902

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @default_language = args[:default_language] if args.key?(:default_language)
  @default_tab = args[:default_tab] if args.key?(:default_tab)
  @description = args[:description] if args.key?(:description)
  @featured_channels_title = args[:featured_channels_title] if args.key?(:featured_channels_title)
  @featured_channels_urls = args[:featured_channels_urls] if args.key?(:featured_channels_urls)
  @keywords = args[:keywords] if args.key?(:keywords)
  @moderate_comments = args[:moderate_comments] if args.key?(:moderate_comments)
  @profile_color = args[:profile_color] if args.key?(:profile_color)
  @show_browse_view = args[:show_browse_view] if args.key?(:show_browse_view)
  @show_related_channels = args[:show_related_channels] if args.key?(:show_related_channels)
  @title = args[:title] if args.key?(:title)
  @tracking_analytics_account_id = args[:tracking_analytics_account_id] if args.key?(:tracking_analytics_account_id)
  @unsubscribed_trailer = args[:unsubscribed_trailer] if args.key?(:unsubscribed_trailer)
end