Class: Google::Apis::YoutubeV3::ChannelSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Branding properties for the channel view.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSettings

Returns a new instance of ChannelSettings.



1768
1769
1770
# File 'lib/google/apis/youtube_v3/classes.rb', line 1768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The country of the channel. Corresponds to the JSON property country

Returns:

  • (String)


1696
1697
1698
# File 'lib/google/apis/youtube_v3/classes.rb', line 1696

def country
  @country
end

#default_languageString

Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1701
1702
1703
# File 'lib/google/apis/youtube_v3/classes.rb', line 1701

def default_language
  @default_language
end

#default_tabString

Which content tab users should see when viewing the channel. Corresponds to the JSON property defaultTab

Returns:

  • (String)


1706
1707
1708
# File 'lib/google/apis/youtube_v3/classes.rb', line 1706

def default_tab
  @default_tab
end

#descriptionString

Specifies the channel description. Corresponds to the JSON property description

Returns:

  • (String)


1711
1712
1713
# File 'lib/google/apis/youtube_v3/classes.rb', line 1711

def description
  @description
end

Title for the featured channels tab. Corresponds to the JSON property featuredChannelsTitle

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/youtube_v3/classes.rb', line 1716

def featured_channels_title
  @featured_channels_title
end

The list of featured channels. Corresponds to the JSON property featuredChannelsUrls

Returns:

  • (Array<String>)


1721
1722
1723
# File 'lib/google/apis/youtube_v3/classes.rb', line 1721

def featured_channels_urls
  @featured_channels_urls
end

#keywordsString

Lists keywords associated with the channel, comma-separated. Corresponds to the JSON property keywords

Returns:

  • (String)


1726
1727
1728
# File 'lib/google/apis/youtube_v3/classes.rb', line 1726

def keywords
  @keywords
end

#moderate_commentsBoolean Also known as: moderate_comments?

Whether user-submitted comments left on the channel page need to be approved by the channel owner to be publicly visible. Corresponds to the JSON property moderateComments

Returns:

  • (Boolean)


1732
1733
1734
# File 'lib/google/apis/youtube_v3/classes.rb', line 1732

def moderate_comments
  @moderate_comments
end

#profile_colorString

A prominent color that can be rendered on this channel page. Corresponds to the JSON property profileColor

Returns:

  • (String)


1738
1739
1740
# File 'lib/google/apis/youtube_v3/classes.rb', line 1738

def profile_color
  @profile_color
end

#show_browse_viewBoolean Also known as: show_browse_view?

Whether the tab to browse the videos should be displayed. Corresponds to the JSON property showBrowseView

Returns:

  • (Boolean)


1743
1744
1745
# File 'lib/google/apis/youtube_v3/classes.rb', line 1743

def show_browse_view
  @show_browse_view
end

Whether related channels should be proposed. Corresponds to the JSON property showRelatedChannels

Returns:

  • (Boolean)


1749
1750
1751
# File 'lib/google/apis/youtube_v3/classes.rb', line 1749

def show_related_channels
  @show_related_channels
end

#titleString

Specifies the channel title. Corresponds to the JSON property title

Returns:

  • (String)


1755
1756
1757
# File 'lib/google/apis/youtube_v3/classes.rb', line 1755

def title
  @title
end

#tracking_analytics_account_idString

The ID for a Google Analytics account to track and measure traffic to the channels. Corresponds to the JSON property trackingAnalyticsAccountId

Returns:

  • (String)


1761
1762
1763
# File 'lib/google/apis/youtube_v3/classes.rb', line 1761

def 
  @tracking_analytics_account_id
end

#unsubscribed_trailerString

The trailer of the channel, for users that are not subscribers. Corresponds to the JSON property unsubscribedTrailer

Returns:

  • (String)


1766
1767
1768
# File 'lib/google/apis/youtube_v3/classes.rb', line 1766

def unsubscribed_trailer
  @unsubscribed_trailer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/google/apis/youtube_v3/classes.rb', line 1773

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @default_language = args[:default_language] if args.key?(:default_language)
  @default_tab = args[:default_tab] if args.key?(:default_tab)
  @description = args[:description] if args.key?(:description)
  @featured_channels_title = args[:featured_channels_title] if args.key?(:featured_channels_title)
  @featured_channels_urls = args[:featured_channels_urls] if args.key?(:featured_channels_urls)
  @keywords = args[:keywords] if args.key?(:keywords)
  @moderate_comments = args[:moderate_comments] if args.key?(:moderate_comments)
  @profile_color = args[:profile_color] if args.key?(:profile_color)
  @show_browse_view = args[:show_browse_view] if args.key?(:show_browse_view)
  @show_related_channels = args[:show_related_channels] if args.key?(:show_related_channels)
  @title = args[:title] if args.key?(:title)
  @tracking_analytics_account_id = args[:tracking_analytics_account_id] if args.key?(:tracking_analytics_account_id)
  @unsubscribed_trailer = args[:unsubscribed_trailer] if args.key?(:unsubscribed_trailer)
end