Class: Google::Apis::YoutubeV3::ChannelSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a channel, including title, description and thumbnails.
Instance Attribute Summary collapse
-
#country ⇒ String
The country of the channel.
-
#custom_url ⇒ String
The custom url of the channel.
-
#default_language ⇒ String
The language of the channel's default title and description.
-
#description ⇒ String
The description of the channel.
-
#localized ⇒ Google::Apis::YoutubeV3::ChannelLocalization
Channel localization setting Corresponds to the JSON property
localized. -
#published_at ⇒ DateTime
The date and time that the channel was created.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The channel's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelSnippet
constructor
A new instance of ChannelSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelSnippet
Returns a new instance of ChannelSnippet.
1968 1969 1970 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
The country of the channel.
Corresponds to the JSON property country
1931 1932 1933 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1931 def country @country end |
#custom_url ⇒ String
The custom url of the channel.
Corresponds to the JSON property customUrl
1936 1937 1938 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1936 def custom_url @custom_url end |
#default_language ⇒ String
The language of the channel's default title and description.
Corresponds to the JSON property defaultLanguage
1941 1942 1943 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1941 def default_language @default_language end |
#description ⇒ String
The description of the channel.
Corresponds to the JSON property description
1946 1947 1948 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1946 def description @description end |
#localized ⇒ Google::Apis::YoutubeV3::ChannelLocalization
Channel localization setting
Corresponds to the JSON property localized
1951 1952 1953 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1951 def localized @localized end |
#published_at ⇒ DateTime
The date and time that the channel was created.
Corresponds to the JSON property publishedAt
1956 1957 1958 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1956 def published_at @published_at end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
1961 1962 1963 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1961 def thumbnails @thumbnails end |
#title ⇒ String
The channel's title.
Corresponds to the JSON property title
1966 1967 1968 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1966 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1973 def update!(**args) @country = args[:country] if args.key?(:country) @custom_url = args[:custom_url] if args.key?(:custom_url) @default_language = args[:default_language] if args.key?(:default_language) @description = args[:description] if args.key?(:description) @localized = args[:localized] if args.key?(:localized) @published_at = args[:published_at] if args.key?(:published_at) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |