Class: Google::Apis::YoutubeV3::ChannelSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a channel, including title, description and thumbnails.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSnippet

Returns a new instance of ChannelSnippet.



1964
1965
1966
# File 'lib/google/apis/youtube_v3/classes.rb', line 1964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The country of the channel. Corresponds to the JSON property country

Returns:

  • (String)


1927
1928
1929
# File 'lib/google/apis/youtube_v3/classes.rb', line 1927

def country
  @country
end

#custom_urlString

The custom url of the channel. Corresponds to the JSON property customUrl

Returns:

  • (String)


1932
1933
1934
# File 'lib/google/apis/youtube_v3/classes.rb', line 1932

def custom_url
  @custom_url
end

#default_languageString

The language of the channel's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1937
1938
1939
# File 'lib/google/apis/youtube_v3/classes.rb', line 1937

def default_language
  @default_language
end

#descriptionString

The description of the channel. Corresponds to the JSON property description

Returns:

  • (String)


1942
1943
1944
# File 'lib/google/apis/youtube_v3/classes.rb', line 1942

def description
  @description
end

#localizedGoogle::Apis::YoutubeV3::ChannelLocalization

Channel localization setting Corresponds to the JSON property localized



1947
1948
1949
# File 'lib/google/apis/youtube_v3/classes.rb', line 1947

def localized
  @localized
end

#published_atDateTime

The date and time that the channel was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


1952
1953
1954
# File 'lib/google/apis/youtube_v3/classes.rb', line 1952

def published_at
  @published_at
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



1957
1958
1959
# File 'lib/google/apis/youtube_v3/classes.rb', line 1957

def thumbnails
  @thumbnails
end

#titleString

The channel's title. Corresponds to the JSON property title

Returns:

  • (String)


1962
1963
1964
# File 'lib/google/apis/youtube_v3/classes.rb', line 1962

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
# File 'lib/google/apis/youtube_v3/classes.rb', line 1969

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @custom_url = args[:custom_url] if args.key?(:custom_url)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end