Class: Google::Apis::YoutubeV3::ChannelSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a channel, including title, description and thumbnails.
Instance Attribute Summary collapse
-
#country ⇒ String
The country of the channel.
-
#custom_url ⇒ String
The custom url of the channel.
-
#default_language ⇒ String
The language of the channel's default title and description.
-
#description ⇒ String
The description of the channel.
-
#localized ⇒ Google::Apis::YoutubeV3::ChannelLocalization
Channel localization setting Corresponds to the JSON property
localized. -
#published_at ⇒ DateTime
The date and time that the channel was created.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The channel's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelSnippet
constructor
A new instance of ChannelSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelSnippet
Returns a new instance of ChannelSnippet.
1964 1965 1966 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
The country of the channel.
Corresponds to the JSON property country
1927 1928 1929 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1927 def country @country end |
#custom_url ⇒ String
The custom url of the channel.
Corresponds to the JSON property customUrl
1932 1933 1934 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1932 def custom_url @custom_url end |
#default_language ⇒ String
The language of the channel's default title and description.
Corresponds to the JSON property defaultLanguage
1937 1938 1939 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1937 def default_language @default_language end |
#description ⇒ String
The description of the channel.
Corresponds to the JSON property description
1942 1943 1944 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1942 def description @description end |
#localized ⇒ Google::Apis::YoutubeV3::ChannelLocalization
Channel localization setting
Corresponds to the JSON property localized
1947 1948 1949 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1947 def localized @localized end |
#published_at ⇒ DateTime
The date and time that the channel was created.
Corresponds to the JSON property publishedAt
1952 1953 1954 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1952 def published_at @published_at end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
1957 1958 1959 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1957 def thumbnails @thumbnails end |
#title ⇒ String
The channel's title.
Corresponds to the JSON property title
1962 1963 1964 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1962 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1969 def update!(**args) @country = args[:country] if args.key?(:country) @custom_url = args[:custom_url] if args.key?(:custom_url) @default_language = args[:default_language] if args.key?(:default_language) @description = args[:description] if args.key?(:description) @localized = args[:localized] if args.key?(:localized) @published_at = args[:published_at] if args.key?(:published_at) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |