Class: Google::Apis::YoutubeV3::ChannelSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a channel, including title, description and thumbnails.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelSnippet

Returns a new instance of ChannelSnippet.



1835
1836
1837
# File 'lib/google/apis/youtube_v3/classes.rb', line 1835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

The country of the channel. Corresponds to the JSON property country

Returns:

  • (String)


1798
1799
1800
# File 'lib/google/apis/youtube_v3/classes.rb', line 1798

def country
  @country
end

#custom_urlString

The custom url of the channel. Corresponds to the JSON property customUrl

Returns:

  • (String)


1803
1804
1805
# File 'lib/google/apis/youtube_v3/classes.rb', line 1803

def custom_url
  @custom_url
end

#default_languageString

The language of the channel's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


1808
1809
1810
# File 'lib/google/apis/youtube_v3/classes.rb', line 1808

def default_language
  @default_language
end

#descriptionString

The description of the channel. Corresponds to the JSON property description

Returns:

  • (String)


1813
1814
1815
# File 'lib/google/apis/youtube_v3/classes.rb', line 1813

def description
  @description
end

#localizedGoogle::Apis::YoutubeV3::ChannelLocalization

Channel localization setting Corresponds to the JSON property localized



1818
1819
1820
# File 'lib/google/apis/youtube_v3/classes.rb', line 1818

def localized
  @localized
end

#published_atDateTime

The date and time that the channel was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


1823
1824
1825
# File 'lib/google/apis/youtube_v3/classes.rb', line 1823

def published_at
  @published_at
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



1828
1829
1830
# File 'lib/google/apis/youtube_v3/classes.rb', line 1828

def thumbnails
  @thumbnails
end

#titleString

The channel's title. Corresponds to the JSON property title

Returns:

  • (String)


1833
1834
1835
# File 'lib/google/apis/youtube_v3/classes.rb', line 1833

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
# File 'lib/google/apis/youtube_v3/classes.rb', line 1840

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @custom_url = args[:custom_url] if args.key?(:custom_url)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end