Class: Google::Apis::YoutubeV3::ChannelStatistics
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Statistics about a channel: number of subscribers, number of videos in the channel, etc.
Instance Attribute Summary collapse
-
#comment_count ⇒ Fixnum
The number of comments for the channel.
-
#hidden_subscriber_count ⇒ Boolean
(also: #hidden_subscriber_count?)
Whether or not the number of subscribers is shown for this user.
-
#subscriber_count ⇒ Fixnum
The number of subscribers that the channel has.
-
#video_count ⇒ Fixnum
The number of videos uploaded to the channel.
-
#view_count ⇒ Fixnum
The number of times the channel has been viewed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelStatistics
constructor
A new instance of ChannelStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelStatistics
Returns a new instance of ChannelStatistics.
1883 1884 1885 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment_count ⇒ Fixnum
The number of comments for the channel.
Corresponds to the JSON property commentCount
1860 1861 1862 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1860 def comment_count @comment_count end |
#hidden_subscriber_count ⇒ Boolean Also known as:
Whether or not the number of subscribers is shown for this user.
Corresponds to the JSON property hiddenSubscriberCount
1865 1866 1867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1865 def hidden_subscriber_count @hidden_subscriber_count end |
#subscriber_count ⇒ Fixnum
The number of subscribers that the channel has.
Corresponds to the JSON property subscriberCount
1871 1872 1873 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1871 def subscriber_count @subscriber_count end |
#video_count ⇒ Fixnum
The number of videos uploaded to the channel.
Corresponds to the JSON property videoCount
1876 1877 1878 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1876 def video_count @video_count end |
#view_count ⇒ Fixnum
The number of times the channel has been viewed.
Corresponds to the JSON property viewCount
1881 1882 1883 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1881 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1888 def update!(**args) @comment_count = args[:comment_count] if args.key?(:comment_count) @hidden_subscriber_count = args[:hidden_subscriber_count] if args.key?(:hidden_subscriber_count) @subscriber_count = args[:subscriber_count] if args.key?(:subscriber_count) @video_count = args[:video_count] if args.key?(:video_count) @view_count = args[:view_count] if args.key?(:view_count) end |