Class: Google::Apis::YoutubeV3::ChannelStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about a channel: number of subscribers, number of videos in the channel, etc.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelStatistics

Returns a new instance of ChannelStatistics.



1881
1882
1883
# File 'lib/google/apis/youtube_v3/classes.rb', line 1881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comment_countFixnum

The number of comments for the channel. Corresponds to the JSON property commentCount

Returns:

  • (Fixnum)


1858
1859
1860
# File 'lib/google/apis/youtube_v3/classes.rb', line 1858

def comment_count
  @comment_count
end

#hidden_subscriber_countBoolean Also known as: hidden_subscriber_count?

Whether or not the number of subscribers is shown for this user. Corresponds to the JSON property hiddenSubscriberCount

Returns:

  • (Boolean)


1863
1864
1865
# File 'lib/google/apis/youtube_v3/classes.rb', line 1863

def hidden_subscriber_count
  @hidden_subscriber_count
end

#subscriber_countFixnum

The number of subscribers that the channel has. Corresponds to the JSON property subscriberCount

Returns:

  • (Fixnum)


1869
1870
1871
# File 'lib/google/apis/youtube_v3/classes.rb', line 1869

def subscriber_count
  @subscriber_count
end

#video_countFixnum

The number of videos uploaded to the channel. Corresponds to the JSON property videoCount

Returns:

  • (Fixnum)


1874
1875
1876
# File 'lib/google/apis/youtube_v3/classes.rb', line 1874

def video_count
  @video_count
end

#view_countFixnum

The number of times the channel has been viewed. Corresponds to the JSON property viewCount

Returns:

  • (Fixnum)


1879
1880
1881
# File 'lib/google/apis/youtube_v3/classes.rb', line 1879

def view_count
  @view_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1886
1887
1888
1889
1890
1891
1892
# File 'lib/google/apis/youtube_v3/classes.rb', line 1886

def update!(**args)
  @comment_count = args[:comment_count] if args.key?(:comment_count)
  @hidden_subscriber_count = args[:hidden_subscriber_count] if args.key?(:hidden_subscriber_count)
  @subscriber_count = args[:subscriber_count] if args.key?(:subscriber_count)
  @video_count = args[:video_count] if args.key?(:video_count)
  @view_count = args[:view_count] if args.key?(:view_count)
end