Class: Google::Apis::YoutubeV3::ChannelStatus
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ChannelStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
JSON template for the status part of a channel.
Instance Attribute Summary collapse
-
#is_channel_monetization_enabled ⇒ Boolean
(also: #is_channel_monetization_enabled?)
Whether the channel is considered ypp monetization enabled.
-
#is_linked ⇒ Boolean
(also: #is_linked?)
If true, then the user is linked to either a YouTube username or G+ account.
-
#long_uploads_status ⇒ String
The long uploads status of this channel.
-
#made_for_kids ⇒ Boolean
(also: #made_for_kids?)
Corresponds to the JSON property
madeForKids. -
#privacy_status ⇒ String
Privacy status of the channel.
-
#self_declared_made_for_kids ⇒ Boolean
(also: #self_declared_made_for_kids?)
Corresponds to the JSON property
selfDeclaredMadeForKids.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelStatus
constructor
A new instance of ChannelStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelStatus
Returns a new instance of ChannelStatus.
2071 2072 2073 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2071 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_channel_monetization_enabled ⇒ Boolean Also known as: is_channel_monetization_enabled?
Whether the channel is considered ypp monetization enabled. See go/yppornot
for more details.
Corresponds to the JSON property isChannelMonetizationEnabled
2038 2039 2040 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2038 def is_channel_monetization_enabled @is_channel_monetization_enabled end |
#is_linked ⇒ Boolean Also known as: is_linked?
If true, then the user is linked to either a YouTube username or G+ account.
Otherwise, the user doesn't have a public YouTube identity.
Corresponds to the JSON property isLinked
2045 2046 2047 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2045 def is_linked @is_linked end |
#long_uploads_status ⇒ String
The long uploads status of this channel. See https://support.google.com/
youtube/answer/71673 for more information.
Corresponds to the JSON property longUploadsStatus
2052 2053 2054 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2052 def long_uploads_status @long_uploads_status end |
#made_for_kids ⇒ Boolean Also known as: made_for_kids?
Corresponds to the JSON property madeForKids
2057 2058 2059 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2057 def made_for_kids @made_for_kids end |
#privacy_status ⇒ String
Privacy status of the channel.
Corresponds to the JSON property privacyStatus
2063 2064 2065 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2063 def privacy_status @privacy_status end |
#self_declared_made_for_kids ⇒ Boolean Also known as: self_declared_made_for_kids?
Corresponds to the JSON property selfDeclaredMadeForKids
2068 2069 2070 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2068 def self_declared_made_for_kids @self_declared_made_for_kids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2076 2077 2078 2079 2080 2081 2082 2083 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2076 def update!(**args) @is_channel_monetization_enabled = args[:is_channel_monetization_enabled] if args.key?(:is_channel_monetization_enabled) @is_linked = args[:is_linked] if args.key?(:is_linked) @long_uploads_status = args[:long_uploads_status] if args.key?(:long_uploads_status) @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids) @privacy_status = args[:privacy_status] if args.key?(:privacy_status) @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids) end |