Class: Google::Apis::YoutubeV3::ChannelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

JSON template for the status part of a channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelStatus

Returns a new instance of ChannelStatus.



1964
1965
1966
# File 'lib/google/apis/youtube_v3/classes.rb', line 1964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_channel_monetization_enabledBoolean Also known as: is_channel_monetization_enabled?

Whether the channel is considered ypp monetization enabled. See go/yppornot for more details. Corresponds to the JSON property isChannelMonetizationEnabled

Returns:

  • (Boolean)


1931
1932
1933
# File 'lib/google/apis/youtube_v3/classes.rb', line 1931

def is_channel_monetization_enabled
  @is_channel_monetization_enabled
end

#is_linkedBoolean Also known as: is_linked?

If true, then the user is linked to either a YouTube username or G+ account. Otherwise, the user doesn't have a public YouTube identity. Corresponds to the JSON property isLinked

Returns:

  • (Boolean)


1938
1939
1940
# File 'lib/google/apis/youtube_v3/classes.rb', line 1938

def is_linked
  @is_linked
end

#long_uploads_statusString

The long uploads status of this channel. See https://support.google.com/ youtube/answer/71673 for more information. Corresponds to the JSON property longUploadsStatus

Returns:

  • (String)


1945
1946
1947
# File 'lib/google/apis/youtube_v3/classes.rb', line 1945

def long_uploads_status
  @long_uploads_status
end

#made_for_kidsBoolean Also known as: made_for_kids?

Corresponds to the JSON property madeForKids

Returns:

  • (Boolean)


1950
1951
1952
# File 'lib/google/apis/youtube_v3/classes.rb', line 1950

def made_for_kids
  @made_for_kids
end

#privacy_statusString

Privacy status of the channel. Corresponds to the JSON property privacyStatus

Returns:

  • (String)


1956
1957
1958
# File 'lib/google/apis/youtube_v3/classes.rb', line 1956

def privacy_status
  @privacy_status
end

#self_declared_made_for_kidsBoolean Also known as: self_declared_made_for_kids?

Corresponds to the JSON property selfDeclaredMadeForKids

Returns:

  • (Boolean)


1961
1962
1963
# File 'lib/google/apis/youtube_v3/classes.rb', line 1961

def self_declared_made_for_kids
  @self_declared_made_for_kids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1969
1970
1971
1972
1973
1974
1975
1976
# File 'lib/google/apis/youtube_v3/classes.rb', line 1969

def update!(**args)
  @is_channel_monetization_enabled = args[:is_channel_monetization_enabled] if args.key?(:is_channel_monetization_enabled)
  @is_linked = args[:is_linked] if args.key?(:is_linked)
  @long_uploads_status = args[:long_uploads_status] if args.key?(:long_uploads_status)
  @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids)
  @privacy_status = args[:privacy_status] if args.key?(:privacy_status)
  @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids)
end