Class: Google::Apis::YoutubeV3::ChannelStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

JSON template for the status part of a channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelStatus

Returns a new instance of ChannelStatus.



1936
1937
1938
# File 'lib/google/apis/youtube_v3/classes.rb', line 1936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_channel_monetization_enabledBoolean Also known as: is_channel_monetization_enabled?

Whether the channel is considered ypp monetization enabled. See go/yppornot for more details. Corresponds to the JSON property isChannelMonetizationEnabled

Returns:

  • (Boolean)


1903
1904
1905
# File 'lib/google/apis/youtube_v3/classes.rb', line 1903

def is_channel_monetization_enabled
  @is_channel_monetization_enabled
end

#is_linkedBoolean Also known as: is_linked?

If true, then the user is linked to either a YouTube username or G+ account. Otherwise, the user doesn't have a public YouTube identity. Corresponds to the JSON property isLinked

Returns:

  • (Boolean)


1910
1911
1912
# File 'lib/google/apis/youtube_v3/classes.rb', line 1910

def is_linked
  @is_linked
end

#long_uploads_statusString

The long uploads status of this channel. See https://support.google.com/ youtube/answer/71673 for more information. Corresponds to the JSON property longUploadsStatus

Returns:

  • (String)


1917
1918
1919
# File 'lib/google/apis/youtube_v3/classes.rb', line 1917

def long_uploads_status
  @long_uploads_status
end

#made_for_kidsBoolean Also known as: made_for_kids?

Corresponds to the JSON property madeForKids

Returns:

  • (Boolean)


1922
1923
1924
# File 'lib/google/apis/youtube_v3/classes.rb', line 1922

def made_for_kids
  @made_for_kids
end

#privacy_statusString

Privacy status of the channel. Corresponds to the JSON property privacyStatus

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/youtube_v3/classes.rb', line 1928

def privacy_status
  @privacy_status
end

#self_declared_made_for_kidsBoolean Also known as: self_declared_made_for_kids?

Corresponds to the JSON property selfDeclaredMadeForKids

Returns:

  • (Boolean)


1933
1934
1935
# File 'lib/google/apis/youtube_v3/classes.rb', line 1933

def self_declared_made_for_kids
  @self_declared_made_for_kids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1941
1942
1943
1944
1945
1946
1947
1948
# File 'lib/google/apis/youtube_v3/classes.rb', line 1941

def update!(**args)
  @is_channel_monetization_enabled = args[:is_channel_monetization_enabled] if args.key?(:is_channel_monetization_enabled)
  @is_linked = args[:is_linked] if args.key?(:is_linked)
  @long_uploads_status = args[:long_uploads_status] if args.key?(:long_uploads_status)
  @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids)
  @privacy_status = args[:privacy_status] if args.key?(:privacy_status)
  @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids)
end