Class: Google::Apis::YoutubeV3::ChannelToAffiliateProgramLinkDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information specific to a creator in an affiliate program linked to a YouTube channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelToAffiliateProgramLinkDetails

Returns a new instance of ChannelToAffiliateProgramLinkDetails.



2004
2005
2006
# File 'lib/google/apis/youtube_v3/classes.rb', line 2004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_idFixnum

Required. Google Merchant Center ID of the partner. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


1987
1988
1989
# File 'lib/google/apis/youtube_v3/classes.rb', line 1987

def merchant_id
  @merchant_id
end

#program_statusString

Required. Affiliate program status. Corresponds to the JSON property programStatus

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/youtube_v3/classes.rb', line 1992

def program_status
  @program_status
end

#status_update_reasonString

Optional. Reason for the last update of the affiliate program status. Corresponds to the JSON property statusUpdateReason

Returns:

  • (String)


1997
1998
1999
# File 'lib/google/apis/youtube_v3/classes.rb', line 1997

def status_update_reason
  @status_update_reason
end

#status_update_timeString

Optional. Timestamp when the affiliate program status was last updated. Corresponds to the JSON property statusUpdateTime

Returns:

  • (String)


2002
2003
2004
# File 'lib/google/apis/youtube_v3/classes.rb', line 2002

def status_update_time
  @status_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2009
2010
2011
2012
2013
2014
# File 'lib/google/apis/youtube_v3/classes.rb', line 2009

def update!(**args)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @program_status = args[:program_status] if args.key?(:program_status)
  @status_update_reason = args[:status_update_reason] if args.key?(:status_update_reason)
  @status_update_time = args[:status_update_time] if args.key?(:status_update_time)
end