Class: Google::Apis::YoutubeV3::ChannelToAffiliateProgramLinkDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information specific to a creator in an affiliate program linked to a YouTube channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelToAffiliateProgramLinkDetails

Returns a new instance of ChannelToAffiliateProgramLinkDetails.



1978
1979
1980
# File 'lib/google/apis/youtube_v3/classes.rb', line 1978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_idFixnum

Required. Google Merchant Center ID of the partner. Corresponds to the JSON property merchantId

Returns:

  • (Fixnum)


1961
1962
1963
# File 'lib/google/apis/youtube_v3/classes.rb', line 1961

def merchant_id
  @merchant_id
end

#program_statusString

Required. Affiliate program status. Corresponds to the JSON property programStatus

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/youtube_v3/classes.rb', line 1966

def program_status
  @program_status
end

#status_update_reasonString

Optional. Reason for the last update of the affiliate program status. Corresponds to the JSON property statusUpdateReason

Returns:

  • (String)


1971
1972
1973
# File 'lib/google/apis/youtube_v3/classes.rb', line 1971

def status_update_reason
  @status_update_reason
end

#status_update_timeString

Optional. Timestamp when the affiliate program status was last updated. Corresponds to the JSON property statusUpdateTime

Returns:

  • (String)


1976
1977
1978
# File 'lib/google/apis/youtube_v3/classes.rb', line 1976

def status_update_time
  @status_update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1983
1984
1985
1986
1987
1988
# File 'lib/google/apis/youtube_v3/classes.rb', line 1983

def update!(**args)
  @merchant_id = args[:merchant_id] if args.key?(:merchant_id)
  @program_status = args[:program_status] if args.key?(:program_status)
  @status_update_reason = args[:status_update_reason] if args.key?(:status_update_reason)
  @status_update_time = args[:status_update_time] if args.key?(:status_update_time)
end