Class: Google::Apis::YoutubeV3::CommentSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a comment, such as its author and text.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommentSnippet

Returns a new instance of CommentSnippet.



2296
2297
2298
# File 'lib/google/apis/youtube_v3/classes.rb', line 2296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_channel_idGoogle::Apis::YoutubeV3::CommentSnippetAuthorChannelId

Contains the id of the author's YouTube channel, if any. Corresponds to the JSON property authorChannelId



2208
2209
2210
# File 'lib/google/apis/youtube_v3/classes.rb', line 2208

def author_channel_id
  @author_channel_id
end

#author_channel_urlString

Link to the author's YouTube channel, if any. Corresponds to the JSON property authorChannelUrl

Returns:

  • (String)


2213
2214
2215
# File 'lib/google/apis/youtube_v3/classes.rb', line 2213

def author_channel_url
  @author_channel_url
end

#author_display_nameString

The name of the user who posted the comment. Corresponds to the JSON property authorDisplayName

Returns:

  • (String)


2218
2219
2220
# File 'lib/google/apis/youtube_v3/classes.rb', line 2218

def author_display_name
  @author_display_name
end

#author_profile_image_urlString

The URL for the avatar of the user who posted the comment. Corresponds to the JSON property authorProfileImageUrl

Returns:

  • (String)


2223
2224
2225
# File 'lib/google/apis/youtube_v3/classes.rb', line 2223

def author_profile_image_url
  @author_profile_image_url
end

#can_rateBoolean Also known as: can_rate?

Whether the current viewer can rate this comment. Corresponds to the JSON property canRate

Returns:

  • (Boolean)


2228
2229
2230
# File 'lib/google/apis/youtube_v3/classes.rb', line 2228

def can_rate
  @can_rate
end

#channel_idString

The id of the corresponding YouTube channel. In case of a channel comment this is the channel the comment refers to. In case of a video or post comment it's the video/post's channel. Corresponds to the JSON property channelId

Returns:

  • (String)


2236
2237
2238
# File 'lib/google/apis/youtube_v3/classes.rb', line 2236

def channel_id
  @channel_id
end

#like_countFixnum

The total number of likes this comment has received. Corresponds to the JSON property likeCount

Returns:

  • (Fixnum)


2241
2242
2243
# File 'lib/google/apis/youtube_v3/classes.rb', line 2241

def like_count
  @like_count
end

#moderation_statusString

The comment's moderation status. Will not be set if the comments were requested through the id filter. Corresponds to the JSON property moderationStatus

Returns:

  • (String)


2247
2248
2249
# File 'lib/google/apis/youtube_v3/classes.rb', line 2247

def moderation_status
  @moderation_status
end

#parent_idString

The unique id of the top-level comment, only set for replies. Corresponds to the JSON property parentId

Returns:

  • (String)


2252
2253
2254
# File 'lib/google/apis/youtube_v3/classes.rb', line 2252

def parent_id
  @parent_id
end

#post_idString

The ID of the post the comment refers to, if any. Corresponds to the JSON property postId

Returns:

  • (String)


2257
2258
2259
# File 'lib/google/apis/youtube_v3/classes.rb', line 2257

def post_id
  @post_id
end

#published_atDateTime

The date and time when the comment was originally published. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


2262
2263
2264
# File 'lib/google/apis/youtube_v3/classes.rb', line 2262

def published_at
  @published_at
end

#text_displayString

The comment's text. The format is either plain text or HTML dependent on what has been requested. Even the plain text representation may differ from the text originally posted in that it may replace video links with video titles etc. Corresponds to the JSON property textDisplay

Returns:

  • (String)


2270
2271
2272
# File 'lib/google/apis/youtube_v3/classes.rb', line 2270

def text_display
  @text_display
end

#text_originalString

The comment's original raw text as initially posted or last updated. The original text will only be returned if it is accessible to the viewer, which is only guaranteed if the viewer is the comment's author. Corresponds to the JSON property textOriginal

Returns:

  • (String)


2277
2278
2279
# File 'lib/google/apis/youtube_v3/classes.rb', line 2277

def text_original
  @text_original
end

#updated_atDateTime

The date and time when the comment was last updated. Corresponds to the JSON property updatedAt

Returns:

  • (DateTime)


2282
2283
2284
# File 'lib/google/apis/youtube_v3/classes.rb', line 2282

def updated_at
  @updated_at
end

#video_idString

The ID of the video the comment refers to, if any. Corresponds to the JSON property videoId

Returns:

  • (String)


2287
2288
2289
# File 'lib/google/apis/youtube_v3/classes.rb', line 2287

def video_id
  @video_id
end

#viewer_ratingString

The rating the viewer has given to this comment. For the time being this will never return RATE_TYPE_DISLIKE and instead return RATE_TYPE_NONE. This may change in the future. Corresponds to the JSON property viewerRating

Returns:

  • (String)


2294
2295
2296
# File 'lib/google/apis/youtube_v3/classes.rb', line 2294

def viewer_rating
  @viewer_rating
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
# File 'lib/google/apis/youtube_v3/classes.rb', line 2301

def update!(**args)
  @author_channel_id = args[:author_channel_id] if args.key?(:author_channel_id)
  @author_channel_url = args[:author_channel_url] if args.key?(:author_channel_url)
  @author_display_name = args[:author_display_name] if args.key?(:author_display_name)
  @author_profile_image_url = args[:author_profile_image_url] if args.key?(:author_profile_image_url)
  @can_rate = args[:can_rate] if args.key?(:can_rate)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @like_count = args[:like_count] if args.key?(:like_count)
  @moderation_status = args[:moderation_status] if args.key?(:moderation_status)
  @parent_id = args[:parent_id] if args.key?(:parent_id)
  @post_id = args[:post_id] if args.key?(:post_id)
  @published_at = args[:published_at] if args.key?(:published_at)
  @text_display = args[:text_display] if args.key?(:text_display)
  @text_original = args[:text_original] if args.key?(:text_original)
  @updated_at = args[:updated_at] if args.key?(:updated_at)
  @video_id = args[:video_id] if args.key?(:video_id)
  @viewer_rating = args[:viewer_rating] if args.key?(:viewer_rating)
end