Class: Google::Apis::YoutubeV3::CommentSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::CommentSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a comment, such as its author and text.
Instance Attribute Summary collapse
-
#author_channel_id ⇒ Google::Apis::YoutubeV3::CommentSnippetAuthorChannelId
Contains the id of the author's YouTube channel, if any.
-
#author_channel_url ⇒ String
Link to the author's YouTube channel, if any.
-
#author_display_name ⇒ String
The name of the user who posted the comment.
-
#author_profile_image_url ⇒ String
The URL for the avatar of the user who posted the comment.
-
#can_rate ⇒ Boolean
(also: #can_rate?)
Whether the current viewer can rate this comment.
-
#channel_id ⇒ String
The id of the corresponding YouTube channel.
-
#like_count ⇒ Fixnum
The total number of likes this comment has received.
-
#moderation_status ⇒ String
The comment's moderation status.
-
#parent_id ⇒ String
The unique id of the top-level comment, only set for replies.
-
#post_id ⇒ String
The ID of the post the comment refers to, if any.
-
#published_at ⇒ DateTime
The date and time when the comment was originally published.
-
#text_display ⇒ String
The comment's text.
-
#text_original ⇒ String
The comment's original raw text as initially posted or last updated.
-
#updated_at ⇒ DateTime
The date and time when the comment was last updated.
-
#video_id ⇒ String
The ID of the video the comment refers to, if any.
-
#viewer_rating ⇒ String
The rating the viewer has given to this comment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommentSnippet
constructor
A new instance of CommentSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommentSnippet
Returns a new instance of CommentSnippet.
2222 2223 2224 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author_channel_id ⇒ Google::Apis::YoutubeV3::CommentSnippetAuthorChannelId
Contains the id of the author's YouTube channel, if any.
Corresponds to the JSON property authorChannelId
2134 2135 2136 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2134 def @author_channel_id end |
#author_channel_url ⇒ String
Link to the author's YouTube channel, if any.
Corresponds to the JSON property authorChannelUrl
2139 2140 2141 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2139 def @author_channel_url end |
#author_display_name ⇒ String
The name of the user who posted the comment.
Corresponds to the JSON property authorDisplayName
2144 2145 2146 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2144 def @author_display_name end |
#author_profile_image_url ⇒ String
The URL for the avatar of the user who posted the comment.
Corresponds to the JSON property authorProfileImageUrl
2149 2150 2151 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2149 def @author_profile_image_url end |
#can_rate ⇒ Boolean Also known as: can_rate?
Whether the current viewer can rate this comment.
Corresponds to the JSON property canRate
2154 2155 2156 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2154 def can_rate @can_rate end |
#channel_id ⇒ String
The id of the corresponding YouTube channel. In case of a channel comment this
is the channel the comment refers to. In case of a video or post comment it's
the video/post's channel.
Corresponds to the JSON property channelId
2162 2163 2164 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2162 def channel_id @channel_id end |
#like_count ⇒ Fixnum
The total number of likes this comment has received.
Corresponds to the JSON property likeCount
2167 2168 2169 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2167 def like_count @like_count end |
#moderation_status ⇒ String
The comment's moderation status. Will not be set if the comments were
requested through the id filter.
Corresponds to the JSON property moderationStatus
2173 2174 2175 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2173 def moderation_status @moderation_status end |
#parent_id ⇒ String
The unique id of the top-level comment, only set for replies.
Corresponds to the JSON property parentId
2178 2179 2180 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2178 def parent_id @parent_id end |
#post_id ⇒ String
The ID of the post the comment refers to, if any.
Corresponds to the JSON property postId
2183 2184 2185 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2183 def post_id @post_id end |
#published_at ⇒ DateTime
The date and time when the comment was originally published.
Corresponds to the JSON property publishedAt
2188 2189 2190 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2188 def published_at @published_at end |
#text_display ⇒ String
The comment's text. The format is either plain text or HTML dependent on what
has been requested. Even the plain text representation may differ from the
text originally posted in that it may replace video links with video titles
etc.
Corresponds to the JSON property textDisplay
2196 2197 2198 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2196 def text_display @text_display end |
#text_original ⇒ String
The comment's original raw text as initially posted or last updated. The
original text will only be returned if it is accessible to the viewer, which
is only guaranteed if the viewer is the comment's author.
Corresponds to the JSON property textOriginal
2203 2204 2205 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2203 def text_original @text_original end |
#updated_at ⇒ DateTime
The date and time when the comment was last updated.
Corresponds to the JSON property updatedAt
2208 2209 2210 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2208 def updated_at @updated_at end |
#video_id ⇒ String
The ID of the video the comment refers to, if any.
Corresponds to the JSON property videoId
2213 2214 2215 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2213 def video_id @video_id end |
#viewer_rating ⇒ String
The rating the viewer has given to this comment. For the time being this will
never return RATE_TYPE_DISLIKE and instead return RATE_TYPE_NONE. This may
change in the future.
Corresponds to the JSON property viewerRating
2220 2221 2222 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2220 def @viewer_rating end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2227 def update!(**args) @author_channel_id = args[:author_channel_id] if args.key?(:author_channel_id) @author_channel_url = args[:author_channel_url] if args.key?(:author_channel_url) @author_display_name = args[:author_display_name] if args.key?(:author_display_name) @author_profile_image_url = args[:author_profile_image_url] if args.key?(:author_profile_image_url) @can_rate = args[:can_rate] if args.key?(:can_rate) @channel_id = args[:channel_id] if args.key?(:channel_id) @like_count = args[:like_count] if args.key?(:like_count) @moderation_status = args[:moderation_status] if args.key?(:moderation_status) @parent_id = args[:parent_id] if args.key?(:parent_id) @post_id = args[:post_id] if args.key?(:post_id) @published_at = args[:published_at] if args.key?(:published_at) @text_display = args[:text_display] if args.key?(:text_display) @text_original = args[:text_original] if args.key?(:text_original) @updated_at = args[:updated_at] if args.key?(:updated_at) @video_id = args[:video_id] if args.key?(:video_id) @viewer_rating = args[:viewer_rating] if args.key?(:viewer_rating) end |