Class: Google::Apis::YoutubeV3::CommentThread

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A comment thread represents information that applies to a top level comment and all its replies. It can also include the top level comment itself and some of the replies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommentThread

Returns a new instance of CommentThread.



2398
2399
2400
# File 'lib/google/apis/youtube_v3/classes.rb', line 2398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


2375
2376
2377
# File 'lib/google/apis/youtube_v3/classes.rb', line 2375

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the comment thread. Corresponds to the JSON property id

Returns:

  • (String)


2380
2381
2382
# File 'lib/google/apis/youtube_v3/classes.rb', line 2380

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# commentThread". Corresponds to the JSON property kind

Returns:

  • (String)


2386
2387
2388
# File 'lib/google/apis/youtube_v3/classes.rb', line 2386

def kind
  @kind
end

#repliesGoogle::Apis::YoutubeV3::CommentThreadReplies

Comments written in (direct or indirect) reply to the top level comment. Corresponds to the JSON property replies



2391
2392
2393
# File 'lib/google/apis/youtube_v3/classes.rb', line 2391

def replies
  @replies
end

#snippetGoogle::Apis::YoutubeV3::CommentThreadSnippet

Basic details about a comment thread. Corresponds to the JSON property snippet



2396
2397
2398
# File 'lib/google/apis/youtube_v3/classes.rb', line 2396

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2403
2404
2405
2406
2407
2408
2409
# File 'lib/google/apis/youtube_v3/classes.rb', line 2403

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @replies = args[:replies] if args.key?(:replies)
  @snippet = args[:snippet] if args.key?(:snippet)
end