Class: Google::Apis::YoutubeV3::CommentThread

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A comment thread represents information that applies to a top level comment and all its replies. It can also include the top level comment itself and some of the replies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommentThread

Returns a new instance of CommentThread.



2298
2299
2300
# File 'lib/google/apis/youtube_v3/classes.rb', line 2298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/youtube_v3/classes.rb', line 2275

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the comment thread. Corresponds to the JSON property id

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/youtube_v3/classes.rb', line 2280

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# commentThread". Corresponds to the JSON property kind

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/youtube_v3/classes.rb', line 2286

def kind
  @kind
end

#repliesGoogle::Apis::YoutubeV3::CommentThreadReplies

Comments written in (direct or indirect) reply to the top level comment. Corresponds to the JSON property replies



2291
2292
2293
# File 'lib/google/apis/youtube_v3/classes.rb', line 2291

def replies
  @replies
end

#snippetGoogle::Apis::YoutubeV3::CommentThreadSnippet

Basic details about a comment thread. Corresponds to the JSON property snippet



2296
2297
2298
# File 'lib/google/apis/youtube_v3/classes.rb', line 2296

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2303
2304
2305
2306
2307
2308
2309
# File 'lib/google/apis/youtube_v3/classes.rb', line 2303

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @replies = args[:replies] if args.key?(:replies)
  @snippet = args[:snippet] if args.key?(:snippet)
end