Class: Google::Apis::YoutubeV3::CommentThreadSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::CommentThreadSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a comment thread.
Instance Attribute Summary collapse
-
#can_reply ⇒ Boolean
(also: #can_reply?)
Whether the current viewer of the thread can reply to it.
-
#channel_id ⇒ String
The YouTube channel the comments in the thread refer to or the channel with the video the comments refer to.
-
#is_public ⇒ Boolean
(also: #is_public?)
Whether the thread (and therefore all its comments) is visible to all YouTube users.
-
#post_id ⇒ String
The ID of the post the comments refer to, if any.
-
#top_level_comment ⇒ Google::Apis::YoutubeV3::Comment
A comment represents a single YouTube comment.
-
#total_reply_count ⇒ Fixnum
The total number of replies (not including the top level comment).
-
#video_id ⇒ String
The ID of the video the comments refer to, if any.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommentThreadSnippet
constructor
A new instance of CommentThreadSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommentThreadSnippet
Returns a new instance of CommentThreadSnippet.
2476 2477 2478 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reply ⇒ Boolean Also known as: can_reply?
Whether the current viewer of the thread can reply to it. This is viewer
specific - other viewers may see a different value for this field.
Corresponds to the JSON property canReply
2439 2440 2441 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2439 def can_reply @can_reply end |
#channel_id ⇒ String
The YouTube channel the comments in the thread refer to or the channel with
the video the comments refer to. If neither video_id nor post_id is set the
comments refer to the channel itself.
Corresponds to the JSON property channelId
2447 2448 2449 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2447 def channel_id @channel_id end |
#is_public ⇒ Boolean Also known as: is_public?
Whether the thread (and therefore all its comments) is visible to all YouTube
users.
Corresponds to the JSON property isPublic
2453 2454 2455 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2453 def is_public @is_public end |
#post_id ⇒ String
The ID of the post the comments refer to, if any.
Corresponds to the JSON property postId
2459 2460 2461 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2459 def post_id @post_id end |
#top_level_comment ⇒ Google::Apis::YoutubeV3::Comment
A comment represents a single YouTube comment.
Corresponds to the JSON property topLevelComment
2464 2465 2466 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2464 def top_level_comment @top_level_comment end |
#total_reply_count ⇒ Fixnum
The total number of replies (not including the top level comment).
Corresponds to the JSON property totalReplyCount
2469 2470 2471 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2469 def total_reply_count @total_reply_count end |
#video_id ⇒ String
The ID of the video the comments refer to, if any.
Corresponds to the JSON property videoId
2474 2475 2476 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2474 def video_id @video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2481 2482 2483 2484 2485 2486 2487 2488 2489 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2481 def update!(**args) @can_reply = args[:can_reply] if args.key?(:can_reply) @channel_id = args[:channel_id] if args.key?(:channel_id) @is_public = args[:is_public] if args.key?(:is_public) @post_id = args[:post_id] if args.key?(:post_id) @top_level_comment = args[:top_level_comment] if args.key?(:top_level_comment) @total_reply_count = args[:total_reply_count] if args.key?(:total_reply_count) @video_id = args[:video_id] if args.key?(:video_id) end |