Class: Google::Apis::YoutubeV3::ContentRating
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ContentRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Ratings schemes. The country-specific ratings are mostly for movies and shows. LINT.IfChange
Instance Attribute Summary collapse
-
#acb_rating ⇒ String
The video's Australian Classification Board (ACB) or Australian Communications and Media Authority (ACMA) rating.
-
#agcom_rating ⇒ String
The video's rating from Italy's Autorità per le Garanzie nelle Comunicazioni ( AGCOM).
-
#anatel_rating ⇒ String
The video's Anatel (Asociación Nacional de Televisión) rating for Chilean television.
-
#bbfc_rating ⇒ String
The video's British Board of Film Classification (BBFC) rating.
-
#bfvc_rating ⇒ String
The video's rating from Thailand's Board of Film and Video Censors.
-
#bmukk_rating ⇒ String
The video's rating from the Austrian Board of Media Classification ( Bundesministerium für Unterricht, Kunst und Kultur).
-
#catv_rating ⇒ String
Rating system for Canadian TV - Canadian TV Classification System The video's rating from the Canadian Radio-Television and Telecommunications Commission ( CRTC) for Canadian English-language broadcasts.
-
#catvfr_rating ⇒ String
The video's rating from the Canadian Radio-Television and Telecommunications Commission (CRTC) for Canadian French-language broadcasts.
-
#cbfc_rating ⇒ String
The video's Central Board of Film Certification (CBFC - India) rating.
-
#ccc_rating ⇒ String
The video's Consejo de Calificación Cinematográfica (Chile) rating.
-
#cce_rating ⇒ String
The video's rating from Portugal's Comissão de Classificação de Espect´culos.
-
#chfilm_rating ⇒ String
The video's rating in Switzerland.
-
#chvrs_rating ⇒ String
The video's Canadian Home Video Rating System (CHVRS) rating.
-
#cicf_rating ⇒ String
The video's rating from the Commission de Contrôle des Films (Belgium).
-
#cna_rating ⇒ String
The video's rating from Romania's CONSILIUL NATIONAL AL AUDIOVIZUALULUI (CNA).
-
#cnc_rating ⇒ String
Rating system in France - Commission de classification cinematographique Corresponds to the JSON property
cncRating. -
#csa_rating ⇒ String
The video's rating from France's Conseil supérieur de l’audiovisuel, which rates broadcast content.
-
#cscf_rating ⇒ String
The video's rating from Luxembourg's Commission de surveillance de la classification des films (CSCF).
-
#czfilm_rating ⇒ String
The video's rating in the Czech Republic.
-
#djctq_rating ⇒ String
The video's Departamento de Justiça, Classificação, Qualificação e Títulos ( DJCQT - Brazil) rating.
-
#djctq_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its DJCQT (Brazil) rating.
-
#ecbmct_rating ⇒ String
Rating system in Turkey - Evaluation and Classification Board of the Ministry of Culture and Tourism Corresponds to the JSON property
ecbmctRating. -
#eefilm_rating ⇒ String
The video's rating in Estonia.
-
#egfilm_rating ⇒ String
The video's rating in Egypt.
-
#eirin_rating ⇒ String
The video's Eirin (映倫) rating.
-
#fcbm_rating ⇒ String
The video's rating from Malaysia's Film Censorship Board.
-
#fco_rating ⇒ String
The video's rating from Hong Kong's Office for Film, Newspaper and Article Administration.
-
#fmoc_rating ⇒ String
This property has been deprecated.
-
#fpb_rating ⇒ String
The video's rating from South Africa's Film and Publication Board.
-
#fpb_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its FPB (South Africa) rating.
-
#fsk_rating ⇒ String
The video's Freiwillige Selbstkontrolle der Filmwirtschaft (FSK - Germany) rating.
-
#grfilm_rating ⇒ String
The video's rating in Greece.
-
#icaa_rating ⇒ String
The video's Instituto de la Cinematografía y de las Artes Audiovisuales (ICAA - Spain) rating.
-
#ifco_rating ⇒ String
The video's Irish Film Classification Office (IFCO - Ireland) rating.
-
#ilfilm_rating ⇒ String
The video's rating in Israel.
-
#incaa_rating ⇒ String
The video's INCAA (Instituto Nacional de Cine y Artes Audiovisuales - Argentina) rating.
-
#kfcb_rating ⇒ String
The video's rating from the Kenya Film Classification Board.
-
#kijkwijzer_rating ⇒ String
The video's NICAM/Kijkwijzer rating from the Nederlands Instituut voor de Classificatie van Audiovisuele Media (Netherlands).
-
#kmrb_rating ⇒ String
The video's Korea Media Rating Board (영상물등급위원회) rating.
-
#lsf_rating ⇒ String
The video's rating from Indonesia's Lembaga Sensor Film.
-
#mccaa_rating ⇒ String
The video's rating from Malta's Film Age-Classification Board.
-
#mccyp_rating ⇒ String
The video's rating from the Danish Film Institute's (Det Danske Filminstitut) Media Council for Children and Young People.
-
#mcst_rating ⇒ String
The video's rating system for Vietnam - MCST Corresponds to the JSON property
mcstRating. -
#mda_rating ⇒ String
The video's rating from Singapore's Media Development Authority (MDA) and, specifically, it's Board of Film Censors (BFC).
-
#medietilsynet_rating ⇒ String
The video's rating from Medietilsynet, the Norwegian Media Authority.
-
#meku_rating ⇒ String
The video's rating from Finland's Kansallinen Audiovisuaalinen Instituutti ( National Audiovisual Institute).
-
#mena_mpaa_rating ⇒ String
The rating system for MENA countries, a clone of MPAA.
-
#mibac_rating ⇒ String
The video's rating from the Ministero dei Beni e delle Attività Culturali e del Turismo (Italy).
-
#moc_rating ⇒ String
The video's Ministerio de Cultura (Colombia) rating.
-
#moctw_rating ⇒ String
The video's rating from Taiwan's Ministry of Culture (文化部).
-
#mpaa_rating ⇒ String
The video's Motion Picture Association of America (MPAA) rating.
-
#mpaat_rating ⇒ String
The rating system for trailer, DVD, and Ad in the US.
-
#mtrcb_rating ⇒ String
The video's rating from the Movie and Television Review and Classification Board (Philippines).
-
#nbc_rating ⇒ String
The video's rating from the Maldives National Bureau of Classification.
-
#nbcpl_rating ⇒ String
The video's rating in Poland.
-
#nfrc_rating ⇒ String
The video's rating from the Bulgarian National Film Center.
-
#nfvcb_rating ⇒ String
The video's rating from Nigeria's National Film and Video Censors Board.
-
#nkclv_rating ⇒ String
The video's rating from the Nacionãlais Kino centrs (National Film Centre of Latvia).
-
#nmc_rating ⇒ String
The National Media Council ratings system for United Arab Emirates.
-
#oflc_rating ⇒ String
The video's Office of Film and Literature Classification (OFLC - New Zealand) rating.
-
#pefilm_rating ⇒ String
The video's rating in Peru.
-
#rcnof_rating ⇒ String
The video's rating from the Hungarian Nemzeti Filmiroda, the Rating Committee of the National Office of Film.
-
#resorteviolencia_rating ⇒ String
The video's rating in Venezuela.
-
#rtc_rating ⇒ String
The video's General Directorate of Radio, Television and Cinematography ( Mexico) rating.
-
#rte_rating ⇒ String
The video's rating from Ireland's Raidió Teilifís Éireann.
-
#russia_rating ⇒ String
The video's National Film Registry of the Russian Federation (MKRF - Russia) rating.
-
#skfilm_rating ⇒ String
The video's rating in Slovakia.
-
#smais_rating ⇒ String
The video's rating in Iceland.
-
#smsa_rating ⇒ String
The video's rating from Statens medieråd (Sweden's National Media Council).
-
#tvpg_rating ⇒ String
The video's TV Parental Guidelines (TVPG) rating.
-
#yt_rating ⇒ String
A rating that YouTube uses to identify age-restricted content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentRating
constructor
A new instance of ContentRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentRating
Returns a new instance of ContentRating.
2953 2954 2955 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2953 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acb_rating ⇒ String
The video's Australian Classification Board (ACB) or Australian Communications
and Media Authority (ACMA) rating. ACMA ratings are used to classify children'
s television programming.
Corresponds to the JSON property acbRating
2568 2569 2570 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2568 def @acb_rating end |
#agcom_rating ⇒ String
The video's rating from Italy's Autorità per le Garanzie nelle Comunicazioni (
AGCOM).
Corresponds to the JSON property agcomRating
2574 2575 2576 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2574 def @agcom_rating end |
#anatel_rating ⇒ String
The video's Anatel (Asociación Nacional de Televisión) rating for Chilean
television.
Corresponds to the JSON property anatelRating
2580 2581 2582 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2580 def @anatel_rating end |
#bbfc_rating ⇒ String
The video's British Board of Film Classification (BBFC) rating.
Corresponds to the JSON property bbfcRating
2585 2586 2587 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2585 def @bbfc_rating end |
#bfvc_rating ⇒ String
The video's rating from Thailand's Board of Film and Video Censors.
Corresponds to the JSON property bfvcRating
2590 2591 2592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2590 def @bfvc_rating end |
#bmukk_rating ⇒ String
The video's rating from the Austrian Board of Media Classification (
Bundesministerium für Unterricht, Kunst und Kultur).
Corresponds to the JSON property bmukkRating
2596 2597 2598 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2596 def @bmukk_rating end |
#catv_rating ⇒ String
Rating system for Canadian TV - Canadian TV Classification System The video's
rating from the Canadian Radio-Television and Telecommunications Commission (
CRTC) for Canadian English-language broadcasts. For more information, see the
Canadian Broadcast Standards Council website.
Corresponds to the JSON property catvRating
2604 2605 2606 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2604 def @catv_rating end |
#catvfr_rating ⇒ String
The video's rating from the Canadian Radio-Television and Telecommunications
Commission (CRTC) for Canadian French-language broadcasts. For more
information, see the Canadian Broadcast Standards Council website.
Corresponds to the JSON property catvfrRating
2611 2612 2613 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2611 def @catvfr_rating end |
#cbfc_rating ⇒ String
The video's Central Board of Film Certification (CBFC - India) rating.
Corresponds to the JSON property cbfcRating
2616 2617 2618 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2616 def @cbfc_rating end |
#ccc_rating ⇒ String
The video's Consejo de Calificación Cinematográfica (Chile) rating.
Corresponds to the JSON property cccRating
2621 2622 2623 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2621 def @ccc_rating end |
#cce_rating ⇒ String
The video's rating from Portugal's Comissão de Classificação de Espect´culos.
Corresponds to the JSON property cceRating
2626 2627 2628 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2626 def @cce_rating end |
#chfilm_rating ⇒ String
The video's rating in Switzerland.
Corresponds to the JSON property chfilmRating
2631 2632 2633 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2631 def @chfilm_rating end |
#chvrs_rating ⇒ String
The video's Canadian Home Video Rating System (CHVRS) rating.
Corresponds to the JSON property chvrsRating
2636 2637 2638 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2636 def @chvrs_rating end |
#cicf_rating ⇒ String
The video's rating from the Commission de Contrôle des Films (Belgium).
Corresponds to the JSON property cicfRating
2641 2642 2643 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2641 def @cicf_rating end |
#cna_rating ⇒ String
The video's rating from Romania's CONSILIUL NATIONAL AL AUDIOVIZUALULUI (CNA).
Corresponds to the JSON property cnaRating
2646 2647 2648 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2646 def @cna_rating end |
#cnc_rating ⇒ String
Rating system in France - Commission de classification cinematographique
Corresponds to the JSON property cncRating
2651 2652 2653 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2651 def @cnc_rating end |
#csa_rating ⇒ String
The video's rating from France's Conseil supérieur de l’audiovisuel, which
rates broadcast content.
Corresponds to the JSON property csaRating
2657 2658 2659 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2657 def @csa_rating end |
#cscf_rating ⇒ String
The video's rating from Luxembourg's Commission de surveillance de la
classification des films (CSCF).
Corresponds to the JSON property cscfRating
2663 2664 2665 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2663 def @cscf_rating end |
#czfilm_rating ⇒ String
The video's rating in the Czech Republic.
Corresponds to the JSON property czfilmRating
2668 2669 2670 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2668 def @czfilm_rating end |
#djctq_rating ⇒ String
The video's Departamento de Justiça, Classificação, Qualificação e Títulos (
DJCQT - Brazil) rating.
Corresponds to the JSON property djctqRating
2674 2675 2676 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2674 def @djctq_rating end |
#djctq_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its DJCQT (Brazil) rating.
Corresponds to the JSON property djctqRatingReasons
2679 2680 2681 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2679 def @djctq_rating_reasons end |
#ecbmct_rating ⇒ String
Rating system in Turkey - Evaluation and Classification Board of the Ministry
of Culture and Tourism
Corresponds to the JSON property ecbmctRating
2685 2686 2687 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2685 def @ecbmct_rating end |
#eefilm_rating ⇒ String
The video's rating in Estonia.
Corresponds to the JSON property eefilmRating
2690 2691 2692 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2690 def @eefilm_rating end |
#egfilm_rating ⇒ String
The video's rating in Egypt.
Corresponds to the JSON property egfilmRating
2695 2696 2697 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2695 def @egfilm_rating end |
#eirin_rating ⇒ String
The video's Eirin (映倫) rating. Eirin is the Japanese rating system.
Corresponds to the JSON property eirinRating
2700 2701 2702 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2700 def @eirin_rating end |
#fcbm_rating ⇒ String
The video's rating from Malaysia's Film Censorship Board.
Corresponds to the JSON property fcbmRating
2705 2706 2707 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2705 def @fcbm_rating end |
#fco_rating ⇒ String
The video's rating from Hong Kong's Office for Film, Newspaper and Article
Administration.
Corresponds to the JSON property fcoRating
2711 2712 2713 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2711 def @fco_rating end |
#fmoc_rating ⇒ String
This property has been deprecated. Use the contentDetails.contentRating.
cncRating instead.
Corresponds to the JSON property fmocRating
2717 2718 2719 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2717 def @fmoc_rating end |
#fpb_rating ⇒ String
The video's rating from South Africa's Film and Publication Board.
Corresponds to the JSON property fpbRating
2722 2723 2724 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2722 def @fpb_rating end |
#fpb_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its FPB (South Africa) rating.
Corresponds to the JSON property fpbRatingReasons
2727 2728 2729 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2727 def @fpb_rating_reasons end |
#fsk_rating ⇒ String
The video's Freiwillige Selbstkontrolle der Filmwirtschaft (FSK - Germany)
rating.
Corresponds to the JSON property fskRating
2733 2734 2735 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2733 def @fsk_rating end |
#grfilm_rating ⇒ String
The video's rating in Greece.
Corresponds to the JSON property grfilmRating
2738 2739 2740 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2738 def @grfilm_rating end |
#icaa_rating ⇒ String
The video's Instituto de la Cinematografía y de las Artes Audiovisuales (ICAA -
Spain) rating.
Corresponds to the JSON property icaaRating
2744 2745 2746 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2744 def @icaa_rating end |
#ifco_rating ⇒ String
The video's Irish Film Classification Office (IFCO - Ireland) rating. See the
IFCO website for more information.
Corresponds to the JSON property ifcoRating
2750 2751 2752 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2750 def @ifco_rating end |
#ilfilm_rating ⇒ String
The video's rating in Israel.
Corresponds to the JSON property ilfilmRating
2755 2756 2757 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2755 def @ilfilm_rating end |
#incaa_rating ⇒ String
The video's INCAA (Instituto Nacional de Cine y Artes Audiovisuales -
Argentina) rating.
Corresponds to the JSON property incaaRating
2761 2762 2763 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2761 def @incaa_rating end |
#kfcb_rating ⇒ String
The video's rating from the Kenya Film Classification Board.
Corresponds to the JSON property kfcbRating
2766 2767 2768 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2766 def @kfcb_rating end |
#kijkwijzer_rating ⇒ String
The video's NICAM/Kijkwijzer rating from the Nederlands Instituut voor de
Classificatie van Audiovisuele Media (Netherlands).
Corresponds to the JSON property kijkwijzerRating
2772 2773 2774 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2772 def @kijkwijzer_rating end |
#kmrb_rating ⇒ String
The video's Korea Media Rating Board (영상물등급위원회) rating. The KMRB rates videos
in South Korea.
Corresponds to the JSON property kmrbRating
2778 2779 2780 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2778 def @kmrb_rating end |
#lsf_rating ⇒ String
The video's rating from Indonesia's Lembaga Sensor Film.
Corresponds to the JSON property lsfRating
2783 2784 2785 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2783 def @lsf_rating end |
#mccaa_rating ⇒ String
The video's rating from Malta's Film Age-Classification Board.
Corresponds to the JSON property mccaaRating
2788 2789 2790 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2788 def @mccaa_rating end |
#mccyp_rating ⇒ String
The video's rating from the Danish Film Institute's (Det Danske Filminstitut)
Media Council for Children and Young People.
Corresponds to the JSON property mccypRating
2794 2795 2796 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2794 def @mccyp_rating end |
#mcst_rating ⇒ String
The video's rating system for Vietnam - MCST
Corresponds to the JSON property mcstRating
2799 2800 2801 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2799 def @mcst_rating end |
#mda_rating ⇒ String
The video's rating from Singapore's Media Development Authority (MDA) and,
specifically, it's Board of Film Censors (BFC).
Corresponds to the JSON property mdaRating
2805 2806 2807 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2805 def @mda_rating end |
#medietilsynet_rating ⇒ String
The video's rating from Medietilsynet, the Norwegian Media Authority.
Corresponds to the JSON property medietilsynetRating
2810 2811 2812 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2810 def @medietilsynet_rating end |
#meku_rating ⇒ String
The video's rating from Finland's Kansallinen Audiovisuaalinen Instituutti (
National Audiovisual Institute).
Corresponds to the JSON property mekuRating
2816 2817 2818 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2816 def @meku_rating end |
#mena_mpaa_rating ⇒ String
The rating system for MENA countries, a clone of MPAA. It is needed to prevent
titles go live w/o additional QC check, since some of them can be
inappropriate for the countries at all. See b/33408548 for more details.
Corresponds to the JSON property menaMpaaRating
2823 2824 2825 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2823 def @mena_mpaa_rating end |
#mibac_rating ⇒ String
The video's rating from the Ministero dei Beni e delle Attività Culturali e
del Turismo (Italy).
Corresponds to the JSON property mibacRating
2829 2830 2831 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2829 def @mibac_rating end |
#moc_rating ⇒ String
The video's Ministerio de Cultura (Colombia) rating.
Corresponds to the JSON property mocRating
2834 2835 2836 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2834 def @moc_rating end |
#moctw_rating ⇒ String
The video's rating from Taiwan's Ministry of Culture (文化部).
Corresponds to the JSON property moctwRating
2839 2840 2841 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2839 def @moctw_rating end |
#mpaa_rating ⇒ String
The video's Motion Picture Association of America (MPAA) rating.
Corresponds to the JSON property mpaaRating
2844 2845 2846 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2844 def @mpaa_rating end |
#mpaat_rating ⇒ String
The rating system for trailer, DVD, and Ad in the US. See http://movielabs.com/
md/ratings/v2.3/html/US_MPAAT_Ratings.html.
Corresponds to the JSON property mpaatRating
2850 2851 2852 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2850 def @mpaat_rating end |
#mtrcb_rating ⇒ String
The video's rating from the Movie and Television Review and Classification
Board (Philippines).
Corresponds to the JSON property mtrcbRating
2856 2857 2858 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2856 def @mtrcb_rating end |
#nbc_rating ⇒ String
The video's rating from the Maldives National Bureau of Classification.
Corresponds to the JSON property nbcRating
2861 2862 2863 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2861 def @nbc_rating end |
#nbcpl_rating ⇒ String
The video's rating in Poland.
Corresponds to the JSON property nbcplRating
2866 2867 2868 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2866 def @nbcpl_rating end |
#nfrc_rating ⇒ String
The video's rating from the Bulgarian National Film Center.
Corresponds to the JSON property nfrcRating
2871 2872 2873 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2871 def @nfrc_rating end |
#nfvcb_rating ⇒ String
The video's rating from Nigeria's National Film and Video Censors Board.
Corresponds to the JSON property nfvcbRating
2876 2877 2878 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2876 def @nfvcb_rating end |
#nkclv_rating ⇒ String
The video's rating from the Nacionãlais Kino centrs (National Film Centre of
Latvia).
Corresponds to the JSON property nkclvRating
2882 2883 2884 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2882 def @nkclv_rating end |
#nmc_rating ⇒ String
The National Media Council ratings system for United Arab Emirates.
Corresponds to the JSON property nmcRating
2887 2888 2889 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2887 def @nmc_rating end |
#oflc_rating ⇒ String
The video's Office of Film and Literature Classification (OFLC - New Zealand)
rating.
Corresponds to the JSON property oflcRating
2893 2894 2895 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2893 def @oflc_rating end |
#pefilm_rating ⇒ String
The video's rating in Peru.
Corresponds to the JSON property pefilmRating
2898 2899 2900 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2898 def @pefilm_rating end |
#rcnof_rating ⇒ String
The video's rating from the Hungarian Nemzeti Filmiroda, the Rating Committee
of the National Office of Film.
Corresponds to the JSON property rcnofRating
2904 2905 2906 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2904 def @rcnof_rating end |
#resorteviolencia_rating ⇒ String
The video's rating in Venezuela.
Corresponds to the JSON property resorteviolenciaRating
2909 2910 2911 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2909 def @resorteviolencia_rating end |
#rtc_rating ⇒ String
The video's General Directorate of Radio, Television and Cinematography (
Mexico) rating.
Corresponds to the JSON property rtcRating
2915 2916 2917 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2915 def @rtc_rating end |
#rte_rating ⇒ String
The video's rating from Ireland's Raidió Teilifís Éireann.
Corresponds to the JSON property rteRating
2920 2921 2922 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2920 def @rte_rating end |
#russia_rating ⇒ String
The video's National Film Registry of the Russian Federation (MKRF - Russia)
rating.
Corresponds to the JSON property russiaRating
2926 2927 2928 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2926 def @russia_rating end |
#skfilm_rating ⇒ String
The video's rating in Slovakia.
Corresponds to the JSON property skfilmRating
2931 2932 2933 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2931 def @skfilm_rating end |
#smais_rating ⇒ String
The video's rating in Iceland.
Corresponds to the JSON property smaisRating
2936 2937 2938 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2936 def @smais_rating end |
#smsa_rating ⇒ String
The video's rating from Statens medieråd (Sweden's National Media Council).
Corresponds to the JSON property smsaRating
2941 2942 2943 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2941 def @smsa_rating end |
#tvpg_rating ⇒ String
The video's TV Parental Guidelines (TVPG) rating.
Corresponds to the JSON property tvpgRating
2946 2947 2948 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2946 def @tvpg_rating end |
#yt_rating ⇒ String
A rating that YouTube uses to identify age-restricted content.
Corresponds to the JSON property ytRating
2951 2952 2953 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2951 def @yt_rating end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 2987 2988 2989 2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2958 def update!(**args) @acb_rating = args[:acb_rating] if args.key?(:acb_rating) @agcom_rating = args[:agcom_rating] if args.key?(:agcom_rating) @anatel_rating = args[:anatel_rating] if args.key?(:anatel_rating) @bbfc_rating = args[:bbfc_rating] if args.key?(:bbfc_rating) @bfvc_rating = args[:bfvc_rating] if args.key?(:bfvc_rating) @bmukk_rating = args[:bmukk_rating] if args.key?(:bmukk_rating) @catv_rating = args[:catv_rating] if args.key?(:catv_rating) @catvfr_rating = args[:catvfr_rating] if args.key?(:catvfr_rating) @cbfc_rating = args[:cbfc_rating] if args.key?(:cbfc_rating) @ccc_rating = args[:ccc_rating] if args.key?(:ccc_rating) @cce_rating = args[:cce_rating] if args.key?(:cce_rating) @chfilm_rating = args[:chfilm_rating] if args.key?(:chfilm_rating) @chvrs_rating = args[:chvrs_rating] if args.key?(:chvrs_rating) @cicf_rating = args[:cicf_rating] if args.key?(:cicf_rating) @cna_rating = args[:cna_rating] if args.key?(:cna_rating) @cnc_rating = args[:cnc_rating] if args.key?(:cnc_rating) @csa_rating = args[:csa_rating] if args.key?(:csa_rating) @cscf_rating = args[:cscf_rating] if args.key?(:cscf_rating) @czfilm_rating = args[:czfilm_rating] if args.key?(:czfilm_rating) @djctq_rating = args[:djctq_rating] if args.key?(:djctq_rating) @djctq_rating_reasons = args[:djctq_rating_reasons] if args.key?(:djctq_rating_reasons) @ecbmct_rating = args[:ecbmct_rating] if args.key?(:ecbmct_rating) @eefilm_rating = args[:eefilm_rating] if args.key?(:eefilm_rating) @egfilm_rating = args[:egfilm_rating] if args.key?(:egfilm_rating) @eirin_rating = args[:eirin_rating] if args.key?(:eirin_rating) @fcbm_rating = args[:fcbm_rating] if args.key?(:fcbm_rating) @fco_rating = args[:fco_rating] if args.key?(:fco_rating) @fmoc_rating = args[:fmoc_rating] if args.key?(:fmoc_rating) @fpb_rating = args[:fpb_rating] if args.key?(:fpb_rating) @fpb_rating_reasons = args[:fpb_rating_reasons] if args.key?(:fpb_rating_reasons) @fsk_rating = args[:fsk_rating] if args.key?(:fsk_rating) @grfilm_rating = args[:grfilm_rating] if args.key?(:grfilm_rating) @icaa_rating = args[:icaa_rating] if args.key?(:icaa_rating) @ifco_rating = args[:ifco_rating] if args.key?(:ifco_rating) @ilfilm_rating = args[:ilfilm_rating] if args.key?(:ilfilm_rating) @incaa_rating = args[:incaa_rating] if args.key?(:incaa_rating) @kfcb_rating = args[:kfcb_rating] if args.key?(:kfcb_rating) @kijkwijzer_rating = args[:kijkwijzer_rating] if args.key?(:kijkwijzer_rating) @kmrb_rating = args[:kmrb_rating] if args.key?(:kmrb_rating) @lsf_rating = args[:lsf_rating] if args.key?(:lsf_rating) @mccaa_rating = args[:mccaa_rating] if args.key?(:mccaa_rating) @mccyp_rating = args[:mccyp_rating] if args.key?(:mccyp_rating) @mcst_rating = args[:mcst_rating] if args.key?(:mcst_rating) @mda_rating = args[:mda_rating] if args.key?(:mda_rating) @medietilsynet_rating = args[:medietilsynet_rating] if args.key?(:medietilsynet_rating) @meku_rating = args[:meku_rating] if args.key?(:meku_rating) @mena_mpaa_rating = args[:mena_mpaa_rating] if args.key?(:mena_mpaa_rating) @mibac_rating = args[:mibac_rating] if args.key?(:mibac_rating) @moc_rating = args[:moc_rating] if args.key?(:moc_rating) @moctw_rating = args[:moctw_rating] if args.key?(:moctw_rating) @mpaa_rating = args[:mpaa_rating] if args.key?(:mpaa_rating) @mpaat_rating = args[:mpaat_rating] if args.key?(:mpaat_rating) @mtrcb_rating = args[:mtrcb_rating] if args.key?(:mtrcb_rating) @nbc_rating = args[:nbc_rating] if args.key?(:nbc_rating) @nbcpl_rating = args[:nbcpl_rating] if args.key?(:nbcpl_rating) @nfrc_rating = args[:nfrc_rating] if args.key?(:nfrc_rating) @nfvcb_rating = args[:nfvcb_rating] if args.key?(:nfvcb_rating) @nkclv_rating = args[:nkclv_rating] if args.key?(:nkclv_rating) @nmc_rating = args[:nmc_rating] if args.key?(:nmc_rating) @oflc_rating = args[:oflc_rating] if args.key?(:oflc_rating) @pefilm_rating = args[:pefilm_rating] if args.key?(:pefilm_rating) @rcnof_rating = args[:rcnof_rating] if args.key?(:rcnof_rating) @resorteviolencia_rating = args[:resorteviolencia_rating] if args.key?(:resorteviolencia_rating) @rtc_rating = args[:rtc_rating] if args.key?(:rtc_rating) @rte_rating = args[:rte_rating] if args.key?(:rte_rating) @russia_rating = args[:russia_rating] if args.key?(:russia_rating) @skfilm_rating = args[:skfilm_rating] if args.key?(:skfilm_rating) @smais_rating = args[:smais_rating] if args.key?(:smais_rating) @smsa_rating = args[:smsa_rating] if args.key?(:smsa_rating) @tvpg_rating = args[:tvpg_rating] if args.key?(:tvpg_rating) @yt_rating = args[:yt_rating] if args.key?(:yt_rating) end |