Class: Google::Apis::YoutubeV3::ContentRating
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ContentRating
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Ratings schemes. The country-specific ratings are mostly for movies and shows. LINT.IfChange
Instance Attribute Summary collapse
-
#acb_rating ⇒ String
The video's Australian Classification Board (ACB) or Australian Communications and Media Authority (ACMA) rating.
-
#agcom_rating ⇒ String
The video's rating from Italy's Autorità per le Garanzie nelle Comunicazioni ( AGCOM).
-
#anatel_rating ⇒ String
The video's Anatel (Asociación Nacional de Televisión) rating for Chilean television.
-
#bbfc_rating ⇒ String
The video's British Board of Film Classification (BBFC) rating.
-
#bfvc_rating ⇒ String
The video's rating from Thailand's Board of Film and Video Censors.
-
#bmukk_rating ⇒ String
The video's rating from the Austrian Board of Media Classification ( Bundesministerium für Unterricht, Kunst und Kultur).
-
#catv_rating ⇒ String
Rating system for Canadian TV - Canadian TV Classification System The video's rating from the Canadian Radio-Television and Telecommunications Commission ( CRTC) for Canadian English-language broadcasts.
-
#catvfr_rating ⇒ String
The video's rating from the Canadian Radio-Television and Telecommunications Commission (CRTC) for Canadian French-language broadcasts.
-
#cbfc_rating ⇒ String
The video's Central Board of Film Certification (CBFC - India) rating.
-
#ccc_rating ⇒ String
The video's Consejo de Calificación Cinematográfica (Chile) rating.
-
#cce_rating ⇒ String
The video's rating from Portugal's Comissão de Classificação de Espect´culos.
-
#chfilm_rating ⇒ String
The video's rating in Switzerland.
-
#chvrs_rating ⇒ String
The video's Canadian Home Video Rating System (CHVRS) rating.
-
#cicf_rating ⇒ String
The video's rating from the Commission de Contrôle des Films (Belgium).
-
#cna_rating ⇒ String
The video's rating from Romania's CONSILIUL NATIONAL AL AUDIOVIZUALULUI (CNA).
-
#cnc_rating ⇒ String
Rating system in France - Commission de classification cinematographique Corresponds to the JSON property
cncRating. -
#csa_rating ⇒ String
The video's rating from France's Conseil supérieur de l’audiovisuel, which rates broadcast content.
-
#cscf_rating ⇒ String
The video's rating from Luxembourg's Commission de surveillance de la classification des films (CSCF).
-
#czfilm_rating ⇒ String
The video's rating in the Czech Republic.
-
#djctq_rating ⇒ String
The video's Departamento de Justiça, Classificação, Qualificação e Títulos ( DJCQT - Brazil) rating.
-
#djctq_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its DJCQT (Brazil) rating.
-
#ecbmct_rating ⇒ String
Rating system in Turkey - Evaluation and Classification Board of the Ministry of Culture and Tourism Corresponds to the JSON property
ecbmctRating. -
#eefilm_rating ⇒ String
The video's rating in Estonia.
-
#egfilm_rating ⇒ String
The video's rating in Egypt.
-
#eirin_rating ⇒ String
The video's Eirin (映倫) rating.
-
#fcbm_rating ⇒ String
The video's rating from Malaysia's Film Censorship Board.
-
#fco_rating ⇒ String
The video's rating from Hong Kong's Office for Film, Newspaper and Article Administration.
-
#fmoc_rating ⇒ String
This property has been deprecated.
-
#fpb_rating ⇒ String
The video's rating from South Africa's Film and Publication Board.
-
#fpb_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its FPB (South Africa) rating.
-
#fsk_rating ⇒ String
The video's Freiwillige Selbstkontrolle der Filmwirtschaft (FSK - Germany) rating.
-
#grfilm_rating ⇒ String
The video's rating in Greece.
-
#icaa_rating ⇒ String
The video's Instituto de la Cinematografía y de las Artes Audiovisuales (ICAA - Spain) rating.
-
#ifco_rating ⇒ String
The video's Irish Film Classification Office (IFCO - Ireland) rating.
-
#ilfilm_rating ⇒ String
The video's rating in Israel.
-
#incaa_rating ⇒ String
The video's INCAA (Instituto Nacional de Cine y Artes Audiovisuales - Argentina) rating.
-
#kfcb_rating ⇒ String
The video's rating from the Kenya Film Classification Board.
-
#kijkwijzer_rating ⇒ String
The video's NICAM/Kijkwijzer rating from the Nederlands Instituut voor de Classificatie van Audiovisuele Media (Netherlands).
-
#kmrb_rating ⇒ String
The video's Korea Media Rating Board (영상물등급위원회) rating.
-
#lsf_rating ⇒ String
The video's rating from Indonesia's Lembaga Sensor Film.
-
#mccaa_rating ⇒ String
The video's rating from Malta's Film Age-Classification Board.
-
#mccyp_rating ⇒ String
The video's rating from the Danish Film Institute's (Det Danske Filminstitut) Media Council for Children and Young People.
-
#mcst_rating ⇒ String
The video's rating system for Vietnam - MCST Corresponds to the JSON property
mcstRating. -
#mda_rating ⇒ String
The video's rating from Singapore's Media Development Authority (MDA) and, specifically, it's Board of Film Censors (BFC).
-
#medietilsynet_rating ⇒ String
The video's rating from Medietilsynet, the Norwegian Media Authority.
-
#meku_rating ⇒ String
The video's rating from Finland's Kansallinen Audiovisuaalinen Instituutti ( National Audiovisual Institute).
-
#mena_mpaa_rating ⇒ String
The rating system for MENA countries, a clone of MPAA.
-
#mibac_rating ⇒ String
The video's rating from the Ministero dei Beni e delle Attività Culturali e del Turismo (Italy).
-
#moc_rating ⇒ String
The video's Ministerio de Cultura (Colombia) rating.
-
#moctw_rating ⇒ String
The video's rating from Taiwan's Ministry of Culture (文化部).
-
#mpaa_rating ⇒ String
The video's Motion Picture Association of America (MPAA) rating.
-
#mpaat_rating ⇒ String
The rating system for trailer, DVD, and Ad in the US.
-
#mtrcb_rating ⇒ String
The video's rating from the Movie and Television Review and Classification Board (Philippines).
-
#nbc_rating ⇒ String
The video's rating from the Maldives National Bureau of Classification.
-
#nbcpl_rating ⇒ String
The video's rating in Poland.
-
#nfrc_rating ⇒ String
The video's rating from the Bulgarian National Film Center.
-
#nfvcb_rating ⇒ String
The video's rating from Nigeria's National Film and Video Censors Board.
-
#nkclv_rating ⇒ String
The video's rating from the Nacionãlais Kino centrs (National Film Centre of Latvia).
-
#nmc_rating ⇒ String
The National Media Council ratings system for United Arab Emirates.
-
#oflc_rating ⇒ String
The video's Office of Film and Literature Classification (OFLC - New Zealand) rating.
-
#pefilm_rating ⇒ String
The video's rating in Peru.
-
#rcnof_rating ⇒ String
The video's rating from the Hungarian Nemzeti Filmiroda, the Rating Committee of the National Office of Film.
-
#resorteviolencia_rating ⇒ String
The video's rating in Venezuela.
-
#rtc_rating ⇒ String
The video's General Directorate of Radio, Television and Cinematography ( Mexico) rating.
-
#rte_rating ⇒ String
The video's rating from Ireland's Raidió Teilifís Éireann.
-
#russia_rating ⇒ String
The video's National Film Registry of the Russian Federation (MKRF - Russia) rating.
-
#skfilm_rating ⇒ String
The video's rating in Slovakia.
-
#smais_rating ⇒ String
The video's rating in Iceland.
-
#smsa_rating ⇒ String
The video's rating from Statens medieråd (Sweden's National Media Council).
-
#tvpg_rating ⇒ String
The video's TV Parental Guidelines (TVPG) rating.
-
#yt_rating ⇒ String
A rating that YouTube uses to identify age-restricted content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentRating
constructor
A new instance of ContentRating.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentRating
Returns a new instance of ContentRating.
2887 2888 2889 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acb_rating ⇒ String
The video's Australian Classification Board (ACB) or Australian Communications
and Media Authority (ACMA) rating. ACMA ratings are used to classify children'
s television programming.
Corresponds to the JSON property acbRating
2502 2503 2504 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2502 def @acb_rating end |
#agcom_rating ⇒ String
The video's rating from Italy's Autorità per le Garanzie nelle Comunicazioni (
AGCOM).
Corresponds to the JSON property agcomRating
2508 2509 2510 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2508 def @agcom_rating end |
#anatel_rating ⇒ String
The video's Anatel (Asociación Nacional de Televisión) rating for Chilean
television.
Corresponds to the JSON property anatelRating
2514 2515 2516 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2514 def @anatel_rating end |
#bbfc_rating ⇒ String
The video's British Board of Film Classification (BBFC) rating.
Corresponds to the JSON property bbfcRating
2519 2520 2521 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2519 def @bbfc_rating end |
#bfvc_rating ⇒ String
The video's rating from Thailand's Board of Film and Video Censors.
Corresponds to the JSON property bfvcRating
2524 2525 2526 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2524 def @bfvc_rating end |
#bmukk_rating ⇒ String
The video's rating from the Austrian Board of Media Classification (
Bundesministerium für Unterricht, Kunst und Kultur).
Corresponds to the JSON property bmukkRating
2530 2531 2532 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2530 def @bmukk_rating end |
#catv_rating ⇒ String
Rating system for Canadian TV - Canadian TV Classification System The video's
rating from the Canadian Radio-Television and Telecommunications Commission (
CRTC) for Canadian English-language broadcasts. For more information, see the
Canadian Broadcast Standards Council website.
Corresponds to the JSON property catvRating
2538 2539 2540 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2538 def @catv_rating end |
#catvfr_rating ⇒ String
The video's rating from the Canadian Radio-Television and Telecommunications
Commission (CRTC) for Canadian French-language broadcasts. For more
information, see the Canadian Broadcast Standards Council website.
Corresponds to the JSON property catvfrRating
2545 2546 2547 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2545 def @catvfr_rating end |
#cbfc_rating ⇒ String
The video's Central Board of Film Certification (CBFC - India) rating.
Corresponds to the JSON property cbfcRating
2550 2551 2552 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2550 def @cbfc_rating end |
#ccc_rating ⇒ String
The video's Consejo de Calificación Cinematográfica (Chile) rating.
Corresponds to the JSON property cccRating
2555 2556 2557 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2555 def @ccc_rating end |
#cce_rating ⇒ String
The video's rating from Portugal's Comissão de Classificação de Espect´culos.
Corresponds to the JSON property cceRating
2560 2561 2562 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2560 def @cce_rating end |
#chfilm_rating ⇒ String
The video's rating in Switzerland.
Corresponds to the JSON property chfilmRating
2565 2566 2567 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2565 def @chfilm_rating end |
#chvrs_rating ⇒ String
The video's Canadian Home Video Rating System (CHVRS) rating.
Corresponds to the JSON property chvrsRating
2570 2571 2572 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2570 def @chvrs_rating end |
#cicf_rating ⇒ String
The video's rating from the Commission de Contrôle des Films (Belgium).
Corresponds to the JSON property cicfRating
2575 2576 2577 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2575 def @cicf_rating end |
#cna_rating ⇒ String
The video's rating from Romania's CONSILIUL NATIONAL AL AUDIOVIZUALULUI (CNA).
Corresponds to the JSON property cnaRating
2580 2581 2582 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2580 def @cna_rating end |
#cnc_rating ⇒ String
Rating system in France - Commission de classification cinematographique
Corresponds to the JSON property cncRating
2585 2586 2587 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2585 def @cnc_rating end |
#csa_rating ⇒ String
The video's rating from France's Conseil supérieur de l’audiovisuel, which
rates broadcast content.
Corresponds to the JSON property csaRating
2591 2592 2593 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2591 def @csa_rating end |
#cscf_rating ⇒ String
The video's rating from Luxembourg's Commission de surveillance de la
classification des films (CSCF).
Corresponds to the JSON property cscfRating
2597 2598 2599 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2597 def @cscf_rating end |
#czfilm_rating ⇒ String
The video's rating in the Czech Republic.
Corresponds to the JSON property czfilmRating
2602 2603 2604 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2602 def @czfilm_rating end |
#djctq_rating ⇒ String
The video's Departamento de Justiça, Classificação, Qualificação e Títulos (
DJCQT - Brazil) rating.
Corresponds to the JSON property djctqRating
2608 2609 2610 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2608 def @djctq_rating end |
#djctq_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its DJCQT (Brazil) rating.
Corresponds to the JSON property djctqRatingReasons
2613 2614 2615 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2613 def @djctq_rating_reasons end |
#ecbmct_rating ⇒ String
Rating system in Turkey - Evaluation and Classification Board of the Ministry
of Culture and Tourism
Corresponds to the JSON property ecbmctRating
2619 2620 2621 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2619 def @ecbmct_rating end |
#eefilm_rating ⇒ String
The video's rating in Estonia.
Corresponds to the JSON property eefilmRating
2624 2625 2626 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2624 def @eefilm_rating end |
#egfilm_rating ⇒ String
The video's rating in Egypt.
Corresponds to the JSON property egfilmRating
2629 2630 2631 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2629 def @egfilm_rating end |
#eirin_rating ⇒ String
The video's Eirin (映倫) rating. Eirin is the Japanese rating system.
Corresponds to the JSON property eirinRating
2634 2635 2636 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2634 def @eirin_rating end |
#fcbm_rating ⇒ String
The video's rating from Malaysia's Film Censorship Board.
Corresponds to the JSON property fcbmRating
2639 2640 2641 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2639 def @fcbm_rating end |
#fco_rating ⇒ String
The video's rating from Hong Kong's Office for Film, Newspaper and Article
Administration.
Corresponds to the JSON property fcoRating
2645 2646 2647 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2645 def @fco_rating end |
#fmoc_rating ⇒ String
This property has been deprecated. Use the contentDetails.contentRating.
cncRating instead.
Corresponds to the JSON property fmocRating
2651 2652 2653 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2651 def @fmoc_rating end |
#fpb_rating ⇒ String
The video's rating from South Africa's Film and Publication Board.
Corresponds to the JSON property fpbRating
2656 2657 2658 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2656 def @fpb_rating end |
#fpb_rating_reasons ⇒ Array<String>
Reasons that explain why the video received its FPB (South Africa) rating.
Corresponds to the JSON property fpbRatingReasons
2661 2662 2663 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2661 def @fpb_rating_reasons end |
#fsk_rating ⇒ String
The video's Freiwillige Selbstkontrolle der Filmwirtschaft (FSK - Germany)
rating.
Corresponds to the JSON property fskRating
2667 2668 2669 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2667 def @fsk_rating end |
#grfilm_rating ⇒ String
The video's rating in Greece.
Corresponds to the JSON property grfilmRating
2672 2673 2674 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2672 def @grfilm_rating end |
#icaa_rating ⇒ String
The video's Instituto de la Cinematografía y de las Artes Audiovisuales (ICAA -
Spain) rating.
Corresponds to the JSON property icaaRating
2678 2679 2680 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2678 def @icaa_rating end |
#ifco_rating ⇒ String
The video's Irish Film Classification Office (IFCO - Ireland) rating. See the
IFCO website for more information.
Corresponds to the JSON property ifcoRating
2684 2685 2686 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2684 def @ifco_rating end |
#ilfilm_rating ⇒ String
The video's rating in Israel.
Corresponds to the JSON property ilfilmRating
2689 2690 2691 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2689 def @ilfilm_rating end |
#incaa_rating ⇒ String
The video's INCAA (Instituto Nacional de Cine y Artes Audiovisuales -
Argentina) rating.
Corresponds to the JSON property incaaRating
2695 2696 2697 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2695 def @incaa_rating end |
#kfcb_rating ⇒ String
The video's rating from the Kenya Film Classification Board.
Corresponds to the JSON property kfcbRating
2700 2701 2702 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2700 def @kfcb_rating end |
#kijkwijzer_rating ⇒ String
The video's NICAM/Kijkwijzer rating from the Nederlands Instituut voor de
Classificatie van Audiovisuele Media (Netherlands).
Corresponds to the JSON property kijkwijzerRating
2706 2707 2708 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2706 def @kijkwijzer_rating end |
#kmrb_rating ⇒ String
The video's Korea Media Rating Board (영상물등급위원회) rating. The KMRB rates videos
in South Korea.
Corresponds to the JSON property kmrbRating
2712 2713 2714 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2712 def @kmrb_rating end |
#lsf_rating ⇒ String
The video's rating from Indonesia's Lembaga Sensor Film.
Corresponds to the JSON property lsfRating
2717 2718 2719 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2717 def @lsf_rating end |
#mccaa_rating ⇒ String
The video's rating from Malta's Film Age-Classification Board.
Corresponds to the JSON property mccaaRating
2722 2723 2724 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2722 def @mccaa_rating end |
#mccyp_rating ⇒ String
The video's rating from the Danish Film Institute's (Det Danske Filminstitut)
Media Council for Children and Young People.
Corresponds to the JSON property mccypRating
2728 2729 2730 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2728 def @mccyp_rating end |
#mcst_rating ⇒ String
The video's rating system for Vietnam - MCST
Corresponds to the JSON property mcstRating
2733 2734 2735 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2733 def @mcst_rating end |
#mda_rating ⇒ String
The video's rating from Singapore's Media Development Authority (MDA) and,
specifically, it's Board of Film Censors (BFC).
Corresponds to the JSON property mdaRating
2739 2740 2741 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2739 def @mda_rating end |
#medietilsynet_rating ⇒ String
The video's rating from Medietilsynet, the Norwegian Media Authority.
Corresponds to the JSON property medietilsynetRating
2744 2745 2746 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2744 def @medietilsynet_rating end |
#meku_rating ⇒ String
The video's rating from Finland's Kansallinen Audiovisuaalinen Instituutti (
National Audiovisual Institute).
Corresponds to the JSON property mekuRating
2750 2751 2752 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2750 def @meku_rating end |
#mena_mpaa_rating ⇒ String
The rating system for MENA countries, a clone of MPAA. It is needed to prevent
titles go live w/o additional QC check, since some of them can be
inappropriate for the countries at all. See b/33408548 for more details.
Corresponds to the JSON property menaMpaaRating
2757 2758 2759 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2757 def @mena_mpaa_rating end |
#mibac_rating ⇒ String
The video's rating from the Ministero dei Beni e delle Attività Culturali e
del Turismo (Italy).
Corresponds to the JSON property mibacRating
2763 2764 2765 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2763 def @mibac_rating end |
#moc_rating ⇒ String
The video's Ministerio de Cultura (Colombia) rating.
Corresponds to the JSON property mocRating
2768 2769 2770 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2768 def @moc_rating end |
#moctw_rating ⇒ String
The video's rating from Taiwan's Ministry of Culture (文化部).
Corresponds to the JSON property moctwRating
2773 2774 2775 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2773 def @moctw_rating end |
#mpaa_rating ⇒ String
The video's Motion Picture Association of America (MPAA) rating.
Corresponds to the JSON property mpaaRating
2778 2779 2780 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2778 def @mpaa_rating end |
#mpaat_rating ⇒ String
The rating system for trailer, DVD, and Ad in the US. See http://movielabs.com/
md/ratings/v2.3/html/US_MPAAT_Ratings.html.
Corresponds to the JSON property mpaatRating
2784 2785 2786 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2784 def @mpaat_rating end |
#mtrcb_rating ⇒ String
The video's rating from the Movie and Television Review and Classification
Board (Philippines).
Corresponds to the JSON property mtrcbRating
2790 2791 2792 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2790 def @mtrcb_rating end |
#nbc_rating ⇒ String
The video's rating from the Maldives National Bureau of Classification.
Corresponds to the JSON property nbcRating
2795 2796 2797 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2795 def @nbc_rating end |
#nbcpl_rating ⇒ String
The video's rating in Poland.
Corresponds to the JSON property nbcplRating
2800 2801 2802 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2800 def @nbcpl_rating end |
#nfrc_rating ⇒ String
The video's rating from the Bulgarian National Film Center.
Corresponds to the JSON property nfrcRating
2805 2806 2807 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2805 def @nfrc_rating end |
#nfvcb_rating ⇒ String
The video's rating from Nigeria's National Film and Video Censors Board.
Corresponds to the JSON property nfvcbRating
2810 2811 2812 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2810 def @nfvcb_rating end |
#nkclv_rating ⇒ String
The video's rating from the Nacionãlais Kino centrs (National Film Centre of
Latvia).
Corresponds to the JSON property nkclvRating
2816 2817 2818 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2816 def @nkclv_rating end |
#nmc_rating ⇒ String
The National Media Council ratings system for United Arab Emirates.
Corresponds to the JSON property nmcRating
2821 2822 2823 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2821 def @nmc_rating end |
#oflc_rating ⇒ String
The video's Office of Film and Literature Classification (OFLC - New Zealand)
rating.
Corresponds to the JSON property oflcRating
2827 2828 2829 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2827 def @oflc_rating end |
#pefilm_rating ⇒ String
The video's rating in Peru.
Corresponds to the JSON property pefilmRating
2832 2833 2834 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2832 def @pefilm_rating end |
#rcnof_rating ⇒ String
The video's rating from the Hungarian Nemzeti Filmiroda, the Rating Committee
of the National Office of Film.
Corresponds to the JSON property rcnofRating
2838 2839 2840 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2838 def @rcnof_rating end |
#resorteviolencia_rating ⇒ String
The video's rating in Venezuela.
Corresponds to the JSON property resorteviolenciaRating
2843 2844 2845 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2843 def @resorteviolencia_rating end |
#rtc_rating ⇒ String
The video's General Directorate of Radio, Television and Cinematography (
Mexico) rating.
Corresponds to the JSON property rtcRating
2849 2850 2851 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2849 def @rtc_rating end |
#rte_rating ⇒ String
The video's rating from Ireland's Raidió Teilifís Éireann.
Corresponds to the JSON property rteRating
2854 2855 2856 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2854 def @rte_rating end |
#russia_rating ⇒ String
The video's National Film Registry of the Russian Federation (MKRF - Russia)
rating.
Corresponds to the JSON property russiaRating
2860 2861 2862 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2860 def @russia_rating end |
#skfilm_rating ⇒ String
The video's rating in Slovakia.
Corresponds to the JSON property skfilmRating
2865 2866 2867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2865 def @skfilm_rating end |
#smais_rating ⇒ String
The video's rating in Iceland.
Corresponds to the JSON property smaisRating
2870 2871 2872 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2870 def @smais_rating end |
#smsa_rating ⇒ String
The video's rating from Statens medieråd (Sweden's National Media Council).
Corresponds to the JSON property smsaRating
2875 2876 2877 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2875 def @smsa_rating end |
#tvpg_rating ⇒ String
The video's TV Parental Guidelines (TVPG) rating.
Corresponds to the JSON property tvpgRating
2880 2881 2882 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2880 def @tvpg_rating end |
#yt_rating ⇒ String
A rating that YouTube uses to identify age-restricted content.
Corresponds to the JSON property ytRating
2885 2886 2887 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2885 def @yt_rating end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 2958 2959 2960 2961 2962 2963 2964 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2892 def update!(**args) @acb_rating = args[:acb_rating] if args.key?(:acb_rating) @agcom_rating = args[:agcom_rating] if args.key?(:agcom_rating) @anatel_rating = args[:anatel_rating] if args.key?(:anatel_rating) @bbfc_rating = args[:bbfc_rating] if args.key?(:bbfc_rating) @bfvc_rating = args[:bfvc_rating] if args.key?(:bfvc_rating) @bmukk_rating = args[:bmukk_rating] if args.key?(:bmukk_rating) @catv_rating = args[:catv_rating] if args.key?(:catv_rating) @catvfr_rating = args[:catvfr_rating] if args.key?(:catvfr_rating) @cbfc_rating = args[:cbfc_rating] if args.key?(:cbfc_rating) @ccc_rating = args[:ccc_rating] if args.key?(:ccc_rating) @cce_rating = args[:cce_rating] if args.key?(:cce_rating) @chfilm_rating = args[:chfilm_rating] if args.key?(:chfilm_rating) @chvrs_rating = args[:chvrs_rating] if args.key?(:chvrs_rating) @cicf_rating = args[:cicf_rating] if args.key?(:cicf_rating) @cna_rating = args[:cna_rating] if args.key?(:cna_rating) @cnc_rating = args[:cnc_rating] if args.key?(:cnc_rating) @csa_rating = args[:csa_rating] if args.key?(:csa_rating) @cscf_rating = args[:cscf_rating] if args.key?(:cscf_rating) @czfilm_rating = args[:czfilm_rating] if args.key?(:czfilm_rating) @djctq_rating = args[:djctq_rating] if args.key?(:djctq_rating) @djctq_rating_reasons = args[:djctq_rating_reasons] if args.key?(:djctq_rating_reasons) @ecbmct_rating = args[:ecbmct_rating] if args.key?(:ecbmct_rating) @eefilm_rating = args[:eefilm_rating] if args.key?(:eefilm_rating) @egfilm_rating = args[:egfilm_rating] if args.key?(:egfilm_rating) @eirin_rating = args[:eirin_rating] if args.key?(:eirin_rating) @fcbm_rating = args[:fcbm_rating] if args.key?(:fcbm_rating) @fco_rating = args[:fco_rating] if args.key?(:fco_rating) @fmoc_rating = args[:fmoc_rating] if args.key?(:fmoc_rating) @fpb_rating = args[:fpb_rating] if args.key?(:fpb_rating) @fpb_rating_reasons = args[:fpb_rating_reasons] if args.key?(:fpb_rating_reasons) @fsk_rating = args[:fsk_rating] if args.key?(:fsk_rating) @grfilm_rating = args[:grfilm_rating] if args.key?(:grfilm_rating) @icaa_rating = args[:icaa_rating] if args.key?(:icaa_rating) @ifco_rating = args[:ifco_rating] if args.key?(:ifco_rating) @ilfilm_rating = args[:ilfilm_rating] if args.key?(:ilfilm_rating) @incaa_rating = args[:incaa_rating] if args.key?(:incaa_rating) @kfcb_rating = args[:kfcb_rating] if args.key?(:kfcb_rating) @kijkwijzer_rating = args[:kijkwijzer_rating] if args.key?(:kijkwijzer_rating) @kmrb_rating = args[:kmrb_rating] if args.key?(:kmrb_rating) @lsf_rating = args[:lsf_rating] if args.key?(:lsf_rating) @mccaa_rating = args[:mccaa_rating] if args.key?(:mccaa_rating) @mccyp_rating = args[:mccyp_rating] if args.key?(:mccyp_rating) @mcst_rating = args[:mcst_rating] if args.key?(:mcst_rating) @mda_rating = args[:mda_rating] if args.key?(:mda_rating) @medietilsynet_rating = args[:medietilsynet_rating] if args.key?(:medietilsynet_rating) @meku_rating = args[:meku_rating] if args.key?(:meku_rating) @mena_mpaa_rating = args[:mena_mpaa_rating] if args.key?(:mena_mpaa_rating) @mibac_rating = args[:mibac_rating] if args.key?(:mibac_rating) @moc_rating = args[:moc_rating] if args.key?(:moc_rating) @moctw_rating = args[:moctw_rating] if args.key?(:moctw_rating) @mpaa_rating = args[:mpaa_rating] if args.key?(:mpaa_rating) @mpaat_rating = args[:mpaat_rating] if args.key?(:mpaat_rating) @mtrcb_rating = args[:mtrcb_rating] if args.key?(:mtrcb_rating) @nbc_rating = args[:nbc_rating] if args.key?(:nbc_rating) @nbcpl_rating = args[:nbcpl_rating] if args.key?(:nbcpl_rating) @nfrc_rating = args[:nfrc_rating] if args.key?(:nfrc_rating) @nfvcb_rating = args[:nfvcb_rating] if args.key?(:nfvcb_rating) @nkclv_rating = args[:nkclv_rating] if args.key?(:nkclv_rating) @nmc_rating = args[:nmc_rating] if args.key?(:nmc_rating) @oflc_rating = args[:oflc_rating] if args.key?(:oflc_rating) @pefilm_rating = args[:pefilm_rating] if args.key?(:pefilm_rating) @rcnof_rating = args[:rcnof_rating] if args.key?(:rcnof_rating) @resorteviolencia_rating = args[:resorteviolencia_rating] if args.key?(:resorteviolencia_rating) @rtc_rating = args[:rtc_rating] if args.key?(:rtc_rating) @rte_rating = args[:rte_rating] if args.key?(:rte_rating) @russia_rating = args[:russia_rating] if args.key?(:russia_rating) @skfilm_rating = args[:skfilm_rating] if args.key?(:skfilm_rating) @smais_rating = args[:smais_rating] if args.key?(:smais_rating) @smsa_rating = args[:smsa_rating] if args.key?(:smsa_rating) @tvpg_rating = args[:tvpg_rating] if args.key?(:tvpg_rating) @yt_rating = args[:yt_rating] if args.key?(:yt_rating) end |