Class: Google::Apis::YoutubeV3::Cuepoint
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Cuepoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Note that there may be a 5-second end-point resolution issue. For instance, if a cuepoint comes in for 22:03:27, we may stuff the cuepoint into 22:03:25 or 22:03:30, depending. This is an artifact of HLS.
Instance Attribute Summary collapse
-
#cue_type ⇒ String
Corresponds to the JSON property
cueType. -
#duration_secs ⇒ Fixnum
The duration of this cuepoint.
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The identifier for cuepoint resource.
-
#insertion_offset_time_ms ⇒ Fixnum
The time when the cuepoint should be inserted by offset to the broadcast actual start time.
-
#walltime_ms ⇒ Fixnum
The wall clock time at which the cuepoint should be inserted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Cuepoint
constructor
A new instance of Cuepoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Cuepoint
Returns a new instance of Cuepoint.
3045 3046 3047 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cue_type ⇒ String
Corresponds to the JSON property cueType
3016 3017 3018 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3016 def cue_type @cue_type end |
#duration_secs ⇒ Fixnum
The duration of this cuepoint.
Corresponds to the JSON property durationSecs
3021 3022 3023 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3021 def duration_secs @duration_secs end |
#etag ⇒ String
Corresponds to the JSON property etag
3026 3027 3028 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3026 def etag @etag end |
#id ⇒ String
The identifier for cuepoint resource.
Corresponds to the JSON property id
3031 3032 3033 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3031 def id @id end |
#insertion_offset_time_ms ⇒ Fixnum
The time when the cuepoint should be inserted by offset to the broadcast
actual start time.
Corresponds to the JSON property insertionOffsetTimeMs
3037 3038 3039 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3037 def insertion_offset_time_ms @insertion_offset_time_ms end |
#walltime_ms ⇒ Fixnum
The wall clock time at which the cuepoint should be inserted. Only one of
insertion_offset_time_ms and walltime_ms may be set at a time.
Corresponds to the JSON property walltimeMs
3043 3044 3045 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3043 def walltime_ms @walltime_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3050 3051 3052 3053 3054 3055 3056 3057 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3050 def update!(**args) @cue_type = args[:cue_type] if args.key?(:cue_type) @duration_secs = args[:duration_secs] if args.key?(:duration_secs) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @insertion_offset_time_ms = args[:insertion_offset_time_ms] if args.key?(:insertion_offset_time_ms) @walltime_ms = args[:walltime_ms] if args.key?(:walltime_ms) end |