Class: Google::Apis::YoutubeV3::CuepointSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Schedule to insert cuepoints into a broadcast by ads automator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CuepointSchedule

Returns a new instance of CuepointSchedule.



3216
3217
3218
# File 'lib/google/apis/youtube_v3/classes.rb', line 3216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

This field is semantically required. If it is set false or not set, other fields in this message will be ignored. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


3197
3198
3199
# File 'lib/google/apis/youtube_v3/classes.rb', line 3197

def enabled
  @enabled
end

#pause_ads_untilString

If set, automatic cuepoint insertion is paused until this timestamp ("No Ad Zone"). The value is specified in ISO 8601 format. Corresponds to the JSON property pauseAdsUntil

Returns:

  • (String)


3204
3205
3206
# File 'lib/google/apis/youtube_v3/classes.rb', line 3204

def pause_ads_until
  @pause_ads_until
end

#repeat_interval_secsFixnum

Interval frequency in seconds that api uses to insert cuepoints automatically. Corresponds to the JSON property repeatIntervalSecs

Returns:

  • (Fixnum)


3209
3210
3211
# File 'lib/google/apis/youtube_v3/classes.rb', line 3209

def repeat_interval_secs
  @repeat_interval_secs
end

#schedule_strategyString

The strategy to use when scheduling cuepoints. Corresponds to the JSON property scheduleStrategy

Returns:

  • (String)


3214
3215
3216
# File 'lib/google/apis/youtube_v3/classes.rb', line 3214

def schedule_strategy
  @schedule_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3221
3222
3223
3224
3225
3226
# File 'lib/google/apis/youtube_v3/classes.rb', line 3221

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @pause_ads_until = args[:pause_ads_until] if args.key?(:pause_ads_until)
  @repeat_interval_secs = args[:repeat_interval_secs] if args.key?(:repeat_interval_secs)
  @schedule_strategy = args[:schedule_strategy] if args.key?(:schedule_strategy)
end