Class: Google::Apis::YoutubeV3::CuepointSchedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Schedule to insert cuepoints into a broadcast by ads automator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CuepointSchedule

Returns a new instance of CuepointSchedule.



3013
3014
3015
# File 'lib/google/apis/youtube_v3/classes.rb', line 3013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

This field is semantically required. If it is set false or not set, other fields in this message will be ignored. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2994
2995
2996
# File 'lib/google/apis/youtube_v3/classes.rb', line 2994

def enabled
  @enabled
end

#pause_ads_untilString

If set, automatic cuepoint insertion is paused until this timestamp ("No Ad Zone"). The value is specified in ISO 8601 format. Corresponds to the JSON property pauseAdsUntil

Returns:

  • (String)


3001
3002
3003
# File 'lib/google/apis/youtube_v3/classes.rb', line 3001

def pause_ads_until
  @pause_ads_until
end

#repeat_interval_secsFixnum

Interval frequency in seconds that api uses to insert cuepoints automatically. Corresponds to the JSON property repeatIntervalSecs

Returns:

  • (Fixnum)


3006
3007
3008
# File 'lib/google/apis/youtube_v3/classes.rb', line 3006

def repeat_interval_secs
  @repeat_interval_secs
end

#schedule_strategyString

The strategy to use when scheduling cuepoints. Corresponds to the JSON property scheduleStrategy

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/youtube_v3/classes.rb', line 3011

def schedule_strategy
  @schedule_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3018
3019
3020
3021
3022
3023
# File 'lib/google/apis/youtube_v3/classes.rb', line 3018

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @pause_ads_until = args[:pause_ads_until] if args.key?(:pause_ads_until)
  @repeat_interval_secs = args[:repeat_interval_secs] if args.key?(:repeat_interval_secs)
  @schedule_strategy = args[:schedule_strategy] if args.key?(:schedule_strategy)
end