Class: Google::Apis::YoutubeV3::CuepointSchedule
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::CuepointSchedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Schedule to insert cuepoints into a broadcast by ads automator.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
This field is semantically required.
-
#pause_ads_until ⇒ String
If set, automatic cuepoint insertion is paused until this timestamp ("No Ad Zone").
-
#repeat_interval_secs ⇒ Fixnum
Interval frequency in seconds that api uses to insert cuepoints automatically.
-
#schedule_strategy ⇒ String
The strategy to use when scheduling cuepoints.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CuepointSchedule
constructor
A new instance of CuepointSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CuepointSchedule
Returns a new instance of CuepointSchedule.
3047 3048 3049 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
This field is semantically required. If it is set false or not set, other
fields in this message will be ignored.
Corresponds to the JSON property enabled
3028 3029 3030 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3028 def enabled @enabled end |
#pause_ads_until ⇒ String
If set, automatic cuepoint insertion is paused until this timestamp ("No Ad
Zone"). The value is specified in ISO 8601 format.
Corresponds to the JSON property pauseAdsUntil
3035 3036 3037 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3035 def pause_ads_until @pause_ads_until end |
#repeat_interval_secs ⇒ Fixnum
Interval frequency in seconds that api uses to insert cuepoints automatically.
Corresponds to the JSON property repeatIntervalSecs
3040 3041 3042 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3040 def repeat_interval_secs @repeat_interval_secs end |
#schedule_strategy ⇒ String
The strategy to use when scheduling cuepoints.
Corresponds to the JSON property scheduleStrategy
3045 3046 3047 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3045 def schedule_strategy @schedule_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3052 3053 3054 3055 3056 3057 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3052 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @pause_ads_until = args[:pause_ads_until] if args.key?(:pause_ads_until) @repeat_interval_secs = args[:repeat_interval_secs] if args.key?(:repeat_interval_secs) @schedule_strategy = args[:schedule_strategy] if args.key?(:schedule_strategy) end |