Class: Google::Apis::YoutubeV3::ImageSettings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ImageSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Branding properties for images associated with the channel.
Instance Attribute Summary collapse
-
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page.
-
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the given channel.
-
#banner_image_url ⇒ String
Banner image.
-
#banner_mobile_extra_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_image_url ⇒ String
Banner image.
-
#banner_mobile_low_image_url ⇒ String
Banner image.
-
#banner_mobile_medium_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_extra_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_image_url ⇒ String
Banner image.
-
#banner_tablet_low_image_url ⇒ String
Banner image.
-
#banner_tv_high_image_url ⇒ String
Banner image.
-
#banner_tv_image_url ⇒ String
Banner image.
-
#banner_tv_low_image_url ⇒ String
Banner image.
-
#banner_tv_medium_image_url ⇒ String
Banner image.
-
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
-
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the expanded video view of the video watch page.
-
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
-
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player in the default view of the video watch page.
-
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the channel or video pages.
-
#watch_icon_image_url ⇒ String
Corresponds to the JSON property
watchIconImageUrl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageSettings
constructor
A new instance of ImageSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageSettings
Returns a new instance of ImageSettings.
3637 3638 3639 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page. The image
should be 1200px by 615px, with a maximum file size of 128k.
Corresponds to the JSON property backgroundImageUrl
3524 3525 3526 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3524 def background_image_url @background_image_url end |
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the
given channel.
Corresponds to the JSON property bannerExternalUrl
3530 3531 3532 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3530 def @banner_external_url end |
#banner_image_url ⇒ String
Banner image. Desktop size (1060x175).
Corresponds to the JSON property bannerImageUrl
3535 3536 3537 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3535 def @banner_image_url end |
#banner_mobile_extra_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1440x395).
Corresponds to the JSON property bannerMobileExtraHdImageUrl
3540 3541 3542 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3540 def @banner_mobile_extra_hd_image_url end |
#banner_mobile_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1280x360).
Corresponds to the JSON property bannerMobileHdImageUrl
3545 3546 3547 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3545 def @banner_mobile_hd_image_url end |
#banner_mobile_image_url ⇒ String
Banner image. Mobile size (640x175).
Corresponds to the JSON property bannerMobileImageUrl
3550 3551 3552 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3550 def @banner_mobile_image_url end |
#banner_mobile_low_image_url ⇒ String
Banner image. Mobile size low resolution (320x88).
Corresponds to the JSON property bannerMobileLowImageUrl
3555 3556 3557 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3555 def @banner_mobile_low_image_url end |
#banner_mobile_medium_hd_image_url ⇒ String
Banner image. Mobile size medium/high resolution (960x263).
Corresponds to the JSON property bannerMobileMediumHdImageUrl
3560 3561 3562 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3560 def @banner_mobile_medium_hd_image_url end |
#banner_tablet_extra_hd_image_url ⇒ String
Banner image. Tablet size extra high resolution (2560x424).
Corresponds to the JSON property bannerTabletExtraHdImageUrl
3565 3566 3567 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3565 def @banner_tablet_extra_hd_image_url end |
#banner_tablet_hd_image_url ⇒ String
Banner image. Tablet size high resolution (2276x377).
Corresponds to the JSON property bannerTabletHdImageUrl
3570 3571 3572 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3570 def @banner_tablet_hd_image_url end |
#banner_tablet_image_url ⇒ String
Banner image. Tablet size (1707x283).
Corresponds to the JSON property bannerTabletImageUrl
3575 3576 3577 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3575 def @banner_tablet_image_url end |
#banner_tablet_low_image_url ⇒ String
Banner image. Tablet size low resolution (1138x188).
Corresponds to the JSON property bannerTabletLowImageUrl
3580 3581 3582 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3580 def @banner_tablet_low_image_url end |
#banner_tv_high_image_url ⇒ String
Banner image. TV size high resolution (1920x1080).
Corresponds to the JSON property bannerTvHighImageUrl
3585 3586 3587 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3585 def @banner_tv_high_image_url end |
#banner_tv_image_url ⇒ String
Banner image. TV size extra high resolution (2120x1192).
Corresponds to the JSON property bannerTvImageUrl
3590 3591 3592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3590 def @banner_tv_image_url end |
#banner_tv_low_image_url ⇒ String
Banner image. TV size low resolution (854x480).
Corresponds to the JSON property bannerTvLowImageUrl
3595 3596 3597 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3595 def @banner_tv_low_image_url end |
#banner_tv_medium_image_url ⇒ String
Banner image. TV size medium resolution (1280x720).
Corresponds to the JSON property bannerTvMediumImageUrl
3600 3601 3602 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3600 def @banner_tv_medium_image_url end |
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
Corresponds to the JSON property largeBrandedBannerImageImapScript
3605 3606 3607 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3605 def @large_branded_banner_image_imap_script end |
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the
expanded video view of the video watch page.
Corresponds to the JSON property largeBrandedBannerImageUrl
3611 3612 3613 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3611 def @large_branded_banner_image_url end |
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
Corresponds to the JSON property smallBrandedBannerImageImapScript
3616 3617 3618 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3616 def @small_branded_banner_image_imap_script end |
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player
in the default view of the video watch page. The URL for the image that
appears above the top-left corner of the video player. This is a 25-pixel-high
image with a flexible width that cannot exceed 170 pixels.
Corresponds to the JSON property smallBrandedBannerImageUrl
3624 3625 3626 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3624 def @small_branded_banner_image_url end |
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics
for views of the channel or video pages.
Corresponds to the JSON property trackingImageUrl
3630 3631 3632 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3630 def tracking_image_url @tracking_image_url end |
#watch_icon_image_url ⇒ String
Corresponds to the JSON property watchIconImageUrl
3635 3636 3637 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3635 def watch_icon_image_url @watch_icon_image_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3642 def update!(**args) @background_image_url = args[:background_image_url] if args.key?(:background_image_url) @banner_external_url = args[:banner_external_url] if args.key?(:banner_external_url) @banner_image_url = args[:banner_image_url] if args.key?(:banner_image_url) @banner_mobile_extra_hd_image_url = args[:banner_mobile_extra_hd_image_url] if args.key?(:banner_mobile_extra_hd_image_url) @banner_mobile_hd_image_url = args[:banner_mobile_hd_image_url] if args.key?(:banner_mobile_hd_image_url) @banner_mobile_image_url = args[:banner_mobile_image_url] if args.key?(:banner_mobile_image_url) @banner_mobile_low_image_url = args[:banner_mobile_low_image_url] if args.key?(:banner_mobile_low_image_url) @banner_mobile_medium_hd_image_url = args[:banner_mobile_medium_hd_image_url] if args.key?(:banner_mobile_medium_hd_image_url) @banner_tablet_extra_hd_image_url = args[:banner_tablet_extra_hd_image_url] if args.key?(:banner_tablet_extra_hd_image_url) @banner_tablet_hd_image_url = args[:banner_tablet_hd_image_url] if args.key?(:banner_tablet_hd_image_url) @banner_tablet_image_url = args[:banner_tablet_image_url] if args.key?(:banner_tablet_image_url) @banner_tablet_low_image_url = args[:banner_tablet_low_image_url] if args.key?(:banner_tablet_low_image_url) @banner_tv_high_image_url = args[:banner_tv_high_image_url] if args.key?(:banner_tv_high_image_url) @banner_tv_image_url = args[:banner_tv_image_url] if args.key?(:banner_tv_image_url) @banner_tv_low_image_url = args[:banner_tv_low_image_url] if args.key?(:banner_tv_low_image_url) @banner_tv_medium_image_url = args[:banner_tv_medium_image_url] if args.key?(:banner_tv_medium_image_url) @large_branded_banner_image_imap_script = args[:large_branded_banner_image_imap_script] if args.key?(:large_branded_banner_image_imap_script) @large_branded_banner_image_url = args[:large_branded_banner_image_url] if args.key?(:large_branded_banner_image_url) @small_branded_banner_image_imap_script = args[:small_branded_banner_image_imap_script] if args.key?(:small_branded_banner_image_imap_script) @small_branded_banner_image_url = args[:small_branded_banner_image_url] if args.key?(:small_branded_banner_image_url) @tracking_image_url = args[:tracking_image_url] if args.key?(:tracking_image_url) @watch_icon_image_url = args[:watch_icon_image_url] if args.key?(:watch_icon_image_url) end |