Class: Google::Apis::YoutubeV3::ImageSettings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ImageSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Branding properties for images associated with the channel.
Instance Attribute Summary collapse
-
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page.
-
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the given channel.
-
#banner_image_url ⇒ String
Banner image.
-
#banner_mobile_extra_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_image_url ⇒ String
Banner image.
-
#banner_mobile_low_image_url ⇒ String
Banner image.
-
#banner_mobile_medium_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_extra_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_image_url ⇒ String
Banner image.
-
#banner_tablet_low_image_url ⇒ String
Banner image.
-
#banner_tv_high_image_url ⇒ String
Banner image.
-
#banner_tv_image_url ⇒ String
Banner image.
-
#banner_tv_low_image_url ⇒ String
Banner image.
-
#banner_tv_medium_image_url ⇒ String
Banner image.
-
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
-
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the expanded video view of the video watch page.
-
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
-
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player in the default view of the video watch page.
-
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the channel or video pages.
-
#watch_icon_image_url ⇒ String
Corresponds to the JSON property
watchIconImageUrl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageSettings
constructor
A new instance of ImageSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageSettings
Returns a new instance of ImageSettings.
3633 3634 3635 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3633 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page. The image
should be 1200px by 615px, with a maximum file size of 128k.
Corresponds to the JSON property backgroundImageUrl
3520 3521 3522 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3520 def background_image_url @background_image_url end |
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the
given channel.
Corresponds to the JSON property bannerExternalUrl
3526 3527 3528 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3526 def @banner_external_url end |
#banner_image_url ⇒ String
Banner image. Desktop size (1060x175).
Corresponds to the JSON property bannerImageUrl
3531 3532 3533 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3531 def @banner_image_url end |
#banner_mobile_extra_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1440x395).
Corresponds to the JSON property bannerMobileExtraHdImageUrl
3536 3537 3538 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3536 def @banner_mobile_extra_hd_image_url end |
#banner_mobile_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1280x360).
Corresponds to the JSON property bannerMobileHdImageUrl
3541 3542 3543 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3541 def @banner_mobile_hd_image_url end |
#banner_mobile_image_url ⇒ String
Banner image. Mobile size (640x175).
Corresponds to the JSON property bannerMobileImageUrl
3546 3547 3548 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3546 def @banner_mobile_image_url end |
#banner_mobile_low_image_url ⇒ String
Banner image. Mobile size low resolution (320x88).
Corresponds to the JSON property bannerMobileLowImageUrl
3551 3552 3553 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3551 def @banner_mobile_low_image_url end |
#banner_mobile_medium_hd_image_url ⇒ String
Banner image. Mobile size medium/high resolution (960x263).
Corresponds to the JSON property bannerMobileMediumHdImageUrl
3556 3557 3558 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3556 def @banner_mobile_medium_hd_image_url end |
#banner_tablet_extra_hd_image_url ⇒ String
Banner image. Tablet size extra high resolution (2560x424).
Corresponds to the JSON property bannerTabletExtraHdImageUrl
3561 3562 3563 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3561 def @banner_tablet_extra_hd_image_url end |
#banner_tablet_hd_image_url ⇒ String
Banner image. Tablet size high resolution (2276x377).
Corresponds to the JSON property bannerTabletHdImageUrl
3566 3567 3568 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3566 def @banner_tablet_hd_image_url end |
#banner_tablet_image_url ⇒ String
Banner image. Tablet size (1707x283).
Corresponds to the JSON property bannerTabletImageUrl
3571 3572 3573 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3571 def @banner_tablet_image_url end |
#banner_tablet_low_image_url ⇒ String
Banner image. Tablet size low resolution (1138x188).
Corresponds to the JSON property bannerTabletLowImageUrl
3576 3577 3578 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3576 def @banner_tablet_low_image_url end |
#banner_tv_high_image_url ⇒ String
Banner image. TV size high resolution (1920x1080).
Corresponds to the JSON property bannerTvHighImageUrl
3581 3582 3583 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3581 def @banner_tv_high_image_url end |
#banner_tv_image_url ⇒ String
Banner image. TV size extra high resolution (2120x1192).
Corresponds to the JSON property bannerTvImageUrl
3586 3587 3588 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3586 def @banner_tv_image_url end |
#banner_tv_low_image_url ⇒ String
Banner image. TV size low resolution (854x480).
Corresponds to the JSON property bannerTvLowImageUrl
3591 3592 3593 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3591 def @banner_tv_low_image_url end |
#banner_tv_medium_image_url ⇒ String
Banner image. TV size medium resolution (1280x720).
Corresponds to the JSON property bannerTvMediumImageUrl
3596 3597 3598 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3596 def @banner_tv_medium_image_url end |
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
Corresponds to the JSON property largeBrandedBannerImageImapScript
3601 3602 3603 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3601 def @large_branded_banner_image_imap_script end |
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the
expanded video view of the video watch page.
Corresponds to the JSON property largeBrandedBannerImageUrl
3607 3608 3609 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3607 def @large_branded_banner_image_url end |
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
Corresponds to the JSON property smallBrandedBannerImageImapScript
3612 3613 3614 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3612 def @small_branded_banner_image_imap_script end |
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player
in the default view of the video watch page. The URL for the image that
appears above the top-left corner of the video player. This is a 25-pixel-high
image with a flexible width that cannot exceed 170 pixels.
Corresponds to the JSON property smallBrandedBannerImageUrl
3620 3621 3622 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3620 def @small_branded_banner_image_url end |
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics
for views of the channel or video pages.
Corresponds to the JSON property trackingImageUrl
3626 3627 3628 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3626 def tracking_image_url @tracking_image_url end |
#watch_icon_image_url ⇒ String
Corresponds to the JSON property watchIconImageUrl
3631 3632 3633 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3631 def watch_icon_image_url @watch_icon_image_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3638 def update!(**args) @background_image_url = args[:background_image_url] if args.key?(:background_image_url) @banner_external_url = args[:banner_external_url] if args.key?(:banner_external_url) @banner_image_url = args[:banner_image_url] if args.key?(:banner_image_url) @banner_mobile_extra_hd_image_url = args[:banner_mobile_extra_hd_image_url] if args.key?(:banner_mobile_extra_hd_image_url) @banner_mobile_hd_image_url = args[:banner_mobile_hd_image_url] if args.key?(:banner_mobile_hd_image_url) @banner_mobile_image_url = args[:banner_mobile_image_url] if args.key?(:banner_mobile_image_url) @banner_mobile_low_image_url = args[:banner_mobile_low_image_url] if args.key?(:banner_mobile_low_image_url) @banner_mobile_medium_hd_image_url = args[:banner_mobile_medium_hd_image_url] if args.key?(:banner_mobile_medium_hd_image_url) @banner_tablet_extra_hd_image_url = args[:banner_tablet_extra_hd_image_url] if args.key?(:banner_tablet_extra_hd_image_url) @banner_tablet_hd_image_url = args[:banner_tablet_hd_image_url] if args.key?(:banner_tablet_hd_image_url) @banner_tablet_image_url = args[:banner_tablet_image_url] if args.key?(:banner_tablet_image_url) @banner_tablet_low_image_url = args[:banner_tablet_low_image_url] if args.key?(:banner_tablet_low_image_url) @banner_tv_high_image_url = args[:banner_tv_high_image_url] if args.key?(:banner_tv_high_image_url) @banner_tv_image_url = args[:banner_tv_image_url] if args.key?(:banner_tv_image_url) @banner_tv_low_image_url = args[:banner_tv_low_image_url] if args.key?(:banner_tv_low_image_url) @banner_tv_medium_image_url = args[:banner_tv_medium_image_url] if args.key?(:banner_tv_medium_image_url) @large_branded_banner_image_imap_script = args[:large_branded_banner_image_imap_script] if args.key?(:large_branded_banner_image_imap_script) @large_branded_banner_image_url = args[:large_branded_banner_image_url] if args.key?(:large_branded_banner_image_url) @small_branded_banner_image_imap_script = args[:small_branded_banner_image_imap_script] if args.key?(:small_branded_banner_image_imap_script) @small_branded_banner_image_url = args[:small_branded_banner_image_url] if args.key?(:small_branded_banner_image_url) @tracking_image_url = args[:tracking_image_url] if args.key?(:tracking_image_url) @watch_icon_image_url = args[:watch_icon_image_url] if args.key?(:watch_icon_image_url) end |