Class: Google::Apis::YoutubeV3::ImageSettings
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ImageSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Branding properties for images associated with the channel.
Instance Attribute Summary collapse
-
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page.
-
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the given channel.
-
#banner_image_url ⇒ String
Banner image.
-
#banner_mobile_extra_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_hd_image_url ⇒ String
Banner image.
-
#banner_mobile_image_url ⇒ String
Banner image.
-
#banner_mobile_low_image_url ⇒ String
Banner image.
-
#banner_mobile_medium_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_extra_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_hd_image_url ⇒ String
Banner image.
-
#banner_tablet_image_url ⇒ String
Banner image.
-
#banner_tablet_low_image_url ⇒ String
Banner image.
-
#banner_tv_high_image_url ⇒ String
Banner image.
-
#banner_tv_image_url ⇒ String
Banner image.
-
#banner_tv_low_image_url ⇒ String
Banner image.
-
#banner_tv_medium_image_url ⇒ String
Banner image.
-
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
-
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the expanded video view of the video watch page.
-
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
-
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player in the default view of the video watch page.
-
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the channel or video pages.
-
#watch_icon_image_url ⇒ String
Corresponds to the JSON property
watchIconImageUrl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageSettings
constructor
A new instance of ImageSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageSettings
Returns a new instance of ImageSettings.
3504 3505 3506 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#background_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the background image shown on the video watch page. The image
should be 1200px by 615px, with a maximum file size of 128k.
Corresponds to the JSON property backgroundImageUrl
3391 3392 3393 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3391 def background_image_url @background_image_url end |
#banner_external_url ⇒ String
This is generated when a ChannelBanner.Insert request has succeeded for the
given channel.
Corresponds to the JSON property bannerExternalUrl
3397 3398 3399 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3397 def @banner_external_url end |
#banner_image_url ⇒ String
Banner image. Desktop size (1060x175).
Corresponds to the JSON property bannerImageUrl
3402 3403 3404 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3402 def @banner_image_url end |
#banner_mobile_extra_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1440x395).
Corresponds to the JSON property bannerMobileExtraHdImageUrl
3407 3408 3409 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3407 def @banner_mobile_extra_hd_image_url end |
#banner_mobile_hd_image_url ⇒ String
Banner image. Mobile size high resolution (1280x360).
Corresponds to the JSON property bannerMobileHdImageUrl
3412 3413 3414 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3412 def @banner_mobile_hd_image_url end |
#banner_mobile_image_url ⇒ String
Banner image. Mobile size (640x175).
Corresponds to the JSON property bannerMobileImageUrl
3417 3418 3419 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3417 def @banner_mobile_image_url end |
#banner_mobile_low_image_url ⇒ String
Banner image. Mobile size low resolution (320x88).
Corresponds to the JSON property bannerMobileLowImageUrl
3422 3423 3424 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3422 def @banner_mobile_low_image_url end |
#banner_mobile_medium_hd_image_url ⇒ String
Banner image. Mobile size medium/high resolution (960x263).
Corresponds to the JSON property bannerMobileMediumHdImageUrl
3427 3428 3429 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3427 def @banner_mobile_medium_hd_image_url end |
#banner_tablet_extra_hd_image_url ⇒ String
Banner image. Tablet size extra high resolution (2560x424).
Corresponds to the JSON property bannerTabletExtraHdImageUrl
3432 3433 3434 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3432 def @banner_tablet_extra_hd_image_url end |
#banner_tablet_hd_image_url ⇒ String
Banner image. Tablet size high resolution (2276x377).
Corresponds to the JSON property bannerTabletHdImageUrl
3437 3438 3439 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3437 def @banner_tablet_hd_image_url end |
#banner_tablet_image_url ⇒ String
Banner image. Tablet size (1707x283).
Corresponds to the JSON property bannerTabletImageUrl
3442 3443 3444 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3442 def @banner_tablet_image_url end |
#banner_tablet_low_image_url ⇒ String
Banner image. Tablet size low resolution (1138x188).
Corresponds to the JSON property bannerTabletLowImageUrl
3447 3448 3449 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3447 def @banner_tablet_low_image_url end |
#banner_tv_high_image_url ⇒ String
Banner image. TV size high resolution (1920x1080).
Corresponds to the JSON property bannerTvHighImageUrl
3452 3453 3454 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3452 def @banner_tv_high_image_url end |
#banner_tv_image_url ⇒ String
Banner image. TV size extra high resolution (2120x1192).
Corresponds to the JSON property bannerTvImageUrl
3457 3458 3459 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3457 def @banner_tv_image_url end |
#banner_tv_low_image_url ⇒ String
Banner image. TV size low resolution (854x480).
Corresponds to the JSON property bannerTvLowImageUrl
3462 3463 3464 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3462 def @banner_tv_low_image_url end |
#banner_tv_medium_image_url ⇒ String
Banner image. TV size medium resolution (1280x720).
Corresponds to the JSON property bannerTvMediumImageUrl
3467 3468 3469 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3467 def @banner_tv_medium_image_url end |
#large_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the large banner image.
Corresponds to the JSON property largeBrandedBannerImageImapScript
3472 3473 3474 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3472 def @large_branded_banner_image_imap_script end |
#large_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 854px by 70px image that appears below the video player in the
expanded video view of the video watch page.
Corresponds to the JSON property largeBrandedBannerImageUrl
3478 3479 3480 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3478 def @large_branded_banner_image_url end |
#small_branded_banner_image_imap_script ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The image map script for the small banner image.
Corresponds to the JSON property smallBrandedBannerImageImapScript
3483 3484 3485 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3483 def @small_branded_banner_image_imap_script end |
#small_branded_banner_image_url ⇒ Google::Apis::YoutubeV3::LocalizedProperty
The URL for the 640px by 70px banner image that appears below the video player
in the default view of the video watch page. The URL for the image that
appears above the top-left corner of the video player. This is a 25-pixel-high
image with a flexible width that cannot exceed 170 pixels.
Corresponds to the JSON property smallBrandedBannerImageUrl
3491 3492 3493 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3491 def @small_branded_banner_image_url end |
#tracking_image_url ⇒ String
The URL for a 1px by 1px tracking pixel that can be used to collect statistics
for views of the channel or video pages.
Corresponds to the JSON property trackingImageUrl
3497 3498 3499 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3497 def tracking_image_url @tracking_image_url end |
#watch_icon_image_url ⇒ String
Corresponds to the JSON property watchIconImageUrl
3502 3503 3504 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3502 def watch_icon_image_url @watch_icon_image_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 3524 3525 3526 3527 3528 3529 3530 3531 3532 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3509 def update!(**args) @background_image_url = args[:background_image_url] if args.key?(:background_image_url) @banner_external_url = args[:banner_external_url] if args.key?(:banner_external_url) @banner_image_url = args[:banner_image_url] if args.key?(:banner_image_url) @banner_mobile_extra_hd_image_url = args[:banner_mobile_extra_hd_image_url] if args.key?(:banner_mobile_extra_hd_image_url) @banner_mobile_hd_image_url = args[:banner_mobile_hd_image_url] if args.key?(:banner_mobile_hd_image_url) @banner_mobile_image_url = args[:banner_mobile_image_url] if args.key?(:banner_mobile_image_url) @banner_mobile_low_image_url = args[:banner_mobile_low_image_url] if args.key?(:banner_mobile_low_image_url) @banner_mobile_medium_hd_image_url = args[:banner_mobile_medium_hd_image_url] if args.key?(:banner_mobile_medium_hd_image_url) @banner_tablet_extra_hd_image_url = args[:banner_tablet_extra_hd_image_url] if args.key?(:banner_tablet_extra_hd_image_url) @banner_tablet_hd_image_url = args[:banner_tablet_hd_image_url] if args.key?(:banner_tablet_hd_image_url) @banner_tablet_image_url = args[:banner_tablet_image_url] if args.key?(:banner_tablet_image_url) @banner_tablet_low_image_url = args[:banner_tablet_low_image_url] if args.key?(:banner_tablet_low_image_url) @banner_tv_high_image_url = args[:banner_tv_high_image_url] if args.key?(:banner_tv_high_image_url) @banner_tv_image_url = args[:banner_tv_image_url] if args.key?(:banner_tv_image_url) @banner_tv_low_image_url = args[:banner_tv_low_image_url] if args.key?(:banner_tv_low_image_url) @banner_tv_medium_image_url = args[:banner_tv_medium_image_url] if args.key?(:banner_tv_medium_image_url) @large_branded_banner_image_imap_script = args[:large_branded_banner_image_imap_script] if args.key?(:large_branded_banner_image_imap_script) @large_branded_banner_image_url = args[:large_branded_banner_image_url] if args.key?(:large_branded_banner_image_url) @small_branded_banner_image_imap_script = args[:small_branded_banner_image_imap_script] if args.key?(:small_branded_banner_image_imap_script) @small_branded_banner_image_url = args[:small_branded_banner_image_url] if args.key?(:small_branded_banner_image_url) @tracking_image_url = args[:tracking_image_url] if args.key?(:tracking_image_url) @watch_icon_image_url = args[:watch_icon_image_url] if args.key?(:watch_icon_image_url) end |