Class: Google::Apis::YoutubeV3::ImageSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Branding properties for images associated with the channel.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageSettings

Returns a new instance of ImageSettings.



3464
3465
3466
# File 'lib/google/apis/youtube_v3/classes.rb', line 3464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#background_image_urlGoogle::Apis::YoutubeV3::LocalizedProperty

The URL for the background image shown on the video watch page. The image should be 1200px by 615px, with a maximum file size of 128k. Corresponds to the JSON property backgroundImageUrl



3351
3352
3353
# File 'lib/google/apis/youtube_v3/classes.rb', line 3351

def background_image_url
  @background_image_url
end

This is generated when a ChannelBanner.Insert request has succeeded for the given channel. Corresponds to the JSON property bannerExternalUrl

Returns:

  • (String)


3357
3358
3359
# File 'lib/google/apis/youtube_v3/classes.rb', line 3357

def banner_external_url
  @banner_external_url
end

Banner image. Desktop size (1060x175). Corresponds to the JSON property bannerImageUrl

Returns:

  • (String)


3362
3363
3364
# File 'lib/google/apis/youtube_v3/classes.rb', line 3362

def banner_image_url
  @banner_image_url
end

Banner image. Mobile size high resolution (1440x395). Corresponds to the JSON property bannerMobileExtraHdImageUrl

Returns:

  • (String)


3367
3368
3369
# File 'lib/google/apis/youtube_v3/classes.rb', line 3367

def banner_mobile_extra_hd_image_url
  @banner_mobile_extra_hd_image_url
end

Banner image. Mobile size high resolution (1280x360). Corresponds to the JSON property bannerMobileHdImageUrl

Returns:

  • (String)


3372
3373
3374
# File 'lib/google/apis/youtube_v3/classes.rb', line 3372

def banner_mobile_hd_image_url
  @banner_mobile_hd_image_url
end

Banner image. Mobile size (640x175). Corresponds to the JSON property bannerMobileImageUrl

Returns:

  • (String)


3377
3378
3379
# File 'lib/google/apis/youtube_v3/classes.rb', line 3377

def banner_mobile_image_url
  @banner_mobile_image_url
end

Banner image. Mobile size low resolution (320x88). Corresponds to the JSON property bannerMobileLowImageUrl

Returns:

  • (String)


3382
3383
3384
# File 'lib/google/apis/youtube_v3/classes.rb', line 3382

def banner_mobile_low_image_url
  @banner_mobile_low_image_url
end

Banner image. Mobile size medium/high resolution (960x263). Corresponds to the JSON property bannerMobileMediumHdImageUrl

Returns:

  • (String)


3387
3388
3389
# File 'lib/google/apis/youtube_v3/classes.rb', line 3387

def banner_mobile_medium_hd_image_url
  @banner_mobile_medium_hd_image_url
end

Banner image. Tablet size extra high resolution (2560x424). Corresponds to the JSON property bannerTabletExtraHdImageUrl

Returns:

  • (String)


3392
3393
3394
# File 'lib/google/apis/youtube_v3/classes.rb', line 3392

def banner_tablet_extra_hd_image_url
  @banner_tablet_extra_hd_image_url
end

Banner image. Tablet size high resolution (2276x377). Corresponds to the JSON property bannerTabletHdImageUrl

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/youtube_v3/classes.rb', line 3397

def banner_tablet_hd_image_url
  @banner_tablet_hd_image_url
end

Banner image. Tablet size (1707x283). Corresponds to the JSON property bannerTabletImageUrl

Returns:

  • (String)


3402
3403
3404
# File 'lib/google/apis/youtube_v3/classes.rb', line 3402

def banner_tablet_image_url
  @banner_tablet_image_url
end

Banner image. Tablet size low resolution (1138x188). Corresponds to the JSON property bannerTabletLowImageUrl

Returns:

  • (String)


3407
3408
3409
# File 'lib/google/apis/youtube_v3/classes.rb', line 3407

def banner_tablet_low_image_url
  @banner_tablet_low_image_url
end

Banner image. TV size high resolution (1920x1080). Corresponds to the JSON property bannerTvHighImageUrl

Returns:

  • (String)


3412
3413
3414
# File 'lib/google/apis/youtube_v3/classes.rb', line 3412

def banner_tv_high_image_url
  @banner_tv_high_image_url
end

Banner image. TV size extra high resolution (2120x1192). Corresponds to the JSON property bannerTvImageUrl

Returns:

  • (String)


3417
3418
3419
# File 'lib/google/apis/youtube_v3/classes.rb', line 3417

def banner_tv_image_url
  @banner_tv_image_url
end

Banner image. TV size low resolution (854x480). Corresponds to the JSON property bannerTvLowImageUrl

Returns:

  • (String)


3422
3423
3424
# File 'lib/google/apis/youtube_v3/classes.rb', line 3422

def banner_tv_low_image_url
  @banner_tv_low_image_url
end

Banner image. TV size medium resolution (1280x720). Corresponds to the JSON property bannerTvMediumImageUrl

Returns:

  • (String)


3427
3428
3429
# File 'lib/google/apis/youtube_v3/classes.rb', line 3427

def banner_tv_medium_image_url
  @banner_tv_medium_image_url
end

#large_branded_banner_image_imap_scriptGoogle::Apis::YoutubeV3::LocalizedProperty

The image map script for the large banner image. Corresponds to the JSON property largeBrandedBannerImageImapScript



3432
3433
3434
# File 'lib/google/apis/youtube_v3/classes.rb', line 3432

def large_branded_banner_image_imap_script
  @large_branded_banner_image_imap_script
end

#large_branded_banner_image_urlGoogle::Apis::YoutubeV3::LocalizedProperty

The URL for the 854px by 70px image that appears below the video player in the expanded video view of the video watch page. Corresponds to the JSON property largeBrandedBannerImageUrl



3438
3439
3440
# File 'lib/google/apis/youtube_v3/classes.rb', line 3438

def large_branded_banner_image_url
  @large_branded_banner_image_url
end

#small_branded_banner_image_imap_scriptGoogle::Apis::YoutubeV3::LocalizedProperty

The image map script for the small banner image. Corresponds to the JSON property smallBrandedBannerImageImapScript



3443
3444
3445
# File 'lib/google/apis/youtube_v3/classes.rb', line 3443

def small_branded_banner_image_imap_script
  @small_branded_banner_image_imap_script
end

#small_branded_banner_image_urlGoogle::Apis::YoutubeV3::LocalizedProperty

The URL for the 640px by 70px banner image that appears below the video player in the default view of the video watch page. The URL for the image that appears above the top-left corner of the video player. This is a 25-pixel-high image with a flexible width that cannot exceed 170 pixels. Corresponds to the JSON property smallBrandedBannerImageUrl



3451
3452
3453
# File 'lib/google/apis/youtube_v3/classes.rb', line 3451

def small_branded_banner_image_url
  @small_branded_banner_image_url
end

#tracking_image_urlString

The URL for a 1px by 1px tracking pixel that can be used to collect statistics for views of the channel or video pages. Corresponds to the JSON property trackingImageUrl

Returns:

  • (String)


3457
3458
3459
# File 'lib/google/apis/youtube_v3/classes.rb', line 3457

def tracking_image_url
  @tracking_image_url
end

#watch_icon_image_urlString

Corresponds to the JSON property watchIconImageUrl

Returns:

  • (String)


3462
3463
3464
# File 'lib/google/apis/youtube_v3/classes.rb', line 3462

def watch_icon_image_url
  @watch_icon_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3469
3470
3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
# File 'lib/google/apis/youtube_v3/classes.rb', line 3469

def update!(**args)
  @background_image_url = args[:background_image_url] if args.key?(:background_image_url)
  @banner_external_url = args[:banner_external_url] if args.key?(:banner_external_url)
  @banner_image_url = args[:banner_image_url] if args.key?(:banner_image_url)
  @banner_mobile_extra_hd_image_url = args[:banner_mobile_extra_hd_image_url] if args.key?(:banner_mobile_extra_hd_image_url)
  @banner_mobile_hd_image_url = args[:banner_mobile_hd_image_url] if args.key?(:banner_mobile_hd_image_url)
  @banner_mobile_image_url = args[:banner_mobile_image_url] if args.key?(:banner_mobile_image_url)
  @banner_mobile_low_image_url = args[:banner_mobile_low_image_url] if args.key?(:banner_mobile_low_image_url)
  @banner_mobile_medium_hd_image_url = args[:banner_mobile_medium_hd_image_url] if args.key?(:banner_mobile_medium_hd_image_url)
  @banner_tablet_extra_hd_image_url = args[:banner_tablet_extra_hd_image_url] if args.key?(:banner_tablet_extra_hd_image_url)
  @banner_tablet_hd_image_url = args[:banner_tablet_hd_image_url] if args.key?(:banner_tablet_hd_image_url)
  @banner_tablet_image_url = args[:banner_tablet_image_url] if args.key?(:banner_tablet_image_url)
  @banner_tablet_low_image_url = args[:banner_tablet_low_image_url] if args.key?(:banner_tablet_low_image_url)
  @banner_tv_high_image_url = args[:banner_tv_high_image_url] if args.key?(:banner_tv_high_image_url)
  @banner_tv_image_url = args[:banner_tv_image_url] if args.key?(:banner_tv_image_url)
  @banner_tv_low_image_url = args[:banner_tv_low_image_url] if args.key?(:banner_tv_low_image_url)
  @banner_tv_medium_image_url = args[:banner_tv_medium_image_url] if args.key?(:banner_tv_medium_image_url)
  @large_branded_banner_image_imap_script = args[:large_branded_banner_image_imap_script] if args.key?(:large_branded_banner_image_imap_script)
  @large_branded_banner_image_url = args[:large_branded_banner_image_url] if args.key?(:large_branded_banner_image_url)
  @small_branded_banner_image_imap_script = args[:small_branded_banner_image_imap_script] if args.key?(:small_branded_banner_image_imap_script)
  @small_branded_banner_image_url = args[:small_branded_banner_image_url] if args.key?(:small_branded_banner_image_url)
  @tracking_image_url = args[:tracking_image_url] if args.key?(:tracking_image_url)
  @watch_icon_image_url = args[:watch_icon_image_url] if args.key?(:watch_icon_image_url)
end