Class: Google::Apis::YoutubeV3::IngestionInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes information necessary for ingesting an RTMP, HTTP, or SRT stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IngestionInfo

Returns a new instance of IngestionInfo.



3572
3573
3574
# File 'lib/google/apis/youtube_v3/classes.rb', line 3572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_ingestion_addressString

The backup ingestion URL that you should use to stream video to YouTube. You have the option of simultaneously streaming the content that you are sending to the ingestionAddress to this URL. Corresponds to the JSON property backupIngestionAddress

Returns:

  • (String)


3544
3545
3546
# File 'lib/google/apis/youtube_v3/classes.rb', line 3544

def backup_ingestion_address
  @backup_ingestion_address
end

#ingestion_addressString

The primary ingestion URL that you should use to stream video to YouTube. You must stream video to this URL. Depending on which application or tool you use to encode your video stream, you may need to enter the stream URL and stream name separately or you may need to concatenate them in the following format: * STREAM_URL/STREAM_NAME* Corresponds to the JSON property ingestionAddress

Returns:

  • (String)


3553
3554
3555
# File 'lib/google/apis/youtube_v3/classes.rb', line 3553

def ingestion_address
  @ingestion_address
end

#rtmps_backup_ingestion_addressString

This ingestion url may be used instead of backupIngestionAddress in order to stream via RTMPS. Not applicable to non-RTMP streams. Corresponds to the JSON property rtmpsBackupIngestionAddress

Returns:

  • (String)


3559
3560
3561
# File 'lib/google/apis/youtube_v3/classes.rb', line 3559

def rtmps_backup_ingestion_address
  @rtmps_backup_ingestion_address
end

#rtmps_ingestion_addressString

This ingestion url may be used instead of ingestionAddress in order to stream via RTMPS. Not applicable to non-RTMP streams. Corresponds to the JSON property rtmpsIngestionAddress

Returns:

  • (String)


3565
3566
3567
# File 'lib/google/apis/youtube_v3/classes.rb', line 3565

def rtmps_ingestion_address
  @rtmps_ingestion_address
end

#stream_nameString

The stream name that YouTube assigns to the video stream. Corresponds to the JSON property streamName

Returns:

  • (String)


3570
3571
3572
# File 'lib/google/apis/youtube_v3/classes.rb', line 3570

def stream_name
  @stream_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3577
3578
3579
3580
3581
3582
3583
# File 'lib/google/apis/youtube_v3/classes.rb', line 3577

def update!(**args)
  @backup_ingestion_address = args[:backup_ingestion_address] if args.key?(:backup_ingestion_address)
  @ingestion_address = args[:ingestion_address] if args.key?(:ingestion_address)
  @rtmps_backup_ingestion_address = args[:rtmps_backup_ingestion_address] if args.key?(:rtmps_backup_ingestion_address)
  @rtmps_ingestion_address = args[:rtmps_ingestion_address] if args.key?(:rtmps_ingestion_address)
  @stream_name = args[:stream_name] if args.key?(:stream_name)
end