Class: Google::Apis::YoutubeV3::InvideoTiming
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::InvideoTiming
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Describes a temporal position of a visual widget inside a video.
Instance Attribute Summary collapse
-
#duration_ms ⇒ Fixnum
Defines the duration in milliseconds for which the promotion should be displayed.
-
#offset_ms ⇒ Fixnum
Defines the time at which the promotion will appear.
-
#type ⇒ String
Describes a timing type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InvideoTiming
constructor
A new instance of InvideoTiming.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InvideoTiming
Returns a new instance of InvideoTiming.
3683 3684 3685 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration_ms ⇒ Fixnum
Defines the duration in milliseconds for which the promotion should be
displayed. If missing, the client should use the default.
Corresponds to the JSON property durationMs
3666 3667 3668 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3666 def duration_ms @duration_ms end |
#offset_ms ⇒ Fixnum
Defines the time at which the promotion will appear. Depending on the value of
type the value of the offsetMs field will represent a time offset from the
start or from the end of the video, expressed in milliseconds.
Corresponds to the JSON property offsetMs
3673 3674 3675 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3673 def offset_ms @offset_ms end |
#type ⇒ String
Describes a timing type. If the value is offsetFromStart, then the offsetMs
field represents an offset from the start of the video. If the value is
offsetFromEnd, then the offsetMs field represents an offset from the end of
the video.
Corresponds to the JSON property type
3681 3682 3683 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3681 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3688 3689 3690 3691 3692 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3688 def update!(**args) @duration_ms = args[:duration_ms] if args.key?(:duration_ms) @offset_ms = args[:offset_ms] if args.key?(:offset_ms) @type = args[:type] if args.key?(:type) end |