Class: Google::Apis::YoutubeV3::ListChannelsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListChannelsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Channel>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListChannelsResponse
constructor
A new instance of ListChannelsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListChannelsResponse
Returns a new instance of ListChannelsResponse.
1506 1507 1508 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
1460 1461 1462 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1460 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
1465 1466 1467 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1465 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Channel>
Corresponds to the JSON property items
1470 1471 1472 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1470 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
channelListResponse".
Corresponds to the JSON property kind
1476 1477 1478 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1476 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
1482 1483 1484 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1482 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
1488 1489 1490 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1488 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
1494 1495 1496 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1494 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
1499 1500 1501 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1499 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
1504 1505 1506 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1504 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1511 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |