Class: Google::Apis::YoutubeV3::ListChannelsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListChannelsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Channel>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListChannelsResponse
constructor
A new instance of ListChannelsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListChannelsResponse
Returns a new instance of ListChannelsResponse.
1403 1404 1405 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
1357 1358 1359 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1357 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
1362 1363 1364 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1362 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Channel>
Corresponds to the JSON property items
1367 1368 1369 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1367 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
channelListResponse".
Corresponds to the JSON property kind
1373 1374 1375 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1373 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
1379 1380 1381 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1379 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
1385 1386 1387 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1385 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
1391 1392 1393 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1391 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
1396 1397 1398 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1396 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
1401 1402 1403 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1401 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 1408 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |