Class: Google::Apis::YoutubeV3::ListChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListChannelsResponse

Returns a new instance of ListChannelsResponse.



1377
1378
1379
# File 'lib/google/apis/youtube_v3/classes.rb', line 1377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/youtube_v3/classes.rb', line 1331

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


1336
1337
1338
# File 'lib/google/apis/youtube_v3/classes.rb', line 1336

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Channel>

Corresponds to the JSON property items



1341
1342
1343
# File 'lib/google/apis/youtube_v3/classes.rb', line 1341

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# channelListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/youtube_v3/classes.rb', line 1347

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1353
1354
1355
# File 'lib/google/apis/youtube_v3/classes.rb', line 1353

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



1359
1360
1361
# File 'lib/google/apis/youtube_v3/classes.rb', line 1359

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


1365
1366
1367
# File 'lib/google/apis/youtube_v3/classes.rb', line 1365

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



1370
1371
1372
# File 'lib/google/apis/youtube_v3/classes.rb', line 1370

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


1375
1376
1377
# File 'lib/google/apis/youtube_v3/classes.rb', line 1375

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
# File 'lib/google/apis/youtube_v3/classes.rb', line 1382

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end