Class: Google::Apis::YoutubeV3::ListChannelsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListChannelsResponse

Returns a new instance of ListChannelsResponse.



1375
1376
1377
# File 'lib/google/apis/youtube_v3/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


1329
1330
1331
# File 'lib/google/apis/youtube_v3/classes.rb', line 1329

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


1334
1335
1336
# File 'lib/google/apis/youtube_v3/classes.rb', line 1334

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Channel>

Corresponds to the JSON property items



1339
1340
1341
# File 'lib/google/apis/youtube_v3/classes.rb', line 1339

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# channelListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


1345
1346
1347
# File 'lib/google/apis/youtube_v3/classes.rb', line 1345

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/youtube_v3/classes.rb', line 1351

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



1357
1358
1359
# File 'lib/google/apis/youtube_v3/classes.rb', line 1357

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/youtube_v3/classes.rb', line 1363

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



1368
1369
1370
# File 'lib/google/apis/youtube_v3/classes.rb', line 1368

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/youtube_v3/classes.rb', line 1373

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
# File 'lib/google/apis/youtube_v3/classes.rb', line 1380

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end