Class: Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCommentThreadsResponse
constructor
A new instance of ListCommentThreadsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCommentThreadsResponse
Returns a new instance of ListCommentThreadsResponse.
2459 2460 2461 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2419 2420 2421 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2419 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
2424 2425 2426 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2424 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
Corresponds to the JSON property items
2429 2430 2431 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2429 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
commentThreadListResponse".
Corresponds to the JSON property kind
2435 2436 2437 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2435 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
2441 2442 2443 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2441 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
2447 2448 2449 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2447 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
2452 2453 2454 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2452 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
2457 2458 2459 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2457 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2464 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |