Class: Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCommentThreadsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCommentThreadsResponse
constructor
A new instance of ListCommentThreadsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCommentThreadsResponse
Returns a new instance of ListCommentThreadsResponse.
2359 2360 2361 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2319 2320 2321 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2319 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
2324 2325 2326 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2324 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::CommentThread>
A list of comment threads that match the request criteria.
Corresponds to the JSON property items
2329 2330 2331 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2329 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
commentThreadListResponse".
Corresponds to the JSON property kind
2335 2336 2337 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2335 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
2341 2342 2343 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2341 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
2347 2348 2349 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2347 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
2352 2353 2354 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2352 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
2357 2358 2359 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2357 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2364 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |