Class: Google::Apis::YoutubeV3::ListCommentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCommentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Comment>
A list of comments that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCommentsResponse
constructor
A new instance of ListCommentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCommentsResponse
Returns a new instance of ListCommentsResponse.
2110 2111 2112 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2070 2071 2072 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2070 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
2075 2076 2077 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2075 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Comment>
A list of comments that match the request criteria.
Corresponds to the JSON property items
2080 2081 2082 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2080 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
commentListResponse".
Corresponds to the JSON property kind
2086 2087 2088 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2086 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
2092 2093 2094 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2092 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
2098 2099 2100 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2098 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
2103 2104 2105 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2103 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
2108 2109 2110 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2108 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2115 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |