Class: Google::Apis::YoutubeV3::ListCommentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListCommentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Comment>
A list of comments that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCommentsResponse
constructor
A new instance of ListCommentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCommentsResponse
Returns a new instance of ListCommentsResponse.
2144 2145 2146 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2144 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
2104 2105 2106 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2104 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
2109 2110 2111 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2109 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Comment>
A list of comments that match the request criteria.
Corresponds to the JSON property items
2114 2115 2116 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2114 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
commentListResponse".
Corresponds to the JSON property kind
2120 2121 2122 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2120 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
2126 2127 2128 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2126 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
2132 2133 2134 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2132 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
2137 2138 2139 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2137 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
2142 2143 2144 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2142 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 2149 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |