Class: Google::Apis::YoutubeV3::ListLiveBroadcastsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLiveBroadcastsResponse

Returns a new instance of ListLiveBroadcastsResponse.



4008
4009
4010
# File 'lib/google/apis/youtube_v3/classes.rb', line 4008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


3962
3963
3964
# File 'lib/google/apis/youtube_v3/classes.rb', line 3962

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


3967
3968
3969
# File 'lib/google/apis/youtube_v3/classes.rb', line 3967

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::LiveBroadcast>

A list of broadcasts that match the request criteria. Corresponds to the JSON property items



3972
3973
3974
# File 'lib/google/apis/youtube_v3/classes.rb', line 3972

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# liveBroadcastListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


3978
3979
3980
# File 'lib/google/apis/youtube_v3/classes.rb', line 3978

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3984
3985
3986
# File 'lib/google/apis/youtube_v3/classes.rb', line 3984

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



3990
3991
3992
# File 'lib/google/apis/youtube_v3/classes.rb', line 3990

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


3996
3997
3998
# File 'lib/google/apis/youtube_v3/classes.rb', line 3996

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



4001
4002
4003
# File 'lib/google/apis/youtube_v3/classes.rb', line 4001

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


4006
4007
4008
# File 'lib/google/apis/youtube_v3/classes.rb', line 4006

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
# File 'lib/google/apis/youtube_v3/classes.rb', line 4013

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end