Class: Google::Apis::YoutubeV3::ListLiveBroadcastsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListLiveBroadcastsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveBroadcast>
A list of broadcasts that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLiveBroadcastsResponse
constructor
A new instance of ListLiveBroadcastsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLiveBroadcastsResponse
Returns a new instance of ListLiveBroadcastsResponse.
3968 3969 3970 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
3922 3923 3924 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3922 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
3927 3928 3929 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3927 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveBroadcast>
A list of broadcasts that match the request criteria.
Corresponds to the JSON property items
3932 3933 3934 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3932 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveBroadcastListResponse".
Corresponds to the JSON property kind
3938 3939 3940 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3938 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
3944 3945 3946 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3944 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
3950 3951 3952 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3950 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
3956 3957 3958 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3956 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
3961 3962 3963 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3961 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
3966 3967 3968 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3966 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3973 3974 3975 3976 3977 3978 3979 3980 3981 3982 3983 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3973 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |