Class: Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLiveStreamsResponse
constructor
A new instance of ListLiveStreamsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLiveStreamsResponse
Returns a new instance of ListLiveStreamsResponse.
5487 5488 5489 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5441 5442 5443 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5441 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5446 5447 5448 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5446 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
Corresponds to the JSON property items
5451 5452 5453 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5451 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveStreamListResponse".
Corresponds to the JSON property kind
5457 5458 5459 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5457 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5463 5464 5465 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5463 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5469 5470 5471 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5469 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
5475 5476 5477 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5475 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5480 5481 5482 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5480 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5485 5486 5487 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5485 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5492 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |