Class: Google::Apis::YoutubeV3::ListLiveStreamsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListLiveStreamsResponse

Returns a new instance of ListLiveStreamsResponse.



5461
5462
5463
# File 'lib/google/apis/youtube_v3/classes.rb', line 5461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


5415
5416
5417
# File 'lib/google/apis/youtube_v3/classes.rb', line 5415

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


5420
5421
5422
# File 'lib/google/apis/youtube_v3/classes.rb', line 5420

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::LiveStream>

A list of live streams that match the request criteria. Corresponds to the JSON property items



5425
5426
5427
# File 'lib/google/apis/youtube_v3/classes.rb', line 5425

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# liveStreamListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


5431
5432
5433
# File 'lib/google/apis/youtube_v3/classes.rb', line 5431

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5437
5438
5439
# File 'lib/google/apis/youtube_v3/classes.rb', line 5437

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



5443
5444
5445
# File 'lib/google/apis/youtube_v3/classes.rb', line 5443

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


5449
5450
5451
# File 'lib/google/apis/youtube_v3/classes.rb', line 5449

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



5454
5455
5456
# File 'lib/google/apis/youtube_v3/classes.rb', line 5454

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


5459
5460
5461
# File 'lib/google/apis/youtube_v3/classes.rb', line 5459

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5466
5467
5468
5469
5470
5471
5472
5473
5474
5475
5476
# File 'lib/google/apis/youtube_v3/classes.rb', line 5466

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end