Class: Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListLiveStreamsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLiveStreamsResponse
constructor
A new instance of ListLiveStreamsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLiveStreamsResponse
Returns a new instance of ListLiveStreamsResponse.
5387 5388 5389 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5341 5342 5343 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5341 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5346 5347 5348 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5346 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveStream>
A list of live streams that match the request criteria.
Corresponds to the JSON property items
5351 5352 5353 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5351 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveStreamListResponse".
Corresponds to the JSON property kind
5357 5358 5359 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5357 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5363 5364 5365 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5363 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5369 5370 5371 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5369 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
5375 5376 5377 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5375 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5380 5381 5382 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5380 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5385 5386 5387 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5385 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5392 5393 5394 5395 5396 5397 5398 5399 5400 5401 5402 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5392 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |