Class: Google::Apis::YoutubeV3::ListPlaylistItemsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListPlaylistItemsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistItem>
A list of playlist items that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPlaylistItemsResponse
constructor
A new instance of ListPlaylistItemsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPlaylistItemsResponse
Returns a new instance of ListPlaylistItemsResponse.
6442 6443 6444 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
6396 6397 6398 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6396 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
6401 6402 6403 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6401 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistItem>
A list of playlist items that match the request criteria.
Corresponds to the JSON property items
6406 6407 6408 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6406 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistItemListResponse".
Corresponds to the JSON property kind
6412 6413 6414 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6412 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6418 6419 6420 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6418 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6424 6425 6426 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6424 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6430 6431 6432 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6430 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
6435 6436 6437 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6435 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
6440 6441 6442 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6440 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6447 6448 6449 6450 6451 6452 6453 6454 6455 6456 6457 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6447 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |