Class: Google::Apis::YoutubeV3::ListPlaylistItemsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPlaylistItemsResponse

Returns a new instance of ListPlaylistItemsResponse.



6308
6309
6310
# File 'lib/google/apis/youtube_v3/classes.rb', line 6308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


6262
6263
6264
# File 'lib/google/apis/youtube_v3/classes.rb', line 6262

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


6267
6268
6269
# File 'lib/google/apis/youtube_v3/classes.rb', line 6267

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::PlaylistItem>

A list of playlist items that match the request criteria. Corresponds to the JSON property items



6272
6273
6274
# File 'lib/google/apis/youtube_v3/classes.rb', line 6272

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# playlistItemListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


6278
6279
6280
# File 'lib/google/apis/youtube_v3/classes.rb', line 6278

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6284
6285
6286
# File 'lib/google/apis/youtube_v3/classes.rb', line 6284

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



6290
6291
6292
# File 'lib/google/apis/youtube_v3/classes.rb', line 6290

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


6296
6297
6298
# File 'lib/google/apis/youtube_v3/classes.rb', line 6296

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



6301
6302
6303
# File 'lib/google/apis/youtube_v3/classes.rb', line 6301

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


6306
6307
6308
# File 'lib/google/apis/youtube_v3/classes.rb', line 6306

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6313
6314
6315
6316
6317
6318
6319
6320
6321
6322
6323
# File 'lib/google/apis/youtube_v3/classes.rb', line 6313

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end