Class: Google::Apis::YoutubeV3::ListPlaylistResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListPlaylistResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Playlist>
A list of playlists that match the request criteria Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPlaylistResponse
constructor
A new instance of ListPlaylistResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPlaylistResponse
Returns a new instance of ListPlaylistResponse.
6755 6756 6757 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6755 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6709 6710 6711 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6709 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
6714 6715 6716 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6714 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Playlist>
A list of playlists that match the request criteria
Corresponds to the JSON property items
6719 6720 6721 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6719 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistListResponse".
Corresponds to the JSON property kind
6725 6726 6727 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6725 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6731 6732 6733 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6731 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6737 6738 6739 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6737 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6743 6744 6745 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6743 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
6748 6749 6750 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6748 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
6753 6754 6755 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6753 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6760 6761 6762 6763 6764 6765 6766 6767 6768 6769 6770 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6760 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |