Class: Google::Apis::YoutubeV3::ListPlaylistResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListPlaylistResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Playlist>
A list of playlists that match the request criteria Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPlaylistResponse
constructor
A new instance of ListPlaylistResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPlaylistResponse
Returns a new instance of ListPlaylistResponse.
6616 6617 6618 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6570 6571 6572 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6570 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
6575 6576 6577 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6575 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Playlist>
A list of playlists that match the request criteria
Corresponds to the JSON property items
6580 6581 6582 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6580 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistListResponse".
Corresponds to the JSON property kind
6586 6587 6588 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6586 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6592 6593 6594 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6592 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6598 6599 6600 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6598 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6604 6605 6606 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6604 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
6609 6610 6611 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6609 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
6614 6615 6616 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6614 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6621 6622 6623 6624 6625 6626 6627 6628 6629 6630 6631 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6621 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |