Class: Google::Apis::YoutubeV3::ListSubscriptionResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListSubscriptionResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Subscription>
A list of subscriptions that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSubscriptionResponse
constructor
A new instance of ListSubscriptionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSubscriptionResponse
Returns a new instance of ListSubscriptionResponse.
7188 7189 7190 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7188 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7142 7143 7144 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7142 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7147 7148 7149 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7147 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Subscription>
A list of subscriptions that match the request criteria.
Corresponds to the JSON property items
7152 7153 7154 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7152 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
subscriptionListResponse".
Corresponds to the JSON property kind
7158 7159 7160 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7158 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7164 7165 7166 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7164 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7170 7171 7172 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7170 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
7176 7177 7178 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7176 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7181 7182 7183 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7181 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
7186 7187 7188 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7186 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7193 7194 7195 7196 7197 7198 7199 7200 7201 7202 7203 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7193 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |