Class: Google::Apis::YoutubeV3::ListSubscriptionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSubscriptionResponse

Returns a new instance of ListSubscriptionResponse.



7088
7089
7090
# File 'lib/google/apis/youtube_v3/classes.rb', line 7088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7042
7043
7044
# File 'lib/google/apis/youtube_v3/classes.rb', line 7042

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


7047
7048
7049
# File 'lib/google/apis/youtube_v3/classes.rb', line 7047

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Subscription>

A list of subscriptions that match the request criteria. Corresponds to the JSON property items



7052
7053
7054
# File 'lib/google/apis/youtube_v3/classes.rb', line 7052

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# subscriptionListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


7058
7059
7060
# File 'lib/google/apis/youtube_v3/classes.rb', line 7058

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7064
7065
7066
# File 'lib/google/apis/youtube_v3/classes.rb', line 7064

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



7070
7071
7072
# File 'lib/google/apis/youtube_v3/classes.rb', line 7070

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


7076
7077
7078
# File 'lib/google/apis/youtube_v3/classes.rb', line 7076

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



7081
7082
7083
# File 'lib/google/apis/youtube_v3/classes.rb', line 7081

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


7086
7087
7088
# File 'lib/google/apis/youtube_v3/classes.rb', line 7086

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7093
7094
7095
7096
7097
7098
7099
7100
7101
7102
7103
# File 'lib/google/apis/youtube_v3/classes.rb', line 7093

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end