Class: Google::Apis::YoutubeV3::ListVideoAbuseReportReasonResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListVideoAbuseReportReasonResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportReason>
A list of valid abuse reasons that are used with
video.ReportAbuse. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#visitor_id ⇒ String
The
visitorIdidentifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVideoAbuseReportReasonResponse
constructor
A new instance of ListVideoAbuseReportReasonResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVideoAbuseReportReasonResponse
Returns a new instance of ListVideoAbuseReportReasonResponse.
7985 7986 7987 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7962 7963 7964 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7962 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7967 7968 7969 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7967 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportReason>
A list of valid abuse reasons that are used with video.ReportAbuse.
Corresponds to the JSON property items
7972 7973 7974 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7972 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoAbuseReportReasonListResponse".
Corresponds to the JSON property kind
7978 7979 7980 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7978 def kind @kind end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
7983 7984 7985 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7983 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7990 7991 7992 7993 7994 7995 7996 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7990 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |