Class: Google::Apis::YoutubeV3::ListVideoCategoryResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListVideoCategoryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::VideoCategory>
A list of video categories that can be associated with YouTube videos.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVideoCategoryResponse
constructor
A new instance of ListVideoCategoryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVideoCategoryResponse
Returns a new instance of ListVideoCategoryResponse.
8438 8439 8440 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
8390 8391 8392 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8390 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
8395 8396 8397 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8395 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::VideoCategory>
A list of video categories that can be associated with YouTube videos. In this
map, the video category ID is the map key, and its value is the corresponding
videoCategory resource.
Corresponds to the JSON property items
8402 8403 8404 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8402 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoCategoryListResponse".
Corresponds to the JSON property kind
8408 8409 8410 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8408 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
8414 8415 8416 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8414 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
8420 8421 8422 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8420 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
8426 8427 8428 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8426 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
8431 8432 8433 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8431 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
8436 8437 8438 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8436 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8443 8444 8445 8446 8447 8448 8449 8450 8451 8452 8453 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8443 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |