Class: Google::Apis::YoutubeV3::ListVideoCategoryResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVideoCategoryResponse

Returns a new instance of ListVideoCategoryResponse.



8147
8148
8149
# File 'lib/google/apis/youtube_v3/classes.rb', line 8147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


8099
8100
8101
# File 'lib/google/apis/youtube_v3/classes.rb', line 8099

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


8104
8105
8106
# File 'lib/google/apis/youtube_v3/classes.rb', line 8104

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::VideoCategory>

A list of video categories that can be associated with YouTube videos. In this map, the video category ID is the map key, and its value is the corresponding videoCategory resource. Corresponds to the JSON property items



8111
8112
8113
# File 'lib/google/apis/youtube_v3/classes.rb', line 8111

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# videoCategoryListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


8117
8118
8119
# File 'lib/google/apis/youtube_v3/classes.rb', line 8117

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8123
8124
8125
# File 'lib/google/apis/youtube_v3/classes.rb', line 8123

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



8129
8130
8131
# File 'lib/google/apis/youtube_v3/classes.rb', line 8129

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


8135
8136
8137
# File 'lib/google/apis/youtube_v3/classes.rb', line 8135

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



8140
8141
8142
# File 'lib/google/apis/youtube_v3/classes.rb', line 8140

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


8145
8146
8147
# File 'lib/google/apis/youtube_v3/classes.rb', line 8145

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8152
8153
8154
8155
8156
8157
8158
8159
8160
8161
8162
# File 'lib/google/apis/youtube_v3/classes.rb', line 8152

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end