Class: Google::Apis::YoutubeV3::ListVideosResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::ListVideosResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Video>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListVideosResponse
constructor
A new instance of ListVideosResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListVideosResponse
Returns a new instance of ListVideosResponse.
8706 8707 8708 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8706 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
8660 8661 8662 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8660 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
8665 8666 8667 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8665 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Video>
Corresponds to the JSON property items
8670 8671 8672 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8670 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoListResponse".
Corresponds to the JSON property kind
8676 8677 8678 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8676 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
8682 8683 8684 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8682 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
8688 8689 8690 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8688 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
8694 8695 8696 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8694 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
8699 8700 8701 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8699 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
8704 8705 8706 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8704 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8711 8712 8713 8714 8715 8716 8717 8718 8719 8720 8721 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8711 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |