Class: Google::Apis::YoutubeV3::ListVideosResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListVideosResponse

Returns a new instance of ListVideosResponse.



8591
8592
8593
# File 'lib/google/apis/youtube_v3/classes.rb', line 8591

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


8545
8546
8547
# File 'lib/google/apis/youtube_v3/classes.rb', line 8545

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


8550
8551
8552
# File 'lib/google/apis/youtube_v3/classes.rb', line 8550

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Video>

Corresponds to the JSON property items

Returns:



8555
8556
8557
# File 'lib/google/apis/youtube_v3/classes.rb', line 8555

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# videoListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


8561
8562
8563
# File 'lib/google/apis/youtube_v3/classes.rb', line 8561

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8567
8568
8569
# File 'lib/google/apis/youtube_v3/classes.rb', line 8567

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



8573
8574
8575
# File 'lib/google/apis/youtube_v3/classes.rb', line 8573

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


8579
8580
8581
# File 'lib/google/apis/youtube_v3/classes.rb', line 8579

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



8584
8585
8586
# File 'lib/google/apis/youtube_v3/classes.rb', line 8584

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


8589
8590
8591
# File 'lib/google/apis/youtube_v3/classes.rb', line 8589

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8596
8597
8598
8599
8600
8601
8602
8603
8604
8605
8606
# File 'lib/google/apis/youtube_v3/classes.rb', line 8596

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end