Class: Google::Apis::YoutubeV3::LiveBroadcastContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Detailed settings of a broadcast.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveBroadcastContentDetails

Returns a new instance of LiveBroadcastContentDetails.



4093
4094
4095
# File 'lib/google/apis/youtube_v3/classes.rb', line 4093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_configGoogle::Apis::YoutubeV3::AvailabilityConfig

Common proto for Live and VOD geo-restrictions Corresponds to the JSON property availabilityConfig



3963
3964
3965
# File 'lib/google/apis/youtube_v3/classes.rb', line 3963

def availability_config
  @availability_config
end

#bound_stream_idString

This value uniquely identifies the live stream bound to the broadcast. Corresponds to the JSON property boundStreamId

Returns:

  • (String)


3968
3969
3970
# File 'lib/google/apis/youtube_v3/classes.rb', line 3968

def bound_stream_id
  @bound_stream_id
end

#bound_stream_last_update_time_msDateTime

The date and time that the live stream referenced by boundStreamId was last updated. Corresponds to the JSON property boundStreamLastUpdateTimeMs

Returns:

  • (DateTime)


3974
3975
3976
# File 'lib/google/apis/youtube_v3/classes.rb', line 3974

def bound_stream_last_update_time_ms
  @bound_stream_last_update_time_ms
end

#closed_captions_typeString

Corresponds to the JSON property closedCaptionsType

Returns:

  • (String)


3979
3980
3981
# File 'lib/google/apis/youtube_v3/classes.rb', line 3979

def closed_captions_type
  @closed_captions_type
end

#enable_auto_startBoolean Also known as: enable_auto_start?

This setting indicates whether auto start is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events. Corresponds to the JSON property enableAutoStart

Returns:

  • (Boolean)


3986
3987
3988
# File 'lib/google/apis/youtube_v3/classes.rb', line 3986

def enable_auto_start
  @enable_auto_start
end

#enable_auto_stopBoolean Also known as: enable_auto_stop?

This setting indicates whether auto stop is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events. Corresponds to the JSON property enableAutoStop

Returns:

  • (Boolean)


3994
3995
3996
# File 'lib/google/apis/youtube_v3/classes.rb', line 3994

def enable_auto_stop
  @enable_auto_stop
end

#enable_closed_captionsBoolean Also known as: enable_closed_captions?

This setting indicates whether HTTP POST closed captioning is enabled for this broadcast. The ingestion URL of the closed captions is returned through the liveStreams API. This is mutually exclusive with using the closed_captions_type property, and is equivalent to setting closed_captions_type to CLOSED_CAPTIONS_HTTP_POST. Corresponds to the JSON property enableClosedCaptions

Returns:

  • (Boolean)


4004
4005
4006
# File 'lib/google/apis/youtube_v3/classes.rb', line 4004

def enable_closed_captions
  @enable_closed_captions
end

#enable_content_encryptionBoolean Also known as: enable_content_encryption?

This setting indicates whether YouTube should enable content encryption for the broadcast. Corresponds to the JSON property enableContentEncryption

Returns:

  • (Boolean)


4011
4012
4013
# File 'lib/google/apis/youtube_v3/classes.rb', line 4011

def enable_content_encryption
  @enable_content_encryption
end

#enable_dvrBoolean Also known as: enable_dvr?

This setting determines whether viewers can access DVR controls while watching the video. DVR controls enable the viewer to control the video playback experience by pausing, rewinding, or fast forwarding content. The default value for this property is true. Important: You must set the value to true and also set the enableArchive property's value to true if you want to make playback available immediately after the broadcast ends. Corresponds to the JSON property enableDvr

Returns:

  • (Boolean)


4022
4023
4024
# File 'lib/google/apis/youtube_v3/classes.rb', line 4022

def enable_dvr
  @enable_dvr
end

#enable_embedBoolean Also known as: enable_embed?

This setting indicates whether the broadcast video can be played in an embedded player. If you choose to archive the video (using the enableArchive property), this setting will also apply to the archived video. Corresponds to the JSON property enableEmbed

Returns:

  • (Boolean)


4030
4031
4032
# File 'lib/google/apis/youtube_v3/classes.rb', line 4030

def enable_embed
  @enable_embed
end

#enable_low_latencyBoolean Also known as: enable_low_latency?

Indicates whether this broadcast has low latency enabled. Corresponds to the JSON property enableLowLatency

Returns:

  • (Boolean)


4036
4037
4038
# File 'lib/google/apis/youtube_v3/classes.rb', line 4036

def enable_low_latency
  @enable_low_latency
end

#latency_preferenceString

If both this and enable_low_latency are set, they must match. LATENCY_NORMAL should match enable_low_latency=false LATENCY_LOW should match enable_low_latency=true LATENCY_ULTRA_LOW should have enable_low_latency omitted. Corresponds to the JSON property latencyPreference

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/youtube_v3/classes.rb', line 4045

def latency_preference
  @latency_preference
end

#meshString

The mesh for projecting the video if projection is mesh. The mesh value must be a UTF-8 string containing the base-64 encoding of 3D mesh data that follows the Spherical Video V2 RFC specification for an mshp box, excluding the box size and type but including the following four reserved zero bytes for the version and flags. Corresponds to the JSON property mesh NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4055
4056
4057
# File 'lib/google/apis/youtube_v3/classes.rb', line 4055

def mesh
  @mesh
end

#monitor_streamGoogle::Apis::YoutubeV3::MonitorStreamInfo

Settings and Info of the monitor stream Corresponds to the JSON property monitorStream



4060
4061
4062
# File 'lib/google/apis/youtube_v3/classes.rb', line 4060

def monitor_stream
  @monitor_stream
end

#projectionString

The projection format of this broadcast. This defaults to rectangular. Corresponds to the JSON property projection

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/youtube_v3/classes.rb', line 4065

def projection
  @projection
end

#record_from_startBoolean Also known as: record_from_start?

Automatically start recording after the event goes live. The default value for this property is true. Important: You must also set the enableDvr property's value to true if you want the playback to be available immediately after the broadcast ends. If you set this property's value to true but do not also set the enableDvr property to true, there may be a delay of around one day before the archived video will be available for playback. Corresponds to the JSON property recordFromStart

Returns:

  • (Boolean)


4075
4076
4077
# File 'lib/google/apis/youtube_v3/classes.rb', line 4075

def record_from_start
  @record_from_start
end

#start_with_slateBoolean Also known as: start_with_slate?

This setting indicates whether the broadcast should automatically begin with an in-stream slate when you update the broadcast's status to live. After updating the status, you then need to send a liveCuepoints.insert request that sets the cuepoint's eventState to end to remove the in-stream slate and make your broadcast stream visible to viewers. Corresponds to the JSON property startWithSlate

Returns:

  • (Boolean)


4085
4086
4087
# File 'lib/google/apis/youtube_v3/classes.rb', line 4085

def start_with_slate
  @start_with_slate
end

#stereo_layoutString

The 3D stereo layout of this broadcast. This defaults to mono. Corresponds to the JSON property stereoLayout

Returns:

  • (String)


4091
4092
4093
# File 'lib/google/apis/youtube_v3/classes.rb', line 4091

def stereo_layout
  @stereo_layout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
4109
4110
4111
4112
4113
4114
4115
4116
4117
# File 'lib/google/apis/youtube_v3/classes.rb', line 4098

def update!(**args)
  @availability_config = args[:availability_config] if args.key?(:availability_config)
  @bound_stream_id = args[:bound_stream_id] if args.key?(:bound_stream_id)
  @bound_stream_last_update_time_ms = args[:bound_stream_last_update_time_ms] if args.key?(:bound_stream_last_update_time_ms)
  @closed_captions_type = args[:closed_captions_type] if args.key?(:closed_captions_type)
  @enable_auto_start = args[:enable_auto_start] if args.key?(:enable_auto_start)
  @enable_auto_stop = args[:enable_auto_stop] if args.key?(:enable_auto_stop)
  @enable_closed_captions = args[:enable_closed_captions] if args.key?(:enable_closed_captions)
  @enable_content_encryption = args[:enable_content_encryption] if args.key?(:enable_content_encryption)
  @enable_dvr = args[:enable_dvr] if args.key?(:enable_dvr)
  @enable_embed = args[:enable_embed] if args.key?(:enable_embed)
  @enable_low_latency = args[:enable_low_latency] if args.key?(:enable_low_latency)
  @latency_preference = args[:latency_preference] if args.key?(:latency_preference)
  @mesh = args[:mesh] if args.key?(:mesh)
  @monitor_stream = args[:monitor_stream] if args.key?(:monitor_stream)
  @projection = args[:projection] if args.key?(:projection)
  @record_from_start = args[:record_from_start] if args.key?(:record_from_start)
  @start_with_slate = args[:start_with_slate] if args.key?(:start_with_slate)
  @stereo_layout = args[:stereo_layout] if args.key?(:stereo_layout)
end