Class: Google::Apis::YoutubeV3::LiveBroadcastContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Detailed settings of a broadcast.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveBroadcastContentDetails

Returns a new instance of LiveBroadcastContentDetails.



3855
3856
3857
# File 'lib/google/apis/youtube_v3/classes.rb', line 3855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bound_stream_idString

This value uniquely identifies the live stream bound to the broadcast. Corresponds to the JSON property boundStreamId

Returns:

  • (String)


3730
3731
3732
# File 'lib/google/apis/youtube_v3/classes.rb', line 3730

def bound_stream_id
  @bound_stream_id
end

#bound_stream_last_update_time_msDateTime

The date and time that the live stream referenced by boundStreamId was last updated. Corresponds to the JSON property boundStreamLastUpdateTimeMs

Returns:

  • (DateTime)


3736
3737
3738
# File 'lib/google/apis/youtube_v3/classes.rb', line 3736

def bound_stream_last_update_time_ms
  @bound_stream_last_update_time_ms
end

#closed_captions_typeString

Corresponds to the JSON property closedCaptionsType

Returns:

  • (String)


3741
3742
3743
# File 'lib/google/apis/youtube_v3/classes.rb', line 3741

def closed_captions_type
  @closed_captions_type
end

#enable_auto_startBoolean Also known as: enable_auto_start?

This setting indicates whether auto start is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events. Corresponds to the JSON property enableAutoStart

Returns:

  • (Boolean)


3748
3749
3750
# File 'lib/google/apis/youtube_v3/classes.rb', line 3748

def enable_auto_start
  @enable_auto_start
end

#enable_auto_stopBoolean Also known as: enable_auto_stop?

This setting indicates whether auto stop is enabled for this broadcast. The default value for this property is false. This setting can only be used by Events. Corresponds to the JSON property enableAutoStop

Returns:

  • (Boolean)


3756
3757
3758
# File 'lib/google/apis/youtube_v3/classes.rb', line 3756

def enable_auto_stop
  @enable_auto_stop
end

#enable_closed_captionsBoolean Also known as: enable_closed_captions?

This setting indicates whether HTTP POST closed captioning is enabled for this broadcast. The ingestion URL of the closed captions is returned through the liveStreams API. This is mutually exclusive with using the closed_captions_type property, and is equivalent to setting closed_captions_type to CLOSED_CAPTIONS_HTTP_POST. Corresponds to the JSON property enableClosedCaptions

Returns:

  • (Boolean)


3766
3767
3768
# File 'lib/google/apis/youtube_v3/classes.rb', line 3766

def enable_closed_captions
  @enable_closed_captions
end

#enable_content_encryptionBoolean Also known as: enable_content_encryption?

This setting indicates whether YouTube should enable content encryption for the broadcast. Corresponds to the JSON property enableContentEncryption

Returns:

  • (Boolean)


3773
3774
3775
# File 'lib/google/apis/youtube_v3/classes.rb', line 3773

def enable_content_encryption
  @enable_content_encryption
end

#enable_dvrBoolean Also known as: enable_dvr?

This setting determines whether viewers can access DVR controls while watching the video. DVR controls enable the viewer to control the video playback experience by pausing, rewinding, or fast forwarding content. The default value for this property is true. Important: You must set the value to true and also set the enableArchive property's value to true if you want to make playback available immediately after the broadcast ends. Corresponds to the JSON property enableDvr

Returns:

  • (Boolean)


3784
3785
3786
# File 'lib/google/apis/youtube_v3/classes.rb', line 3784

def enable_dvr
  @enable_dvr
end

#enable_embedBoolean Also known as: enable_embed?

This setting indicates whether the broadcast video can be played in an embedded player. If you choose to archive the video (using the enableArchive property), this setting will also apply to the archived video. Corresponds to the JSON property enableEmbed

Returns:

  • (Boolean)


3792
3793
3794
# File 'lib/google/apis/youtube_v3/classes.rb', line 3792

def enable_embed
  @enable_embed
end

#enable_low_latencyBoolean Also known as: enable_low_latency?

Indicates whether this broadcast has low latency enabled. Corresponds to the JSON property enableLowLatency

Returns:

  • (Boolean)


3798
3799
3800
# File 'lib/google/apis/youtube_v3/classes.rb', line 3798

def enable_low_latency
  @enable_low_latency
end

#latency_preferenceString

If both this and enable_low_latency are set, they must match. LATENCY_NORMAL should match enable_low_latency=false LATENCY_LOW should match enable_low_latency=true LATENCY_ULTRA_LOW should have enable_low_latency omitted. Corresponds to the JSON property latencyPreference

Returns:

  • (String)


3807
3808
3809
# File 'lib/google/apis/youtube_v3/classes.rb', line 3807

def latency_preference
  @latency_preference
end

#meshString

The mesh for projecting the video if projection is mesh. The mesh value must be a UTF-8 string containing the base-64 encoding of 3D mesh data that follows the Spherical Video V2 RFC specification for an mshp box, excluding the box size and type but including the following four reserved zero bytes for the version and flags. Corresponds to the JSON property mesh NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3817
3818
3819
# File 'lib/google/apis/youtube_v3/classes.rb', line 3817

def mesh
  @mesh
end

#monitor_streamGoogle::Apis::YoutubeV3::MonitorStreamInfo

Settings and Info of the monitor stream Corresponds to the JSON property monitorStream



3822
3823
3824
# File 'lib/google/apis/youtube_v3/classes.rb', line 3822

def monitor_stream
  @monitor_stream
end

#projectionString

The projection format of this broadcast. This defaults to rectangular. Corresponds to the JSON property projection

Returns:

  • (String)


3827
3828
3829
# File 'lib/google/apis/youtube_v3/classes.rb', line 3827

def projection
  @projection
end

#record_from_startBoolean Also known as: record_from_start?

Automatically start recording after the event goes live. The default value for this property is true. Important: You must also set the enableDvr property's value to true if you want the playback to be available immediately after the broadcast ends. If you set this property's value to true but do not also set the enableDvr property to true, there may be a delay of around one day before the archived video will be available for playback. Corresponds to the JSON property recordFromStart

Returns:

  • (Boolean)


3837
3838
3839
# File 'lib/google/apis/youtube_v3/classes.rb', line 3837

def record_from_start
  @record_from_start
end

#start_with_slateBoolean Also known as: start_with_slate?

This setting indicates whether the broadcast should automatically begin with an in-stream slate when you update the broadcast's status to live. After updating the status, you then need to send a liveCuepoints.insert request that sets the cuepoint's eventState to end to remove the in-stream slate and make your broadcast stream visible to viewers. Corresponds to the JSON property startWithSlate

Returns:

  • (Boolean)


3847
3848
3849
# File 'lib/google/apis/youtube_v3/classes.rb', line 3847

def start_with_slate
  @start_with_slate
end

#stereo_layoutString

The 3D stereo layout of this broadcast. This defaults to mono. Corresponds to the JSON property stereoLayout

Returns:

  • (String)


3853
3854
3855
# File 'lib/google/apis/youtube_v3/classes.rb', line 3853

def stereo_layout
  @stereo_layout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/google/apis/youtube_v3/classes.rb', line 3860

def update!(**args)
  @bound_stream_id = args[:bound_stream_id] if args.key?(:bound_stream_id)
  @bound_stream_last_update_time_ms = args[:bound_stream_last_update_time_ms] if args.key?(:bound_stream_last_update_time_ms)
  @closed_captions_type = args[:closed_captions_type] if args.key?(:closed_captions_type)
  @enable_auto_start = args[:enable_auto_start] if args.key?(:enable_auto_start)
  @enable_auto_stop = args[:enable_auto_stop] if args.key?(:enable_auto_stop)
  @enable_closed_captions = args[:enable_closed_captions] if args.key?(:enable_closed_captions)
  @enable_content_encryption = args[:enable_content_encryption] if args.key?(:enable_content_encryption)
  @enable_dvr = args[:enable_dvr] if args.key?(:enable_dvr)
  @enable_embed = args[:enable_embed] if args.key?(:enable_embed)
  @enable_low_latency = args[:enable_low_latency] if args.key?(:enable_low_latency)
  @latency_preference = args[:latency_preference] if args.key?(:latency_preference)
  @mesh = args[:mesh] if args.key?(:mesh)
  @monitor_stream = args[:monitor_stream] if args.key?(:monitor_stream)
  @projection = args[:projection] if args.key?(:projection)
  @record_from_start = args[:record_from_start] if args.key?(:record_from_start)
  @start_with_slate = args[:start_with_slate] if args.key?(:start_with_slate)
  @stereo_layout = args[:stereo_layout] if args.key?(:stereo_layout)
end