Class: Google::Apis::YoutubeV3::LiveBroadcastContentDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastContentDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Detailed settings of a broadcast.
Instance Attribute Summary collapse
-
#bound_stream_id ⇒ String
This value uniquely identifies the live stream bound to the broadcast.
-
#bound_stream_last_update_time_ms ⇒ DateTime
The date and time that the live stream referenced by boundStreamId was last updated.
-
#closed_captions_type ⇒ String
Corresponds to the JSON property
closedCaptionsType. -
#enable_auto_start ⇒ Boolean
(also: #enable_auto_start?)
This setting indicates whether auto start is enabled for this broadcast.
-
#enable_auto_stop ⇒ Boolean
(also: #enable_auto_stop?)
This setting indicates whether auto stop is enabled for this broadcast.
-
#enable_closed_captions ⇒ Boolean
(also: #enable_closed_captions?)
This setting indicates whether HTTP POST closed captioning is enabled for this broadcast.
-
#enable_content_encryption ⇒ Boolean
(also: #enable_content_encryption?)
This setting indicates whether YouTube should enable content encryption for the broadcast.
-
#enable_dvr ⇒ Boolean
(also: #enable_dvr?)
This setting determines whether viewers can access DVR controls while watching the video.
-
#enable_embed ⇒ Boolean
(also: #enable_embed?)
This setting indicates whether the broadcast video can be played in an embedded player.
-
#enable_low_latency ⇒ Boolean
(also: #enable_low_latency?)
Indicates whether this broadcast has low latency enabled.
-
#latency_preference ⇒ String
If both this and enable_low_latency are set, they must match.
-
#mesh ⇒ String
The mesh for projecting the video if projection is mesh.
-
#monitor_stream ⇒ Google::Apis::YoutubeV3::MonitorStreamInfo
Settings and Info of the monitor stream Corresponds to the JSON property
monitorStream. -
#projection ⇒ String
The projection format of this broadcast.
-
#record_from_start ⇒ Boolean
(also: #record_from_start?)
Automatically start recording after the event goes live.
-
#start_with_slate ⇒ Boolean
(also: #start_with_slate?)
This setting indicates whether the broadcast should automatically begin with an in-stream slate when you update the broadcast's status to live.
-
#stereo_layout ⇒ String
The 3D stereo layout of this broadcast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastContentDetails
constructor
A new instance of LiveBroadcastContentDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastContentDetails
Returns a new instance of LiveBroadcastContentDetails.
3889 3890 3891 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bound_stream_id ⇒ String
This value uniquely identifies the live stream bound to the broadcast.
Corresponds to the JSON property boundStreamId
3764 3765 3766 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3764 def bound_stream_id @bound_stream_id end |
#bound_stream_last_update_time_ms ⇒ DateTime
The date and time that the live stream referenced by boundStreamId was last
updated.
Corresponds to the JSON property boundStreamLastUpdateTimeMs
3770 3771 3772 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3770 def bound_stream_last_update_time_ms @bound_stream_last_update_time_ms end |
#closed_captions_type ⇒ String
Corresponds to the JSON property closedCaptionsType
3775 3776 3777 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3775 def closed_captions_type @closed_captions_type end |
#enable_auto_start ⇒ Boolean Also known as: enable_auto_start?
This setting indicates whether auto start is enabled for this broadcast. The
default value for this property is false. This setting can only be used by
Events.
Corresponds to the JSON property enableAutoStart
3782 3783 3784 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3782 def enable_auto_start @enable_auto_start end |
#enable_auto_stop ⇒ Boolean Also known as: enable_auto_stop?
This setting indicates whether auto stop is enabled for this broadcast. The
default value for this property is false. This setting can only be used by
Events.
Corresponds to the JSON property enableAutoStop
3790 3791 3792 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3790 def enable_auto_stop @enable_auto_stop end |
#enable_closed_captions ⇒ Boolean Also known as: enable_closed_captions?
This setting indicates whether HTTP POST closed captioning is enabled for this
broadcast. The ingestion URL of the closed captions is returned through the
liveStreams API. This is mutually exclusive with using the
closed_captions_type property, and is equivalent to setting
closed_captions_type to CLOSED_CAPTIONS_HTTP_POST.
Corresponds to the JSON property enableClosedCaptions
3800 3801 3802 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3800 def enable_closed_captions @enable_closed_captions end |
#enable_content_encryption ⇒ Boolean Also known as: enable_content_encryption?
This setting indicates whether YouTube should enable content encryption for
the broadcast.
Corresponds to the JSON property enableContentEncryption
3807 3808 3809 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3807 def enable_content_encryption @enable_content_encryption end |
#enable_dvr ⇒ Boolean Also known as: enable_dvr?
This setting determines whether viewers can access DVR controls while watching
the video. DVR controls enable the viewer to control the video playback
experience by pausing, rewinding, or fast forwarding content. The default
value for this property is true. Important: You must set the value to true
and also set the enableArchive property's value to true if you want to make
playback available immediately after the broadcast ends.
Corresponds to the JSON property enableDvr
3818 3819 3820 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3818 def enable_dvr @enable_dvr end |
#enable_embed ⇒ Boolean Also known as: enable_embed?
This setting indicates whether the broadcast video can be played in an
embedded player. If you choose to archive the video (using the enableArchive
property), this setting will also apply to the archived video.
Corresponds to the JSON property enableEmbed
3826 3827 3828 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3826 def @enable_embed end |
#enable_low_latency ⇒ Boolean Also known as: enable_low_latency?
Indicates whether this broadcast has low latency enabled.
Corresponds to the JSON property enableLowLatency
3832 3833 3834 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3832 def enable_low_latency @enable_low_latency end |
#latency_preference ⇒ String
If both this and enable_low_latency are set, they must match. LATENCY_NORMAL
should match enable_low_latency=false LATENCY_LOW should match
enable_low_latency=true LATENCY_ULTRA_LOW should have enable_low_latency
omitted.
Corresponds to the JSON property latencyPreference
3841 3842 3843 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3841 def latency_preference @latency_preference end |
#mesh ⇒ String
The mesh for projecting the video if projection is mesh. The mesh value must
be a UTF-8 string containing the base-64 encoding of 3D mesh data that follows
the Spherical Video V2 RFC specification for an mshp box, excluding the box
size and type but including the following four reserved zero bytes for the
version and flags.
Corresponds to the JSON property mesh
NOTE: Values are automatically base64 encoded/decoded in the client library.
3851 3852 3853 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3851 def mesh @mesh end |
#monitor_stream ⇒ Google::Apis::YoutubeV3::MonitorStreamInfo
Settings and Info of the monitor stream
Corresponds to the JSON property monitorStream
3856 3857 3858 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3856 def monitor_stream @monitor_stream end |
#projection ⇒ String
The projection format of this broadcast. This defaults to rectangular.
Corresponds to the JSON property projection
3861 3862 3863 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3861 def projection @projection end |
#record_from_start ⇒ Boolean Also known as: record_from_start?
Automatically start recording after the event goes live. The default value for
this property is true. Important: You must also set the enableDvr property's
value to true if you want the playback to be available immediately after the
broadcast ends. If you set this property's value to true but do not also set
the enableDvr property to true, there may be a delay of around one day before
the archived video will be available for playback.
Corresponds to the JSON property recordFromStart
3871 3872 3873 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3871 def record_from_start @record_from_start end |
#start_with_slate ⇒ Boolean Also known as: start_with_slate?
This setting indicates whether the broadcast should automatically begin with
an in-stream slate when you update the broadcast's status to live. After
updating the status, you then need to send a liveCuepoints.insert request that
sets the cuepoint's eventState to end to remove the in-stream slate and make
your broadcast stream visible to viewers.
Corresponds to the JSON property startWithSlate
3881 3882 3883 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3881 def start_with_slate @start_with_slate end |
#stereo_layout ⇒ String
The 3D stereo layout of this broadcast. This defaults to mono.
Corresponds to the JSON property stereoLayout
3887 3888 3889 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3887 def stereo_layout @stereo_layout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3894 3895 3896 3897 3898 3899 3900 3901 3902 3903 3904 3905 3906 3907 3908 3909 3910 3911 3912 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 3894 def update!(**args) @bound_stream_id = args[:bound_stream_id] if args.key?(:bound_stream_id) @bound_stream_last_update_time_ms = args[:bound_stream_last_update_time_ms] if args.key?(:bound_stream_last_update_time_ms) @closed_captions_type = args[:closed_captions_type] if args.key?(:closed_captions_type) @enable_auto_start = args[:enable_auto_start] if args.key?(:enable_auto_start) @enable_auto_stop = args[:enable_auto_stop] if args.key?(:enable_auto_stop) @enable_closed_captions = args[:enable_closed_captions] if args.key?(:enable_closed_captions) @enable_content_encryption = args[:enable_content_encryption] if args.key?(:enable_content_encryption) @enable_dvr = args[:enable_dvr] if args.key?(:enable_dvr) @enable_embed = args[:enable_embed] if args.key?(:enable_embed) @enable_low_latency = args[:enable_low_latency] if args.key?(:enable_low_latency) @latency_preference = args[:latency_preference] if args.key?(:latency_preference) @mesh = args[:mesh] if args.key?(:mesh) @monitor_stream = args[:monitor_stream] if args.key?(:monitor_stream) @projection = args[:projection] if args.key?(:projection) @record_from_start = args[:record_from_start] if args.key?(:record_from_start) @start_with_slate = args[:start_with_slate] if args.key?(:start_with_slate) @stereo_layout = args[:stereo_layout] if args.key?(:stereo_layout) end |