Class: Google::Apis::YoutubeV3::LiveBroadcastSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic broadcast information.
Instance Attribute Summary collapse
-
#actual_end_time ⇒ DateTime
The date and time that the broadcast actually ended.
-
#actual_start_time ⇒ DateTime
The date and time that the broadcast actually started.
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast.
-
#description ⇒ String
The broadcast's description.
-
#is_default_broadcast ⇒ Boolean
(also: #is_default_broadcast?)
Indicates whether this broadcast is the default broadcast.
-
#live_chat_id ⇒ String
The id of the live chat for this broadcast.
-
#published_at ⇒ DateTime
The date and time that the broadcast was added to YouTube's live broadcast schedule.
-
#scheduled_end_time ⇒ DateTime
The date and time that the broadcast is scheduled to end.
-
#scheduled_start_time ⇒ DateTime
The date and time that the broadcast is scheduled to start.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The broadcast's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastSnippet
constructor
A new instance of LiveBroadcastSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastSnippet
Returns a new instance of LiveBroadcastSnippet.
4139 4140 4141 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_end_time ⇒ DateTime
The date and time that the broadcast actually ended. This information is only
available once the broadcast's state is complete.
Corresponds to the JSON property actualEndTime
4079 4080 4081 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4079 def actual_end_time @actual_end_time end |
#actual_start_time ⇒ DateTime
The date and time that the broadcast actually started. This information is
only available once the broadcast's state is live.
Corresponds to the JSON property actualStartTime
4085 4086 4087 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4085 def actual_start_time @actual_start_time end |
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is publishing
the broadcast.
Corresponds to the JSON property channelId
4091 4092 4093 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4091 def channel_id @channel_id end |
#description ⇒ String
The broadcast's description. As with the title, you can set this field by
modifying the broadcast resource or by setting the description field of the
corresponding video resource.
Corresponds to the JSON property description
4098 4099 4100 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4098 def description @description end |
#is_default_broadcast ⇒ Boolean Also known as: is_default_broadcast?
Indicates whether this broadcast is the default broadcast. Internal only.
Corresponds to the JSON property isDefaultBroadcast
4103 4104 4105 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4103 def is_default_broadcast @is_default_broadcast end |
#live_chat_id ⇒ String
The id of the live chat for this broadcast.
Corresponds to the JSON property liveChatId
4109 4110 4111 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4109 def live_chat_id @live_chat_id end |
#published_at ⇒ DateTime
The date and time that the broadcast was added to YouTube's live broadcast
schedule.
Corresponds to the JSON property publishedAt
4115 4116 4117 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4115 def published_at @published_at end |
#scheduled_end_time ⇒ DateTime
The date and time that the broadcast is scheduled to end.
Corresponds to the JSON property scheduledEndTime
4120 4121 4122 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4120 def scheduled_end_time @scheduled_end_time end |
#scheduled_start_time ⇒ DateTime
The date and time that the broadcast is scheduled to start.
Corresponds to the JSON property scheduledStartTime
4125 4126 4127 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4125 def scheduled_start_time @scheduled_start_time end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
4130 4131 4132 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4130 def thumbnails @thumbnails end |
#title ⇒ String
The broadcast's title. Note that the broadcast represents exactly one YouTube
video. You can set this field by modifying the broadcast resource or by
setting the title field of the corresponding video resource.
Corresponds to the JSON property title
4137 4138 4139 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4137 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4144 4145 4146 4147 4148 4149 4150 4151 4152 4153 4154 4155 4156 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4144 def update!(**args) @actual_end_time = args[:actual_end_time] if args.key?(:actual_end_time) @actual_start_time = args[:actual_start_time] if args.key?(:actual_start_time) @channel_id = args[:channel_id] if args.key?(:channel_id) @description = args[:description] if args.key?(:description) @is_default_broadcast = args[:is_default_broadcast] if args.key?(:is_default_broadcast) @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id) @published_at = args[:published_at] if args.key?(:published_at) @scheduled_end_time = args[:scheduled_end_time] if args.key?(:scheduled_end_time) @scheduled_start_time = args[:scheduled_start_time] if args.key?(:scheduled_start_time) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |