Class: Google::Apis::YoutubeV3::LiveBroadcastSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic broadcast information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveBroadcastSnippet

Returns a new instance of LiveBroadcastSnippet.



4113
4114
4115
# File 'lib/google/apis/youtube_v3/classes.rb', line 4113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_end_timeDateTime

The date and time that the broadcast actually ended. This information is only available once the broadcast's state is complete. Corresponds to the JSON property actualEndTime

Returns:

  • (DateTime)


4053
4054
4055
# File 'lib/google/apis/youtube_v3/classes.rb', line 4053

def actual_end_time
  @actual_end_time
end

#actual_start_timeDateTime

The date and time that the broadcast actually started. This information is only available once the broadcast's state is live. Corresponds to the JSON property actualStartTime

Returns:

  • (DateTime)


4059
4060
4061
# File 'lib/google/apis/youtube_v3/classes.rb', line 4059

def actual_start_time
  @actual_start_time
end

#channel_idString

The ID that YouTube uses to uniquely identify the channel that is publishing the broadcast. Corresponds to the JSON property channelId

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/youtube_v3/classes.rb', line 4065

def channel_id
  @channel_id
end

#descriptionString

The broadcast's description. As with the title, you can set this field by modifying the broadcast resource or by setting the description field of the corresponding video resource. Corresponds to the JSON property description

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/youtube_v3/classes.rb', line 4072

def description
  @description
end

#is_default_broadcastBoolean Also known as: is_default_broadcast?

Indicates whether this broadcast is the default broadcast. Internal only. Corresponds to the JSON property isDefaultBroadcast

Returns:

  • (Boolean)


4077
4078
4079
# File 'lib/google/apis/youtube_v3/classes.rb', line 4077

def is_default_broadcast
  @is_default_broadcast
end

#live_chat_idString

The id of the live chat for this broadcast. Corresponds to the JSON property liveChatId

Returns:

  • (String)


4083
4084
4085
# File 'lib/google/apis/youtube_v3/classes.rb', line 4083

def live_chat_id
  @live_chat_id
end

#published_atDateTime

The date and time that the broadcast was added to YouTube's live broadcast schedule. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


4089
4090
4091
# File 'lib/google/apis/youtube_v3/classes.rb', line 4089

def published_at
  @published_at
end

#scheduled_end_timeDateTime

The date and time that the broadcast is scheduled to end. Corresponds to the JSON property scheduledEndTime

Returns:

  • (DateTime)


4094
4095
4096
# File 'lib/google/apis/youtube_v3/classes.rb', line 4094

def scheduled_end_time
  @scheduled_end_time
end

#scheduled_start_timeDateTime

The date and time that the broadcast is scheduled to start. Corresponds to the JSON property scheduledStartTime

Returns:

  • (DateTime)


4099
4100
4101
# File 'lib/google/apis/youtube_v3/classes.rb', line 4099

def scheduled_start_time
  @scheduled_start_time
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



4104
4105
4106
# File 'lib/google/apis/youtube_v3/classes.rb', line 4104

def thumbnails
  @thumbnails
end

#titleString

The broadcast's title. Note that the broadcast represents exactly one YouTube video. You can set this field by modifying the broadcast resource or by setting the title field of the corresponding video resource. Corresponds to the JSON property title

Returns:

  • (String)


4111
4112
4113
# File 'lib/google/apis/youtube_v3/classes.rb', line 4111

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
4130
# File 'lib/google/apis/youtube_v3/classes.rb', line 4118

def update!(**args)
  @actual_end_time = args[:actual_end_time] if args.key?(:actual_end_time)
  @actual_start_time = args[:actual_start_time] if args.key?(:actual_start_time)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @description = args[:description] if args.key?(:description)
  @is_default_broadcast = args[:is_default_broadcast] if args.key?(:is_default_broadcast)
  @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id)
  @published_at = args[:published_at] if args.key?(:published_at)
  @scheduled_end_time = args[:scheduled_end_time] if args.key?(:scheduled_end_time)
  @scheduled_start_time = args[:scheduled_start_time] if args.key?(:scheduled_start_time)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end