Class: Google::Apis::YoutubeV3::LiveBroadcastStatistics
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Statistics about the live broadcast. These represent a snapshot of the values at the time of the request. Statistics are only returned for live broadcasts.
Instance Attribute Summary collapse
-
#concurrent_viewers ⇒ Fixnum
The number of viewers currently watching the broadcast.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastStatistics
constructor
A new instance of LiveBroadcastStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastStatistics
Returns a new instance of LiveBroadcastStatistics.
4108 4109 4110 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#concurrent_viewers ⇒ Fixnum
The number of viewers currently watching the broadcast. The property and its
value will be present if the broadcast has current viewers and the broadcast
owner has not hidden the viewcount for the video. Note that YouTube stops
tracking the number of concurrent viewers for a broadcast when the broadcast
ends. So, this property would not identify the number of viewers watching an
archived video of a live broadcast that already ended.
Corresponds to the JSON property concurrentViewers
4106 4107 4108 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4106 def concurrent_viewers @concurrent_viewers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4113 4114 4115 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4113 def update!(**args) @concurrent_viewers = args[:concurrent_viewers] if args.key?(:concurrent_viewers) end |