Class: Google::Apis::YoutubeV3::LiveBroadcastStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Live broadcast state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveBroadcastStatus

Returns a new instance of LiveBroadcastStatus.



4370
4371
4372
# File 'lib/google/apis/youtube_v3/classes.rb', line 4370

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#life_cycle_statusString

The broadcast's status. The status can be updated using the API's liveBroadcasts.transition method. Corresponds to the JSON property lifeCycleStatus

Returns:

  • (String)


4335
4336
4337
# File 'lib/google/apis/youtube_v3/classes.rb', line 4335

def life_cycle_status
  @life_cycle_status
end

#live_broadcast_priorityString

Priority of the live broadcast event (internal state). Corresponds to the JSON property liveBroadcastPriority

Returns:

  • (String)


4340
4341
4342
# File 'lib/google/apis/youtube_v3/classes.rb', line 4340

def live_broadcast_priority
  @live_broadcast_priority
end

#made_for_kidsBoolean Also known as: made_for_kids?

Whether the broadcast is made for kids or not, decided by YouTube instead of the creator. This field is read only. Corresponds to the JSON property madeForKids

Returns:

  • (Boolean)


4346
4347
4348
# File 'lib/google/apis/youtube_v3/classes.rb', line 4346

def made_for_kids
  @made_for_kids
end

#privacy_statusString

The broadcast's privacy status. Note that the broadcast represents exactly one YouTube video, so the privacy settings are identical to those supported for videos. In addition, you can set this field by modifying the broadcast resource or by setting the privacyStatus field of the corresponding video resource. Corresponds to the JSON property privacyStatus

Returns:

  • (String)


4356
4357
4358
# File 'lib/google/apis/youtube_v3/classes.rb', line 4356

def privacy_status
  @privacy_status
end

#recording_statusString

The broadcast's recording status. Corresponds to the JSON property recordingStatus

Returns:

  • (String)


4361
4362
4363
# File 'lib/google/apis/youtube_v3/classes.rb', line 4361

def recording_status
  @recording_status
end

#self_declared_made_for_kidsBoolean Also known as: self_declared_made_for_kids?

This field will be set to True if the creator declares the broadcast to be kids only: go/live-cw-work. Corresponds to the JSON property selfDeclaredMadeForKids

Returns:

  • (Boolean)


4367
4368
4369
# File 'lib/google/apis/youtube_v3/classes.rb', line 4367

def self_declared_made_for_kids
  @self_declared_made_for_kids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4375
4376
4377
4378
4379
4380
4381
4382
# File 'lib/google/apis/youtube_v3/classes.rb', line 4375

def update!(**args)
  @life_cycle_status = args[:life_cycle_status] if args.key?(:life_cycle_status)
  @live_broadcast_priority = args[:live_broadcast_priority] if args.key?(:live_broadcast_priority)
  @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids)
  @privacy_status = args[:privacy_status] if args.key?(:privacy_status)
  @recording_status = args[:recording_status] if args.key?(:recording_status)
  @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids)
end