Class: Google::Apis::YoutubeV3::LiveBroadcastStatus
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveBroadcastStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Live broadcast state.
Instance Attribute Summary collapse
-
#life_cycle_status ⇒ String
The broadcast's status.
-
#live_broadcast_priority ⇒ String
Priority of the live broadcast event (internal state).
-
#made_for_kids ⇒ Boolean
(also: #made_for_kids?)
Whether the broadcast is made for kids or not, decided by YouTube instead of the creator.
-
#privacy_status ⇒ String
The broadcast's privacy status.
-
#recording_status ⇒ String
The broadcast's recording status.
-
#self_declared_made_for_kids ⇒ Boolean
(also: #self_declared_made_for_kids?)
This field will be set to True if the creator declares the broadcast to be kids only: go/live-cw-work.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveBroadcastStatus
constructor
A new instance of LiveBroadcastStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveBroadcastStatus
Returns a new instance of LiveBroadcastStatus.
4161 4162 4163 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#life_cycle_status ⇒ String
The broadcast's status. The status can be updated using the API's
liveBroadcasts.transition method.
Corresponds to the JSON property lifeCycleStatus
4126 4127 4128 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4126 def life_cycle_status @life_cycle_status end |
#live_broadcast_priority ⇒ String
Priority of the live broadcast event (internal state).
Corresponds to the JSON property liveBroadcastPriority
4131 4132 4133 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4131 def live_broadcast_priority @live_broadcast_priority end |
#made_for_kids ⇒ Boolean Also known as: made_for_kids?
Whether the broadcast is made for kids or not, decided by YouTube instead of
the creator. This field is read only.
Corresponds to the JSON property madeForKids
4137 4138 4139 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4137 def made_for_kids @made_for_kids end |
#privacy_status ⇒ String
The broadcast's privacy status. Note that the broadcast represents exactly one
YouTube video, so the privacy settings are identical to those supported for
videos. In addition, you can set this field by modifying the broadcast
resource or by setting the privacyStatus field of the corresponding video
resource.
Corresponds to the JSON property privacyStatus
4147 4148 4149 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4147 def privacy_status @privacy_status end |
#recording_status ⇒ String
The broadcast's recording status.
Corresponds to the JSON property recordingStatus
4152 4153 4154 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4152 def recording_status @recording_status end |
#self_declared_made_for_kids ⇒ Boolean Also known as: self_declared_made_for_kids?
This field will be set to True if the creator declares the broadcast to be
kids only: go/live-cw-work.
Corresponds to the JSON property selfDeclaredMadeForKids
4158 4159 4160 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4158 def self_declared_made_for_kids @self_declared_made_for_kids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4166 4167 4168 4169 4170 4171 4172 4173 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4166 def update!(**args) @life_cycle_status = args[:life_cycle_status] if args.key?(:life_cycle_status) @live_broadcast_priority = args[:live_broadcast_priority] if args.key?(:live_broadcast_priority) @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids) @privacy_status = args[:privacy_status] if args.key?(:privacy_status) @recording_status = args[:recording_status] if args.key?(:recording_status) @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids) end |