Class: Google::Apis::YoutubeV3::LiveChatFanFundingEventDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatFanFundingEventDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#amount_display_string ⇒ String
A rendered string that displays the fund amount and currency to the user.
-
#amount_micros ⇒ Fixnum
The amount of the fund.
-
#currency ⇒ String
The currency in which the fund was made.
-
#user_comment ⇒ String
The comment added by the user to this fan funding event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatFanFundingEventDetails
constructor
A new instance of LiveChatFanFundingEventDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatFanFundingEventDetails
Returns a new instance of LiveChatFanFundingEventDetails.
4241 4242 4243 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_display_string ⇒ String
A rendered string that displays the fund amount and currency to the user.
Corresponds to the JSON property amountDisplayString
4224 4225 4226 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4224 def amount_display_string @amount_display_string end |
#amount_micros ⇒ Fixnum
The amount of the fund.
Corresponds to the JSON property amountMicros
4229 4230 4231 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4229 def amount_micros @amount_micros end |
#currency ⇒ String
The currency in which the fund was made.
Corresponds to the JSON property currency
4234 4235 4236 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4234 def currency @currency end |
#user_comment ⇒ String
The comment added by the user to this fan funding event.
Corresponds to the JSON property userComment
4239 4240 4241 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4239 def user_comment @user_comment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4246 4247 4248 4249 4250 4251 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4246 def update!(**args) @amount_display_string = args[:amount_display_string] if args.key?(:amount_display_string) @amount_micros = args[:amount_micros] if args.key?(:amount_micros) @currency = args[:currency] if args.key?(:currency) @user_comment = args[:user_comment] if args.key?(:user_comment) end |