Class: Google::Apis::YoutubeV3::LiveChatGiftDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about the gift event, this is only set if the type is 'giftEvent'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatGiftDetails

Returns a new instance of LiveChatGiftDetails.



4538
4539
4540
# File 'lib/google/apis/youtube_v3/classes.rb', line 4538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

The alternative text to be used for accessibility. Corresponds to the JSON property altText

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/youtube_v3/classes.rb', line 4500

def alt_text
  @alt_text
end

#combo_countFixnum

The number of times the gift has been sent in a row. Corresponds to the JSON property comboCount

Returns:

  • (Fixnum)


4505
4506
4507
# File 'lib/google/apis/youtube_v3/classes.rb', line 4505

def combo_count
  @combo_count
end

#gift_durationString

The duration of the gift. Corresponds to the JSON property giftDuration

Returns:

  • (String)


4510
4511
4512
# File 'lib/google/apis/youtube_v3/classes.rb', line 4510

def gift_duration
  @gift_duration
end

#gift_nameString

The name of the gift. Corresponds to the JSON property giftName

Returns:

  • (String)


4515
4516
4517
# File 'lib/google/apis/youtube_v3/classes.rb', line 4515

def gift_name
  @gift_name
end

#gift_urlString

The URL of the gift image. Corresponds to the JSON property giftUrl

Returns:

  • (String)


4520
4521
4522
# File 'lib/google/apis/youtube_v3/classes.rb', line 4520

def gift_url
  @gift_url
end

#has_visual_effectBoolean Also known as: has_visual_effect?

Whether the gift involves a visual effect. Corresponds to the JSON property hasVisualEffect

Returns:

  • (Boolean)


4525
4526
4527
# File 'lib/google/apis/youtube_v3/classes.rb', line 4525

def has_visual_effect
  @has_visual_effect
end

#jewels_amountFixnum

The value of the gift in jewels. Corresponds to the JSON property jewelsAmount

Returns:

  • (Fixnum)


4531
4532
4533
# File 'lib/google/apis/youtube_v3/classes.rb', line 4531

def jewels_amount
  @jewels_amount
end

#languageString

The BCP-47 language code of the gift. Corresponds to the JSON property language

Returns:

  • (String)


4536
4537
4538
# File 'lib/google/apis/youtube_v3/classes.rb', line 4536

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
# File 'lib/google/apis/youtube_v3/classes.rb', line 4543

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @combo_count = args[:combo_count] if args.key?(:combo_count)
  @gift_duration = args[:gift_duration] if args.key?(:gift_duration)
  @gift_name = args[:gift_name] if args.key?(:gift_name)
  @gift_url = args[:gift_url] if args.key?(:gift_url)
  @has_visual_effect = args[:has_visual_effect] if args.key?(:has_visual_effect)
  @jewels_amount = args[:jewels_amount] if args.key?(:jewels_amount)
  @language = args[:language] if args.key?(:language)
end