Class: Google::Apis::YoutubeV3::LiveChatGiftDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatGiftDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Details about the gift event, this is only set if the type is 'giftEvent'.
Instance Attribute Summary collapse
-
#alt_text ⇒ String
The alternative text to be used for accessibility.
-
#combo_count ⇒ Fixnum
The number of times the gift has been sent in a row.
-
#gift_duration ⇒ String
The duration of the gift.
-
#gift_name ⇒ String
The name of the gift.
-
#gift_url ⇒ String
The URL of the gift image.
-
#has_visual_effect ⇒ Boolean
(also: #has_visual_effect?)
Whether the gift involves a visual effect.
-
#jewels_amount ⇒ Fixnum
The value of the gift in jewels.
-
#language ⇒ String
The BCP-47 language code of the gift.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatGiftDetails
constructor
A new instance of LiveChatGiftDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatGiftDetails
Returns a new instance of LiveChatGiftDetails.
4373 4374 4375 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alt_text ⇒ String
The alternative text to be used for accessibility.
Corresponds to the JSON property altText
4335 4336 4337 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4335 def alt_text @alt_text end |
#combo_count ⇒ Fixnum
The number of times the gift has been sent in a row.
Corresponds to the JSON property comboCount
4340 4341 4342 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4340 def combo_count @combo_count end |
#gift_duration ⇒ String
The duration of the gift.
Corresponds to the JSON property giftDuration
4345 4346 4347 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4345 def gift_duration @gift_duration end |
#gift_name ⇒ String
The name of the gift.
Corresponds to the JSON property giftName
4350 4351 4352 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4350 def gift_name @gift_name end |
#gift_url ⇒ String
The URL of the gift image.
Corresponds to the JSON property giftUrl
4355 4356 4357 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4355 def gift_url @gift_url end |
#has_visual_effect ⇒ Boolean Also known as: has_visual_effect?
Whether the gift involves a visual effect.
Corresponds to the JSON property hasVisualEffect
4360 4361 4362 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4360 def has_visual_effect @has_visual_effect end |
#jewels_amount ⇒ Fixnum
The value of the gift in jewels.
Corresponds to the JSON property jewelsAmount
4366 4367 4368 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4366 def jewels_amount @jewels_amount end |
#language ⇒ String
The BCP-47 language code of the gift.
Corresponds to the JSON property language
4371 4372 4373 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4371 def language @language end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4378 4379 4380 4381 4382 4383 4384 4385 4386 4387 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4378 def update!(**args) @alt_text = args[:alt_text] if args.key?(:alt_text) @combo_count = args[:combo_count] if args.key?(:combo_count) @gift_duration = args[:gift_duration] if args.key?(:gift_duration) @gift_name = args[:gift_name] if args.key?(:gift_name) @gift_url = args[:gift_url] if args.key?(:gift_url) @has_visual_effect = args[:has_visual_effect] if args.key?(:has_visual_effect) @jewels_amount = args[:jewels_amount] if args.key?(:jewels_amount) @language = args[:language] if args.key?(:language) end |