Class: Google::Apis::YoutubeV3::LiveChatGiftDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about the gift event, this is only set if the type is 'giftEvent'.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatGiftDetails

Returns a new instance of LiveChatGiftDetails.



4299
4300
4301
# File 'lib/google/apis/youtube_v3/classes.rb', line 4299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

The alternative text to be used for accessibility. Corresponds to the JSON property altText

Returns:

  • (String)


4261
4262
4263
# File 'lib/google/apis/youtube_v3/classes.rb', line 4261

def alt_text
  @alt_text
end

#combo_countFixnum

The number of times the gift has been sent in a row. Corresponds to the JSON property comboCount

Returns:

  • (Fixnum)


4266
4267
4268
# File 'lib/google/apis/youtube_v3/classes.rb', line 4266

def combo_count
  @combo_count
end

#gift_durationString

The duration of the gift. Corresponds to the JSON property giftDuration

Returns:

  • (String)


4271
4272
4273
# File 'lib/google/apis/youtube_v3/classes.rb', line 4271

def gift_duration
  @gift_duration
end

#gift_nameString

The name of the gift. Corresponds to the JSON property giftName

Returns:

  • (String)


4276
4277
4278
# File 'lib/google/apis/youtube_v3/classes.rb', line 4276

def gift_name
  @gift_name
end

#gift_urlString

The URL of the gift image. Corresponds to the JSON property giftUrl

Returns:

  • (String)


4281
4282
4283
# File 'lib/google/apis/youtube_v3/classes.rb', line 4281

def gift_url
  @gift_url
end

#has_visual_effectBoolean Also known as: has_visual_effect?

Whether the gift involves a visual effect. Corresponds to the JSON property hasVisualEffect

Returns:

  • (Boolean)


4286
4287
4288
# File 'lib/google/apis/youtube_v3/classes.rb', line 4286

def has_visual_effect
  @has_visual_effect
end

#jewels_countFixnum

The cost of the gift in jewels. Corresponds to the JSON property jewelsCount

Returns:

  • (Fixnum)


4292
4293
4294
# File 'lib/google/apis/youtube_v3/classes.rb', line 4292

def jewels_count
  @jewels_count
end

#languageString

The BCP-47 language code of the gift. Corresponds to the JSON property language

Returns:

  • (String)


4297
4298
4299
# File 'lib/google/apis/youtube_v3/classes.rb', line 4297

def language
  @language
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4304
4305
4306
4307
4308
4309
4310
4311
4312
4313
# File 'lib/google/apis/youtube_v3/classes.rb', line 4304

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @combo_count = args[:combo_count] if args.key?(:combo_count)
  @gift_duration = args[:gift_duration] if args.key?(:gift_duration)
  @gift_name = args[:gift_name] if args.key?(:gift_name)
  @gift_url = args[:gift_url] if args.key?(:gift_url)
  @has_visual_effect = args[:has_visual_effect] if args.key?(:has_visual_effect)
  @jewels_count = args[:jewels_count] if args.key?(:jewels_count)
  @language = args[:language] if args.key?(:language)
end