Class: Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#associated_membership_gifting_message_id ⇒ String
The ID of the membership gifting message that is related to this gift membership.
-
#gifter_channel_id ⇒ String
The ID of the user that made the membership gifting purchase.
-
#member_level_name ⇒ String
The name of the Level at which the viewer is a member.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatGiftMembershipReceivedDetails
constructor
A new instance of LiveChatGiftMembershipReceivedDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatGiftMembershipReceivedDetails
Returns a new instance of LiveChatGiftMembershipReceivedDetails.
4441 4442 4443 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_membership_gifting_message_id ⇒ String
The ID of the membership gifting message that is related to this gift
membership. This ID will always refer to a message whose type is '
membershipGiftingEvent'.
Corresponds to the JSON property associatedMembershipGiftingMessageId
4425 4426 4427 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4425 def @associated_membership_gifting_message_id end |
#gifter_channel_id ⇒ String
The ID of the user that made the membership gifting purchase. This matches the
snippet.authorChannelId of the associated membership gifting message.
Corresponds to the JSON property gifterChannelId
4431 4432 4433 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4431 def gifter_channel_id @gifter_channel_id end |
#member_level_name ⇒ String
The name of the Level at which the viewer is a member. This matches the
snippet.membershipGiftingDetails.giftMembershipsLevelName of the associated
membership gifting message. The Level names are defined by the YouTube channel
offering the Membership. In some situations this field isn't filled.
Corresponds to the JSON property memberLevelName
4439 4440 4441 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4439 def member_level_name @member_level_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4446 4447 4448 4449 4450 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4446 def update!(**args) @associated_membership_gifting_message_id = args[:associated_membership_gifting_message_id] if args.key?(:associated_membership_gifting_message_id) @gifter_channel_id = args[:gifter_channel_id] if args.key?(:gifter_channel_id) @member_level_name = args[:member_level_name] if args.key?(:member_level_name) end |