Class: Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#associated_membership_gifting_message_id ⇒ String
The ID of the membership gifting message that is related to this gift membership.
-
#gifter_channel_id ⇒ String
The ID of the user that made the membership gifting purchase.
-
#member_level_name ⇒ String
The name of the Level at which the viewer is a member.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatGiftMembershipReceivedDetails
constructor
A new instance of LiveChatGiftMembershipReceivedDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatGiftMembershipReceivedDetails
Returns a new instance of LiveChatGiftMembershipReceivedDetails.
4415 4416 4417 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associated_membership_gifting_message_id ⇒ String
The ID of the membership gifting message that is related to this gift
membership. This ID will always refer to a message whose type is '
membershipGiftingEvent'.
Corresponds to the JSON property associatedMembershipGiftingMessageId
4399 4400 4401 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4399 def @associated_membership_gifting_message_id end |
#gifter_channel_id ⇒ String
The ID of the user that made the membership gifting purchase. This matches the
snippet.authorChannelId of the associated membership gifting message.
Corresponds to the JSON property gifterChannelId
4405 4406 4407 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4405 def gifter_channel_id @gifter_channel_id end |
#member_level_name ⇒ String
The name of the Level at which the viewer is a member. This matches the
snippet.membershipGiftingDetails.giftMembershipsLevelName of the associated
membership gifting message. The Level names are defined by the YouTube channel
offering the Membership. In some situations this field isn't filled.
Corresponds to the JSON property memberLevelName
4413 4414 4415 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4413 def member_level_name @member_level_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4420 4421 4422 4423 4424 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4420 def update!(**args) @associated_membership_gifting_message_id = args[:associated_membership_gifting_message_id] if args.key?(:associated_membership_gifting_message_id) @gifter_channel_id = args[:gifter_channel_id] if args.key?(:gifter_channel_id) @member_level_name = args[:member_level_name] if args.key?(:member_level_name) end |