Class: Google::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatGiftMembershipReceivedDetails

Returns a new instance of LiveChatGiftMembershipReceivedDetails.



4341
4342
4343
# File 'lib/google/apis/youtube_v3/classes.rb', line 4341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_membership_gifting_message_idString

The ID of the membership gifting message that is related to this gift membership. This ID will always refer to a message whose type is ' membershipGiftingEvent'. Corresponds to the JSON property associatedMembershipGiftingMessageId

Returns:

  • (String)


4325
4326
4327
# File 'lib/google/apis/youtube_v3/classes.rb', line 4325

def associated_membership_gifting_message_id
  @associated_membership_gifting_message_id
end

#gifter_channel_idString

The ID of the user that made the membership gifting purchase. This matches the snippet.authorChannelId of the associated membership gifting message. Corresponds to the JSON property gifterChannelId

Returns:

  • (String)


4331
4332
4333
# File 'lib/google/apis/youtube_v3/classes.rb', line 4331

def gifter_channel_id
  @gifter_channel_id
end

#member_level_nameString

The name of the Level at which the viewer is a member. This matches the snippet.membershipGiftingDetails.giftMembershipsLevelName of the associated membership gifting message. The Level names are defined by the YouTube channel offering the Membership. In some situations this field isn't filled. Corresponds to the JSON property memberLevelName

Returns:

  • (String)


4339
4340
4341
# File 'lib/google/apis/youtube_v3/classes.rb', line 4339

def member_level_name
  @member_level_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4346
4347
4348
4349
4350
# File 'lib/google/apis/youtube_v3/classes.rb', line 4346

def update!(**args)
  @associated_membership_gifting_message_id = args[:associated_membership_gifting_message_id] if args.key?(:associated_membership_gifting_message_id)
  @gifter_channel_id = args[:gifter_channel_id] if args.key?(:gifter_channel_id)
  @member_level_name = args[:member_level_name] if args.key?(:member_level_name)
end