Class: Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMemberMilestoneChatDetails

Returns a new instance of LiveChatMemberMilestoneChatDetails.



4451
4452
4453
# File 'lib/google/apis/youtube_v3/classes.rb', line 4451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#member_level_nameString

The name of the Level at which the viever is a member. The Level names are defined by the YouTube channel offering the Membership. In some situations this field isn't filled. Corresponds to the JSON property memberLevelName

Returns:

  • (String)


4436
4437
4438
# File 'lib/google/apis/youtube_v3/classes.rb', line 4436

def member_level_name
  @member_level_name
end

#member_monthFixnum

The total amount of months (rounded up) the viewer has been a member that granted them this Member Milestone Chat. This is the same number of months as is being displayed to YouTube users. Corresponds to the JSON property memberMonth

Returns:

  • (Fixnum)


4443
4444
4445
# File 'lib/google/apis/youtube_v3/classes.rb', line 4443

def member_month
  @member_month
end

#user_commentString

The comment added by the member to this Member Milestone Chat. This field is empty for messages without a comment from the member. Corresponds to the JSON property userComment

Returns:

  • (String)


4449
4450
4451
# File 'lib/google/apis/youtube_v3/classes.rb', line 4449

def user_comment
  @user_comment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4456
4457
4458
4459
4460
# File 'lib/google/apis/youtube_v3/classes.rb', line 4456

def update!(**args)
  @member_level_name = args[:member_level_name] if args.key?(:member_level_name)
  @member_month = args[:member_month] if args.key?(:member_month)
  @user_comment = args[:user_comment] if args.key?(:user_comment)
end