Class: Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#member_level_name ⇒ String
The name of the Level at which the viever is a member.
-
#member_month ⇒ Fixnum
The total amount of months (rounded up) the viewer has been a member that granted them this Member Milestone Chat.
-
#user_comment ⇒ String
The comment added by the member to this Member Milestone Chat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMemberMilestoneChatDetails
constructor
A new instance of LiveChatMemberMilestoneChatDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMemberMilestoneChatDetails
Returns a new instance of LiveChatMemberMilestoneChatDetails.
4377 4378 4379 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#member_level_name ⇒ String
The name of the Level at which the viever is a member. The Level names are
defined by the YouTube channel offering the Membership. In some situations
this field isn't filled.
Corresponds to the JSON property memberLevelName
4362 4363 4364 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4362 def member_level_name @member_level_name end |
#member_month ⇒ Fixnum
The total amount of months (rounded up) the viewer has been a member that
granted them this Member Milestone Chat. This is the same number of months as
is being displayed to YouTube users.
Corresponds to the JSON property memberMonth
4369 4370 4371 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4369 def member_month @member_month end |
#user_comment ⇒ String
The comment added by the member to this Member Milestone Chat. This field is
empty for messages without a comment from the member.
Corresponds to the JSON property userComment
4375 4376 4377 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4375 def user_comment @user_comment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4382 4383 4384 4385 4386 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4382 def update!(**args) @member_level_name = args[:member_level_name] if args.key?(:member_level_name) @member_month = args[:member_month] if args.key?(:member_month) @user_comment = args[:user_comment] if args.key?(:user_comment) end |