Class: Google::Apis::YoutubeV3::LiveChatMembershipGiftingDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMembershipGiftingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#gift_memberships_count ⇒ Fixnum
The number of gift memberships purchased by the user.
-
#gift_memberships_level_name ⇒ String
The name of the level of the gift memberships purchased by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMembershipGiftingDetails
constructor
A new instance of LiveChatMembershipGiftingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMembershipGiftingDetails
Returns a new instance of LiveChatMembershipGiftingDetails.
4654 4655 4656 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gift_memberships_count ⇒ Fixnum
The number of gift memberships purchased by the user.
Corresponds to the JSON property giftMembershipsCount
4645 4646 4647 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4645 def gift_memberships_count @gift_memberships_count end |
#gift_memberships_level_name ⇒ String
The name of the level of the gift memberships purchased by the user. The Level
names are defined by the YouTube channel offering the Membership. In some
situations this field isn't filled.
Corresponds to the JSON property giftMembershipsLevelName
4652 4653 4654 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4652 def gift_memberships_level_name @gift_memberships_level_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4659 4660 4661 4662 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4659 def update!(**args) @gift_memberships_count = args[:gift_memberships_count] if args.key?(:gift_memberships_count) @gift_memberships_level_name = args[:gift_memberships_level_name] if args.key?(:gift_memberships_level_name) end |