Class: Google::Apis::YoutubeV3::LiveChatMembershipGiftingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMembershipGiftingDetails

Returns a new instance of LiveChatMembershipGiftingDetails.



4644
4645
4646
# File 'lib/google/apis/youtube_v3/classes.rb', line 4644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gift_memberships_countFixnum

The number of gift memberships purchased by the user. Corresponds to the JSON property giftMembershipsCount

Returns:

  • (Fixnum)


4635
4636
4637
# File 'lib/google/apis/youtube_v3/classes.rb', line 4635

def gift_memberships_count
  @gift_memberships_count
end

#gift_memberships_level_nameString

The name of the level of the gift memberships purchased by the user. The Level names are defined by the YouTube channel offering the Membership. In some situations this field isn't filled. Corresponds to the JSON property giftMembershipsLevelName

Returns:

  • (String)


4642
4643
4644
# File 'lib/google/apis/youtube_v3/classes.rb', line 4642

def gift_memberships_level_name
  @gift_memberships_level_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4649
4650
4651
4652
# File 'lib/google/apis/youtube_v3/classes.rb', line 4649

def update!(**args)
  @gift_memberships_count = args[:gift_memberships_count] if args.key?(:gift_memberships_count)
  @gift_memberships_level_name = args[:gift_memberships_level_name] if args.key?(:gift_memberships_level_name)
end