Class: Google::Apis::YoutubeV3::LiveChatMessage
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A liveChatMessage resource represents a chat message in a YouTube Live Chat.
Instance Attribute Summary collapse
-
#author_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageAuthorDetails
The authorDetails object contains basic details about the user that posted this message.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the message.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::LiveChatMessageSnippet
Next ID: 35 Corresponds to the JSON property
snippet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMessage
constructor
A new instance of LiveChatMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMessage
Returns a new instance of LiveChatMessage.
4690 4691 4692 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#author_details ⇒ Google::Apis::YoutubeV3::LiveChatMessageAuthorDetails
The authorDetails object contains basic details about the user that posted
this message.
Corresponds to the JSON property authorDetails
4667 4668 4669 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4667 def @author_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4672 4673 4674 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4672 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the message.
Corresponds to the JSON property id
4677 4678 4679 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4677 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatMessage".
Corresponds to the JSON property kind
4683 4684 4685 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4683 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::LiveChatMessageSnippet
Next ID: 35
Corresponds to the JSON property snippet
4688 4689 4690 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4688 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 4701 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4695 def update!(**args) @author_details = args[:author_details] if args.key?(:author_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |