Class: Google::Apis::YoutubeV3::LiveChatMessageAuthorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMessageAuthorDetails

Returns a new instance of LiveChatMessageAuthorDetails.



4583
4584
4585
# File 'lib/google/apis/youtube_v3/classes.rb', line 4583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The YouTube channel ID. Corresponds to the JSON property channelId

Returns:

  • (String)


4542
4543
4544
# File 'lib/google/apis/youtube_v3/classes.rb', line 4542

def channel_id
  @channel_id
end

#channel_urlString

The channel's URL. Corresponds to the JSON property channelUrl

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/youtube_v3/classes.rb', line 4547

def channel_url
  @channel_url
end

#display_nameString

The channel's display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/youtube_v3/classes.rb', line 4552

def display_name
  @display_name
end

#is_chat_moderatorBoolean Also known as: is_chat_moderator?

Whether the author is a moderator of the live chat. Corresponds to the JSON property isChatModerator

Returns:

  • (Boolean)


4557
4558
4559
# File 'lib/google/apis/youtube_v3/classes.rb', line 4557

def is_chat_moderator
  @is_chat_moderator
end

#is_chat_ownerBoolean Also known as: is_chat_owner?

Whether the author is the owner of the live chat. Corresponds to the JSON property isChatOwner

Returns:

  • (Boolean)


4563
4564
4565
# File 'lib/google/apis/youtube_v3/classes.rb', line 4563

def is_chat_owner
  @is_chat_owner
end

#is_chat_sponsorBoolean Also known as: is_chat_sponsor?

Whether the author is a sponsor of the live chat. Corresponds to the JSON property isChatSponsor

Returns:

  • (Boolean)


4569
4570
4571
# File 'lib/google/apis/youtube_v3/classes.rb', line 4569

def is_chat_sponsor
  @is_chat_sponsor
end

#is_verifiedBoolean Also known as: is_verified?

Whether the author's identity has been verified by YouTube. Corresponds to the JSON property isVerified

Returns:

  • (Boolean)


4575
4576
4577
# File 'lib/google/apis/youtube_v3/classes.rb', line 4575

def is_verified
  @is_verified
end

#profile_image_urlString

The channels's avatar URL. Corresponds to the JSON property profileImageUrl

Returns:

  • (String)


4581
4582
4583
# File 'lib/google/apis/youtube_v3/classes.rb', line 4581

def profile_image_url
  @profile_image_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4588
4589
4590
4591
4592
4593
4594
4595
4596
4597
# File 'lib/google/apis/youtube_v3/classes.rb', line 4588

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_url = args[:channel_url] if args.key?(:channel_url)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_chat_moderator = args[:is_chat_moderator] if args.key?(:is_chat_moderator)
  @is_chat_owner = args[:is_chat_owner] if args.key?(:is_chat_owner)
  @is_chat_sponsor = args[:is_chat_sponsor] if args.key?(:is_chat_sponsor)
  @is_verified = args[:is_verified] if args.key?(:is_verified)
  @profile_image_url = args[:profile_image_url] if args.key?(:profile_image_url)
end