Class: Google::Apis::YoutubeV3::LiveChatMessageListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatMessageListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#active_poll_item ⇒ Google::Apis::YoutubeV3::LiveChatMessage
A liveChatMessage resource represents a chat message in a YouTube Live Chat.
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatMessage>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Corresponds to the JSON property
nextPageToken. -
#offline_at ⇒ DateTime
The date and time when the underlying stream went offline.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#polling_interval_millis ⇒ Fixnum
The amount of time the client should wait before polling again.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatMessageListResponse
constructor
A new instance of LiveChatMessageListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatMessageListResponse
Returns a new instance of LiveChatMessageListResponse.
4606 4607 4608 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_poll_item ⇒ Google::Apis::YoutubeV3::LiveChatMessage
A liveChatMessage resource represents a chat message in a YouTube Live Chat.
Corresponds to the JSON property activePollItem
4552 4553 4554 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4552 def active_poll_item @active_poll_item end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4557 4558 4559 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4557 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
4562 4563 4564 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4562 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatMessage>
Corresponds to the JSON property items
4567 4568 4569 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4567 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatMessageListResponse".
Corresponds to the JSON property kind
4573 4574 4575 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4573 def kind @kind end |
#next_page_token ⇒ String
Corresponds to the JSON property nextPageToken
4578 4579 4580 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4578 def next_page_token @next_page_token end |
#offline_at ⇒ DateTime
The date and time when the underlying stream went offline.
Corresponds to the JSON property offlineAt
4583 4584 4585 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4583 def offline_at @offline_at end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4589 4590 4591 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4589 def page_info @page_info end |
#polling_interval_millis ⇒ Fixnum
The amount of time the client should wait before polling again.
Corresponds to the JSON property pollingIntervalMillis
4594 4595 4596 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4594 def polling_interval_millis @polling_interval_millis end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4599 4600 4601 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4599 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4604 4605 4606 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4604 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4611 4612 4613 4614 4615 4616 4617 4618 4619 4620 4621 4622 4623 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4611 def update!(**args) @active_poll_item = args[:active_poll_item] if args.key?(:active_poll_item) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @offline_at = args[:offline_at] if args.key?(:offline_at) @page_info = args[:page_info] if args.key?(:page_info) @polling_interval_millis = args[:polling_interval_millis] if args.key?(:polling_interval_millis) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |