Class: Google::Apis::YoutubeV3::LiveChatMessageSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Next ID: 35

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatMessageSnippet

Returns a new instance of LiveChatMessageSnippet.



4766
4767
4768
# File 'lib/google/apis/youtube_v3/classes.rb', line 4766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#author_channel_idString

The ID of the user that authored this message, this field is not always filled. textMessageEvent - the user that wrote the message fanFundingEvent - the user that funded the broadcast newSponsorEvent - the user that just became a sponsor memberMilestoneChatEvent - the member that sent the message membershipGiftingEvent - the user that made the purchase giftMembershipReceivedEvent - the user that received the gift membership messageDeletedEvent - the moderator that took the action messageRetractedEvent

  • the author that retracted their message userBannedEvent - the moderator that took the action superChatEvent - the user that made the purchase superStickerEvent - the user that made the purchase pollEvent - the user that created the poll Corresponds to the JSON property authorChannelId

Returns:

  • (String)


4662
4663
4664
# File 'lib/google/apis/youtube_v3/classes.rb', line 4662

def author_channel_id
  @author_channel_id
end

#display_messageString

Contains a string that can be displayed to the user. If this field is not present the message is silent, at the moment only messages of type TOMBSTONE and CHAT_ENDED_EVENT are silent. Corresponds to the JSON property displayMessage

Returns:

  • (String)


4669
4670
4671
# File 'lib/google/apis/youtube_v3/classes.rb', line 4669

def display_message
  @display_message
end

#fan_funding_event_detailsGoogle::Apis::YoutubeV3::LiveChatFanFundingEventDetails

Details about the funding event, this is only set if the type is ' fanFundingEvent'. Corresponds to the JSON property fanFundingEventDetails



4675
4676
4677
# File 'lib/google/apis/youtube_v3/classes.rb', line 4675

def fan_funding_event_details
  @fan_funding_event_details
end

#gift_detailsGoogle::Apis::YoutubeV3::LiveChatGiftDetails

Details about the gift event, this is only set if the type is 'giftEvent'. Corresponds to the JSON property giftDetails



4680
4681
4682
# File 'lib/google/apis/youtube_v3/classes.rb', line 4680

def gift_details
  @gift_details
end

#gift_membership_received_detailsGoogle::Apis::YoutubeV3::LiveChatGiftMembershipReceivedDetails

Details about the Gift Membership Received event, this is only set if the type is 'giftMembershipReceivedEvent'. Corresponds to the JSON property giftMembershipReceivedDetails



4686
4687
4688
# File 'lib/google/apis/youtube_v3/classes.rb', line 4686

def gift_membership_received_details
  @gift_membership_received_details
end

#has_display_contentBoolean Also known as: has_display_content?

Whether the message has display content that should be displayed to users. Corresponds to the JSON property hasDisplayContent

Returns:

  • (Boolean)


4691
4692
4693
# File 'lib/google/apis/youtube_v3/classes.rb', line 4691

def has_display_content
  @has_display_content
end

#live_chat_idString

Corresponds to the JSON property liveChatId

Returns:

  • (String)


4697
4698
4699
# File 'lib/google/apis/youtube_v3/classes.rb', line 4697

def live_chat_id
  @live_chat_id
end

#member_milestone_chat_detailsGoogle::Apis::YoutubeV3::LiveChatMemberMilestoneChatDetails

Details about the Member Milestone Chat event, this is only set if the type is 'memberMilestoneChatEvent'. Corresponds to the JSON property memberMilestoneChatDetails



4703
4704
4705
# File 'lib/google/apis/youtube_v3/classes.rb', line 4703

def member_milestone_chat_details
  @member_milestone_chat_details
end

#membership_gifting_detailsGoogle::Apis::YoutubeV3::LiveChatMembershipGiftingDetails

Details about the Membership Gifting event, this is only set if the type is ' membershipGiftingEvent'. Corresponds to the JSON property membershipGiftingDetails



4709
4710
4711
# File 'lib/google/apis/youtube_v3/classes.rb', line 4709

def membership_gifting_details
  @membership_gifting_details
end

#message_deleted_detailsGoogle::Apis::YoutubeV3::LiveChatMessageDeletedDetails

Corresponds to the JSON property messageDeletedDetails



4714
4715
4716
# File 'lib/google/apis/youtube_v3/classes.rb', line 4714

def message_deleted_details
  @message_deleted_details
end

#message_retracted_detailsGoogle::Apis::YoutubeV3::LiveChatMessageRetractedDetails

Corresponds to the JSON property messageRetractedDetails



4719
4720
4721
# File 'lib/google/apis/youtube_v3/classes.rb', line 4719

def message_retracted_details
  @message_retracted_details
end

#new_sponsor_detailsGoogle::Apis::YoutubeV3::LiveChatNewSponsorDetails

Details about the New Member Announcement event, this is only set if the type is 'newSponsorEvent'. Please note that "member" is the new term for "sponsor". Corresponds to the JSON property newSponsorDetails



4725
4726
4727
# File 'lib/google/apis/youtube_v3/classes.rb', line 4725

def new_sponsor_details
  @new_sponsor_details
end

#poll_detailsGoogle::Apis::YoutubeV3::LiveChatPollDetails

Details about the poll event, this is only set if the type is 'pollEvent'. Corresponds to the JSON property pollDetails



4730
4731
4732
# File 'lib/google/apis/youtube_v3/classes.rb', line 4730

def poll_details
  @poll_details
end

#published_atDateTime

The date and time when the message was orignally published. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


4735
4736
4737
# File 'lib/google/apis/youtube_v3/classes.rb', line 4735

def published_at
  @published_at
end

#super_chat_detailsGoogle::Apis::YoutubeV3::LiveChatSuperChatDetails

Details about the Super Chat event, this is only set if the type is ' superChatEvent'. Corresponds to the JSON property superChatDetails



4741
4742
4743
# File 'lib/google/apis/youtube_v3/classes.rb', line 4741

def super_chat_details
  @super_chat_details
end

#super_sticker_detailsGoogle::Apis::YoutubeV3::LiveChatSuperStickerDetails

Details about the Super Sticker event, this is only set if the type is ' superStickerEvent'. Corresponds to the JSON property superStickerDetails



4747
4748
4749
# File 'lib/google/apis/youtube_v3/classes.rb', line 4747

def super_sticker_details
  @super_sticker_details
end

#text_message_detailsGoogle::Apis::YoutubeV3::LiveChatTextMessageDetails

Details about the text message, this is only set if the type is ' textMessageEvent'. Corresponds to the JSON property textMessageDetails



4753
4754
4755
# File 'lib/google/apis/youtube_v3/classes.rb', line 4753

def text_message_details
  @text_message_details
end

#typeString

The type of message, this will always be present, it determines the contents of the message as well as which fields will be present. Corresponds to the JSON property type

Returns:

  • (String)


4759
4760
4761
# File 'lib/google/apis/youtube_v3/classes.rb', line 4759

def type
  @type
end

#user_banned_detailsGoogle::Apis::YoutubeV3::LiveChatUserBannedMessageDetails

Corresponds to the JSON property userBannedDetails



4764
4765
4766
# File 'lib/google/apis/youtube_v3/classes.rb', line 4764

def user_banned_details
  @user_banned_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4771
4772
4773
4774
4775
4776
4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
4787
4788
4789
4790
4791
# File 'lib/google/apis/youtube_v3/classes.rb', line 4771

def update!(**args)
  @author_channel_id = args[:author_channel_id] if args.key?(:author_channel_id)
  @display_message = args[:display_message] if args.key?(:display_message)
  @fan_funding_event_details = args[:fan_funding_event_details] if args.key?(:fan_funding_event_details)
  @gift_details = args[:gift_details] if args.key?(:gift_details)
  @gift_membership_received_details = args[:gift_membership_received_details] if args.key?(:gift_membership_received_details)
  @has_display_content = args[:has_display_content] if args.key?(:has_display_content)
  @live_chat_id = args[:live_chat_id] if args.key?(:live_chat_id)
  @member_milestone_chat_details = args[:member_milestone_chat_details] if args.key?(:member_milestone_chat_details)
  @membership_gifting_details = args[:membership_gifting_details] if args.key?(:membership_gifting_details)
  @message_deleted_details = args[:message_deleted_details] if args.key?(:message_deleted_details)
  @message_retracted_details = args[:message_retracted_details] if args.key?(:message_retracted_details)
  @new_sponsor_details = args[:new_sponsor_details] if args.key?(:new_sponsor_details)
  @poll_details = args[:poll_details] if args.key?(:poll_details)
  @published_at = args[:published_at] if args.key?(:published_at)
  @super_chat_details = args[:super_chat_details] if args.key?(:super_chat_details)
  @super_sticker_details = args[:super_sticker_details] if args.key?(:super_sticker_details)
  @text_message_details = args[:text_message_details] if args.key?(:text_message_details)
  @type = args[:type] if args.key?(:type)
  @user_banned_details = args[:user_banned_details] if args.key?(:user_banned_details)
end