Class: Google::Apis::YoutubeV3::LiveChatModeratorListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatModeratorListResponse

Returns a new instance of LiveChatModeratorListResponse.



4987
4988
4989
# File 'lib/google/apis/youtube_v3/classes.rb', line 4987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


4941
4942
4943
# File 'lib/google/apis/youtube_v3/classes.rb', line 4941

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


4946
4947
4948
# File 'lib/google/apis/youtube_v3/classes.rb', line 4946

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::LiveChatModerator>

A list of moderators that match the request criteria. Corresponds to the JSON property items



4951
4952
4953
# File 'lib/google/apis/youtube_v3/classes.rb', line 4951

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# liveChatModeratorListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


4957
4958
4959
# File 'lib/google/apis/youtube_v3/classes.rb', line 4957

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4963
4964
4965
# File 'lib/google/apis/youtube_v3/classes.rb', line 4963

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



4969
4970
4971
# File 'lib/google/apis/youtube_v3/classes.rb', line 4969

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


4975
4976
4977
# File 'lib/google/apis/youtube_v3/classes.rb', line 4975

def prev_page_token
  @prev_page_token
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



4980
4981
4982
# File 'lib/google/apis/youtube_v3/classes.rb', line 4980

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


4985
4986
4987
# File 'lib/google/apis/youtube_v3/classes.rb', line 4985

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4992
4993
4994
4995
4996
4997
4998
4999
5000
5001
5002
# File 'lib/google/apis/youtube_v3/classes.rb', line 4992

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end