Class: Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModeratorListResponse
constructor
A new instance of LiveChatModeratorListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModeratorListResponse
Returns a new instance of LiveChatModeratorListResponse.
4961 4962 4963 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4915 4916 4917 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4915 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
4920 4921 4922 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4920 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
Corresponds to the JSON property items
4925 4926 4927 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4925 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatModeratorListResponse".
Corresponds to the JSON property kind
4931 4932 4933 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4931 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
4937 4938 4939 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4937 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4943 4944 4945 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4943 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
4949 4950 4951 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4949 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4954 4955 4956 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4954 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4959 4960 4961 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4959 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4966 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |