Class: Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModeratorListResponse
constructor
A new instance of LiveChatModeratorListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModeratorListResponse
Returns a new instance of LiveChatModeratorListResponse.
4887 4888 4889 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4841 4842 4843 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4841 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
4846 4847 4848 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4846 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
Corresponds to the JSON property items
4851 4852 4853 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4851 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatModeratorListResponse".
Corresponds to the JSON property kind
4857 4858 4859 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4857 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
4863 4864 4865 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4863 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4869 4870 4871 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4869 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
4875 4876 4877 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4875 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4880 4881 4882 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4880 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4885 4886 4887 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4885 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4892 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |