Class: Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatModeratorListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatModeratorListResponse
constructor
A new instance of LiveChatModeratorListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatModeratorListResponse
Returns a new instance of LiveChatModeratorListResponse.
4853 4854 4855 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
4807 4808 4809 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4807 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
4812 4813 4814 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4812 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::LiveChatModerator>
A list of moderators that match the request criteria.
Corresponds to the JSON property items
4817 4818 4819 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4817 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveChatModeratorListResponse".
Corresponds to the JSON property kind
4823 4824 4825 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4823 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
4829 4830 4831 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4829 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
4835 4836 4837 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4835 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
4841 4842 4843 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4841 def prev_page_token @prev_page_token end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
4846 4847 4848 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4846 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
4851 4852 4853 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4851 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4858 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |