Class: Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#is_upgrade ⇒ Boolean
(also: #is_upgrade?)
If the viewer just had upgraded from a lower level.
-
#member_level_name ⇒ String
The name of the Level that the viewer just had joined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatNewSponsorDetails
constructor
A new instance of LiveChatNewSponsorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatNewSponsorDetails
Returns a new instance of LiveChatNewSponsorDetails.
5187 5188 5189 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_upgrade ⇒ Boolean Also known as: is_upgrade?
If the viewer just had upgraded from a lower level. For viewers that were not
members at the time of purchase, this field is false.
Corresponds to the JSON property isUpgrade
5177 5178 5179 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5177 def is_upgrade @is_upgrade end |
#member_level_name ⇒ String
The name of the Level that the viewer just had joined. The Level names are
defined by the YouTube channel offering the Membership. In some situations
this field isn't filled.
Corresponds to the JSON property memberLevelName
5185 5186 5187 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5185 def member_level_name @member_level_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5192 5193 5194 5195 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5192 def update!(**args) @is_upgrade = args[:is_upgrade] if args.key?(:is_upgrade) @member_level_name = args[:member_level_name] if args.key?(:member_level_name) end |