Class: Google::Apis::YoutubeV3::LiveChatNewSponsorDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatNewSponsorDetails

Returns a new instance of LiveChatNewSponsorDetails.



5022
5023
5024
# File 'lib/google/apis/youtube_v3/classes.rb', line 5022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_upgradeBoolean Also known as: is_upgrade?

If the viewer just had upgraded from a lower level. For viewers that were not members at the time of purchase, this field is false. Corresponds to the JSON property isUpgrade

Returns:

  • (Boolean)


5012
5013
5014
# File 'lib/google/apis/youtube_v3/classes.rb', line 5012

def is_upgrade
  @is_upgrade
end

#member_level_nameString

The name of the Level that the viewer just had joined. The Level names are defined by the YouTube channel offering the Membership. In some situations this field isn't filled. Corresponds to the JSON property memberLevelName

Returns:

  • (String)


5020
5021
5022
# File 'lib/google/apis/youtube_v3/classes.rb', line 5020

def member_level_name
  @member_level_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5027
5028
5029
5030
# File 'lib/google/apis/youtube_v3/classes.rb', line 5027

def update!(**args)
  @is_upgrade = args[:is_upgrade] if args.key?(:is_upgrade)
  @member_level_name = args[:member_level_name] if args.key?(:member_level_name)
end