Class: Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatNewSponsorDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#is_upgrade ⇒ Boolean
(also: #is_upgrade?)
If the viewer just had upgraded from a lower level.
-
#member_level_name ⇒ String
The name of the Level that the viewer just had joined.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatNewSponsorDetails
constructor
A new instance of LiveChatNewSponsorDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatNewSponsorDetails
Returns a new instance of LiveChatNewSponsorDetails.
4948 4949 4950 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_upgrade ⇒ Boolean Also known as: is_upgrade?
If the viewer just had upgraded from a lower level. For viewers that were not
members at the time of purchase, this field is false.
Corresponds to the JSON property isUpgrade
4938 4939 4940 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4938 def is_upgrade @is_upgrade end |
#member_level_name ⇒ String
The name of the Level that the viewer just had joined. The Level names are
defined by the YouTube channel offering the Membership. In some situations
this field isn't filled.
Corresponds to the JSON property memberLevelName
4946 4947 4948 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4946 def member_level_name @member_level_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4953 4954 4955 4956 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4953 def update!(**args) @is_upgrade = args[:is_upgrade] if args.key?(:is_upgrade) @member_level_name = args[:member_level_name] if args.key?(:member_level_name) end |