Class: Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadata
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#options ⇒ Array<Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadataPollOption>
The options will be returned in the order that is displayed in 1P Corresponds to the JSON property
options. -
#question_text ⇒ String
Corresponds to the JSON property
questionText.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveChatPollDetailsPollMetadata
constructor
A new instance of LiveChatPollDetailsPollMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveChatPollDetailsPollMetadata
Returns a new instance of LiveChatPollDetailsPollMetadata.
4964 4965 4966 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#options ⇒ Array<Google::Apis::YoutubeV3::LiveChatPollDetailsPollMetadataPollOption>
The options will be returned in the order that is displayed in 1P
Corresponds to the JSON property options
4957 4958 4959 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4957 def @options end |
#question_text ⇒ String
Corresponds to the JSON property questionText
4962 4963 4964 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4962 def question_text @question_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4969 4970 4971 4972 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 4969 def update!(**args) @options = args[:options] if args.key?(:options) @question_text = args[:question_text] if args.key?(:question_text) end |