Class: Google::Apis::YoutubeV3::LiveChatSuperStickerDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveChatSuperStickerDetails

Returns a new instance of LiveChatSuperStickerDetails.



5074
5075
5076
# File 'lib/google/apis/youtube_v3/classes.rb', line 5074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_display_stringString

A rendered string that displays the fund amount and currency to the user. Corresponds to the JSON property amountDisplayString

Returns:

  • (String)


5051
5052
5053
# File 'lib/google/apis/youtube_v3/classes.rb', line 5051

def amount_display_string
  @amount_display_string
end

#amount_microsFixnum

The amount purchased by the user, in micros (1,750,000 micros = 1.75). Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


5056
5057
5058
# File 'lib/google/apis/youtube_v3/classes.rb', line 5056

def amount_micros
  @amount_micros
end

#currencyString

The currency in which the purchase was made. Corresponds to the JSON property currency

Returns:

  • (String)


5061
5062
5063
# File 'lib/google/apis/youtube_v3/classes.rb', line 5061

def currency
  @currency
end

#super_sticker_metadataGoogle::Apis::YoutubeV3::SuperStickerMetadata

Information about the Super Sticker. Corresponds to the JSON property superStickerMetadata



5066
5067
5068
# File 'lib/google/apis/youtube_v3/classes.rb', line 5066

def 
  @super_sticker_metadata
end

#tierFixnum

The tier in which the amount belongs. Lower amounts belong to lower tiers. The lowest tier is 1. Corresponds to the JSON property tier

Returns:

  • (Fixnum)


5072
5073
5074
# File 'lib/google/apis/youtube_v3/classes.rb', line 5072

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5079
5080
5081
5082
5083
5084
5085
# File 'lib/google/apis/youtube_v3/classes.rb', line 5079

def update!(**args)
  @amount_display_string = args[:amount_display_string] if args.key?(:amount_display_string)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @currency = args[:currency] if args.key?(:currency)
  @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata)
  @tier = args[:tier] if args.key?(:tier)
end