Class: Google::Apis::YoutubeV3::LiveStream
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A live stream describes a live ingestion point.
Instance Attribute Summary collapse
-
#cdn ⇒ Google::Apis::YoutubeV3::CdnSettings
Brief description of the live stream cdn settings.
-
#content_details ⇒ Google::Apis::YoutubeV3::LiveStreamContentDetails
Detailed settings of a stream.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the stream.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::LiveStreamSnippet
The snippet object contains basic details about the stream, including its channel, title, and description.
-
#status ⇒ Google::Apis::YoutubeV3::LiveStreamStatus
Brief description of the live stream status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStream
constructor
A new instance of LiveStream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStream
Returns a new instance of LiveStream.
5180 5181 5182 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5180 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cdn ⇒ Google::Apis::YoutubeV3::CdnSettings
Brief description of the live stream cdn settings.
Corresponds to the JSON property cdn
5146 5147 5148 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5146 def cdn @cdn end |
#content_details ⇒ Google::Apis::YoutubeV3::LiveStreamContentDetails
Detailed settings of a stream.
Corresponds to the JSON property contentDetails
5151 5152 5153 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5151 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5156 5157 5158 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5156 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the stream.
Corresponds to the JSON property id
5161 5162 5163 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5161 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
liveStream".
Corresponds to the JSON property kind
5167 5168 5169 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5167 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::LiveStreamSnippet
The snippet object contains basic details about the stream, including its
channel, title, and description.
Corresponds to the JSON property snippet
5173 5174 5175 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5173 def snippet @snippet end |
#status ⇒ Google::Apis::YoutubeV3::LiveStreamStatus
Brief description of the live stream status.
Corresponds to the JSON property status
5178 5179 5180 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5178 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5185 5186 5187 5188 5189 5190 5191 5192 5193 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5185 def update!(**args) @cdn = args[:cdn] if args.key?(:cdn) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) @status = args[:status] if args.key?(:status) end |