Class: Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
The long-form description of the issue and how to resolve it.
-
#reason ⇒ String
The short-form reason for this issue.
-
#severity ⇒ String
How severe this issue is to the stream.
-
#type ⇒ String
The kind of error happening.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStreamConfigurationIssue
constructor
A new instance of LiveStreamConfigurationIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStreamConfigurationIssue
Returns a new instance of LiveStreamConfigurationIssue.
5254 5255 5256 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The long-form description of the issue and how to resolve it.
Corresponds to the JSON property description
5237 5238 5239 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5237 def description @description end |
#reason ⇒ String
The short-form reason for this issue.
Corresponds to the JSON property reason
5242 5243 5244 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5242 def reason @reason end |
#severity ⇒ String
How severe this issue is to the stream.
Corresponds to the JSON property severity
5247 5248 5249 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5247 def severity @severity end |
#type ⇒ String
The kind of error happening.
Corresponds to the JSON property type
5252 5253 5254 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5252 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5259 5260 5261 5262 5263 5264 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5259 def update!(**args) @description = args[:description] if args.key?(:description) @reason = args[:reason] if args.key?(:reason) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |