Class: Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStreamConfigurationIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
The long-form description of the issue and how to resolve it.
-
#reason ⇒ String
The short-form reason for this issue.
-
#severity ⇒ String
How severe this issue is to the stream.
-
#type ⇒ String
The kind of error happening.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStreamConfigurationIssue
constructor
A new instance of LiveStreamConfigurationIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStreamConfigurationIssue
Returns a new instance of LiveStreamConfigurationIssue.
5220 5221 5222 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The long-form description of the issue and how to resolve it.
Corresponds to the JSON property description
5203 5204 5205 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5203 def description @description end |
#reason ⇒ String
The short-form reason for this issue.
Corresponds to the JSON property reason
5208 5209 5210 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5208 def reason @reason end |
#severity ⇒ String
How severe this issue is to the stream.
Corresponds to the JSON property severity
5213 5214 5215 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5213 def severity @severity end |
#type ⇒ String
The kind of error happening.
Corresponds to the JSON property type
5218 5219 5220 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5218 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5225 5226 5227 5228 5229 5230 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5225 def update!(**args) @description = args[:description] if args.key?(:description) @reason = args[:reason] if args.key?(:reason) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |