Class: Google::Apis::YoutubeV3::LiveStreamContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Detailed settings of a stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LiveStreamContentDetails

Returns a new instance of LiveStreamContentDetails.



5258
5259
5260
# File 'lib/google/apis/youtube_v3/classes.rb', line 5258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#closed_captions_ingestion_urlString

The ingestion URL where the closed captions of this stream are sent. Corresponds to the JSON property closedCaptionsIngestionUrl

Returns:

  • (String)


5240
5241
5242
# File 'lib/google/apis/youtube_v3/classes.rb', line 5240

def closed_captions_ingestion_url
  @closed_captions_ingestion_url
end

#is_reusableBoolean Also known as: is_reusable?

Indicates whether the stream is reusable, which means that it can be bound to multiple broadcasts. It is common for broadcasters to reuse the same stream for many different broadcasts if those broadcasts occur at different times. If you set this value to false, then the stream will not be reusable, which means that it can only be bound to one broadcast. Non-reusable streams differ from reusable streams in the following ways: - A non-reusable stream can only be bound to one broadcast. - A non-reusable stream might be deleted by an automated process after the broadcast ends. - The liveStreams.list method does not list non-reusable streams if you call the method and set the mine parameter to true. The only way to use that method to retrieve the resource for a non-reusable stream is to use the id parameter to identify the stream. Corresponds to the JSON property isReusable

Returns:

  • (Boolean)


5255
5256
5257
# File 'lib/google/apis/youtube_v3/classes.rb', line 5255

def is_reusable
  @is_reusable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5263
5264
5265
5266
# File 'lib/google/apis/youtube_v3/classes.rb', line 5263

def update!(**args)
  @closed_captions_ingestion_url = args[:closed_captions_ingestion_url] if args.key?(:closed_captions_ingestion_url)
  @is_reusable = args[:is_reusable] if args.key?(:is_reusable)
end