Class: Google::Apis::YoutubeV3::LiveStreamSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::LiveStreamSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is transmitting the stream.
-
#description ⇒ String
The stream's description.
-
#is_default_stream ⇒ Boolean
(also: #is_default_stream?)
Corresponds to the JSON property
isDefaultStream. -
#published_at ⇒ DateTime
The date and time that the stream was created.
-
#title ⇒ String
The stream's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LiveStreamSnippet
constructor
A new instance of LiveStreamSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LiveStreamSnippet
Returns a new instance of LiveStreamSnippet.
5402 5403 5404 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that is transmitting
the stream.
Corresponds to the JSON property channelId
5379 5380 5381 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5379 def channel_id @channel_id end |
#description ⇒ String
The stream's description. The value cannot be longer than 10000 characters.
Corresponds to the JSON property description
5384 5385 5386 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5384 def description @description end |
#is_default_stream ⇒ Boolean Also known as: is_default_stream?
Corresponds to the JSON property isDefaultStream
5389 5390 5391 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5389 def is_default_stream @is_default_stream end |
#published_at ⇒ DateTime
The date and time that the stream was created.
Corresponds to the JSON property publishedAt
5395 5396 5397 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5395 def published_at @published_at end |
#title ⇒ String
The stream's title. The value must be between 1 and 128 characters long.
Corresponds to the JSON property title
5400 5401 5402 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5400 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5407 5408 5409 5410 5411 5412 5413 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5407 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @description = args[:description] if args.key?(:description) @is_default_stream = args[:is_default_stream] if args.key?(:is_default_stream) @published_at = args[:published_at] if args.key?(:published_at) @title = args[:title] if args.key?(:title) end |