Class: Google::Apis::YoutubeV3::MemberListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MemberListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemberListResponse
constructor
A new instance of MemberListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemberListResponse
Returns a new instance of MemberListResponse.
5711 5712 5713 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5671 5672 5673 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5671 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5676 5677 5678 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5676 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
Corresponds to the JSON property items
5681 5682 5683 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5681 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
memberListResponse".
Corresponds to the JSON property kind
5687 5688 5689 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5687 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5693 5694 5695 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5693 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5699 5700 5701 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5699 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5704 5705 5706 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5704 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5709 5710 5711 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5709 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5716 5717 5718 5719 5720 5721 5722 5723 5724 5725 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5716 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |