Class: Google::Apis::YoutubeV3::MemberListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MemberListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MemberListResponse
constructor
A new instance of MemberListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MemberListResponse
Returns a new instance of MemberListResponse.
5611 5612 5613 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5571 5572 5573 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5571 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
5576 5577 5578 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5576 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::Member>
A list of members that match the request criteria.
Corresponds to the JSON property items
5581 5582 5583 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5581 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
memberListResponse".
Corresponds to the JSON property kind
5587 5588 5589 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5587 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
5593 5594 5595 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5593 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
5599 5600 5601 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5599 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
5604 5605 5606 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5604 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
5609 5610 5611 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5609 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5616 5617 5618 5619 5620 5621 5622 5623 5624 5625 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5616 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |