Class: Google::Apis::YoutubeV3::MemberListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemberListResponse

Returns a new instance of MemberListResponse.



5577
5578
5579
# File 'lib/google/apis/youtube_v3/classes.rb', line 5577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


5537
5538
5539
# File 'lib/google/apis/youtube_v3/classes.rb', line 5537

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


5542
5543
5544
# File 'lib/google/apis/youtube_v3/classes.rb', line 5542

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::Member>

A list of members that match the request criteria. Corresponds to the JSON property items



5547
5548
5549
# File 'lib/google/apis/youtube_v3/classes.rb', line 5547

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# memberListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/youtube_v3/classes.rb', line 5553

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5559
5560
5561
# File 'lib/google/apis/youtube_v3/classes.rb', line 5559

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



5565
5566
5567
# File 'lib/google/apis/youtube_v3/classes.rb', line 5565

def page_info
  @page_info
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



5570
5571
5572
# File 'lib/google/apis/youtube_v3/classes.rb', line 5570

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


5575
5576
5577
# File 'lib/google/apis/youtube_v3/classes.rb', line 5575

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
# File 'lib/google/apis/youtube_v3/classes.rb', line 5582

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end