Class: Google::Apis::YoutubeV3::MembershipsDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsDetails

Returns a new instance of MembershipsDetails.



5791
5792
5793
# File 'lib/google/apis/youtube_v3/classes.rb', line 5791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessible_levelsArray<String>

Ids of all levels that the user has access to. This includes the currently active level and all other levels that are included because of a higher purchase. Corresponds to the JSON property accessibleLevels

Returns:

  • (Array<String>)


5768
5769
5770
# File 'lib/google/apis/youtube_v3/classes.rb', line 5768

def accessible_levels
  @accessible_levels
end

#highest_accessible_levelString

Id of the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevel

Returns:

  • (String)


5773
5774
5775
# File 'lib/google/apis/youtube_v3/classes.rb', line 5773

def highest_accessible_level
  @highest_accessible_level
end

#highest_accessible_level_display_nameString

Display name for the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevelDisplayName

Returns:

  • (String)


5778
5779
5780
# File 'lib/google/apis/youtube_v3/classes.rb', line 5778

def highest_accessible_level_display_name
  @highest_accessible_level_display_name
end

#memberships_durationGoogle::Apis::YoutubeV3::MembershipsDuration

Data about memberships duration without taking into consideration pricing levels. Corresponds to the JSON property membershipsDuration



5784
5785
5786
# File 'lib/google/apis/youtube_v3/classes.rb', line 5784

def memberships_duration
  @memberships_duration
end

#memberships_duration_at_levelsArray<Google::Apis::YoutubeV3::MembershipsDurationAtLevel>

Data about memberships duration on particular pricing levels. Corresponds to the JSON property membershipsDurationAtLevels



5789
5790
5791
# File 'lib/google/apis/youtube_v3/classes.rb', line 5789

def memberships_duration_at_levels
  @memberships_duration_at_levels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5796
5797
5798
5799
5800
5801
5802
# File 'lib/google/apis/youtube_v3/classes.rb', line 5796

def update!(**args)
  @accessible_levels = args[:accessible_levels] if args.key?(:accessible_levels)
  @highest_accessible_level = args[:highest_accessible_level] if args.key?(:highest_accessible_level)
  @highest_accessible_level_display_name = args[:highest_accessible_level_display_name] if args.key?(:highest_accessible_level_display_name)
  @memberships_duration = args[:memberships_duration] if args.key?(:memberships_duration)
  @memberships_duration_at_levels = args[:memberships_duration_at_levels] if args.key?(:memberships_duration_at_levels)
end