Class: Google::Apis::YoutubeV3::MembershipsDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsDetails

Returns a new instance of MembershipsDetails.



5691
5692
5693
# File 'lib/google/apis/youtube_v3/classes.rb', line 5691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessible_levelsArray<String>

Ids of all levels that the user has access to. This includes the currently active level and all other levels that are included because of a higher purchase. Corresponds to the JSON property accessibleLevels

Returns:

  • (Array<String>)


5668
5669
5670
# File 'lib/google/apis/youtube_v3/classes.rb', line 5668

def accessible_levels
  @accessible_levels
end

#highest_accessible_levelString

Id of the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevel

Returns:

  • (String)


5673
5674
5675
# File 'lib/google/apis/youtube_v3/classes.rb', line 5673

def highest_accessible_level
  @highest_accessible_level
end

#highest_accessible_level_display_nameString

Display name for the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevelDisplayName

Returns:

  • (String)


5678
5679
5680
# File 'lib/google/apis/youtube_v3/classes.rb', line 5678

def highest_accessible_level_display_name
  @highest_accessible_level_display_name
end

#memberships_durationGoogle::Apis::YoutubeV3::MembershipsDuration

Data about memberships duration without taking into consideration pricing levels. Corresponds to the JSON property membershipsDuration



5684
5685
5686
# File 'lib/google/apis/youtube_v3/classes.rb', line 5684

def memberships_duration
  @memberships_duration
end

#memberships_duration_at_levelsArray<Google::Apis::YoutubeV3::MembershipsDurationAtLevel>

Data about memberships duration on particular pricing levels. Corresponds to the JSON property membershipsDurationAtLevels



5689
5690
5691
# File 'lib/google/apis/youtube_v3/classes.rb', line 5689

def memberships_duration_at_levels
  @memberships_duration_at_levels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5696
5697
5698
5699
5700
5701
5702
# File 'lib/google/apis/youtube_v3/classes.rb', line 5696

def update!(**args)
  @accessible_levels = args[:accessible_levels] if args.key?(:accessible_levels)
  @highest_accessible_level = args[:highest_accessible_level] if args.key?(:highest_accessible_level)
  @highest_accessible_level_display_name = args[:highest_accessible_level_display_name] if args.key?(:highest_accessible_level_display_name)
  @memberships_duration = args[:memberships_duration] if args.key?(:memberships_duration)
  @memberships_duration_at_levels = args[:memberships_duration_at_levels] if args.key?(:memberships_duration_at_levels)
end