Class: Google::Apis::YoutubeV3::MembershipsDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsDetails

Returns a new instance of MembershipsDetails.



5657
5658
5659
# File 'lib/google/apis/youtube_v3/classes.rb', line 5657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accessible_levelsArray<String>

Ids of all levels that the user has access to. This includes the currently active level and all other levels that are included because of a higher purchase. Corresponds to the JSON property accessibleLevels

Returns:

  • (Array<String>)


5634
5635
5636
# File 'lib/google/apis/youtube_v3/classes.rb', line 5634

def accessible_levels
  @accessible_levels
end

#highest_accessible_levelString

Id of the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevel

Returns:

  • (String)


5639
5640
5641
# File 'lib/google/apis/youtube_v3/classes.rb', line 5639

def highest_accessible_level
  @highest_accessible_level
end

#highest_accessible_level_display_nameString

Display name for the highest level that the user has access to at the moment. Corresponds to the JSON property highestAccessibleLevelDisplayName

Returns:

  • (String)


5644
5645
5646
# File 'lib/google/apis/youtube_v3/classes.rb', line 5644

def highest_accessible_level_display_name
  @highest_accessible_level_display_name
end

#memberships_durationGoogle::Apis::YoutubeV3::MembershipsDuration

Data about memberships duration without taking into consideration pricing levels. Corresponds to the JSON property membershipsDuration



5650
5651
5652
# File 'lib/google/apis/youtube_v3/classes.rb', line 5650

def memberships_duration
  @memberships_duration
end

#memberships_duration_at_levelsArray<Google::Apis::YoutubeV3::MembershipsDurationAtLevel>

Data about memberships duration on particular pricing levels. Corresponds to the JSON property membershipsDurationAtLevels



5655
5656
5657
# File 'lib/google/apis/youtube_v3/classes.rb', line 5655

def memberships_duration_at_levels
  @memberships_duration_at_levels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5662
5663
5664
5665
5666
5667
5668
# File 'lib/google/apis/youtube_v3/classes.rb', line 5662

def update!(**args)
  @accessible_levels = args[:accessible_levels] if args.key?(:accessible_levels)
  @highest_accessible_level = args[:highest_accessible_level] if args.key?(:highest_accessible_level)
  @highest_accessible_level_display_name = args[:highest_accessible_level_display_name] if args.key?(:highest_accessible_level_display_name)
  @memberships_duration = args[:memberships_duration] if args.key?(:memberships_duration)
  @memberships_duration_at_levels = args[:memberships_duration_at_levels] if args.key?(:memberships_duration_at_levels)
end