Class: Google::Apis::YoutubeV3::MembershipsLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A membershipsLevel resource represents an offer made by YouTube creators for their fans. Users can become members of the channel by joining one of the available levels. They will provide recurring monetary support and receives special benefits.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsLevel

Returns a new instance of MembershipsLevel.



6034
6035
6036
# File 'lib/google/apis/youtube_v3/classes.rb', line 6034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


6016
6017
6018
# File 'lib/google/apis/youtube_v3/classes.rb', line 6016

def etag
  @etag
end

#idString

The ID that YouTube assigns to uniquely identify the memberships level. Corresponds to the JSON property id

Returns:

  • (String)


6021
6022
6023
# File 'lib/google/apis/youtube_v3/classes.rb', line 6021

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# membershipsLevelListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


6027
6028
6029
# File 'lib/google/apis/youtube_v3/classes.rb', line 6027

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::MembershipsLevelSnippet

The snippet object contains basic details about the level. Corresponds to the JSON property snippet



6032
6033
6034
# File 'lib/google/apis/youtube_v3/classes.rb', line 6032

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6039
6040
6041
6042
6043
6044
# File 'lib/google/apis/youtube_v3/classes.rb', line 6039

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end