Class: Google::Apis::YoutubeV3::MembershipsLevel

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A membershipsLevel resource represents an offer made by YouTube creators for their fans. Users can become members of the channel by joining one of the available levels. They will provide recurring monetary support and receives special benefits.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipsLevel

Returns a new instance of MembershipsLevel.



5891
5892
5893
# File 'lib/google/apis/youtube_v3/classes.rb', line 5891

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


5873
5874
5875
# File 'lib/google/apis/youtube_v3/classes.rb', line 5873

def etag
  @etag
end

#idString

The ID that YouTube assigns to uniquely identify the memberships level. Corresponds to the JSON property id

Returns:

  • (String)


5878
5879
5880
# File 'lib/google/apis/youtube_v3/classes.rb', line 5878

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# membershipsLevelListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


5884
5885
5886
# File 'lib/google/apis/youtube_v3/classes.rb', line 5884

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::MembershipsLevelSnippet

The snippet object contains basic details about the level. Corresponds to the JSON property snippet



5889
5890
5891
# File 'lib/google/apis/youtube_v3/classes.rb', line 5889

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5896
5897
5898
5899
5900
5901
# File 'lib/google/apis/youtube_v3/classes.rb', line 5896

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end