Class: Google::Apis::YoutubeV3::MembershipsLevel
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MembershipsLevel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A membershipsLevel resource represents an offer made by YouTube creators for their fans. Users can become members of the channel by joining one of the available levels. They will provide recurring monetary support and receives special benefits.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the memberships level.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::MembershipsLevelSnippet
The snippet object contains basic details about the level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipsLevel
constructor
A new instance of MembershipsLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipsLevel
Returns a new instance of MembershipsLevel.
5865 5866 5867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5865 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5847 5848 5849 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5847 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the memberships level.
Corresponds to the JSON property id
5852 5853 5854 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5852 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
membershipsLevelListResponse".
Corresponds to the JSON property kind
5858 5859 5860 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5858 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::MembershipsLevelSnippet
The snippet object contains basic details about the level.
Corresponds to the JSON property snippet
5863 5864 5865 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5863 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5870 5871 5872 5873 5874 5875 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5870 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |