Class: Google::Apis::YoutubeV3::MembershipsLevel
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::MembershipsLevel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A membershipsLevel resource represents an offer made by YouTube creators for their fans. Users can become members of the channel by joining one of the available levels. They will provide recurring monetary support and receives special benefits.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube assigns to uniquely identify the memberships level.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::MembershipsLevelSnippet
The snippet object contains basic details about the level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipsLevel
constructor
A new instance of MembershipsLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipsLevel
Returns a new instance of MembershipsLevel.
5757 5758 5759 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
5739 5740 5741 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5739 def etag @etag end |
#id ⇒ String
The ID that YouTube assigns to uniquely identify the memberships level.
Corresponds to the JSON property id
5744 5745 5746 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5744 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
membershipsLevelListResponse".
Corresponds to the JSON property kind
5750 5751 5752 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5750 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::MembershipsLevelSnippet
The snippet object contains basic details about the level.
Corresponds to the JSON property snippet
5755 5756 5757 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5755 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5762 5763 5764 5765 5766 5767 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 5762 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |