Class: Google::Apis::YoutubeV3::MonitorStreamInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Settings and Info of the monitor stream

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitorStreamInfo

Returns a new instance of MonitorStreamInfo.



5974
5975
5976
# File 'lib/google/apis/youtube_v3/classes.rb', line 5974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#broadcast_stream_delay_msFixnum

If you have set the enableMonitorStream property to true, then this property determines the length of the live broadcast delay. Corresponds to the JSON property broadcastStreamDelayMs

Returns:

  • (Fixnum)


5955
5956
5957
# File 'lib/google/apis/youtube_v3/classes.rb', line 5955

def broadcast_stream_delay_ms
  @broadcast_stream_delay_ms
end

#embed_htmlString

HTML code that embeds a player that plays the monitor stream. Corresponds to the JSON property embedHtml

Returns:

  • (String)


5960
5961
5962
# File 'lib/google/apis/youtube_v3/classes.rb', line 5960

def embed_html
  @embed_html
end

#enable_monitor_streamBoolean Also known as: enable_monitor_stream?

This value determines whether the monitor stream is enabled for the broadcast. If the monitor stream is enabled, then YouTube will broadcast the event content on a special stream intended only for the broadcaster's consumption. The broadcaster can use the stream to review the event content and also to identify the optimal times to insert cuepoints. You need to set this value to true if you intend to have a broadcast delay for your event. Note: This property cannot be updated once the broadcast is in the testing or live state. Corresponds to the JSON property enableMonitorStream

Returns:

  • (Boolean)


5971
5972
5973
# File 'lib/google/apis/youtube_v3/classes.rb', line 5971

def enable_monitor_stream
  @enable_monitor_stream
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5979
5980
5981
5982
5983
# File 'lib/google/apis/youtube_v3/classes.rb', line 5979

def update!(**args)
  @broadcast_stream_delay_ms = args[:broadcast_stream_delay_ms] if args.key?(:broadcast_stream_delay_ms)
  @embed_html = args[:embed_html] if args.key?(:embed_html)
  @enable_monitor_stream = args[:enable_monitor_stream] if args.key?(:enable_monitor_stream)
end