Class: Google::Apis::YoutubeV3::MonitorStreamInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Settings and Info of the monitor stream

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitorStreamInfo

Returns a new instance of MonitorStreamInfo.



5900
5901
5902
# File 'lib/google/apis/youtube_v3/classes.rb', line 5900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#broadcast_stream_delay_msFixnum

If you have set the enableMonitorStream property to true, then this property determines the length of the live broadcast delay. Corresponds to the JSON property broadcastStreamDelayMs

Returns:

  • (Fixnum)


5881
5882
5883
# File 'lib/google/apis/youtube_v3/classes.rb', line 5881

def broadcast_stream_delay_ms
  @broadcast_stream_delay_ms
end

#embed_htmlString

HTML code that embeds a player that plays the monitor stream. Corresponds to the JSON property embedHtml

Returns:

  • (String)


5886
5887
5888
# File 'lib/google/apis/youtube_v3/classes.rb', line 5886

def embed_html
  @embed_html
end

#enable_monitor_streamBoolean Also known as: enable_monitor_stream?

This value determines whether the monitor stream is enabled for the broadcast. If the monitor stream is enabled, then YouTube will broadcast the event content on a special stream intended only for the broadcaster's consumption. The broadcaster can use the stream to review the event content and also to identify the optimal times to insert cuepoints. You need to set this value to true if you intend to have a broadcast delay for your event. Note: This property cannot be updated once the broadcast is in the testing or live state. Corresponds to the JSON property enableMonitorStream

Returns:

  • (Boolean)


5897
5898
5899
# File 'lib/google/apis/youtube_v3/classes.rb', line 5897

def enable_monitor_stream
  @enable_monitor_stream
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5905
5906
5907
5908
5909
# File 'lib/google/apis/youtube_v3/classes.rb', line 5905

def update!(**args)
  @broadcast_stream_delay_ms = args[:broadcast_stream_delay_ms] if args.key?(:broadcast_stream_delay_ms)
  @embed_html = args[:embed_html] if args.key?(:embed_html)
  @enable_monitor_stream = args[:enable_monitor_stream] if args.key?(:enable_monitor_stream)
end