Class: Google::Apis::YoutubeV3::Playlist

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. A playlist can contain up to 200 videos, and YouTube does not limit the number of playlists that each user creates. By default, playlists are publicly visible to other users, but playlists can be public or private. YouTube also uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history - watch later To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistItems.list method to retrieve any of those lists. You can also add or remove items from those lists by calling the playlistItems.insert and playlistItems.delete methods.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Playlist

Returns a new instance of Playlist.



6240
6241
6242
# File 'lib/google/apis/youtube_v3/classes.rb', line 6240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_detailsGoogle::Apis::YoutubeV3::PlaylistContentDetails

The contentDetails object contains information like video count. Corresponds to the JSON property contentDetails



6201
6202
6203
# File 'lib/google/apis/youtube_v3/classes.rb', line 6201

def content_details
  @content_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


6206
6207
6208
# File 'lib/google/apis/youtube_v3/classes.rb', line 6206

def etag
  @etag
end

#idString

The ID that YouTube uses to uniquely identify the playlist. Corresponds to the JSON property id

Returns:

  • (String)


6211
6212
6213
# File 'lib/google/apis/youtube_v3/classes.rb', line 6211

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# playlist". Corresponds to the JSON property kind

Returns:

  • (String)


6217
6218
6219
# File 'lib/google/apis/youtube_v3/classes.rb', line 6217

def kind
  @kind
end

#localizationsHash<String,Google::Apis::YoutubeV3::PlaylistLocalization>

Localizations for different languages Corresponds to the JSON property localizations



6222
6223
6224
# File 'lib/google/apis/youtube_v3/classes.rb', line 6222

def localizations
  @localizations
end

#playerGoogle::Apis::YoutubeV3::PlaylistPlayer

The player object contains information that you would use to play the playlist in an embedded player. Corresponds to the JSON property player



6228
6229
6230
# File 'lib/google/apis/youtube_v3/classes.rb', line 6228

def player
  @player
end

#snippetGoogle::Apis::YoutubeV3::PlaylistSnippet

Basic details about a playlist, including title, description and thumbnails. Corresponds to the JSON property snippet



6233
6234
6235
# File 'lib/google/apis/youtube_v3/classes.rb', line 6233

def snippet
  @snippet
end

#statusGoogle::Apis::YoutubeV3::PlaylistStatus

The status object contains status information for the playlist. Corresponds to the JSON property status



6238
6239
6240
# File 'lib/google/apis/youtube_v3/classes.rb', line 6238

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6245
6246
6247
6248
6249
6250
6251
6252
6253
6254
# File 'lib/google/apis/youtube_v3/classes.rb', line 6245

def update!(**args)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @localizations = args[:localizations] if args.key?(:localizations)
  @player = args[:player] if args.key?(:player)
  @snippet = args[:snippet] if args.key?(:snippet)
  @status = args[:status] if args.key?(:status)
end