Class: Google::Apis::YoutubeV3::Playlist
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Playlist
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A playlist resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. A playlist can contain up to 200 videos, and YouTube does not limit the number of playlists that each user creates. By default, playlists are publicly visible to other users, but playlists can be public or private. YouTube also uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history - watch later To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistItems.list method to retrieve any of those lists. You can also add or remove items from those lists by calling the playlistItems.insert and playlistItems.delete methods.
Instance Attribute Summary collapse
-
#content_details ⇒ Google::Apis::YoutubeV3::PlaylistContentDetails
The contentDetails object contains information like video count.
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the playlist.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::PlaylistLocalization>
Localizations for different languages Corresponds to the JSON property
localizations. -
#player ⇒ Google::Apis::YoutubeV3::PlaylistPlayer
The player object contains information that you would use to play the playlist in an embedded player.
-
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistSnippet
Basic details about a playlist, including title, description and thumbnails.
-
#status ⇒ Google::Apis::YoutubeV3::PlaylistStatus
The status object contains status information for the playlist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Playlist
constructor
A new instance of Playlist.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Playlist
Returns a new instance of Playlist.
6097 6098 6099 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_details ⇒ Google::Apis::YoutubeV3::PlaylistContentDetails
The contentDetails object contains information like video count.
Corresponds to the JSON property contentDetails
6058 6059 6060 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6058 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6063 6064 6065 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6063 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the playlist.
Corresponds to the JSON property id
6068 6069 6070 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6068 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlist".
Corresponds to the JSON property kind
6074 6075 6076 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6074 def kind @kind end |
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::PlaylistLocalization>
Localizations for different languages
Corresponds to the JSON property localizations
6079 6080 6081 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6079 def localizations @localizations end |
#player ⇒ Google::Apis::YoutubeV3::PlaylistPlayer
The player object contains information that you would use to play the playlist
in an embedded player.
Corresponds to the JSON property player
6085 6086 6087 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6085 def player @player end |
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistSnippet
Basic details about a playlist, including title, description and thumbnails.
Corresponds to the JSON property snippet
6090 6091 6092 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6090 def snippet @snippet end |
#status ⇒ Google::Apis::YoutubeV3::PlaylistStatus
The status object contains status information for the playlist.
Corresponds to the JSON property status
6095 6096 6097 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6095 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6102 def update!(**args) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @localizations = args[:localizations] if args.key?(:localizations) @player = args[:player] if args.key?(:player) @snippet = args[:snippet] if args.key?(:snippet) @status = args[:status] if args.key?(:status) end |