Class: Google::Apis::YoutubeV3::PlaylistImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistImage

Returns a new instance of PlaylistImage.



6308
6309
6310
# File 'lib/google/apis/youtube_v3/classes.rb', line 6308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Identifies this resource (playlist id and image type). Corresponds to the JSON property id

Returns:

  • (String)


6283
6284
6285
# File 'lib/google/apis/youtube_v3/classes.rb', line 6283

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# playlistImages". Corresponds to the JSON property kind

Returns:

  • (String)


6289
6290
6291
# File 'lib/google/apis/youtube_v3/classes.rb', line 6289

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::PlaylistImageSnippet

A playlistImage resource identifies another resource, such as a image, that is associated with a playlist. In addition, the playlistImage resource contains details about the included resource that pertain specifically to how that resource is used in that playlist. YouTube uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistImages.list method to retrieve image data for any of those playlists. You can also add or remove images from those lists by calling the playlistImages.insert and playlistImages.delete methods. Corresponds to the JSON property snippet



6306
6307
6308
# File 'lib/google/apis/youtube_v3/classes.rb', line 6306

def snippet
  @snippet
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6313
6314
6315
6316
6317
# File 'lib/google/apis/youtube_v3/classes.rb', line 6313

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
end