Class: Google::Apis::YoutubeV3::PlaylistImage
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistImage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Identifies this resource (playlist id and image type).
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistImageSnippet
A playlistImage resource identifies another resource, such as a image, that is associated with a playlist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistImage
constructor
A new instance of PlaylistImage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistImage
Returns a new instance of PlaylistImage.
6304 6305 6306 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Identifies this resource (playlist id and image type).
Corresponds to the JSON property id
6279 6280 6281 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6279 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistImages".
Corresponds to the JSON property kind
6285 6286 6287 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6285 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::PlaylistImageSnippet
A playlistImage resource identifies another resource, such as a image, that
is associated with a playlist. In addition, the playlistImage resource
contains details about the included resource that pertain specifically to how
that resource is used in that playlist. YouTube uses playlists to identify
special collections of videos for a channel, such as: - uploaded videos -
favorite videos - positively rated (liked) videos - watch history To be more
specific, these lists are associated with a channel, which is a collection of
a person, group, or company's videos, playlists, and other YouTube information.
You can retrieve the playlist IDs for each of these lists from the channel
resource for a given channel. You can then use the playlistImages.list method
to retrieve image data for any of those playlists. You can also add or remove
images from those lists by calling the playlistImages.insert and
playlistImages.delete methods.
Corresponds to the JSON property snippet
6302 6303 6304 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6302 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6309 6310 6311 6312 6313 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6309 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |