Class: Google::Apis::YoutubeV3::PlaylistImageListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistImageListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistImage>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistImageListResponse
constructor
A new instance of PlaylistImageListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistImageListResponse
Returns a new instance of PlaylistImageListResponse.
6349 6350 6351 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistImage>
Corresponds to the JSON property items
6323 6324 6325 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6323 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistImageListResponse".
Corresponds to the JSON property kind
6329 6330 6331 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6329 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6335 6336 6337 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6335 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6341 6342 6343 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6341 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6347 6348 6349 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6347 def prev_page_token @prev_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6354 6355 6356 6357 6358 6359 6360 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6354 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) end |