Class: Google::Apis::YoutubeV3::PlaylistImageListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistImageListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistImage>
Corresponds to the JSON property
items. -
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistImageListResponse
constructor
A new instance of PlaylistImageListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistImageListResponse
Returns a new instance of PlaylistImageListResponse.
6210 6211 6212 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#items ⇒ Array<Google::Apis::YoutubeV3::PlaylistImage>
Corresponds to the JSON property items
6184 6185 6186 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6184 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
playlistImageListResponse".
Corresponds to the JSON property kind
6190 6191 6192 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6190 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6196 6197 6198 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6196 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6202 6203 6204 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6202 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6208 6209 6210 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6208 def prev_page_token @prev_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6215 6216 6217 6218 6219 6220 6221 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6215 def update!(**args) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) end |