Class: Google::Apis::YoutubeV3::PlaylistImageListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistImageListResponse

Returns a new instance of PlaylistImageListResponse.



6076
6077
6078
# File 'lib/google/apis/youtube_v3/classes.rb', line 6076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::YoutubeV3::PlaylistImage>

Corresponds to the JSON property items



6050
6051
6052
# File 'lib/google/apis/youtube_v3/classes.rb', line 6050

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# playlistImageListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


6056
6057
6058
# File 'lib/google/apis/youtube_v3/classes.rb', line 6056

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6062
6063
6064
# File 'lib/google/apis/youtube_v3/classes.rb', line 6062

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



6068
6069
6070
# File 'lib/google/apis/youtube_v3/classes.rb', line 6068

def page_info
  @page_info
end

#prev_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set. Corresponds to the JSON property prevPageToken

Returns:

  • (String)


6074
6075
6076
# File 'lib/google/apis/youtube_v3/classes.rb', line 6074

def prev_page_token
  @prev_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6081
6082
6083
6084
6085
6086
6087
# File 'lib/google/apis/youtube_v3/classes.rb', line 6081

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token)
end