Class: Google::Apis::YoutubeV3::PlaylistImageSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistImageSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A playlistImage resource identifies another resource, such as a image, that is associated with a playlist. In addition, the playlistImage resource contains details about the included resource that pertain specifically to how that resource is used in that playlist. YouTube uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistImages.list method to retrieve image data for any of those playlists. You can also add or remove images from those lists by calling the playlistImages.insert and playlistImages.delete methods.
Instance Attribute Summary collapse
-
#height ⇒ Fixnum
The image height.
-
#playlist_id ⇒ String
The Playlist ID of the playlist this image is associated with.
-
#type ⇒ String
The image type.
-
#width ⇒ Fixnum
The image width.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistImageSnippet
constructor
A new instance of PlaylistImageSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistImageSnippet
Returns a new instance of PlaylistImageSnippet.
6399 6400 6401 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#height ⇒ Fixnum
The image height.
Corresponds to the JSON property height
6382 6383 6384 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6382 def height @height end |
#playlist_id ⇒ String
The Playlist ID of the playlist this image is associated with.
Corresponds to the JSON property playlistId
6387 6388 6389 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6387 def playlist_id @playlist_id end |
#type ⇒ String
The image type.
Corresponds to the JSON property type
6392 6393 6394 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6392 def type @type end |
#width ⇒ Fixnum
The image width.
Corresponds to the JSON property width
6397 6398 6399 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6397 def width @width end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6404 6405 6406 6407 6408 6409 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6404 def update!(**args) @height = args[:height] if args.key?(:height) @playlist_id = args[:playlist_id] if args.key?(:playlist_id) @type = args[:type] if args.key?(:type) @width = args[:width] if args.key?(:width) end |