Class: Google::Apis::YoutubeV3::PlaylistItemContentDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistItemContentDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#end_at ⇒ String
The time, measured in seconds from the start of the video, when the video should stop playing.
-
#note ⇒ String
A user-generated note for this item.
-
#start_at ⇒ String
The time, measured in seconds from the start of the video, when the video should start playing.
-
#video_id ⇒ String
The ID that YouTube uses to uniquely identify a video.
-
#video_published_at ⇒ DateTime
The date and time that the video was published to YouTube.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistItemContentDetails
constructor
A new instance of PlaylistItemContentDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistItemContentDetails
Returns a new instance of PlaylistItemContentDetails.
6514 6515 6516 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_at ⇒ String
The time, measured in seconds from the start of the video, when the video
should stop playing. (The playlist owner can specify the times when the video
should start and stop playing when the video is played in the context of the
playlist.) By default, assume that the video.endTime is the end of the video.
Corresponds to the JSON property endAt
6488 6489 6490 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6488 def end_at @end_at end |
#note ⇒ String
A user-generated note for this item.
Corresponds to the JSON property note
6493 6494 6495 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6493 def note @note end |
#start_at ⇒ String
The time, measured in seconds from the start of the video, when the video
should start playing. (The playlist owner can specify the times when the video
should start and stop playing when the video is played in the context of the
playlist.) The default value is 0.
Corresponds to the JSON property startAt
6501 6502 6503 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6501 def start_at @start_at end |
#video_id ⇒ String
The ID that YouTube uses to uniquely identify a video. To retrieve the video
resource, set the id query parameter to this value in your API request.
Corresponds to the JSON property videoId
6507 6508 6509 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6507 def video_id @video_id end |
#video_published_at ⇒ DateTime
The date and time that the video was published to YouTube.
Corresponds to the JSON property videoPublishedAt
6512 6513 6514 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6512 def video_published_at @video_published_at end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6519 6520 6521 6522 6523 6524 6525 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6519 def update!(**args) @end_at = args[:end_at] if args.key?(:end_at) @note = args[:note] if args.key?(:note) @start_at = args[:start_at] if args.key?(:start_at) @video_id = args[:video_id] if args.key?(:video_id) @video_published_at = args[:video_published_at] if args.key?(:video_published_at) end |