Class: Google::Apis::YoutubeV3::PlaylistItemContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistItemContentDetails

Returns a new instance of PlaylistItemContentDetails.



6375
6376
6377
# File 'lib/google/apis/youtube_v3/classes.rb', line 6375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_atString

The time, measured in seconds from the start of the video, when the video should stop playing. (The playlist owner can specify the times when the video should start and stop playing when the video is played in the context of the playlist.) By default, assume that the video.endTime is the end of the video. Corresponds to the JSON property endAt

Returns:

  • (String)


6349
6350
6351
# File 'lib/google/apis/youtube_v3/classes.rb', line 6349

def end_at
  @end_at
end

#noteString

A user-generated note for this item. Corresponds to the JSON property note

Returns:

  • (String)


6354
6355
6356
# File 'lib/google/apis/youtube_v3/classes.rb', line 6354

def note
  @note
end

#start_atString

The time, measured in seconds from the start of the video, when the video should start playing. (The playlist owner can specify the times when the video should start and stop playing when the video is played in the context of the playlist.) The default value is 0. Corresponds to the JSON property startAt

Returns:

  • (String)


6362
6363
6364
# File 'lib/google/apis/youtube_v3/classes.rb', line 6362

def start_at
  @start_at
end

#video_idString

The ID that YouTube uses to uniquely identify a video. To retrieve the video resource, set the id query parameter to this value in your API request. Corresponds to the JSON property videoId

Returns:

  • (String)


6368
6369
6370
# File 'lib/google/apis/youtube_v3/classes.rb', line 6368

def video_id
  @video_id
end

#video_published_atDateTime

The date and time that the video was published to YouTube. Corresponds to the JSON property videoPublishedAt

Returns:

  • (DateTime)


6373
6374
6375
# File 'lib/google/apis/youtube_v3/classes.rb', line 6373

def video_published_at
  @video_published_at
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6380
6381
6382
6383
6384
6385
6386
# File 'lib/google/apis/youtube_v3/classes.rb', line 6380

def update!(**args)
  @end_at = args[:end_at] if args.key?(:end_at)
  @note = args[:note] if args.key?(:note)
  @start_at = args[:start_at] if args.key?(:start_at)
  @video_id = args[:video_id] if args.key?(:video_id)
  @video_published_at = args[:video_published_at] if args.key?(:video_published_at)
end