Class: Google::Apis::YoutubeV3::PlaylistItemContentDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistItemContentDetails

Returns a new instance of PlaylistItemContentDetails.



6241
6242
6243
# File 'lib/google/apis/youtube_v3/classes.rb', line 6241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_atString

The time, measured in seconds from the start of the video, when the video should stop playing. (The playlist owner can specify the times when the video should start and stop playing when the video is played in the context of the playlist.) By default, assume that the video.endTime is the end of the video. Corresponds to the JSON property endAt

Returns:

  • (String)


6215
6216
6217
# File 'lib/google/apis/youtube_v3/classes.rb', line 6215

def end_at
  @end_at
end

#noteString

A user-generated note for this item. Corresponds to the JSON property note

Returns:

  • (String)


6220
6221
6222
# File 'lib/google/apis/youtube_v3/classes.rb', line 6220

def note
  @note
end

#start_atString

The time, measured in seconds from the start of the video, when the video should start playing. (The playlist owner can specify the times when the video should start and stop playing when the video is played in the context of the playlist.) The default value is 0. Corresponds to the JSON property startAt

Returns:

  • (String)


6228
6229
6230
# File 'lib/google/apis/youtube_v3/classes.rb', line 6228

def start_at
  @start_at
end

#video_idString

The ID that YouTube uses to uniquely identify a video. To retrieve the video resource, set the id query parameter to this value in your API request. Corresponds to the JSON property videoId

Returns:

  • (String)


6234
6235
6236
# File 'lib/google/apis/youtube_v3/classes.rb', line 6234

def video_id
  @video_id
end

#video_published_atDateTime

The date and time that the video was published to YouTube. Corresponds to the JSON property videoPublishedAt

Returns:

  • (DateTime)


6239
6240
6241
# File 'lib/google/apis/youtube_v3/classes.rb', line 6239

def video_published_at
  @video_published_at
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6246
6247
6248
6249
6250
6251
6252
# File 'lib/google/apis/youtube_v3/classes.rb', line 6246

def update!(**args)
  @end_at = args[:end_at] if args.key?(:end_at)
  @note = args[:note] if args.key?(:note)
  @start_at = args[:start_at] if args.key?(:start_at)
  @video_id = args[:video_id] if args.key?(:video_id)
  @video_published_at = args[:video_published_at] if args.key?(:video_published_at)
end