Class: Google::Apis::YoutubeV3::PlaylistItemSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a playlist, including title, description and thumbnails. Basic details of a YouTube Playlist item provided by the author. Next ID: 15

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistItemSnippet

Returns a new instance of PlaylistItemSnippet.



6524
6525
6526
# File 'lib/google/apis/youtube_v3/classes.rb', line 6524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the user that added the item to the playlist. Corresponds to the JSON property channelId

Returns:

  • (String)


6469
6470
6471
# File 'lib/google/apis/youtube_v3/classes.rb', line 6469

def channel_id
  @channel_id
end

#channel_titleString

Channel title for the channel that the playlist item belongs to. Corresponds to the JSON property channelTitle

Returns:

  • (String)


6474
6475
6476
# File 'lib/google/apis/youtube_v3/classes.rb', line 6474

def channel_title
  @channel_title
end

#descriptionString

The item's description. Corresponds to the JSON property description

Returns:

  • (String)


6479
6480
6481
# File 'lib/google/apis/youtube_v3/classes.rb', line 6479

def description
  @description
end

#playlist_idString

The ID that YouTube uses to uniquely identify thGe playlist that the playlist item is in. Corresponds to the JSON property playlistId

Returns:

  • (String)


6485
6486
6487
# File 'lib/google/apis/youtube_v3/classes.rb', line 6485

def playlist_id
  @playlist_id
end

#positionFixnum

The order in which the item appears in the playlist. The value uses a zero- based index, so the first item has a position of 0, the second item has a position of 1, and so forth. Corresponds to the JSON property position

Returns:

  • (Fixnum)


6492
6493
6494
# File 'lib/google/apis/youtube_v3/classes.rb', line 6492

def position
  @position
end

#published_atDateTime

The date and time that the item was added to the playlist. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


6497
6498
6499
# File 'lib/google/apis/youtube_v3/classes.rb', line 6497

def published_at
  @published_at
end

#resource_idGoogle::Apis::YoutubeV3::ResourceId

A resource id is a generic reference that points to another YouTube resource. Corresponds to the JSON property resourceId



6502
6503
6504
# File 'lib/google/apis/youtube_v3/classes.rb', line 6502

def resource_id
  @resource_id
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



6507
6508
6509
# File 'lib/google/apis/youtube_v3/classes.rb', line 6507

def thumbnails
  @thumbnails
end

#titleString

The item's title. Corresponds to the JSON property title

Returns:

  • (String)


6512
6513
6514
# File 'lib/google/apis/youtube_v3/classes.rb', line 6512

def title
  @title
end

#video_owner_channel_idString

Channel id for the channel this video belongs to. Corresponds to the JSON property videoOwnerChannelId

Returns:

  • (String)


6517
6518
6519
# File 'lib/google/apis/youtube_v3/classes.rb', line 6517

def video_owner_channel_id
  @video_owner_channel_id
end

#video_owner_channel_titleString

Channel title for the channel this video belongs to. Corresponds to the JSON property videoOwnerChannelTitle

Returns:

  • (String)


6522
6523
6524
# File 'lib/google/apis/youtube_v3/classes.rb', line 6522

def video_owner_channel_title
  @video_owner_channel_title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6529
6530
6531
6532
6533
6534
6535
6536
6537
6538
6539
6540
6541
# File 'lib/google/apis/youtube_v3/classes.rb', line 6529

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @description = args[:description] if args.key?(:description)
  @playlist_id = args[:playlist_id] if args.key?(:playlist_id)
  @position = args[:position] if args.key?(:position)
  @published_at = args[:published_at] if args.key?(:published_at)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
  @video_owner_channel_id = args[:video_owner_channel_id] if args.key?(:video_owner_channel_id)
  @video_owner_channel_title = args[:video_owner_channel_title] if args.key?(:video_owner_channel_title)
end