Class: Google::Apis::YoutubeV3::PlaylistSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::PlaylistSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a playlist, including title, description and thumbnails.
Instance Attribute Summary collapse
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that published the playlist.
-
#channel_title ⇒ String
The channel title of the channel that the video belongs to.
-
#default_language ⇒ String
The language of the playlist's default title and description.
-
#description ⇒ String
The playlist's description.
-
#localized ⇒ Google::Apis::YoutubeV3::PlaylistLocalization
Playlist localization setting Corresponds to the JSON property
localized. -
#published_at ⇒ DateTime
The date and time that the playlist was created.
-
#tags ⇒ Array<String>
Keyword tags associated with the playlist.
-
#thumbnail_video_id ⇒ String
Note: if the playlist has a custom thumbnail, this field will not be populated.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The playlist's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PlaylistSnippet
constructor
A new instance of PlaylistSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PlaylistSnippet
Returns a new instance of PlaylistSnippet.
6888 6889 6890 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that published the
playlist.
Corresponds to the JSON property channelId
6835 6836 6837 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6835 def channel_id @channel_id end |
#channel_title ⇒ String
The channel title of the channel that the video belongs to.
Corresponds to the JSON property channelTitle
6840 6841 6842 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6840 def channel_title @channel_title end |
#default_language ⇒ String
The language of the playlist's default title and description.
Corresponds to the JSON property defaultLanguage
6845 6846 6847 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6845 def default_language @default_language end |
#description ⇒ String
The playlist's description.
Corresponds to the JSON property description
6850 6851 6852 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6850 def description @description end |
#localized ⇒ Google::Apis::YoutubeV3::PlaylistLocalization
Playlist localization setting
Corresponds to the JSON property localized
6855 6856 6857 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6855 def localized @localized end |
#published_at ⇒ DateTime
The date and time that the playlist was created.
Corresponds to the JSON property publishedAt
6860 6861 6862 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6860 def published_at @published_at end |
#tags ⇒ Array<String>
Keyword tags associated with the playlist.
Corresponds to the JSON property tags
6865 6866 6867 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6865 def @tags end |
#thumbnail_video_id ⇒ String
Note: if the playlist has a custom thumbnail, this field will not be populated.
The video id selected by the user that will be used as the thumbnail of this
playlist. This field defaults to the first publicly viewable video in the
playlist, if: 1. The user has never selected a video to be the thumbnail of
the playlist. 2. The user selects a video to be the thumbnail, and then
removes that video from the playlist. 3. The user selects a non-owned video to
be the thumbnail, but that video becomes private, or gets deleted.
Corresponds to the JSON property thumbnailVideoId
6876 6877 6878 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6876 def thumbnail_video_id @thumbnail_video_id end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
6881 6882 6883 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6881 def thumbnails @thumbnails end |
#title ⇒ String
The playlist's title.
Corresponds to the JSON property title
6886 6887 6888 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6886 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6893 6894 6895 6896 6897 6898 6899 6900 6901 6902 6903 6904 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6893 def update!(**args) @channel_id = args[:channel_id] if args.key?(:channel_id) @channel_title = args[:channel_title] if args.key?(:channel_title) @default_language = args[:default_language] if args.key?(:default_language) @description = args[:description] if args.key?(:description) @localized = args[:localized] if args.key?(:localized) @published_at = args[:published_at] if args.key?(:published_at) @tags = args[:tags] if args.key?(:tags) @thumbnail_video_id = args[:thumbnail_video_id] if args.key?(:thumbnail_video_id) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |