Class: Google::Apis::YoutubeV3::PlaylistSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a playlist, including title, description and thumbnails.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistSnippet

Returns a new instance of PlaylistSnippet.



6639
6640
6641
# File 'lib/google/apis/youtube_v3/classes.rb', line 6639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the channel that published the playlist. Corresponds to the JSON property channelId

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/youtube_v3/classes.rb', line 6586

def channel_id
  @channel_id
end

#channel_titleString

The channel title of the channel that the video belongs to. Corresponds to the JSON property channelTitle

Returns:

  • (String)


6591
6592
6593
# File 'lib/google/apis/youtube_v3/classes.rb', line 6591

def channel_title
  @channel_title
end

#default_languageString

The language of the playlist's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


6596
6597
6598
# File 'lib/google/apis/youtube_v3/classes.rb', line 6596

def default_language
  @default_language
end

#descriptionString

The playlist's description. Corresponds to the JSON property description

Returns:

  • (String)


6601
6602
6603
# File 'lib/google/apis/youtube_v3/classes.rb', line 6601

def description
  @description
end

#localizedGoogle::Apis::YoutubeV3::PlaylistLocalization

Playlist localization setting Corresponds to the JSON property localized



6606
6607
6608
# File 'lib/google/apis/youtube_v3/classes.rb', line 6606

def localized
  @localized
end

#published_atDateTime

The date and time that the playlist was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


6611
6612
6613
# File 'lib/google/apis/youtube_v3/classes.rb', line 6611

def published_at
  @published_at
end

#tagsArray<String>

Keyword tags associated with the playlist. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6616
6617
6618
# File 'lib/google/apis/youtube_v3/classes.rb', line 6616

def tags
  @tags
end

#thumbnail_video_idString

Note: if the playlist has a custom thumbnail, this field will not be populated. The video id selected by the user that will be used as the thumbnail of this playlist. This field defaults to the first publicly viewable video in the playlist, if: 1. The user has never selected a video to be the thumbnail of the playlist. 2. The user selects a video to be the thumbnail, and then removes that video from the playlist. 3. The user selects a non-owned video to be the thumbnail, but that video becomes private, or gets deleted. Corresponds to the JSON property thumbnailVideoId

Returns:

  • (String)


6627
6628
6629
# File 'lib/google/apis/youtube_v3/classes.rb', line 6627

def thumbnail_video_id
  @thumbnail_video_id
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



6632
6633
6634
# File 'lib/google/apis/youtube_v3/classes.rb', line 6632

def thumbnails
  @thumbnails
end

#titleString

The playlist's title. Corresponds to the JSON property title

Returns:

  • (String)


6637
6638
6639
# File 'lib/google/apis/youtube_v3/classes.rb', line 6637

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
6655
# File 'lib/google/apis/youtube_v3/classes.rb', line 6644

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @tags = args[:tags] if args.key?(:tags)
  @thumbnail_video_id = args[:thumbnail_video_id] if args.key?(:thumbnail_video_id)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end