Class: Google::Apis::YoutubeV3::PlaylistSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a playlist, including title, description and thumbnails.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PlaylistSnippet

Returns a new instance of PlaylistSnippet.



6605
6606
6607
# File 'lib/google/apis/youtube_v3/classes.rb', line 6605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the channel that published the playlist. Corresponds to the JSON property channelId

Returns:

  • (String)


6552
6553
6554
# File 'lib/google/apis/youtube_v3/classes.rb', line 6552

def channel_id
  @channel_id
end

#channel_titleString

The channel title of the channel that the video belongs to. Corresponds to the JSON property channelTitle

Returns:

  • (String)


6557
6558
6559
# File 'lib/google/apis/youtube_v3/classes.rb', line 6557

def channel_title
  @channel_title
end

#default_languageString

The language of the playlist's default title and description. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


6562
6563
6564
# File 'lib/google/apis/youtube_v3/classes.rb', line 6562

def default_language
  @default_language
end

#descriptionString

The playlist's description. Corresponds to the JSON property description

Returns:

  • (String)


6567
6568
6569
# File 'lib/google/apis/youtube_v3/classes.rb', line 6567

def description
  @description
end

#localizedGoogle::Apis::YoutubeV3::PlaylistLocalization

Playlist localization setting Corresponds to the JSON property localized



6572
6573
6574
# File 'lib/google/apis/youtube_v3/classes.rb', line 6572

def localized
  @localized
end

#published_atDateTime

The date and time that the playlist was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


6577
6578
6579
# File 'lib/google/apis/youtube_v3/classes.rb', line 6577

def published_at
  @published_at
end

#tagsArray<String>

Keyword tags associated with the playlist. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


6582
6583
6584
# File 'lib/google/apis/youtube_v3/classes.rb', line 6582

def tags
  @tags
end

#thumbnail_video_idString

Note: if the playlist has a custom thumbnail, this field will not be populated. The video id selected by the user that will be used as the thumbnail of this playlist. This field defaults to the first publicly viewable video in the playlist, if: 1. The user has never selected a video to be the thumbnail of the playlist. 2. The user selects a video to be the thumbnail, and then removes that video from the playlist. 3. The user selects a non-owned video to be the thumbnail, but that video becomes private, or gets deleted. Corresponds to the JSON property thumbnailVideoId

Returns:

  • (String)


6593
6594
6595
# File 'lib/google/apis/youtube_v3/classes.rb', line 6593

def thumbnail_video_id
  @thumbnail_video_id
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



6598
6599
6600
# File 'lib/google/apis/youtube_v3/classes.rb', line 6598

def thumbnails
  @thumbnails
end

#titleString

The playlist's title. Corresponds to the JSON property title

Returns:

  • (String)


6603
6604
6605
# File 'lib/google/apis/youtube_v3/classes.rb', line 6603

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6610
6611
6612
6613
6614
6615
6616
6617
6618
6619
6620
6621
# File 'lib/google/apis/youtube_v3/classes.rb', line 6610

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @tags = args[:tags] if args.key?(:tags)
  @thumbnail_video_id = args[:thumbnail_video_id] if args.key?(:thumbnail_video_id)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end