Class: Google::Apis::YoutubeV3::ResourceId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A resource id is a generic reference that points to another YouTube resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceId

Returns a new instance of ResourceId.



6723
6724
6725
# File 'lib/google/apis/youtube_v3/classes.rb', line 6723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the referred resource, if that resource is a channel. This property is only present if the resourceId.kind value is youtube#channel. Corresponds to the JSON property channelId

Returns:

  • (String)


6702
6703
6704
# File 'lib/google/apis/youtube_v3/classes.rb', line 6702

def channel_id
  @channel_id
end

#kindString

The type of the API resource. Corresponds to the JSON property kind

Returns:

  • (String)


6707
6708
6709
# File 'lib/google/apis/youtube_v3/classes.rb', line 6707

def kind
  @kind
end

#playlist_idString

The ID that YouTube uses to uniquely identify the referred resource, if that resource is a playlist. This property is only present if the resourceId.kind value is youtube#playlist. Corresponds to the JSON property playlistId

Returns:

  • (String)


6714
6715
6716
# File 'lib/google/apis/youtube_v3/classes.rb', line 6714

def playlist_id
  @playlist_id
end

#video_idString

The ID that YouTube uses to uniquely identify the referred resource, if that resource is a video. This property is only present if the resourceId.kind value is youtube#video. Corresponds to the JSON property videoId

Returns:

  • (String)


6721
6722
6723
# File 'lib/google/apis/youtube_v3/classes.rb', line 6721

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6728
6729
6730
6731
6732
6733
# File 'lib/google/apis/youtube_v3/classes.rb', line 6728

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @kind = args[:kind] if args.key?(:kind)
  @playlist_id = args[:playlist_id] if args.key?(:playlist_id)
  @video_id = args[:video_id] if args.key?(:video_id)
end