Class: Google::Apis::YoutubeV3::SearchListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SearchListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#region_code ⇒ String
Corresponds to the JSON property
regionCode. -
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchListsResponse
constructor
A new instance of SearchListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchListsResponse
Returns a new instance of SearchListsResponse.
7067 7068 7069 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7016 7017 7018 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7016 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7021 7022 7023 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7021 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
Corresponds to the JSON property items
7026 7027 7028 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7026 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
searchListResponse".
Corresponds to the JSON property kind
7032 7033 7034 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7032 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7038 7039 7040 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7038 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7044 7045 7046 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7044 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
7050 7051 7052 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7050 def prev_page_token @prev_page_token end |
#region_code ⇒ String
Corresponds to the JSON property regionCode
7055 7056 7057 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7055 def region_code @region_code end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7060 7061 7062 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7060 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Corresponds to the JSON property visitorId
7065 7066 7067 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7065 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7072 7073 7074 7075 7076 7077 7078 7079 7080 7081 7082 7083 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7072 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @region_code = args[:region_code] if args.key?(:region_code) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |