Class: Google::Apis::YoutubeV3::SearchListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SearchListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#region_code ⇒ String
Corresponds to the JSON property
regionCode. -
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchListsResponse
constructor
A new instance of SearchListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchListsResponse
Returns a new instance of SearchListsResponse.
6928 6929 6930 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6877 6878 6879 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6877 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
6882 6883 6884 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6882 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
Corresponds to the JSON property items
6887 6888 6889 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6887 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
searchListResponse".
Corresponds to the JSON property kind
6893 6894 6895 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6893 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6899 6900 6901 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6899 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6905 6906 6907 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6905 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6911 6912 6913 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6911 def prev_page_token @prev_page_token end |
#region_code ⇒ String
Corresponds to the JSON property regionCode
6916 6917 6918 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6916 def region_code @region_code end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
6921 6922 6923 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6921 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitor ID identifies the visitor.
Corresponds to the JSON property visitorId
6926 6927 6928 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6926 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6933 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @region_code = args[:region_code] if args.key?(:region_code) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |