Class: Google::Apis::YoutubeV3::SearchListsResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SearchListsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.
-
#region_code ⇒ String
Corresponds to the JSON property
regionCode. -
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchListsResponse
constructor
A new instance of SearchListsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchListsResponse
Returns a new instance of SearchListsResponse.
6794 6795 6796 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
6743 6744 6745 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6743 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
6748 6749 6750 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6748 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SearchResult>
Pagination information for token pagination.
Corresponds to the JSON property items
6753 6754 6755 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6753 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
searchListResponse".
Corresponds to the JSON property kind
6759 6760 6761 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6759 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
6765 6766 6767 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6765 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
6771 6772 6773 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6771 def page_info @page_info end |
#prev_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the previous page in the result set.
Corresponds to the JSON property prevPageToken
6777 6778 6779 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6777 def prev_page_token @prev_page_token end |
#region_code ⇒ String
Corresponds to the JSON property regionCode
6782 6783 6784 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6782 def region_code @region_code end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
6787 6788 6789 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6787 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
6792 6793 6794 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6792 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6799 6800 6801 6802 6803 6804 6805 6806 6807 6808 6809 6810 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 6799 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @prev_page_token = args[:prev_page_token] if args.key?(:prev_page_token) @region_code = args[:region_code] if args.key?(:region_code) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |