Class: Google::Apis::YoutubeV3::SearchResultSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a search result, including title, description and thumbnails of the item referenced by the search result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchResultSnippet

Returns a new instance of SearchResultSnippet.



7007
7008
7009
# File 'lib/google/apis/youtube_v3/classes.rb', line 7007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The value that YouTube uses to uniquely identify the channel that published the resource that the search result identifies. Corresponds to the JSON property channelId

Returns:

  • (String)


6972
6973
6974
# File 'lib/google/apis/youtube_v3/classes.rb', line 6972

def channel_id
  @channel_id
end

#channel_titleString

The title of the channel that published the resource that the search result identifies. Corresponds to the JSON property channelTitle

Returns:

  • (String)


6978
6979
6980
# File 'lib/google/apis/youtube_v3/classes.rb', line 6978

def channel_title
  @channel_title
end

#descriptionString

A description of the search result. Corresponds to the JSON property description

Returns:

  • (String)


6983
6984
6985
# File 'lib/google/apis/youtube_v3/classes.rb', line 6983

def description
  @description
end

#live_broadcast_contentString

It indicates if the resource (video or channel) has upcoming/active live broadcast content. Or it's "none" if there is not any upcoming/active live broadcasts. Corresponds to the JSON property liveBroadcastContent

Returns:

  • (String)


6990
6991
6992
# File 'lib/google/apis/youtube_v3/classes.rb', line 6990

def live_broadcast_content
  @live_broadcast_content
end

#published_atDateTime

The creation date and time of the resource that the search result identifies. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


6995
6996
6997
# File 'lib/google/apis/youtube_v3/classes.rb', line 6995

def published_at
  @published_at
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



7000
7001
7002
# File 'lib/google/apis/youtube_v3/classes.rb', line 7000

def thumbnails
  @thumbnails
end

#titleString

The title of the search result. Corresponds to the JSON property title

Returns:

  • (String)


7005
7006
7007
# File 'lib/google/apis/youtube_v3/classes.rb', line 7005

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/google/apis/youtube_v3/classes.rb', line 7012

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @description = args[:description] if args.key?(:description)
  @live_broadcast_content = args[:live_broadcast_content] if args.key?(:live_broadcast_content)
  @published_at = args[:published_at] if args.key?(:published_at)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end