Class: Google::Apis::YoutubeV3::SubscriptionSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a subscription, including title, description and thumbnails of the subscribed item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionSnippet

Returns a new instance of SubscriptionSnippet.



7215
7216
7217
# File 'lib/google/apis/youtube_v3/classes.rb', line 7215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the subscriber's channel. Corresponds to the JSON property channelId

Returns:

  • (String)


7188
7189
7190
# File 'lib/google/apis/youtube_v3/classes.rb', line 7188

def channel_id
  @channel_id
end

#descriptionString

The subscription's details. Corresponds to the JSON property description

Returns:

  • (String)


7193
7194
7195
# File 'lib/google/apis/youtube_v3/classes.rb', line 7193

def description
  @description
end

#published_atDateTime

The date and time that the subscription was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


7198
7199
7200
# File 'lib/google/apis/youtube_v3/classes.rb', line 7198

def published_at
  @published_at
end

#resource_idGoogle::Apis::YoutubeV3::ResourceId

A resource id is a generic reference that points to another YouTube resource. Corresponds to the JSON property resourceId



7203
7204
7205
# File 'lib/google/apis/youtube_v3/classes.rb', line 7203

def resource_id
  @resource_id
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



7208
7209
7210
# File 'lib/google/apis/youtube_v3/classes.rb', line 7208

def thumbnails
  @thumbnails
end

#titleString

The subscription's title. Corresponds to the JSON property title

Returns:

  • (String)


7213
7214
7215
# File 'lib/google/apis/youtube_v3/classes.rb', line 7213

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7220
7221
7222
7223
7224
7225
7226
7227
# File 'lib/google/apis/youtube_v3/classes.rb', line 7220

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @description = args[:description] if args.key?(:description)
  @published_at = args[:published_at] if args.key?(:published_at)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end