Class: Google::Apis::YoutubeV3::SubscriptionSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a subscription, including title, description and thumbnails of the subscribed item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscriptionSnippet

Returns a new instance of SubscriptionSnippet.



7107
7108
7109
# File 'lib/google/apis/youtube_v3/classes.rb', line 7107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_idString

The ID that YouTube uses to uniquely identify the subscriber's channel. Corresponds to the JSON property channelId

Returns:

  • (String)


7080
7081
7082
# File 'lib/google/apis/youtube_v3/classes.rb', line 7080

def channel_id
  @channel_id
end

#descriptionString

The subscription's details. Corresponds to the JSON property description

Returns:

  • (String)


7085
7086
7087
# File 'lib/google/apis/youtube_v3/classes.rb', line 7085

def description
  @description
end

#published_atDateTime

The date and time that the subscription was created. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


7090
7091
7092
# File 'lib/google/apis/youtube_v3/classes.rb', line 7090

def published_at
  @published_at
end

#resource_idGoogle::Apis::YoutubeV3::ResourceId

A resource id is a generic reference that points to another YouTube resource. Corresponds to the JSON property resourceId



7095
7096
7097
# File 'lib/google/apis/youtube_v3/classes.rb', line 7095

def resource_id
  @resource_id
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



7100
7101
7102
# File 'lib/google/apis/youtube_v3/classes.rb', line 7100

def thumbnails
  @thumbnails
end

#titleString

The subscription's title. Corresponds to the JSON property title

Returns:

  • (String)


7105
7106
7107
# File 'lib/google/apis/youtube_v3/classes.rb', line 7105

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7112
7113
7114
7115
7116
7117
7118
7119
# File 'lib/google/apis/youtube_v3/classes.rb', line 7112

def update!(**args)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @description = args[:description] if args.key?(:description)
  @published_at = args[:published_at] if args.key?(:published_at)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end