Class: Google::Apis::YoutubeV3::SuperChatEventListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperChatEventListResponse

Returns a new instance of SuperChatEventListResponse.



7380
7381
7382
# File 'lib/google/apis/youtube_v3/classes.rb', line 7380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7340
7341
7342
# File 'lib/google/apis/youtube_v3/classes.rb', line 7340

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


7345
7346
7347
# File 'lib/google/apis/youtube_v3/classes.rb', line 7345

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::SuperChatEvent>

A list of Super Chat purchases that match the request criteria. Corresponds to the JSON property items



7350
7351
7352
# File 'lib/google/apis/youtube_v3/classes.rb', line 7350

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# superChatEventListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


7356
7357
7358
# File 'lib/google/apis/youtube_v3/classes.rb', line 7356

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7362
7363
7364
# File 'lib/google/apis/youtube_v3/classes.rb', line 7362

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



7368
7369
7370
# File 'lib/google/apis/youtube_v3/classes.rb', line 7368

def page_info
  @page_info
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



7373
7374
7375
# File 'lib/google/apis/youtube_v3/classes.rb', line 7373

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


7378
7379
7380
# File 'lib/google/apis/youtube_v3/classes.rb', line 7378

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
# File 'lib/google/apis/youtube_v3/classes.rb', line 7385

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end