Class: Google::Apis::YoutubeV3::SuperChatEventListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SuperChatEventListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SuperChatEvent>
A list of Super Chat purchases that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuperChatEventListResponse
constructor
A new instance of SuperChatEventListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuperChatEventListResponse
Returns a new instance of SuperChatEventListResponse.
7380 7381 7382 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7340 7341 7342 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7340 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7345 7346 7347 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7345 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SuperChatEvent>
A list of Super Chat purchases that match the request criteria.
Corresponds to the JSON property items
7350 7351 7352 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7350 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
superChatEventListResponse".
Corresponds to the JSON property kind
7356 7357 7358 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7356 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7362 7363 7364 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7362 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7368 7369 7370 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7368 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7373 7374 7375 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7373 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
7378 7379 7380 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7378 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7385 7386 7387 7388 7389 7390 7391 7392 7393 7394 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7385 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |