Class: Google::Apis::YoutubeV3::SuperChatEventListResponse
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SuperChatEventListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#event_id ⇒ String
Serialized EventId of the request which produced this response.
-
#items ⇒ Array<Google::Apis::YoutubeV3::SuperChatEvent>
A list of Super Chat purchases that match the request criteria.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
-
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items available and number of resources returned in a single page.
-
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
-
#visitor_id ⇒ String
The visitorId identifies the visitor.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuperChatEventListResponse
constructor
A new instance of SuperChatEventListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuperChatEventListResponse
Returns a new instance of SuperChatEventListResponse.
7280 7281 7282 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7240 7241 7242 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7240 def etag @etag end |
#event_id ⇒ String
Serialized EventId of the request which produced this response.
Corresponds to the JSON property eventId
7245 7246 7247 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7245 def event_id @event_id end |
#items ⇒ Array<Google::Apis::YoutubeV3::SuperChatEvent>
A list of Super Chat purchases that match the request criteria.
Corresponds to the JSON property items
7250 7251 7252 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7250 def items @items end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
superChatEventListResponse".
Corresponds to the JSON property kind
7256 7257 7258 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7256 def kind @kind end |
#next_page_token ⇒ String
The token that can be used as the value of the pageToken parameter to retrieve
the next page in the result set.
Corresponds to the JSON property nextPageToken
7262 7263 7264 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7262 def next_page_token @next_page_token end |
#page_info ⇒ Google::Apis::YoutubeV3::PageInfo
Paging details for lists of resources, including total number of items
available and number of resources returned in a single page.
Corresponds to the JSON property pageInfo
7268 7269 7270 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7268 def page_info @page_info end |
#token_pagination ⇒ Google::Apis::YoutubeV3::TokenPagination
Stub token pagination template to suppress results.
Corresponds to the JSON property tokenPagination
7273 7274 7275 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7273 def token_pagination @token_pagination end |
#visitor_id ⇒ String
The visitorId identifies the visitor.
Corresponds to the JSON property visitorId
7278 7279 7280 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7278 def visitor_id @visitor_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7285 7286 7287 7288 7289 7290 7291 7292 7293 7294 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7285 def update!(**args) @etag = args[:etag] if args.key?(:etag) @event_id = args[:event_id] if args.key?(:event_id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @page_info = args[:page_info] if args.key?(:page_info) @token_pagination = args[:token_pagination] if args.key?(:token_pagination) @visitor_id = args[:visitor_id] if args.key?(:visitor_id) end |