Class: Google::Apis::YoutubeV3::SuperChatEventListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperChatEventListResponse

Returns a new instance of SuperChatEventListResponse.



7246
7247
7248
# File 'lib/google/apis/youtube_v3/classes.rb', line 7246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7206
7207
7208
# File 'lib/google/apis/youtube_v3/classes.rb', line 7206

def etag
  @etag
end

#event_idString

Serialized EventId of the request which produced this response. Corresponds to the JSON property eventId

Returns:

  • (String)


7211
7212
7213
# File 'lib/google/apis/youtube_v3/classes.rb', line 7211

def event_id
  @event_id
end

#itemsArray<Google::Apis::YoutubeV3::SuperChatEvent>

A list of Super Chat purchases that match the request criteria. Corresponds to the JSON property items



7216
7217
7218
# File 'lib/google/apis/youtube_v3/classes.rb', line 7216

def items
  @items
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# superChatEventListResponse". Corresponds to the JSON property kind

Returns:

  • (String)


7222
7223
7224
# File 'lib/google/apis/youtube_v3/classes.rb', line 7222

def kind
  @kind
end

#next_page_tokenString

The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7228
7229
7230
# File 'lib/google/apis/youtube_v3/classes.rb', line 7228

def next_page_token
  @next_page_token
end

#page_infoGoogle::Apis::YoutubeV3::PageInfo

Paging details for lists of resources, including total number of items available and number of resources returned in a single page. Corresponds to the JSON property pageInfo



7234
7235
7236
# File 'lib/google/apis/youtube_v3/classes.rb', line 7234

def page_info
  @page_info
end

#token_paginationGoogle::Apis::YoutubeV3::TokenPagination

Stub token pagination template to suppress results. Corresponds to the JSON property tokenPagination



7239
7240
7241
# File 'lib/google/apis/youtube_v3/classes.rb', line 7239

def token_pagination
  @token_pagination
end

#visitor_idString

The visitorId identifies the visitor. Corresponds to the JSON property visitorId

Returns:

  • (String)


7244
7245
7246
# File 'lib/google/apis/youtube_v3/classes.rb', line 7244

def visitor_id
  @visitor_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7251
7252
7253
7254
7255
7256
7257
7258
7259
7260
# File 'lib/google/apis/youtube_v3/classes.rb', line 7251

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @event_id = args[:event_id] if args.key?(:event_id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @page_info = args[:page_info] if args.key?(:page_info)
  @token_pagination = args[:token_pagination] if args.key?(:token_pagination)
  @visitor_id = args[:visitor_id] if args.key?(:visitor_id)
end