Class: Google::Apis::YoutubeV3::SuperChatEventSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SuperChatEventSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#amount_micros ⇒ Fixnum
The purchase amount, in micros of the purchase currency.
-
#channel_id ⇒ String
Channel id where the event occurred.
-
#comment_text ⇒ String
The text contents of the comment left by the user.
-
#created_at ⇒ DateTime
The date and time when the event occurred.
-
#currency ⇒ String
The currency in which the purchase was made.
-
#display_string ⇒ String
A rendered string that displays the purchase amount and currency (e.g., "$1.00" ).
-
#is_super_sticker_event ⇒ Boolean
(also: #is_super_sticker_event?)
True if this event is a Super Sticker event.
-
#message_type ⇒ Fixnum
The tier for the paid message, which is based on the amount of money spent to purchase the message.
-
#super_sticker_metadata ⇒ Google::Apis::YoutubeV3::SuperStickerMetadata
If this event is a Super Sticker event, this field will contain metadata about the Super Sticker.
-
#supporter_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the supporter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuperChatEventSnippet
constructor
A new instance of SuperChatEventSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuperChatEventSnippet
Returns a new instance of SuperChatEventSnippet.
7599 7600 7601 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_micros ⇒ Fixnum
The purchase amount, in micros of the purchase currency. e.g., 1 is
represented as 1000000.
Corresponds to the JSON property amountMicros
7548 7549 7550 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7548 def amount_micros @amount_micros end |
#channel_id ⇒ String
Channel id where the event occurred.
Corresponds to the JSON property channelId
7553 7554 7555 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7553 def channel_id @channel_id end |
#comment_text ⇒ String
The text contents of the comment left by the user.
Corresponds to the JSON property commentText
7558 7559 7560 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7558 def comment_text @comment_text end |
#created_at ⇒ DateTime
The date and time when the event occurred.
Corresponds to the JSON property createdAt
7563 7564 7565 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7563 def created_at @created_at end |
#currency ⇒ String
The currency in which the purchase was made. ISO 4217.
Corresponds to the JSON property currency
7568 7569 7570 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7568 def currency @currency end |
#display_string ⇒ String
A rendered string that displays the purchase amount and currency (e.g., "$1.00"
). The string is rendered for the given language.
Corresponds to the JSON property displayString
7574 7575 7576 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7574 def display_string @display_string end |
#is_super_sticker_event ⇒ Boolean Also known as: is_super_sticker_event?
True if this event is a Super Sticker event.
Corresponds to the JSON property isSuperStickerEvent
7579 7580 7581 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7579 def is_super_sticker_event @is_super_sticker_event end |
#message_type ⇒ Fixnum
The tier for the paid message, which is based on the amount of money spent to
purchase the message.
Corresponds to the JSON property messageType
7586 7587 7588 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7586 def @message_type end |
#super_sticker_metadata ⇒ Google::Apis::YoutubeV3::SuperStickerMetadata
If this event is a Super Sticker event, this field will contain metadata about
the Super Sticker.
Corresponds to the JSON property superStickerMetadata
7592 7593 7594 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7592 def @super_sticker_metadata end |
#supporter_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the supporter.
Corresponds to the JSON property supporterDetails
7597 7598 7599 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7597 def supporter_details @supporter_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7604 7605 7606 7607 7608 7609 7610 7611 7612 7613 7614 7615 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7604 def update!(**args) @amount_micros = args[:amount_micros] if args.key?(:amount_micros) @channel_id = args[:channel_id] if args.key?(:channel_id) @comment_text = args[:comment_text] if args.key?(:comment_text) @created_at = args[:created_at] if args.key?(:created_at) @currency = args[:currency] if args.key?(:currency) @display_string = args[:display_string] if args.key?(:display_string) @is_super_sticker_event = args[:is_super_sticker_event] if args.key?(:is_super_sticker_event) @message_type = args[:message_type] if args.key?(:message_type) @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata) @supporter_details = args[:supporter_details] if args.key?(:supporter_details) end |