Class: Google::Apis::YoutubeV3::SuperChatEventSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperChatEventSnippet

Returns a new instance of SuperChatEventSnippet.



7595
7596
7597
# File 'lib/google/apis/youtube_v3/classes.rb', line 7595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_microsFixnum

The purchase amount, in micros of the purchase currency. e.g., 1 is represented as 1000000. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


7544
7545
7546
# File 'lib/google/apis/youtube_v3/classes.rb', line 7544

def amount_micros
  @amount_micros
end

#channel_idString

Channel id where the event occurred. Corresponds to the JSON property channelId

Returns:

  • (String)


7549
7550
7551
# File 'lib/google/apis/youtube_v3/classes.rb', line 7549

def channel_id
  @channel_id
end

#comment_textString

The text contents of the comment left by the user. Corresponds to the JSON property commentText

Returns:

  • (String)


7554
7555
7556
# File 'lib/google/apis/youtube_v3/classes.rb', line 7554

def comment_text
  @comment_text
end

#created_atDateTime

The date and time when the event occurred. Corresponds to the JSON property createdAt

Returns:

  • (DateTime)


7559
7560
7561
# File 'lib/google/apis/youtube_v3/classes.rb', line 7559

def created_at
  @created_at
end

#currencyString

The currency in which the purchase was made. ISO 4217. Corresponds to the JSON property currency

Returns:

  • (String)


7564
7565
7566
# File 'lib/google/apis/youtube_v3/classes.rb', line 7564

def currency
  @currency
end

#display_stringString

A rendered string that displays the purchase amount and currency (e.g., "$1.00" ). The string is rendered for the given language. Corresponds to the JSON property displayString

Returns:

  • (String)


7570
7571
7572
# File 'lib/google/apis/youtube_v3/classes.rb', line 7570

def display_string
  @display_string
end

#is_super_sticker_eventBoolean Also known as: is_super_sticker_event?

True if this event is a Super Sticker event. Corresponds to the JSON property isSuperStickerEvent

Returns:

  • (Boolean)


7575
7576
7577
# File 'lib/google/apis/youtube_v3/classes.rb', line 7575

def is_super_sticker_event
  @is_super_sticker_event
end

#message_typeFixnum

The tier for the paid message, which is based on the amount of money spent to purchase the message. Corresponds to the JSON property messageType

Returns:

  • (Fixnum)


7582
7583
7584
# File 'lib/google/apis/youtube_v3/classes.rb', line 7582

def message_type
  @message_type
end

#super_sticker_metadataGoogle::Apis::YoutubeV3::SuperStickerMetadata

If this event is a Super Sticker event, this field will contain metadata about the Super Sticker. Corresponds to the JSON property superStickerMetadata



7588
7589
7590
# File 'lib/google/apis/youtube_v3/classes.rb', line 7588

def 
  @super_sticker_metadata
end

#supporter_detailsGoogle::Apis::YoutubeV3::ChannelProfileDetails

Details about the supporter. Corresponds to the JSON property supporterDetails



7593
7594
7595
# File 'lib/google/apis/youtube_v3/classes.rb', line 7593

def supporter_details
  @supporter_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7600
7601
7602
7603
7604
7605
7606
7607
7608
7609
7610
7611
# File 'lib/google/apis/youtube_v3/classes.rb', line 7600

def update!(**args)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @comment_text = args[:comment_text] if args.key?(:comment_text)
  @created_at = args[:created_at] if args.key?(:created_at)
  @currency = args[:currency] if args.key?(:currency)
  @display_string = args[:display_string] if args.key?(:display_string)
  @is_super_sticker_event = args[:is_super_sticker_event] if args.key?(:is_super_sticker_event)
  @message_type = args[:message_type] if args.key?(:message_type)
  @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata)
  @supporter_details = args[:supporter_details] if args.key?(:supporter_details)
end