Class: Google::Apis::YoutubeV3::SuperChatEventSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperChatEventSnippet

Returns a new instance of SuperChatEventSnippet.



7356
7357
7358
# File 'lib/google/apis/youtube_v3/classes.rb', line 7356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amount_microsFixnum

The purchase amount, in micros of the purchase currency. e.g., 1 is represented as 1000000. Corresponds to the JSON property amountMicros

Returns:

  • (Fixnum)


7305
7306
7307
# File 'lib/google/apis/youtube_v3/classes.rb', line 7305

def amount_micros
  @amount_micros
end

#channel_idString

Channel id where the event occurred. Corresponds to the JSON property channelId

Returns:

  • (String)


7310
7311
7312
# File 'lib/google/apis/youtube_v3/classes.rb', line 7310

def channel_id
  @channel_id
end

#comment_textString

The text contents of the comment left by the user. Corresponds to the JSON property commentText

Returns:

  • (String)


7315
7316
7317
# File 'lib/google/apis/youtube_v3/classes.rb', line 7315

def comment_text
  @comment_text
end

#created_atDateTime

The date and time when the event occurred. Corresponds to the JSON property createdAt

Returns:

  • (DateTime)


7320
7321
7322
# File 'lib/google/apis/youtube_v3/classes.rb', line 7320

def created_at
  @created_at
end

#currencyString

The currency in which the purchase was made. ISO 4217. Corresponds to the JSON property currency

Returns:

  • (String)


7325
7326
7327
# File 'lib/google/apis/youtube_v3/classes.rb', line 7325

def currency
  @currency
end

#display_stringString

A rendered string that displays the purchase amount and currency (e.g., "$1.00" ). The string is rendered for the given language. Corresponds to the JSON property displayString

Returns:

  • (String)


7331
7332
7333
# File 'lib/google/apis/youtube_v3/classes.rb', line 7331

def display_string
  @display_string
end

#is_super_sticker_eventBoolean Also known as: is_super_sticker_event?

True if this event is a Super Sticker event. Corresponds to the JSON property isSuperStickerEvent

Returns:

  • (Boolean)


7336
7337
7338
# File 'lib/google/apis/youtube_v3/classes.rb', line 7336

def is_super_sticker_event
  @is_super_sticker_event
end

#message_typeFixnum

The tier for the paid message, which is based on the amount of money spent to purchase the message. Corresponds to the JSON property messageType

Returns:

  • (Fixnum)


7343
7344
7345
# File 'lib/google/apis/youtube_v3/classes.rb', line 7343

def message_type
  @message_type
end

#super_sticker_metadataGoogle::Apis::YoutubeV3::SuperStickerMetadata

If this event is a Super Sticker event, this field will contain metadata about the Super Sticker. Corresponds to the JSON property superStickerMetadata



7349
7350
7351
# File 'lib/google/apis/youtube_v3/classes.rb', line 7349

def 
  @super_sticker_metadata
end

#supporter_detailsGoogle::Apis::YoutubeV3::ChannelProfileDetails

Details about the supporter. Corresponds to the JSON property supporterDetails



7354
7355
7356
# File 'lib/google/apis/youtube_v3/classes.rb', line 7354

def supporter_details
  @supporter_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7361
7362
7363
7364
7365
7366
7367
7368
7369
7370
7371
7372
# File 'lib/google/apis/youtube_v3/classes.rb', line 7361

def update!(**args)
  @amount_micros = args[:amount_micros] if args.key?(:amount_micros)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @comment_text = args[:comment_text] if args.key?(:comment_text)
  @created_at = args[:created_at] if args.key?(:created_at)
  @currency = args[:currency] if args.key?(:currency)
  @display_string = args[:display_string] if args.key?(:display_string)
  @is_super_sticker_event = args[:is_super_sticker_event] if args.key?(:is_super_sticker_event)
  @message_type = args[:message_type] if args.key?(:message_type)
  @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata)
  @supporter_details = args[:supporter_details] if args.key?(:supporter_details)
end