Class: Google::Apis::YoutubeV3::SuperChatEventSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::SuperChatEventSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#amount_micros ⇒ Fixnum
The purchase amount, in micros of the purchase currency.
-
#channel_id ⇒ String
Channel id where the event occurred.
-
#comment_text ⇒ String
The text contents of the comment left by the user.
-
#created_at ⇒ DateTime
The date and time when the event occurred.
-
#currency ⇒ String
The currency in which the purchase was made.
-
#display_string ⇒ String
A rendered string that displays the purchase amount and currency (e.g., "$1.00" ).
-
#is_super_sticker_event ⇒ Boolean
(also: #is_super_sticker_event?)
True if this event is a Super Sticker event.
-
#message_type ⇒ Fixnum
The tier for the paid message, which is based on the amount of money spent to purchase the message.
-
#super_sticker_metadata ⇒ Google::Apis::YoutubeV3::SuperStickerMetadata
If this event is a Super Sticker event, this field will contain metadata about the Super Sticker.
-
#supporter_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the supporter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SuperChatEventSnippet
constructor
A new instance of SuperChatEventSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SuperChatEventSnippet
Returns a new instance of SuperChatEventSnippet.
7322 7323 7324 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount_micros ⇒ Fixnum
The purchase amount, in micros of the purchase currency. e.g., 1 is
represented as 1000000.
Corresponds to the JSON property amountMicros
7271 7272 7273 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7271 def amount_micros @amount_micros end |
#channel_id ⇒ String
Channel id where the event occurred.
Corresponds to the JSON property channelId
7276 7277 7278 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7276 def channel_id @channel_id end |
#comment_text ⇒ String
The text contents of the comment left by the user.
Corresponds to the JSON property commentText
7281 7282 7283 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7281 def comment_text @comment_text end |
#created_at ⇒ DateTime
The date and time when the event occurred.
Corresponds to the JSON property createdAt
7286 7287 7288 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7286 def created_at @created_at end |
#currency ⇒ String
The currency in which the purchase was made. ISO 4217.
Corresponds to the JSON property currency
7291 7292 7293 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7291 def currency @currency end |
#display_string ⇒ String
A rendered string that displays the purchase amount and currency (e.g., "$1.00"
). The string is rendered for the given language.
Corresponds to the JSON property displayString
7297 7298 7299 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7297 def display_string @display_string end |
#is_super_sticker_event ⇒ Boolean Also known as: is_super_sticker_event?
True if this event is a Super Sticker event.
Corresponds to the JSON property isSuperStickerEvent
7302 7303 7304 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7302 def is_super_sticker_event @is_super_sticker_event end |
#message_type ⇒ Fixnum
The tier for the paid message, which is based on the amount of money spent to
purchase the message.
Corresponds to the JSON property messageType
7309 7310 7311 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7309 def @message_type end |
#super_sticker_metadata ⇒ Google::Apis::YoutubeV3::SuperStickerMetadata
If this event is a Super Sticker event, this field will contain metadata about
the Super Sticker.
Corresponds to the JSON property superStickerMetadata
7315 7316 7317 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7315 def @super_sticker_metadata end |
#supporter_details ⇒ Google::Apis::YoutubeV3::ChannelProfileDetails
Details about the supporter.
Corresponds to the JSON property supporterDetails
7320 7321 7322 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7320 def supporter_details @supporter_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7327 7328 7329 7330 7331 7332 7333 7334 7335 7336 7337 7338 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7327 def update!(**args) @amount_micros = args[:amount_micros] if args.key?(:amount_micros) @channel_id = args[:channel_id] if args.key?(:channel_id) @comment_text = args[:comment_text] if args.key?(:comment_text) @created_at = args[:created_at] if args.key?(:created_at) @currency = args[:currency] if args.key?(:currency) @display_string = args[:display_string] if args.key?(:display_string) @is_super_sticker_event = args[:is_super_sticker_event] if args.key?(:is_super_sticker_event) @message_type = args[:message_type] if args.key?(:message_type) @super_sticker_metadata = args[:super_sticker_metadata] if args.key?(:super_sticker_metadata) @supporter_details = args[:supporter_details] if args.key?(:supporter_details) end |