Class: Google::Apis::YoutubeV3::SuperStickerMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SuperStickerMetadata

Returns a new instance of SuperStickerMetadata.



7362
7363
7364
# File 'lib/google/apis/youtube_v3/classes.rb', line 7362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alt_textString

Internationalized alt text that describes the sticker image and any animation associated with it. Corresponds to the JSON property altText

Returns:

  • (String)


7349
7350
7351
# File 'lib/google/apis/youtube_v3/classes.rb', line 7349

def alt_text
  @alt_text
end

#alt_text_languageString

Specifies the localization language in which the alt text is returned. Corresponds to the JSON property altTextLanguage

Returns:

  • (String)


7354
7355
7356
# File 'lib/google/apis/youtube_v3/classes.rb', line 7354

def alt_text_language
  @alt_text_language
end

#sticker_idString

Unique identifier of the Super Sticker. This is a shorter form of the alt_text that includes pack name and a recognizable characteristic of the sticker. Corresponds to the JSON property stickerId

Returns:

  • (String)


7360
7361
7362
# File 'lib/google/apis/youtube_v3/classes.rb', line 7360

def sticker_id
  @sticker_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7367
7368
7369
7370
7371
# File 'lib/google/apis/youtube_v3/classes.rb', line 7367

def update!(**args)
  @alt_text = args[:alt_text] if args.key?(:alt_text)
  @alt_text_language = args[:alt_text_language] if args.key?(:alt_text_language)
  @sticker_id = args[:sticker_id] if args.key?(:sticker_id)
end