Class: Google::Apis::YoutubeV3::ThirdPartyLink

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A third party account link resource represents a link between a YouTube account or a channel and an account on a third-party service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyLink

Returns a new instance of ThirdPartyLink.



7573
7574
7575
# File 'lib/google/apis/youtube_v3/classes.rb', line 7573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource Corresponds to the JSON property etag

Returns:

  • (String)


7547
7548
7549
# File 'lib/google/apis/youtube_v3/classes.rb', line 7547

def etag
  @etag
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# thirdPartyLink". Corresponds to the JSON property kind

Returns:

  • (String)


7553
7554
7555
# File 'lib/google/apis/youtube_v3/classes.rb', line 7553

def kind
  @kind
end

#linking_tokenString

The linking_token identifies a YouTube account and channel with which the third party account is linked. Corresponds to the JSON property linkingToken

Returns:

  • (String)


7559
7560
7561
# File 'lib/google/apis/youtube_v3/classes.rb', line 7559

def linking_token
  @linking_token
end

#snippetGoogle::Apis::YoutubeV3::ThirdPartyLinkSnippet

Basic information about a third party account link, including its type and type-specific information. Corresponds to the JSON property snippet



7565
7566
7567
# File 'lib/google/apis/youtube_v3/classes.rb', line 7565

def snippet
  @snippet
end

#statusGoogle::Apis::YoutubeV3::ThirdPartyLinkStatus

The third-party link status object contains information about the status of the link. Corresponds to the JSON property status



7571
7572
7573
# File 'lib/google/apis/youtube_v3/classes.rb', line 7571

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7578
7579
7580
7581
7582
7583
7584
# File 'lib/google/apis/youtube_v3/classes.rb', line 7578

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @linking_token = args[:linking_token] if args.key?(:linking_token)
  @snippet = args[:snippet] if args.key?(:snippet)
  @status = args[:status] if args.key?(:status)
end