Class: Google::Apis::YoutubeV3::ThirdPartyLinkSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic information about a third party account link, including its type and type-specific information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyLinkSnippet

Returns a new instance of ThirdPartyLinkSnippet.



7667
7668
7669
# File 'lib/google/apis/youtube_v3/classes.rb', line 7667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Information specific to a creator in an affiliate program linked to a YouTube channel. Corresponds to the JSON property channelToAffiliateProgramLink



7654
7655
7656
# File 'lib/google/apis/youtube_v3/classes.rb', line 7654

def channel_to_affiliate_program_link
  @channel_to_affiliate_program_link
end

Information specific to a store on a merchandising platform linked to a YouTube channel. Corresponds to the JSON property channelToStoreLink



7660
7661
7662
# File 'lib/google/apis/youtube_v3/classes.rb', line 7660

def channel_to_store_link
  @channel_to_store_link
end

#typeString

Type of the link named after the entities that are being linked. Corresponds to the JSON property type

Returns:

  • (String)


7665
7666
7667
# File 'lib/google/apis/youtube_v3/classes.rb', line 7665

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7672
7673
7674
7675
7676
# File 'lib/google/apis/youtube_v3/classes.rb', line 7672

def update!(**args)
  @channel_to_affiliate_program_link = args[:channel_to_affiliate_program_link] if args.key?(:channel_to_affiliate_program_link)
  @channel_to_store_link = args[:channel_to_store_link] if args.key?(:channel_to_store_link)
  @type = args[:type] if args.key?(:type)
end