Class: Google::Apis::YoutubeV3::ThirdPartyLinkSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic information about a third party account link, including its type and type-specific information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ThirdPartyLinkSnippet

Returns a new instance of ThirdPartyLinkSnippet.



7561
7562
7563
# File 'lib/google/apis/youtube_v3/classes.rb', line 7561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Information specific to a store on a merchandising platform linked to a YouTube channel. Corresponds to the JSON property channelToStoreLink



7554
7555
7556
# File 'lib/google/apis/youtube_v3/classes.rb', line 7554

def channel_to_store_link
  @channel_to_store_link
end

#typeString

Type of the link named after the entities that are being linked. Corresponds to the JSON property type

Returns:

  • (String)


7559
7560
7561
# File 'lib/google/apis/youtube_v3/classes.rb', line 7559

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7566
7567
7568
7569
# File 'lib/google/apis/youtube_v3/classes.rb', line 7566

def update!(**args)
  @channel_to_store_link = args[:channel_to_store_link] if args.key?(:channel_to_store_link)
  @type = args[:type] if args.key?(:type)
end