Class: Google::Apis::YoutubeV3::Video

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A video resource represents a YouTube video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Video

Returns a new instance of Video.



8097
8098
8099
# File 'lib/google/apis/youtube_v3/classes.rb', line 8097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_gatingGoogle::Apis::YoutubeV3::VideoAgeGating

Age restriction details related to a video. This data can only be retrieved by the video owner. Corresponds to the JSON property ageGating



7981
7982
7983
# File 'lib/google/apis/youtube_v3/classes.rb', line 7981

def age_gating
  @age_gating
end

#brand_partnerGoogle::Apis::YoutubeV3::BrandPartner

Details about the brand partner linked to the video for Creator Initiated Linking (CIL). Next ID: 6 Corresponds to the JSON property brandPartner



7987
7988
7989
# File 'lib/google/apis/youtube_v3/classes.rb', line 7987

def brand_partner
  @brand_partner
end

#content_detailsGoogle::Apis::YoutubeV3::VideoContentDetails

Details about the content of a YouTube Video. Corresponds to the JSON property contentDetails



7992
7993
7994
# File 'lib/google/apis/youtube_v3/classes.rb', line 7992

def content_details
  @content_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7997
7998
7999
# File 'lib/google/apis/youtube_v3/classes.rb', line 7997

def etag
  @etag
end

#file_detailsGoogle::Apis::YoutubeV3::VideoFileDetails

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information. Corresponds to the JSON property fileDetails



8004
8005
8006
# File 'lib/google/apis/youtube_v3/classes.rb', line 8004

def file_details
  @file_details
end

#idString

The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


8009
8010
8011
# File 'lib/google/apis/youtube_v3/classes.rb', line 8009

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# video". Corresponds to the JSON property kind

Returns:

  • (String)


8015
8016
8017
# File 'lib/google/apis/youtube_v3/classes.rb', line 8015

def kind
  @kind
end

#live_streaming_detailsGoogle::Apis::YoutubeV3::VideoLiveStreamingDetails

Details about the live streaming metadata. Corresponds to the JSON property liveStreamingDetails



8020
8021
8022
# File 'lib/google/apis/youtube_v3/classes.rb', line 8020

def live_streaming_details
  @live_streaming_details
end

#localizationsHash<String,Google::Apis::YoutubeV3::VideoLocalization>

The localizations object contains localized versions of the basic details about the video, such as its title and description. Corresponds to the JSON property localizations



8026
8027
8028
# File 'lib/google/apis/youtube_v3/classes.rb', line 8026

def localizations
  @localizations
end

#monetization_detailsGoogle::Apis::YoutubeV3::VideoMonetizationDetails

Details about monetization of a YouTube Video. Corresponds to the JSON property monetizationDetails



8031
8032
8033
# File 'lib/google/apis/youtube_v3/classes.rb', line 8031

def monetization_details
  @monetization_details
end

Details about paid content, such as paid product placement, sponsorships or endorsement, contained in a YouTube video and a method to inform viewers of paid promotion. This data can only be retrieved by the video owner. Corresponds to the JSON property paidProductPlacementDetails



8038
8039
8040
# File 'lib/google/apis/youtube_v3/classes.rb', line 8038

def paid_product_placement_details
  @paid_product_placement_details
end

#playerGoogle::Apis::YoutubeV3::VideoPlayer

Player to be used for a video playback. Corresponds to the JSON property player



8043
8044
8045
# File 'lib/google/apis/youtube_v3/classes.rb', line 8043

def player
  @player
end

#processing_detailsGoogle::Apis::YoutubeV3::VideoProcessingDetails

Describes processing status and progress and availability of some other Video resource parts. Corresponds to the JSON property processingDetails



8049
8050
8051
# File 'lib/google/apis/youtube_v3/classes.rb', line 8049

def processing_details
  @processing_details
end

#project_detailsGoogle::Apis::YoutubeV3::VideoProjectDetails

DEPRECATED. b/157517979: This part was never populated after it was added. However, it sees non-zero traffic because there is generated client code in the wild that refers to it [1]. We keep this field and do NOT remove it because otherwise V3 would return an error when this part gets requested [2]. [ 1] https://developers.google.com/resources/api-libraries/documentation/youtube/ v3/csharp/latest/ classGoogle_1_1Apis_1_1YouTube_1_1v3_1_1Data_1_1VideoProjectDetails.html [2] http://google3/video/youtube/src/python/servers/data_api/common.py?l=1565-1569& rcl=344141677 Corresponds to the JSON property projectDetails



8062
8063
8064
# File 'lib/google/apis/youtube_v3/classes.rb', line 8062

def project_details
  @project_details
end

#recording_detailsGoogle::Apis::YoutubeV3::VideoRecordingDetails

Recording information associated with the video. Corresponds to the JSON property recordingDetails



8067
8068
8069
# File 'lib/google/apis/youtube_v3/classes.rb', line 8067

def recording_details
  @recording_details
end

#snippetGoogle::Apis::YoutubeV3::VideoSnippet

Basic details about a video, including title, description, uploader, thumbnails and category. Corresponds to the JSON property snippet



8073
8074
8075
# File 'lib/google/apis/youtube_v3/classes.rb', line 8073

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



8079
8080
8081
# File 'lib/google/apis/youtube_v3/classes.rb', line 8079

def statistics
  @statistics
end

#statusGoogle::Apis::YoutubeV3::VideoStatus

Basic details about a video category, such as its localized title. Next Id: 19 Corresponds to the JSON property status



8084
8085
8086
# File 'lib/google/apis/youtube_v3/classes.rb', line 8084

def status
  @status
end

#suggestionsGoogle::Apis::YoutubeV3::VideoSuggestions

Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions. Corresponds to the JSON property suggestions



8090
8091
8092
# File 'lib/google/apis/youtube_v3/classes.rb', line 8090

def suggestions
  @suggestions
end

#topic_detailsGoogle::Apis::YoutubeV3::VideoTopicDetails

Freebase topic information related to the video. Corresponds to the JSON property topicDetails



8095
8096
8097
# File 'lib/google/apis/youtube_v3/classes.rb', line 8095

def topic_details
  @topic_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8102
8103
8104
8105
8106
8107
8108
8109
8110
8111
8112
8113
8114
8115
8116
8117
8118
8119
8120
8121
8122
8123
# File 'lib/google/apis/youtube_v3/classes.rb', line 8102

def update!(**args)
  @age_gating = args[:age_gating] if args.key?(:age_gating)
  @brand_partner = args[:brand_partner] if args.key?(:brand_partner)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @file_details = args[:file_details] if args.key?(:file_details)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @live_streaming_details = args[:live_streaming_details] if args.key?(:live_streaming_details)
  @localizations = args[:localizations] if args.key?(:localizations)
  @monetization_details = args[:monetization_details] if args.key?(:monetization_details)
  @paid_product_placement_details = args[:paid_product_placement_details] if args.key?(:paid_product_placement_details)
  @player = args[:player] if args.key?(:player)
  @processing_details = args[:processing_details] if args.key?(:processing_details)
  @project_details = args[:project_details] if args.key?(:project_details)
  @recording_details = args[:recording_details] if args.key?(:recording_details)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
  @status = args[:status] if args.key?(:status)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @topic_details = args[:topic_details] if args.key?(:topic_details)
end