Class: Google::Apis::YoutubeV3::Video
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Video
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A video resource represents a YouTube video.
Instance Attribute Summary collapse
-
#age_gating ⇒ Google::Apis::YoutubeV3::VideoAgeGating
Age restriction details related to a video.
-
#brand_partner ⇒ Google::Apis::YoutubeV3::BrandPartner
Details about the brand partner linked to the video for Creator Initiated Linking (CIL).
-
#content_details ⇒ Google::Apis::YoutubeV3::VideoContentDetails
Details about the content of a YouTube Video.
-
#etag ⇒ String
Etag of this resource.
-
#file_details ⇒ Google::Apis::YoutubeV3::VideoFileDetails
Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the video.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#live_streaming_details ⇒ Google::Apis::YoutubeV3::VideoLiveStreamingDetails
Details about the live streaming metadata.
-
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::VideoLocalization>
The localizations object contains localized versions of the basic details about the video, such as its title and description.
-
#monetization_details ⇒ Google::Apis::YoutubeV3::VideoMonetizationDetails
Details about monetization of a YouTube Video.
-
#paid_product_placement_details ⇒ Google::Apis::YoutubeV3::VideoPaidProductPlacementDetails
Details about paid content, such as paid product placement, sponsorships or endorsement, contained in a YouTube video and a method to inform viewers of paid promotion.
-
#player ⇒ Google::Apis::YoutubeV3::VideoPlayer
Player to be used for a video playback.
-
#processing_details ⇒ Google::Apis::YoutubeV3::VideoProcessingDetails
Describes processing status and progress and availability of some other Video resource parts.
-
#project_details ⇒ Google::Apis::YoutubeV3::VideoProjectDetails
DEPRECATED.
-
#recording_details ⇒ Google::Apis::YoutubeV3::VideoRecordingDetails
Recording information associated with the video.
-
#snippet ⇒ Google::Apis::YoutubeV3::VideoSnippet
Basic details about a video, including title, description, uploader, thumbnails and category.
-
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatistics
Statistics about the video, such as the number of times the video was viewed or liked.
-
#status ⇒ Google::Apis::YoutubeV3::VideoStatus
Basic details about a video category, such as its localized title.
-
#suggestions ⇒ Google::Apis::YoutubeV3::VideoSuggestions
Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions.
-
#topic_details ⇒ Google::Apis::YoutubeV3::VideoTopicDetails
Freebase topic information related to the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Video
constructor
A new instance of Video.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Video
Returns a new instance of Video.
8093 8094 8095 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8093 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_gating ⇒ Google::Apis::YoutubeV3::VideoAgeGating
Age restriction details related to a video. This data can only be retrieved by
the video owner.
Corresponds to the JSON property ageGating
7977 7978 7979 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7977 def age_gating @age_gating end |
#brand_partner ⇒ Google::Apis::YoutubeV3::BrandPartner
Details about the brand partner linked to the video for Creator Initiated
Linking (CIL). Next ID: 6
Corresponds to the JSON property brandPartner
7983 7984 7985 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7983 def brand_partner @brand_partner end |
#content_details ⇒ Google::Apis::YoutubeV3::VideoContentDetails
Details about the content of a YouTube Video.
Corresponds to the JSON property contentDetails
7988 7989 7990 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7988 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7993 7994 7995 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7993 def etag @etag end |
#file_details ⇒ Google::Apis::YoutubeV3::VideoFileDetails
Describes original video file properties, including technical details about
audio and video streams, but also metadata information like content length,
digitization time, or geotagging information.
Corresponds to the JSON property fileDetails
8000 8001 8002 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8000 def file_details @file_details end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the video.
Corresponds to the JSON property id
8005 8006 8007 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8005 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
video".
Corresponds to the JSON property kind
8011 8012 8013 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8011 def kind @kind end |
#live_streaming_details ⇒ Google::Apis::YoutubeV3::VideoLiveStreamingDetails
Details about the live streaming metadata.
Corresponds to the JSON property liveStreamingDetails
8016 8017 8018 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8016 def live_streaming_details @live_streaming_details end |
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::VideoLocalization>
The localizations object contains localized versions of the basic details
about the video, such as its title and description.
Corresponds to the JSON property localizations
8022 8023 8024 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8022 def localizations @localizations end |
#monetization_details ⇒ Google::Apis::YoutubeV3::VideoMonetizationDetails
Details about monetization of a YouTube Video.
Corresponds to the JSON property monetizationDetails
8027 8028 8029 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8027 def monetization_details @monetization_details end |
#paid_product_placement_details ⇒ Google::Apis::YoutubeV3::VideoPaidProductPlacementDetails
Details about paid content, such as paid product placement, sponsorships or
endorsement, contained in a YouTube video and a method to inform viewers of
paid promotion. This data can only be retrieved by the video owner.
Corresponds to the JSON property paidProductPlacementDetails
8034 8035 8036 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8034 def paid_product_placement_details @paid_product_placement_details end |
#player ⇒ Google::Apis::YoutubeV3::VideoPlayer
Player to be used for a video playback.
Corresponds to the JSON property player
8039 8040 8041 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8039 def player @player end |
#processing_details ⇒ Google::Apis::YoutubeV3::VideoProcessingDetails
Describes processing status and progress and availability of some other Video
resource parts.
Corresponds to the JSON property processingDetails
8045 8046 8047 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8045 def processing_details @processing_details end |
#project_details ⇒ Google::Apis::YoutubeV3::VideoProjectDetails
DEPRECATED. b/157517979: This part was never populated after it was added.
However, it sees non-zero traffic because there is generated client code in
the wild that refers to it [1]. We keep this field and do NOT remove it
because otherwise V3 would return an error when this part gets requested [2]. [
1] https://developers.google.com/resources/api-libraries/documentation/youtube/
v3/csharp/latest/
classGoogle_1_1Apis_1_1YouTube_1_1v3_1_1Data_1_1VideoProjectDetails.html [2]
http://google3/video/youtube/src/python/servers/data_api/common.py?l=1565-1569&
rcl=344141677
Corresponds to the JSON property projectDetails
8058 8059 8060 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8058 def project_details @project_details end |
#recording_details ⇒ Google::Apis::YoutubeV3::VideoRecordingDetails
Recording information associated with the video.
Corresponds to the JSON property recordingDetails
8063 8064 8065 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8063 def recording_details @recording_details end |
#snippet ⇒ Google::Apis::YoutubeV3::VideoSnippet
Basic details about a video, including title, description, uploader,
thumbnails and category.
Corresponds to the JSON property snippet
8069 8070 8071 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8069 def snippet @snippet end |
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatistics
Statistics about the video, such as the number of times the video was viewed
or liked.
Corresponds to the JSON property statistics
8075 8076 8077 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8075 def statistics @statistics end |
#status ⇒ Google::Apis::YoutubeV3::VideoStatus
Basic details about a video category, such as its localized title. Next Id: 19
Corresponds to the JSON property status
8080 8081 8082 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8080 def status @status end |
#suggestions ⇒ Google::Apis::YoutubeV3::VideoSuggestions
Specifies suggestions on how to improve video content, including encoding
hints, tag suggestions, and editor suggestions.
Corresponds to the JSON property suggestions
8086 8087 8088 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8086 def suggestions @suggestions end |
#topic_details ⇒ Google::Apis::YoutubeV3::VideoTopicDetails
Freebase topic information related to the video.
Corresponds to the JSON property topicDetails
8091 8092 8093 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8091 def topic_details @topic_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8098 8099 8100 8101 8102 8103 8104 8105 8106 8107 8108 8109 8110 8111 8112 8113 8114 8115 8116 8117 8118 8119 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8098 def update!(**args) @age_gating = args[:age_gating] if args.key?(:age_gating) @brand_partner = args[:brand_partner] if args.key?(:brand_partner) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @file_details = args[:file_details] if args.key?(:file_details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @live_streaming_details = args[:live_streaming_details] if args.key?(:live_streaming_details) @localizations = args[:localizations] if args.key?(:localizations) @monetization_details = args[:monetization_details] if args.key?(:monetization_details) @paid_product_placement_details = args[:paid_product_placement_details] if args.key?(:paid_product_placement_details) @player = args[:player] if args.key?(:player) @processing_details = args[:processing_details] if args.key?(:processing_details) @project_details = args[:project_details] if args.key?(:project_details) @recording_details = args[:recording_details] if args.key?(:recording_details) @snippet = args[:snippet] if args.key?(:snippet) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @suggestions = args[:suggestions] if args.key?(:suggestions) @topic_details = args[:topic_details] if args.key?(:topic_details) end |