Class: Google::Apis::YoutubeV3::Video

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A video resource represents a YouTube video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Video

Returns a new instance of Video.



7954
7955
7956
# File 'lib/google/apis/youtube_v3/classes.rb', line 7954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_gatingGoogle::Apis::YoutubeV3::VideoAgeGating

Age restriction details related to a video. This data can only be retrieved by the video owner. Corresponds to the JSON property ageGating



7838
7839
7840
# File 'lib/google/apis/youtube_v3/classes.rb', line 7838

def age_gating
  @age_gating
end

#brand_partnerGoogle::Apis::YoutubeV3::BrandPartner

Details about the brand partner linked to the video for Creator Initiated Linking (CIL). Next ID: 6 Corresponds to the JSON property brandPartner



7844
7845
7846
# File 'lib/google/apis/youtube_v3/classes.rb', line 7844

def brand_partner
  @brand_partner
end

#content_detailsGoogle::Apis::YoutubeV3::VideoContentDetails

Details about the content of a YouTube Video. Corresponds to the JSON property contentDetails



7849
7850
7851
# File 'lib/google/apis/youtube_v3/classes.rb', line 7849

def content_details
  @content_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7854
7855
7856
# File 'lib/google/apis/youtube_v3/classes.rb', line 7854

def etag
  @etag
end

#file_detailsGoogle::Apis::YoutubeV3::VideoFileDetails

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information. Corresponds to the JSON property fileDetails



7861
7862
7863
# File 'lib/google/apis/youtube_v3/classes.rb', line 7861

def file_details
  @file_details
end

#idString

The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


7866
7867
7868
# File 'lib/google/apis/youtube_v3/classes.rb', line 7866

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# video". Corresponds to the JSON property kind

Returns:

  • (String)


7872
7873
7874
# File 'lib/google/apis/youtube_v3/classes.rb', line 7872

def kind
  @kind
end

#live_streaming_detailsGoogle::Apis::YoutubeV3::VideoLiveStreamingDetails

Details about the live streaming metadata. Corresponds to the JSON property liveStreamingDetails



7877
7878
7879
# File 'lib/google/apis/youtube_v3/classes.rb', line 7877

def live_streaming_details
  @live_streaming_details
end

#localizationsHash<String,Google::Apis::YoutubeV3::VideoLocalization>

The localizations object contains localized versions of the basic details about the video, such as its title and description. Corresponds to the JSON property localizations



7883
7884
7885
# File 'lib/google/apis/youtube_v3/classes.rb', line 7883

def localizations
  @localizations
end

#monetization_detailsGoogle::Apis::YoutubeV3::VideoMonetizationDetails

Details about monetization of a YouTube Video. Corresponds to the JSON property monetizationDetails



7888
7889
7890
# File 'lib/google/apis/youtube_v3/classes.rb', line 7888

def monetization_details
  @monetization_details
end

Details about paid content, such as paid product placement, sponsorships or endorsement, contained in a YouTube video and a method to inform viewers of paid promotion. This data can only be retrieved by the video owner. Corresponds to the JSON property paidProductPlacementDetails



7895
7896
7897
# File 'lib/google/apis/youtube_v3/classes.rb', line 7895

def paid_product_placement_details
  @paid_product_placement_details
end

#playerGoogle::Apis::YoutubeV3::VideoPlayer

Player to be used for a video playback. Corresponds to the JSON property player



7900
7901
7902
# File 'lib/google/apis/youtube_v3/classes.rb', line 7900

def player
  @player
end

#processing_detailsGoogle::Apis::YoutubeV3::VideoProcessingDetails

Describes processing status and progress and availability of some other Video resource parts. Corresponds to the JSON property processingDetails



7906
7907
7908
# File 'lib/google/apis/youtube_v3/classes.rb', line 7906

def processing_details
  @processing_details
end

#project_detailsGoogle::Apis::YoutubeV3::VideoProjectDetails

DEPRECATED. b/157517979: This part was never populated after it was added. However, it sees non-zero traffic because there is generated client code in the wild that refers to it [1]. We keep this field and do NOT remove it because otherwise V3 would return an error when this part gets requested [2]. [ 1] https://developers.google.com/resources/api-libraries/documentation/youtube/ v3/csharp/latest/ classGoogle_1_1Apis_1_1YouTube_1_1v3_1_1Data_1_1VideoProjectDetails.html [2] http://google3/video/youtube/src/python/servers/data_api/common.py?l=1565-1569& rcl=344141677 Corresponds to the JSON property projectDetails



7919
7920
7921
# File 'lib/google/apis/youtube_v3/classes.rb', line 7919

def project_details
  @project_details
end

#recording_detailsGoogle::Apis::YoutubeV3::VideoRecordingDetails

Recording information associated with the video. Corresponds to the JSON property recordingDetails



7924
7925
7926
# File 'lib/google/apis/youtube_v3/classes.rb', line 7924

def recording_details
  @recording_details
end

#snippetGoogle::Apis::YoutubeV3::VideoSnippet

Basic details about a video, including title, description, uploader, thumbnails and category. Corresponds to the JSON property snippet



7930
7931
7932
# File 'lib/google/apis/youtube_v3/classes.rb', line 7930

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



7936
7937
7938
# File 'lib/google/apis/youtube_v3/classes.rb', line 7936

def statistics
  @statistics
end

#statusGoogle::Apis::YoutubeV3::VideoStatus

Basic details about a video category, such as its localized title. Next Id: 19 Corresponds to the JSON property status



7941
7942
7943
# File 'lib/google/apis/youtube_v3/classes.rb', line 7941

def status
  @status
end

#suggestionsGoogle::Apis::YoutubeV3::VideoSuggestions

Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions. Corresponds to the JSON property suggestions



7947
7948
7949
# File 'lib/google/apis/youtube_v3/classes.rb', line 7947

def suggestions
  @suggestions
end

#topic_detailsGoogle::Apis::YoutubeV3::VideoTopicDetails

Freebase topic information related to the video. Corresponds to the JSON property topicDetails



7952
7953
7954
# File 'lib/google/apis/youtube_v3/classes.rb', line 7952

def topic_details
  @topic_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7959
7960
7961
7962
7963
7964
7965
7966
7967
7968
7969
7970
7971
7972
7973
7974
7975
7976
7977
7978
7979
7980
# File 'lib/google/apis/youtube_v3/classes.rb', line 7959

def update!(**args)
  @age_gating = args[:age_gating] if args.key?(:age_gating)
  @brand_partner = args[:brand_partner] if args.key?(:brand_partner)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @file_details = args[:file_details] if args.key?(:file_details)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @live_streaming_details = args[:live_streaming_details] if args.key?(:live_streaming_details)
  @localizations = args[:localizations] if args.key?(:localizations)
  @monetization_details = args[:monetization_details] if args.key?(:monetization_details)
  @paid_product_placement_details = args[:paid_product_placement_details] if args.key?(:paid_product_placement_details)
  @player = args[:player] if args.key?(:player)
  @processing_details = args[:processing_details] if args.key?(:processing_details)
  @project_details = args[:project_details] if args.key?(:project_details)
  @recording_details = args[:recording_details] if args.key?(:recording_details)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
  @status = args[:status] if args.key?(:status)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @topic_details = args[:topic_details] if args.key?(:topic_details)
end