Class: Google::Apis::YoutubeV3::Video
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::Video
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A video resource represents a YouTube video.
Instance Attribute Summary collapse
-
#age_gating ⇒ Google::Apis::YoutubeV3::VideoAgeGating
Age restriction details related to a video.
-
#content_details ⇒ Google::Apis::YoutubeV3::VideoContentDetails
Details about the content of a YouTube Video.
-
#etag ⇒ String
Etag of this resource.
-
#file_details ⇒ Google::Apis::YoutubeV3::VideoFileDetails
Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the video.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#live_streaming_details ⇒ Google::Apis::YoutubeV3::VideoLiveStreamingDetails
Details about the live streaming metadata.
-
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::VideoLocalization>
The localizations object contains localized versions of the basic details about the video, such as its title and description.
-
#monetization_details ⇒ Google::Apis::YoutubeV3::VideoMonetizationDetails
Details about monetization of a YouTube Video.
-
#paid_product_placement_details ⇒ Google::Apis::YoutubeV3::VideoPaidProductPlacementDetails
Details about paid content, such as paid product placement, sponsorships or endorsement, contained in a YouTube video and a method to inform viewers of paid promotion.
-
#player ⇒ Google::Apis::YoutubeV3::VideoPlayer
Player to be used for a video playback.
-
#processing_details ⇒ Google::Apis::YoutubeV3::VideoProcessingDetails
Describes processing status and progress and availability of some other Video resource parts.
-
#project_details ⇒ Google::Apis::YoutubeV3::VideoProjectDetails
DEPRECATED.
-
#recording_details ⇒ Google::Apis::YoutubeV3::VideoRecordingDetails
Recording information associated with the video.
-
#snippet ⇒ Google::Apis::YoutubeV3::VideoSnippet
Basic details about a video, including title, description, uploader, thumbnails and category.
-
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatistics
Statistics about the video, such as the number of times the video was viewed or liked.
-
#status ⇒ Google::Apis::YoutubeV3::VideoStatus
Basic details about a video category, such as its localized title.
-
#suggestions ⇒ Google::Apis::YoutubeV3::VideoSuggestions
Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions.
-
#topic_details ⇒ Google::Apis::YoutubeV3::VideoTopicDetails
Freebase topic information related to the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Video
constructor
A new instance of Video.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Video
Returns a new instance of Video.
7841 7842 7843 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#age_gating ⇒ Google::Apis::YoutubeV3::VideoAgeGating
Age restriction details related to a video. This data can only be retrieved by
the video owner.
Corresponds to the JSON property ageGating
7731 7732 7733 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7731 def age_gating @age_gating end |
#content_details ⇒ Google::Apis::YoutubeV3::VideoContentDetails
Details about the content of a YouTube Video.
Corresponds to the JSON property contentDetails
7736 7737 7738 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7736 def content_details @content_details end |
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
7741 7742 7743 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7741 def etag @etag end |
#file_details ⇒ Google::Apis::YoutubeV3::VideoFileDetails
Describes original video file properties, including technical details about
audio and video streams, but also metadata information like content length,
digitization time, or geotagging information.
Corresponds to the JSON property fileDetails
7748 7749 7750 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7748 def file_details @file_details end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the video.
Corresponds to the JSON property id
7753 7754 7755 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7753 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
video".
Corresponds to the JSON property kind
7759 7760 7761 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7759 def kind @kind end |
#live_streaming_details ⇒ Google::Apis::YoutubeV3::VideoLiveStreamingDetails
Details about the live streaming metadata.
Corresponds to the JSON property liveStreamingDetails
7764 7765 7766 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7764 def live_streaming_details @live_streaming_details end |
#localizations ⇒ Hash<String,Google::Apis::YoutubeV3::VideoLocalization>
The localizations object contains localized versions of the basic details
about the video, such as its title and description.
Corresponds to the JSON property localizations
7770 7771 7772 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7770 def localizations @localizations end |
#monetization_details ⇒ Google::Apis::YoutubeV3::VideoMonetizationDetails
Details about monetization of a YouTube Video.
Corresponds to the JSON property monetizationDetails
7775 7776 7777 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7775 def monetization_details @monetization_details end |
#paid_product_placement_details ⇒ Google::Apis::YoutubeV3::VideoPaidProductPlacementDetails
Details about paid content, such as paid product placement, sponsorships or
endorsement, contained in a YouTube video and a method to inform viewers of
paid promotion. This data can only be retrieved by the video owner.
Corresponds to the JSON property paidProductPlacementDetails
7782 7783 7784 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7782 def paid_product_placement_details @paid_product_placement_details end |
#player ⇒ Google::Apis::YoutubeV3::VideoPlayer
Player to be used for a video playback.
Corresponds to the JSON property player
7787 7788 7789 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7787 def player @player end |
#processing_details ⇒ Google::Apis::YoutubeV3::VideoProcessingDetails
Describes processing status and progress and availability of some other Video
resource parts.
Corresponds to the JSON property processingDetails
7793 7794 7795 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7793 def processing_details @processing_details end |
#project_details ⇒ Google::Apis::YoutubeV3::VideoProjectDetails
DEPRECATED. b/157517979: This part was never populated after it was added.
However, it sees non-zero traffic because there is generated client code in
the wild that refers to it [1]. We keep this field and do NOT remove it
because otherwise V3 would return an error when this part gets requested [2]. [
1] https://developers.google.com/resources/api-libraries/documentation/youtube/
v3/csharp/latest/
classGoogle_1_1Apis_1_1YouTube_1_1v3_1_1Data_1_1VideoProjectDetails.html [2]
http://google3/video/youtube/src/python/servers/data_api/common.py?l=1565-1569&
rcl=344141677
Corresponds to the JSON property projectDetails
7806 7807 7808 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7806 def project_details @project_details end |
#recording_details ⇒ Google::Apis::YoutubeV3::VideoRecordingDetails
Recording information associated with the video.
Corresponds to the JSON property recordingDetails
7811 7812 7813 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7811 def recording_details @recording_details end |
#snippet ⇒ Google::Apis::YoutubeV3::VideoSnippet
Basic details about a video, including title, description, uploader,
thumbnails and category.
Corresponds to the JSON property snippet
7817 7818 7819 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7817 def snippet @snippet end |
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatistics
Statistics about the video, such as the number of times the video was viewed
or liked.
Corresponds to the JSON property statistics
7823 7824 7825 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7823 def statistics @statistics end |
#status ⇒ Google::Apis::YoutubeV3::VideoStatus
Basic details about a video category, such as its localized title. Next Id: 19
Corresponds to the JSON property status
7828 7829 7830 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7828 def status @status end |
#suggestions ⇒ Google::Apis::YoutubeV3::VideoSuggestions
Specifies suggestions on how to improve video content, including encoding
hints, tag suggestions, and editor suggestions.
Corresponds to the JSON property suggestions
7834 7835 7836 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7834 def suggestions @suggestions end |
#topic_details ⇒ Google::Apis::YoutubeV3::VideoTopicDetails
Freebase topic information related to the video.
Corresponds to the JSON property topicDetails
7839 7840 7841 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7839 def topic_details @topic_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7846 7847 7848 7849 7850 7851 7852 7853 7854 7855 7856 7857 7858 7859 7860 7861 7862 7863 7864 7865 7866 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7846 def update!(**args) @age_gating = args[:age_gating] if args.key?(:age_gating) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @file_details = args[:file_details] if args.key?(:file_details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @live_streaming_details = args[:live_streaming_details] if args.key?(:live_streaming_details) @localizations = args[:localizations] if args.key?(:localizations) @monetization_details = args[:monetization_details] if args.key?(:monetization_details) @paid_product_placement_details = args[:paid_product_placement_details] if args.key?(:paid_product_placement_details) @player = args[:player] if args.key?(:player) @processing_details = args[:processing_details] if args.key?(:processing_details) @project_details = args[:project_details] if args.key?(:project_details) @recording_details = args[:recording_details] if args.key?(:recording_details) @snippet = args[:snippet] if args.key?(:snippet) @statistics = args[:statistics] if args.key?(:statistics) @status = args[:status] if args.key?(:status) @suggestions = args[:suggestions] if args.key?(:suggestions) @topic_details = args[:topic_details] if args.key?(:topic_details) end |