Class: Google::Apis::YoutubeV3::Video

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A video resource represents a YouTube video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Video

Returns a new instance of Video.



7807
7808
7809
# File 'lib/google/apis/youtube_v3/classes.rb', line 7807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#age_gatingGoogle::Apis::YoutubeV3::VideoAgeGating

Age restriction details related to a video. This data can only be retrieved by the video owner. Corresponds to the JSON property ageGating



7697
7698
7699
# File 'lib/google/apis/youtube_v3/classes.rb', line 7697

def age_gating
  @age_gating
end

#content_detailsGoogle::Apis::YoutubeV3::VideoContentDetails

Details about the content of a YouTube Video. Corresponds to the JSON property contentDetails



7702
7703
7704
# File 'lib/google/apis/youtube_v3/classes.rb', line 7702

def content_details
  @content_details
end

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


7707
7708
7709
# File 'lib/google/apis/youtube_v3/classes.rb', line 7707

def etag
  @etag
end

#file_detailsGoogle::Apis::YoutubeV3::VideoFileDetails

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information. Corresponds to the JSON property fileDetails



7714
7715
7716
# File 'lib/google/apis/youtube_v3/classes.rb', line 7714

def file_details
  @file_details
end

#idString

The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


7719
7720
7721
# File 'lib/google/apis/youtube_v3/classes.rb', line 7719

def id
  @id
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# video". Corresponds to the JSON property kind

Returns:

  • (String)


7725
7726
7727
# File 'lib/google/apis/youtube_v3/classes.rb', line 7725

def kind
  @kind
end

#live_streaming_detailsGoogle::Apis::YoutubeV3::VideoLiveStreamingDetails

Details about the live streaming metadata. Corresponds to the JSON property liveStreamingDetails



7730
7731
7732
# File 'lib/google/apis/youtube_v3/classes.rb', line 7730

def live_streaming_details
  @live_streaming_details
end

#localizationsHash<String,Google::Apis::YoutubeV3::VideoLocalization>

The localizations object contains localized versions of the basic details about the video, such as its title and description. Corresponds to the JSON property localizations



7736
7737
7738
# File 'lib/google/apis/youtube_v3/classes.rb', line 7736

def localizations
  @localizations
end

#monetization_detailsGoogle::Apis::YoutubeV3::VideoMonetizationDetails

Details about monetization of a YouTube Video. Corresponds to the JSON property monetizationDetails



7741
7742
7743
# File 'lib/google/apis/youtube_v3/classes.rb', line 7741

def monetization_details
  @monetization_details
end

Details about paid content, such as paid product placement, sponsorships or endorsement, contained in a YouTube video and a method to inform viewers of paid promotion. This data can only be retrieved by the video owner. Corresponds to the JSON property paidProductPlacementDetails



7748
7749
7750
# File 'lib/google/apis/youtube_v3/classes.rb', line 7748

def paid_product_placement_details
  @paid_product_placement_details
end

#playerGoogle::Apis::YoutubeV3::VideoPlayer

Player to be used for a video playback. Corresponds to the JSON property player



7753
7754
7755
# File 'lib/google/apis/youtube_v3/classes.rb', line 7753

def player
  @player
end

#processing_detailsGoogle::Apis::YoutubeV3::VideoProcessingDetails

Describes processing status and progress and availability of some other Video resource parts. Corresponds to the JSON property processingDetails



7759
7760
7761
# File 'lib/google/apis/youtube_v3/classes.rb', line 7759

def processing_details
  @processing_details
end

#project_detailsGoogle::Apis::YoutubeV3::VideoProjectDetails

DEPRECATED. b/157517979: This part was never populated after it was added. However, it sees non-zero traffic because there is generated client code in the wild that refers to it [1]. We keep this field and do NOT remove it because otherwise V3 would return an error when this part gets requested [2]. [ 1] https://developers.google.com/resources/api-libraries/documentation/youtube/ v3/csharp/latest/ classGoogle_1_1Apis_1_1YouTube_1_1v3_1_1Data_1_1VideoProjectDetails.html [2] http://google3/video/youtube/src/python/servers/data_api/common.py?l=1565-1569& rcl=344141677 Corresponds to the JSON property projectDetails



7772
7773
7774
# File 'lib/google/apis/youtube_v3/classes.rb', line 7772

def project_details
  @project_details
end

#recording_detailsGoogle::Apis::YoutubeV3::VideoRecordingDetails

Recording information associated with the video. Corresponds to the JSON property recordingDetails



7777
7778
7779
# File 'lib/google/apis/youtube_v3/classes.rb', line 7777

def recording_details
  @recording_details
end

#snippetGoogle::Apis::YoutubeV3::VideoSnippet

Basic details about a video, including title, description, uploader, thumbnails and category. Corresponds to the JSON property snippet



7783
7784
7785
# File 'lib/google/apis/youtube_v3/classes.rb', line 7783

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



7789
7790
7791
# File 'lib/google/apis/youtube_v3/classes.rb', line 7789

def statistics
  @statistics
end

#statusGoogle::Apis::YoutubeV3::VideoStatus

Basic details about a video category, such as its localized title. Next Id: 19 Corresponds to the JSON property status



7794
7795
7796
# File 'lib/google/apis/youtube_v3/classes.rb', line 7794

def status
  @status
end

#suggestionsGoogle::Apis::YoutubeV3::VideoSuggestions

Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions. Corresponds to the JSON property suggestions



7800
7801
7802
# File 'lib/google/apis/youtube_v3/classes.rb', line 7800

def suggestions
  @suggestions
end

#topic_detailsGoogle::Apis::YoutubeV3::VideoTopicDetails

Freebase topic information related to the video. Corresponds to the JSON property topicDetails



7805
7806
7807
# File 'lib/google/apis/youtube_v3/classes.rb', line 7805

def topic_details
  @topic_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7812
7813
7814
7815
7816
7817
7818
7819
7820
7821
7822
7823
7824
7825
7826
7827
7828
7829
7830
7831
7832
# File 'lib/google/apis/youtube_v3/classes.rb', line 7812

def update!(**args)
  @age_gating = args[:age_gating] if args.key?(:age_gating)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @file_details = args[:file_details] if args.key?(:file_details)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @live_streaming_details = args[:live_streaming_details] if args.key?(:live_streaming_details)
  @localizations = args[:localizations] if args.key?(:localizations)
  @monetization_details = args[:monetization_details] if args.key?(:monetization_details)
  @paid_product_placement_details = args[:paid_product_placement_details] if args.key?(:paid_product_placement_details)
  @player = args[:player] if args.key?(:player)
  @processing_details = args[:processing_details] if args.key?(:processing_details)
  @project_details = args[:project_details] if args.key?(:project_details)
  @recording_details = args[:recording_details] if args.key?(:recording_details)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
  @status = args[:status] if args.key?(:status)
  @suggestions = args[:suggestions] if args.key?(:suggestions)
  @topic_details = args[:topic_details] if args.key?(:topic_details)
end