Class: Google::Apis::YoutubeV3::VideoAbuseReportReasonSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video category, such as its localized title.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoAbuseReportReasonSnippet

Returns a new instance of VideoAbuseReportReasonSnippet.



8095
8096
8097
# File 'lib/google/apis/youtube_v3/classes.rb', line 8095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

The localized label belonging to this abuse report reason. Corresponds to the JSON property label

Returns:

  • (String)


8087
8088
8089
# File 'lib/google/apis/youtube_v3/classes.rb', line 8087

def label
  @label
end

#secondary_reasonsArray<Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason>

The secondary reasons associated with this reason, if any are available. ( There might be 0 or more.) Corresponds to the JSON property secondaryReasons



8093
8094
8095
# File 'lib/google/apis/youtube_v3/classes.rb', line 8093

def secondary_reasons
  @secondary_reasons
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8100
8101
8102
8103
# File 'lib/google/apis/youtube_v3/classes.rb', line 8100

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @secondary_reasons = args[:secondary_reasons] if args.key?(:secondary_reasons)
end