Class: Google::Apis::YoutubeV3::VideoAbuseReportReasonSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoAbuseReportReasonSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a video category, such as its localized title.
Instance Attribute Summary collapse
-
#label ⇒ String
The localized label belonging to this abuse report reason.
-
#secondary_reasons ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason>
The secondary reasons associated with this reason, if any are available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoAbuseReportReasonSnippet
constructor
A new instance of VideoAbuseReportReasonSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoAbuseReportReasonSnippet
Returns a new instance of VideoAbuseReportReasonSnippet.
8014 8015 8016 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label ⇒ String
The localized label belonging to this abuse report reason.
Corresponds to the JSON property label
8006 8007 8008 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8006 def label @label end |
#secondary_reasons ⇒ Array<Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason>
The secondary reasons associated with this reason, if any are available. (
There might be 0 or more.)
Corresponds to the JSON property secondaryReasons
8012 8013 8014 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8012 def secondary_reasons @secondary_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8019 8020 8021 8022 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8019 def update!(**args) @label = args[:label] if args.key?(:label) @secondary_reasons = args[:secondary_reasons] if args.key?(:secondary_reasons) end |