Class: Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoAbuseReportSecondaryReason
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of this abuse report secondary reason.
-
#label ⇒ String
The localized label for this abuse report secondary reason.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoAbuseReportSecondaryReason
constructor
A new instance of VideoAbuseReportSecondaryReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoAbuseReportSecondaryReason
Returns a new instance of VideoAbuseReportSecondaryReason.
8005 8006 8007 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The ID of this abuse report secondary reason.
Corresponds to the JSON property id
7998 7999 8000 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 7998 def id @id end |
#label ⇒ String
The localized label for this abuse report secondary reason.
Corresponds to the JSON property label
8003 8004 8005 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8003 def label @label end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8010 8011 8012 8013 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8010 def update!(**args) @id = args[:id] if args.key?(:id) @label = args[:label] if args.key?(:label) end |