Class: Google::Apis::YoutubeV3::VideoCategory
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A videoCategory resource identifies a category that has been or could be associated with uploaded videos.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#id ⇒ String
The ID that YouTube uses to uniquely identify the video category.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#snippet ⇒ Google::Apis::YoutubeV3::VideoCategorySnippet
Basic details about a video category, such as its localized title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoCategory
constructor
A new instance of VideoCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoCategory
Returns a new instance of VideoCategory.
8194 8195 8196 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
8176 8177 8178 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8176 def etag @etag end |
#id ⇒ String
The ID that YouTube uses to uniquely identify the video category.
Corresponds to the JSON property id
8181 8182 8183 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8181 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoCategory".
Corresponds to the JSON property kind
8187 8188 8189 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8187 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::VideoCategorySnippet
Basic details about a video category, such as its localized title.
Corresponds to the JSON property snippet
8192 8193 8194 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8192 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8199 8200 8201 8202 8203 8204 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8199 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) end |