Class: Google::Apis::YoutubeV3::VideoContentDetailsRegionRestriction
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoContentDetailsRegionRestriction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
DEPRECATED Region restriction of the video.
Instance Attribute Summary collapse
-
#allowed ⇒ Array<String>
A list of region codes that identify countries where the video is viewable.
-
#blocked ⇒ Array<String>
A list of region codes that identify countries where the video is blocked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoContentDetailsRegionRestriction
constructor
A new instance of VideoContentDetailsRegionRestriction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoContentDetailsRegionRestriction
Returns a new instance of VideoContentDetailsRegionRestriction.
8592 8593 8594 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Array<String>
A list of region codes that identify countries where the video is viewable. If
this property is present and a country is not listed in its value, then the
video is blocked from appearing in that country. If this property is present
and contains an empty list, the video is blocked in all countries.
Corresponds to the JSON property allowed
8582 8583 8584 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8582 def allowed @allowed end |
#blocked ⇒ Array<String>
A list of region codes that identify countries where the video is blocked. If
this property is present and a country is not listed in its value, then the
video is viewable in that country. If this property is present and contains an
empty list, the video is viewable in all countries.
Corresponds to the JSON property blocked
8590 8591 8592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8590 def blocked @blocked end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8597 8598 8599 8600 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8597 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @blocked = args[:blocked] if args.key?(:blocked) end |