Class: Google::Apis::YoutubeV3::VideoContentDetailsRegionRestriction
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoContentDetailsRegionRestriction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
DEPRECATED Region restriction of the video.
Instance Attribute Summary collapse
-
#allowed ⇒ Array<String>
A list of region codes that identify countries where the video is viewable.
-
#blocked ⇒ Array<String>
A list of region codes that identify countries where the video is blocked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoContentDetailsRegionRestriction
constructor
A new instance of VideoContentDetailsRegionRestriction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoContentDetailsRegionRestriction
Returns a new instance of VideoContentDetailsRegionRestriction.
8588 8589 8590 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Array<String>
A list of region codes that identify countries where the video is viewable. If
this property is present and a country is not listed in its value, then the
video is blocked from appearing in that country. If this property is present
and contains an empty list, the video is blocked in all countries.
Corresponds to the JSON property allowed
8578 8579 8580 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8578 def allowed @allowed end |
#blocked ⇒ Array<String>
A list of region codes that identify countries where the video is blocked. If
this property is present and a country is not listed in its value, then the
video is viewable in that country. If this property is present and contains an
empty list, the video is viewable in all countries.
Corresponds to the JSON property blocked
8586 8587 8588 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8586 def blocked @blocked end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8593 8594 8595 8596 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8593 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @blocked = args[:blocked] if args.key?(:blocked) end |