Class: Google::Apis::YoutubeV3::VideoFileDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoFileDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.
Instance Attribute Summary collapse
-
#audio_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>
A list of audio streams contained in the uploaded video file.
-
#bitrate_bps ⇒ Fixnum
The uploaded video file's combined (video and audio) bitrate in bits per second.
-
#container ⇒ String
The uploaded video file's container format.
-
#creation_time ⇒ String
The date and time when the uploaded video file was created.
-
#duration_ms ⇒ Fixnum
The length of the uploaded video in milliseconds.
-
#file_name ⇒ String
The uploaded file's name.
-
#file_size ⇒ Fixnum
The uploaded file's size in bytes.
-
#file_type ⇒ String
The uploaded file's type as detected by YouTube's video processing engine.
-
#video_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>
A list of video streams contained in the uploaded video file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFileDetails
constructor
A new instance of VideoFileDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFileDetails
Returns a new instance of VideoFileDetails.
8660 8661 8662 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>
A list of audio streams contained in the uploaded video file. Each item in the
list contains detailed metadata about an audio stream.
Corresponds to the JSON property audioStreams
8609 8610 8611 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8609 def audio_streams @audio_streams end |
#bitrate_bps ⇒ Fixnum
The uploaded video file's combined (video and audio) bitrate in bits per
second.
Corresponds to the JSON property bitrateBps
8615 8616 8617 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8615 def bitrate_bps @bitrate_bps end |
#container ⇒ String
The uploaded video file's container format.
Corresponds to the JSON property container
8620 8621 8622 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8620 def container @container end |
#creation_time ⇒ String
The date and time when the uploaded video file was created. The value is
specified in ISO 8601 format. Currently, the following ISO 8601 formats are
supported: - Date only: YYYY-MM-DD - Naive time: YYYY-MM-DDTHH:MM:SS - Time
with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM
Corresponds to the JSON property creationTime
8628 8629 8630 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8628 def creation_time @creation_time end |
#duration_ms ⇒ Fixnum
The length of the uploaded video in milliseconds.
Corresponds to the JSON property durationMs
8633 8634 8635 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8633 def duration_ms @duration_ms end |
#file_name ⇒ String
The uploaded file's name. This field is present whether a video file or
another type of file was uploaded.
Corresponds to the JSON property fileName
8639 8640 8641 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8639 def file_name @file_name end |
#file_size ⇒ Fixnum
The uploaded file's size in bytes. This field is present whether a video file
or another type of file was uploaded.
Corresponds to the JSON property fileSize
8645 8646 8647 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8645 def file_size @file_size end |
#file_type ⇒ String
The uploaded file's type as detected by YouTube's video processing engine.
Currently, YouTube only processes video files, but this field is present
whether a video file or another type of file was uploaded.
Corresponds to the JSON property fileType
8652 8653 8654 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8652 def file_type @file_type end |
#video_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>
A list of video streams contained in the uploaded video file. Each item in the
list contains detailed metadata about a video stream.
Corresponds to the JSON property videoStreams
8658 8659 8660 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8658 def video_streams @video_streams end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8665 def update!(**args) @audio_streams = args[:audio_streams] if args.key?(:audio_streams) @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps) @container = args[:container] if args.key?(:container) @creation_time = args[:creation_time] if args.key?(:creation_time) @duration_ms = args[:duration_ms] if args.key?(:duration_ms) @file_name = args[:file_name] if args.key?(:file_name) @file_size = args[:file_size] if args.key?(:file_size) @file_type = args[:file_type] if args.key?(:file_type) @video_streams = args[:video_streams] if args.key?(:video_streams) end |