Class: Google::Apis::YoutubeV3::VideoFileDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoFileDetails

Returns a new instance of VideoFileDetails.



8521
8522
8523
# File 'lib/google/apis/youtube_v3/classes.rb', line 8521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>

A list of audio streams contained in the uploaded video file. Each item in the list contains detailed metadata about an audio stream. Corresponds to the JSON property audioStreams



8470
8471
8472
# File 'lib/google/apis/youtube_v3/classes.rb', line 8470

def audio_streams
  @audio_streams
end

#bitrate_bpsFixnum

The uploaded video file's combined (video and audio) bitrate in bits per second. Corresponds to the JSON property bitrateBps

Returns:

  • (Fixnum)


8476
8477
8478
# File 'lib/google/apis/youtube_v3/classes.rb', line 8476

def bitrate_bps
  @bitrate_bps
end

#containerString

The uploaded video file's container format. Corresponds to the JSON property container

Returns:

  • (String)


8481
8482
8483
# File 'lib/google/apis/youtube_v3/classes.rb', line 8481

def container
  @container
end

#creation_timeString

The date and time when the uploaded video file was created. The value is specified in ISO 8601 format. Currently, the following ISO 8601 formats are supported: - Date only: YYYY-MM-DD - Naive time: YYYY-MM-DDTHH:MM:SS - Time with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM Corresponds to the JSON property creationTime

Returns:

  • (String)


8489
8490
8491
# File 'lib/google/apis/youtube_v3/classes.rb', line 8489

def creation_time
  @creation_time
end

#duration_msFixnum

The length of the uploaded video in milliseconds. Corresponds to the JSON property durationMs

Returns:

  • (Fixnum)


8494
8495
8496
# File 'lib/google/apis/youtube_v3/classes.rb', line 8494

def duration_ms
  @duration_ms
end

#file_nameString

The uploaded file's name. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileName

Returns:

  • (String)


8500
8501
8502
# File 'lib/google/apis/youtube_v3/classes.rb', line 8500

def file_name
  @file_name
end

#file_sizeFixnum

The uploaded file's size in bytes. This field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileSize

Returns:

  • (Fixnum)


8506
8507
8508
# File 'lib/google/apis/youtube_v3/classes.rb', line 8506

def file_size
  @file_size
end

#file_typeString

The uploaded file's type as detected by YouTube's video processing engine. Currently, YouTube only processes video files, but this field is present whether a video file or another type of file was uploaded. Corresponds to the JSON property fileType

Returns:

  • (String)


8513
8514
8515
# File 'lib/google/apis/youtube_v3/classes.rb', line 8513

def file_type
  @file_type
end

#video_streamsArray<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>

A list of video streams contained in the uploaded video file. Each item in the list contains detailed metadata about a video stream. Corresponds to the JSON property videoStreams



8519
8520
8521
# File 'lib/google/apis/youtube_v3/classes.rb', line 8519

def video_streams
  @video_streams
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8526
8527
8528
8529
8530
8531
8532
8533
8534
8535
8536
# File 'lib/google/apis/youtube_v3/classes.rb', line 8526

def update!(**args)
  @audio_streams = args[:audio_streams] if args.key?(:audio_streams)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @container = args[:container] if args.key?(:container)
  @creation_time = args[:creation_time] if args.key?(:creation_time)
  @duration_ms = args[:duration_ms] if args.key?(:duration_ms)
  @file_name = args[:file_name] if args.key?(:file_name)
  @file_size = args[:file_size] if args.key?(:file_size)
  @file_type = args[:file_type] if args.key?(:file_type)
  @video_streams = args[:video_streams] if args.key?(:video_streams)
end