Class: Google::Apis::YoutubeV3::VideoFileDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoFileDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Describes original video file properties, including technical details about audio and video streams, but also metadata information like content length, digitization time, or geotagging information.
Instance Attribute Summary collapse
-
#audio_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>
A list of audio streams contained in the uploaded video file.
-
#bitrate_bps ⇒ Fixnum
The uploaded video file's combined (video and audio) bitrate in bits per second.
-
#container ⇒ String
The uploaded video file's container format.
-
#creation_time ⇒ String
The date and time when the uploaded video file was created.
-
#duration_ms ⇒ Fixnum
The length of the uploaded video in milliseconds.
-
#file_name ⇒ String
The uploaded file's name.
-
#file_size ⇒ Fixnum
The uploaded file's size in bytes.
-
#file_type ⇒ String
The uploaded file's type as detected by YouTube's video processing engine.
-
#video_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>
A list of video streams contained in the uploaded video file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFileDetails
constructor
A new instance of VideoFileDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFileDetails
Returns a new instance of VideoFileDetails.
8488 8489 8490 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8488 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsAudioStream>
A list of audio streams contained in the uploaded video file. Each item in the
list contains detailed metadata about an audio stream.
Corresponds to the JSON property audioStreams
8437 8438 8439 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8437 def audio_streams @audio_streams end |
#bitrate_bps ⇒ Fixnum
The uploaded video file's combined (video and audio) bitrate in bits per
second.
Corresponds to the JSON property bitrateBps
8443 8444 8445 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8443 def bitrate_bps @bitrate_bps end |
#container ⇒ String
The uploaded video file's container format.
Corresponds to the JSON property container
8448 8449 8450 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8448 def container @container end |
#creation_time ⇒ String
The date and time when the uploaded video file was created. The value is
specified in ISO 8601 format. Currently, the following ISO 8601 formats are
supported: - Date only: YYYY-MM-DD - Naive time: YYYY-MM-DDTHH:MM:SS - Time
with timezone: YYYY-MM-DDTHH:MM:SS+HH:MM
Corresponds to the JSON property creationTime
8456 8457 8458 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8456 def creation_time @creation_time end |
#duration_ms ⇒ Fixnum
The length of the uploaded video in milliseconds.
Corresponds to the JSON property durationMs
8461 8462 8463 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8461 def duration_ms @duration_ms end |
#file_name ⇒ String
The uploaded file's name. This field is present whether a video file or
another type of file was uploaded.
Corresponds to the JSON property fileName
8467 8468 8469 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8467 def file_name @file_name end |
#file_size ⇒ Fixnum
The uploaded file's size in bytes. This field is present whether a video file
or another type of file was uploaded.
Corresponds to the JSON property fileSize
8473 8474 8475 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8473 def file_size @file_size end |
#file_type ⇒ String
The uploaded file's type as detected by YouTube's video processing engine.
Currently, YouTube only processes video files, but this field is present
whether a video file or another type of file was uploaded.
Corresponds to the JSON property fileType
8480 8481 8482 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8480 def file_type @file_type end |
#video_streams ⇒ Array<Google::Apis::YoutubeV3::VideoFileDetailsVideoStream>
A list of video streams contained in the uploaded video file. Each item in the
list contains detailed metadata about a video stream.
Corresponds to the JSON property videoStreams
8486 8487 8488 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8486 def video_streams @video_streams end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8493 8494 8495 8496 8497 8498 8499 8500 8501 8502 8503 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8493 def update!(**args) @audio_streams = args[:audio_streams] if args.key?(:audio_streams) @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps) @container = args[:container] if args.key?(:container) @creation_time = args[:creation_time] if args.key?(:creation_time) @duration_ms = args[:duration_ms] if args.key?(:duration_ms) @file_name = args[:file_name] if args.key?(:file_name) @file_size = args[:file_size] if args.key?(:file_size) @file_type = args[:file_type] if args.key?(:file_type) @video_streams = args[:video_streams] if args.key?(:video_streams) end |