Class: Google::Apis::YoutubeV3::VideoFileDetailsVideoStream
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoFileDetailsVideoStream
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Information about a video stream.
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ Float
The video content's display aspect ratio, which specifies the aspect ratio in which the video should be displayed.
-
#bitrate_bps ⇒ Fixnum
The video stream's bitrate, in bits per second.
-
#codec ⇒ String
The video codec that the stream uses.
-
#frame_rate_fps ⇒ Float
The video stream's frame rate, in frames per second.
-
#height_pixels ⇒ Fixnum
The encoded video content's height in pixels.
-
#rotation ⇒ String
The amount that YouTube needs to rotate the original source content to properly display the video.
-
#vendor ⇒ String
A value that uniquely identifies a video vendor.
-
#width_pixels ⇒ Fixnum
The encoded video content's width in pixels.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoFileDetailsVideoStream
constructor
A new instance of VideoFileDetailsVideoStream.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoFileDetailsVideoStream
Returns a new instance of VideoFileDetailsVideoStream.
8625 8626 8627 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aspect_ratio ⇒ Float
The video content's display aspect ratio, which specifies the aspect ratio in
which the video should be displayed.
Corresponds to the JSON property aspectRatio
8585 8586 8587 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8585 def aspect_ratio @aspect_ratio end |
#bitrate_bps ⇒ Fixnum
The video stream's bitrate, in bits per second.
Corresponds to the JSON property bitrateBps
8590 8591 8592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8590 def bitrate_bps @bitrate_bps end |
#codec ⇒ String
The video codec that the stream uses.
Corresponds to the JSON property codec
8595 8596 8597 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8595 def codec @codec end |
#frame_rate_fps ⇒ Float
The video stream's frame rate, in frames per second.
Corresponds to the JSON property frameRateFps
8600 8601 8602 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8600 def frame_rate_fps @frame_rate_fps end |
#height_pixels ⇒ Fixnum
The encoded video content's height in pixels.
Corresponds to the JSON property heightPixels
8605 8606 8607 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8605 def height_pixels @height_pixels end |
#rotation ⇒ String
The amount that YouTube needs to rotate the original source content to
properly display the video.
Corresponds to the JSON property rotation
8611 8612 8613 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8611 def rotation @rotation end |
#vendor ⇒ String
A value that uniquely identifies a video vendor. Typically, the value is a
four-letter vendor code.
Corresponds to the JSON property vendor
8617 8618 8619 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8617 def vendor @vendor end |
#width_pixels ⇒ Fixnum
The encoded video content's width in pixels. You can calculate the video's
encoding aspect ratio as width_pixels / height_pixels.
Corresponds to the JSON property widthPixels
8623 8624 8625 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8623 def width_pixels @width_pixels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8630 8631 8632 8633 8634 8635 8636 8637 8638 8639 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8630 def update!(**args) @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio) @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps) @codec = args[:codec] if args.key?(:codec) @frame_rate_fps = args[:frame_rate_fps] if args.key?(:frame_rate_fps) @height_pixels = args[:height_pixels] if args.key?(:height_pixels) @rotation = args[:rotation] if args.key?(:rotation) @vendor = args[:vendor] if args.key?(:vendor) @width_pixels = args[:width_pixels] if args.key?(:width_pixels) end |