Class: Google::Apis::YoutubeV3::VideoFileDetailsVideoStream

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Information about a video stream.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoFileDetailsVideoStream

Returns a new instance of VideoFileDetailsVideoStream.



8477
8478
8479
# File 'lib/google/apis/youtube_v3/classes.rb', line 8477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aspect_ratioFloat

The video content's display aspect ratio, which specifies the aspect ratio in which the video should be displayed. Corresponds to the JSON property aspectRatio

Returns:

  • (Float)


8437
8438
8439
# File 'lib/google/apis/youtube_v3/classes.rb', line 8437

def aspect_ratio
  @aspect_ratio
end

#bitrate_bpsFixnum

The video stream's bitrate, in bits per second. Corresponds to the JSON property bitrateBps

Returns:

  • (Fixnum)


8442
8443
8444
# File 'lib/google/apis/youtube_v3/classes.rb', line 8442

def bitrate_bps
  @bitrate_bps
end

#codecString

The video codec that the stream uses. Corresponds to the JSON property codec

Returns:

  • (String)


8447
8448
8449
# File 'lib/google/apis/youtube_v3/classes.rb', line 8447

def codec
  @codec
end

#frame_rate_fpsFloat

The video stream's frame rate, in frames per second. Corresponds to the JSON property frameRateFps

Returns:

  • (Float)


8452
8453
8454
# File 'lib/google/apis/youtube_v3/classes.rb', line 8452

def frame_rate_fps
  @frame_rate_fps
end

#height_pixelsFixnum

The encoded video content's height in pixels. Corresponds to the JSON property heightPixels

Returns:

  • (Fixnum)


8457
8458
8459
# File 'lib/google/apis/youtube_v3/classes.rb', line 8457

def height_pixels
  @height_pixels
end

#rotationString

The amount that YouTube needs to rotate the original source content to properly display the video. Corresponds to the JSON property rotation

Returns:

  • (String)


8463
8464
8465
# File 'lib/google/apis/youtube_v3/classes.rb', line 8463

def rotation
  @rotation
end

#vendorString

A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor code. Corresponds to the JSON property vendor

Returns:

  • (String)


8469
8470
8471
# File 'lib/google/apis/youtube_v3/classes.rb', line 8469

def vendor
  @vendor
end

#width_pixelsFixnum

The encoded video content's width in pixels. You can calculate the video's encoding aspect ratio as width_pixels / height_pixels. Corresponds to the JSON property widthPixels

Returns:

  • (Fixnum)


8475
8476
8477
# File 'lib/google/apis/youtube_v3/classes.rb', line 8475

def width_pixels
  @width_pixels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8482
8483
8484
8485
8486
8487
8488
8489
8490
8491
# File 'lib/google/apis/youtube_v3/classes.rb', line 8482

def update!(**args)
  @aspect_ratio = args[:aspect_ratio] if args.key?(:aspect_ratio)
  @bitrate_bps = args[:bitrate_bps] if args.key?(:bitrate_bps)
  @codec = args[:codec] if args.key?(:codec)
  @frame_rate_fps = args[:frame_rate_fps] if args.key?(:frame_rate_fps)
  @height_pixels = args[:height_pixels] if args.key?(:height_pixels)
  @rotation = args[:rotation] if args.key?(:rotation)
  @vendor = args[:vendor] if args.key?(:vendor)
  @width_pixels = args[:width_pixels] if args.key?(:width_pixels)
end