Class: Google::Apis::YoutubeV3::VideoLiveStreamingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about the live streaming metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoLiveStreamingDetails

Returns a new instance of VideoLiveStreamingDetails.



8805
8806
8807
# File 'lib/google/apis/youtube_v3/classes.rb', line 8805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_live_chat_idString

The ID of the currently active live chat attached to this video. This field is filled only if the video is a currently live broadcast that has live chat. Once the broadcast transitions to complete this field will be removed and the live chat closed down. For persistent broadcasts that live chat id will no longer be tied to this video but rather to the new video being displayed at the persistent page. Corresponds to the JSON property activeLiveChatId

Returns:

  • (String)


8769
8770
8771
# File 'lib/google/apis/youtube_v3/classes.rb', line 8769

def active_live_chat_id
  @active_live_chat_id
end

#actual_end_timeDateTime

The time that the broadcast actually ended. This value will not be available until the broadcast is over. Corresponds to the JSON property actualEndTime

Returns:

  • (DateTime)


8775
8776
8777
# File 'lib/google/apis/youtube_v3/classes.rb', line 8775

def actual_end_time
  @actual_end_time
end

#actual_start_timeDateTime

The time that the broadcast actually started. This value will not be available until the broadcast begins. Corresponds to the JSON property actualStartTime

Returns:

  • (DateTime)


8781
8782
8783
# File 'lib/google/apis/youtube_v3/classes.rb', line 8781

def actual_start_time
  @actual_start_time
end

#concurrent_viewersFixnum

The number of viewers currently watching the broadcast. The property and its value will be present if the broadcast has current viewers and the broadcast owner has not hidden the viewcount for the video. Note that YouTube stops tracking the number of concurrent viewers for a broadcast when the broadcast ends. So, this property would not identify the number of viewers watching an archived video of a live broadcast that already ended. Corresponds to the JSON property concurrentViewers

Returns:

  • (Fixnum)


8791
8792
8793
# File 'lib/google/apis/youtube_v3/classes.rb', line 8791

def concurrent_viewers
  @concurrent_viewers
end

#scheduled_end_timeDateTime

The time that the broadcast is scheduled to end. If the value is empty or the property is not present, then the broadcast is scheduled to continue indefinitely. Corresponds to the JSON property scheduledEndTime

Returns:

  • (DateTime)


8798
8799
8800
# File 'lib/google/apis/youtube_v3/classes.rb', line 8798

def scheduled_end_time
  @scheduled_end_time
end

#scheduled_start_timeDateTime

The time that the broadcast is scheduled to begin. Corresponds to the JSON property scheduledStartTime

Returns:

  • (DateTime)


8803
8804
8805
# File 'lib/google/apis/youtube_v3/classes.rb', line 8803

def scheduled_start_time
  @scheduled_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8810
8811
8812
8813
8814
8815
8816
8817
# File 'lib/google/apis/youtube_v3/classes.rb', line 8810

def update!(**args)
  @active_live_chat_id = args[:active_live_chat_id] if args.key?(:active_live_chat_id)
  @actual_end_time = args[:actual_end_time] if args.key?(:actual_end_time)
  @actual_start_time = args[:actual_start_time] if args.key?(:actual_start_time)
  @concurrent_viewers = args[:concurrent_viewers] if args.key?(:concurrent_viewers)
  @scheduled_end_time = args[:scheduled_end_time] if args.key?(:scheduled_end_time)
  @scheduled_start_time = args[:scheduled_start_time] if args.key?(:scheduled_start_time)
end