Class: Google::Apis::YoutubeV3::VideoLiveStreamingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Details about the live streaming metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoLiveStreamingDetails

Returns a new instance of VideoLiveStreamingDetails.



8772
8773
8774
# File 'lib/google/apis/youtube_v3/classes.rb', line 8772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_live_chat_idString

The ID of the currently active live chat attached to this video. This field is filled only if the video is a currently live broadcast that has live chat. Once the broadcast transitions to complete this field will be removed and the live chat closed down. For persistent broadcasts that live chat id will no longer be tied to this video but rather to the new video being displayed at the persistent page. Corresponds to the JSON property activeLiveChatId

Returns:

  • (String)


8736
8737
8738
# File 'lib/google/apis/youtube_v3/classes.rb', line 8736

def active_live_chat_id
  @active_live_chat_id
end

#actual_end_timeDateTime

The time that the broadcast actually ended. This value will not be available until the broadcast is over. Corresponds to the JSON property actualEndTime

Returns:

  • (DateTime)


8742
8743
8744
# File 'lib/google/apis/youtube_v3/classes.rb', line 8742

def actual_end_time
  @actual_end_time
end

#actual_start_timeDateTime

The time that the broadcast actually started. This value will not be available until the broadcast begins. Corresponds to the JSON property actualStartTime

Returns:

  • (DateTime)


8748
8749
8750
# File 'lib/google/apis/youtube_v3/classes.rb', line 8748

def actual_start_time
  @actual_start_time
end

#concurrent_viewersFixnum

The number of viewers currently watching the broadcast. The property and its value will be present if the broadcast has current viewers and the broadcast owner has not hidden the viewcount for the video. Note that YouTube stops tracking the number of concurrent viewers for a broadcast when the broadcast ends. So, this property would not identify the number of viewers watching an archived video of a live broadcast that already ended. Corresponds to the JSON property concurrentViewers

Returns:

  • (Fixnum)


8758
8759
8760
# File 'lib/google/apis/youtube_v3/classes.rb', line 8758

def concurrent_viewers
  @concurrent_viewers
end

#scheduled_end_timeDateTime

The time that the broadcast is scheduled to end. If the value is empty or the property is not present, then the broadcast is scheduled to continue indefinitely. Corresponds to the JSON property scheduledEndTime

Returns:

  • (DateTime)


8765
8766
8767
# File 'lib/google/apis/youtube_v3/classes.rb', line 8765

def scheduled_end_time
  @scheduled_end_time
end

#scheduled_start_timeDateTime

The time that the broadcast is scheduled to begin. Corresponds to the JSON property scheduledStartTime

Returns:

  • (DateTime)


8770
8771
8772
# File 'lib/google/apis/youtube_v3/classes.rb', line 8770

def scheduled_start_time
  @scheduled_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8777
8778
8779
8780
8781
8782
8783
8784
# File 'lib/google/apis/youtube_v3/classes.rb', line 8777

def update!(**args)
  @active_live_chat_id = args[:active_live_chat_id] if args.key?(:active_live_chat_id)
  @actual_end_time = args[:actual_end_time] if args.key?(:actual_end_time)
  @actual_start_time = args[:actual_start_time] if args.key?(:actual_start_time)
  @concurrent_viewers = args[:concurrent_viewers] if args.key?(:concurrent_viewers)
  @scheduled_end_time = args[:scheduled_end_time] if args.key?(:scheduled_end_time)
  @scheduled_start_time = args[:scheduled_start_time] if args.key?(:scheduled_start_time)
end