Class: Google::Apis::YoutubeV3::VideoProcessingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Describes processing status and progress and availability of some other Video resource parts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoProcessingDetails

Returns a new instance of VideoProcessingDetails.



8945
8946
8947
# File 'lib/google/apis/youtube_v3/classes.rb', line 8945

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editor_suggestions_availabilityString

This value indicates whether video editing suggestions, which might improve video quality or the playback experience, are available for the video. You can retrieve these suggestions by requesting the suggestions part in your videos. list() request. Corresponds to the JSON property editorSuggestionsAvailability

Returns:

  • (String)


8896
8897
8898
# File 'lib/google/apis/youtube_v3/classes.rb', line 8896

def editor_suggestions_availability
  @editor_suggestions_availability
end

#file_details_availabilityString

This value indicates whether file details are available for the uploaded video. You can retrieve a video's file details by requesting the fileDetails part in your videos.list() request. Corresponds to the JSON property fileDetailsAvailability

Returns:

  • (String)


8903
8904
8905
# File 'lib/google/apis/youtube_v3/classes.rb', line 8903

def file_details_availability
  @file_details_availability
end

#processing_failure_reasonString

The reason that YouTube failed to process the video. This property will only have a value if the processingStatus property's value is failed. Corresponds to the JSON property processingFailureReason

Returns:

  • (String)


8909
8910
8911
# File 'lib/google/apis/youtube_v3/classes.rb', line 8909

def processing_failure_reason
  @processing_failure_reason
end

#processing_issues_availabilityString

This value indicates whether the video processing engine has generated suggestions that might improve YouTube's ability to process the the video, warnings that explain video processing problems, or errors that cause video processing problems. You can retrieve these suggestions by requesting the suggestions part in your videos.list() request. Corresponds to the JSON property processingIssuesAvailability

Returns:

  • (String)


8918
8919
8920
# File 'lib/google/apis/youtube_v3/classes.rb', line 8918

def processing_issues_availability
  @processing_issues_availability
end

#processing_progressGoogle::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress

Video processing progress and completion time estimate. Corresponds to the JSON property processingProgress



8923
8924
8925
# File 'lib/google/apis/youtube_v3/classes.rb', line 8923

def processing_progress
  @processing_progress
end

#processing_statusString

The video's processing status. This value indicates whether YouTube was able to process the video or if the video is still being processed. Corresponds to the JSON property processingStatus

Returns:

  • (String)


8929
8930
8931
# File 'lib/google/apis/youtube_v3/classes.rb', line 8929

def processing_status
  @processing_status
end

#tag_suggestions_availabilityString

This value indicates whether keyword (tag) suggestions are available for the video. Tags can be added to a video's metadata to make it easier for other users to find the video. You can retrieve these suggestions by requesting the suggestions part in your videos.list() request. Corresponds to the JSON property tagSuggestionsAvailability

Returns:

  • (String)


8937
8938
8939
# File 'lib/google/apis/youtube_v3/classes.rb', line 8937

def tag_suggestions_availability
  @tag_suggestions_availability
end

#thumbnails_availabilityString

This value indicates whether thumbnail images have been generated for the video. Corresponds to the JSON property thumbnailsAvailability

Returns:

  • (String)


8943
8944
8945
# File 'lib/google/apis/youtube_v3/classes.rb', line 8943

def thumbnails_availability
  @thumbnails_availability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8950
8951
8952
8953
8954
8955
8956
8957
8958
8959
# File 'lib/google/apis/youtube_v3/classes.rb', line 8950

def update!(**args)
  @editor_suggestions_availability = args[:editor_suggestions_availability] if args.key?(:editor_suggestions_availability)
  @file_details_availability = args[:file_details_availability] if args.key?(:file_details_availability)
  @processing_failure_reason = args[:processing_failure_reason] if args.key?(:processing_failure_reason)
  @processing_issues_availability = args[:processing_issues_availability] if args.key?(:processing_issues_availability)
  @processing_progress = args[:processing_progress] if args.key?(:processing_progress)
  @processing_status = args[:processing_status] if args.key?(:processing_status)
  @tag_suggestions_availability = args[:tag_suggestions_availability] if args.key?(:tag_suggestions_availability)
  @thumbnails_availability = args[:thumbnails_availability] if args.key?(:thumbnails_availability)
end