Class: Google::Apis::YoutubeV3::VideoProcessingDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoProcessingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Describes processing status and progress and availability of some other Video resource parts.
Instance Attribute Summary collapse
-
#editor_suggestions_availability ⇒ String
This value indicates whether video editing suggestions, which might improve video quality or the playback experience, are available for the video.
-
#file_details_availability ⇒ String
This value indicates whether file details are available for the uploaded video.
-
#processing_failure_reason ⇒ String
The reason that YouTube failed to process the video.
-
#processing_issues_availability ⇒ String
This value indicates whether the video processing engine has generated suggestions that might improve YouTube's ability to process the the video, warnings that explain video processing problems, or errors that cause video processing problems.
-
#processing_progress ⇒ Google::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress
Video processing progress and completion time estimate.
-
#processing_status ⇒ String
The video's processing status.
-
#tag_suggestions_availability ⇒ String
This value indicates whether keyword (tag) suggestions are available for the video.
-
#thumbnails_availability ⇒ String
This value indicates whether thumbnail images have been generated for the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoProcessingDetails
constructor
A new instance of VideoProcessingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoProcessingDetails
Returns a new instance of VideoProcessingDetails.
8830 8831 8832 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#editor_suggestions_availability ⇒ String
This value indicates whether video editing suggestions, which might improve
video quality or the playback experience, are available for the video. You can
retrieve these suggestions by requesting the suggestions part in your videos.
list() request.
Corresponds to the JSON property editorSuggestionsAvailability
8781 8782 8783 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8781 def editor_suggestions_availability @editor_suggestions_availability end |
#file_details_availability ⇒ String
This value indicates whether file details are available for the uploaded video.
You can retrieve a video's file details by requesting the fileDetails part in
your videos.list() request.
Corresponds to the JSON property fileDetailsAvailability
8788 8789 8790 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8788 def file_details_availability @file_details_availability end |
#processing_failure_reason ⇒ String
The reason that YouTube failed to process the video. This property will only
have a value if the processingStatus property's value is failed.
Corresponds to the JSON property processingFailureReason
8794 8795 8796 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8794 def processing_failure_reason @processing_failure_reason end |
#processing_issues_availability ⇒ String
This value indicates whether the video processing engine has generated
suggestions that might improve YouTube's ability to process the the video,
warnings that explain video processing problems, or errors that cause video
processing problems. You can retrieve these suggestions by requesting the
suggestions part in your videos.list() request.
Corresponds to the JSON property processingIssuesAvailability
8803 8804 8805 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8803 def processing_issues_availability @processing_issues_availability end |
#processing_progress ⇒ Google::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress
Video processing progress and completion time estimate.
Corresponds to the JSON property processingProgress
8808 8809 8810 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8808 def processing_progress @processing_progress end |
#processing_status ⇒ String
The video's processing status. This value indicates whether YouTube was able
to process the video or if the video is still being processed.
Corresponds to the JSON property processingStatus
8814 8815 8816 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8814 def processing_status @processing_status end |
#tag_suggestions_availability ⇒ String
This value indicates whether keyword (tag) suggestions are available for the
video. Tags can be added to a video's metadata to make it easier for other
users to find the video. You can retrieve these suggestions by requesting the
suggestions part in your videos.list() request.
Corresponds to the JSON property tagSuggestionsAvailability
8822 8823 8824 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8822 def tag_suggestions_availability @tag_suggestions_availability end |
#thumbnails_availability ⇒ String
This value indicates whether thumbnail images have been generated for the
video.
Corresponds to the JSON property thumbnailsAvailability
8828 8829 8830 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8828 def thumbnails_availability @thumbnails_availability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8835 def update!(**args) @editor_suggestions_availability = args[:editor_suggestions_availability] if args.key?(:editor_suggestions_availability) @file_details_availability = args[:file_details_availability] if args.key?(:file_details_availability) @processing_failure_reason = args[:processing_failure_reason] if args.key?(:processing_failure_reason) @processing_issues_availability = args[:processing_issues_availability] if args.key?(:processing_issues_availability) @processing_progress = args[:processing_progress] if args.key?(:processing_progress) @processing_status = args[:processing_status] if args.key?(:processing_status) @tag_suggestions_availability = args[:tag_suggestions_availability] if args.key?(:tag_suggestions_availability) @thumbnails_availability = args[:thumbnails_availability] if args.key?(:thumbnails_availability) end |