Class: Google::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoProcessingDetailsProcessingProgress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Video processing progress and completion time estimate.
Instance Attribute Summary collapse
-
#parts_processed ⇒ Fixnum
The number of parts of the video that YouTube has already processed.
-
#parts_total ⇒ Fixnum
An estimate of the total number of parts that need to be processed for the video.
-
#time_left_ms ⇒ Fixnum
An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoProcessingDetailsProcessingProgress
constructor
A new instance of VideoProcessingDetailsProcessingProgress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoProcessingDetailsProcessingProgress
Returns a new instance of VideoProcessingDetailsProcessingProgress.
8989 8990 8991 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#parts_processed ⇒ Fixnum
The number of parts of the video that YouTube has already processed. You can
estimate the percentage of the video that YouTube has already processed by
calculating: 100 * parts_processed / parts_total Note that since the estimated
number of parts could increase without a corresponding increase in the number
of parts that have already been processed, it is possible that the calculated
progress could periodically decrease while YouTube processes a video.
Corresponds to the JSON property partsProcessed
8974 8975 8976 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8974 def parts_processed @parts_processed end |
#parts_total ⇒ Fixnum
An estimate of the total number of parts that need to be processed for the
video. The number may be updated with more precise estimates while YouTube
processes the video.
Corresponds to the JSON property partsTotal
8981 8982 8983 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8981 def parts_total @parts_total end |
#time_left_ms ⇒ Fixnum
An estimate of the amount of time, in millseconds, that YouTube needs to
finish processing the video.
Corresponds to the JSON property timeLeftMs
8987 8988 8989 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8987 def time_left_ms @time_left_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8994 8995 8996 8997 8998 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8994 def update!(**args) @parts_processed = args[:parts_processed] if args.key?(:parts_processed) @parts_total = args[:parts_total] if args.key?(:parts_total) @time_left_ms = args[:time_left_ms] if args.key?(:time_left_ms) end |