Class: Google::Apis::YoutubeV3::VideoRecordingDetails
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoRecordingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Recording information associated with the video.
Instance Attribute Summary collapse
-
#location ⇒ Google::Apis::YoutubeV3::GeoPoint
Geographical coordinates of a point, in WGS84.
-
#location_description ⇒ String
The text description of the location where the video was recorded.
-
#recording_date ⇒ DateTime
The date and time when the video was recorded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoRecordingDetails
constructor
A new instance of VideoRecordingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoRecordingDetails
Returns a new instance of VideoRecordingDetails.
8985 8986 8987 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ Google::Apis::YoutubeV3::GeoPoint
Geographical coordinates of a point, in WGS84.
Corresponds to the JSON property location
8973 8974 8975 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8973 def location @location end |
#location_description ⇒ String
The text description of the location where the video was recorded.
Corresponds to the JSON property locationDescription
8978 8979 8980 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8978 def location_description @location_description end |
#recording_date ⇒ DateTime
The date and time when the video was recorded.
Corresponds to the JSON property recordingDate
8983 8984 8985 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8983 def recording_date @recording_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8990 8991 8992 8993 8994 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 8990 def update!(**args) @location = args[:location] if args.key?(:location) @location_description = args[:location_description] if args.key?(:location_description) @recording_date = args[:recording_date] if args.key?(:recording_date) end |