Class: Google::Apis::YoutubeV3::VideoSnippet
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoSnippet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a video, including title, description, uploader, thumbnails and category.
Instance Attribute Summary collapse
-
#category_id ⇒ String
The YouTube video category associated with the video.
-
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that the video was uploaded to.
-
#channel_title ⇒ String
Channel title for the channel that the video belongs to.
-
#default_audio_language ⇒ String
The default_audio_language property specifies the language spoken in the video' s default audio track.
-
#default_language ⇒ String
The language of the videos's default snippet.
-
#description ⇒ String
The video's description.
-
#live_broadcast_content ⇒ String
Indicates if the video is an upcoming/active live broadcast.
-
#localized ⇒ Google::Apis::YoutubeV3::VideoLocalization
Localized versions of certain video properties (e.g. title).
-
#published_at ⇒ DateTime
The date and time when the video was uploaded.
-
#tags ⇒ Array<String>
A list of keyword tags associated with the video.
-
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
-
#title ⇒ String
The video's title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoSnippet
constructor
A new instance of VideoSnippet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoSnippet
Returns a new instance of VideoSnippet.
9346 9347 9348 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category_id ⇒ String
The YouTube video category associated with the video.
Corresponds to the JSON property categoryId
9286 9287 9288 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9286 def category_id @category_id end |
#channel_id ⇒ String
The ID that YouTube uses to uniquely identify the channel that the video was
uploaded to.
Corresponds to the JSON property channelId
9292 9293 9294 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9292 def channel_id @channel_id end |
#channel_title ⇒ String
Channel title for the channel that the video belongs to.
Corresponds to the JSON property channelTitle
9297 9298 9299 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9297 def channel_title @channel_title end |
#default_audio_language ⇒ String
The default_audio_language property specifies the language spoken in the video'
s default audio track.
Corresponds to the JSON property defaultAudioLanguage
9303 9304 9305 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9303 def default_audio_language @default_audio_language end |
#default_language ⇒ String
The language of the videos's default snippet.
Corresponds to the JSON property defaultLanguage
9308 9309 9310 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9308 def default_language @default_language end |
#description ⇒ String
The video's description. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property description
9313 9314 9315 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9313 def description @description end |
#live_broadcast_content ⇒ String
Indicates if the video is an upcoming/active live broadcast. Or it's "none" if
the video is not an upcoming/active live broadcast.
Corresponds to the JSON property liveBroadcastContent
9319 9320 9321 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9319 def live_broadcast_content @live_broadcast_content end |
#localized ⇒ Google::Apis::YoutubeV3::VideoLocalization
Localized versions of certain video properties (e.g. title).
Corresponds to the JSON property localized
9324 9325 9326 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9324 def localized @localized end |
#published_at ⇒ DateTime
The date and time when the video was uploaded.
Corresponds to the JSON property publishedAt
9329 9330 9331 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9329 def published_at @published_at end |
#tags ⇒ Array<String>
A list of keyword tags associated with the video. Tags may contain spaces.
Corresponds to the JSON property tags
9334 9335 9336 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9334 def @tags end |
#thumbnails ⇒ Google::Apis::YoutubeV3::ThumbnailDetails
Internal representation of thumbnails for a YouTube resource.
Corresponds to the JSON property thumbnails
9339 9340 9341 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9339 def thumbnails @thumbnails end |
#title ⇒ String
The video's title. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property title
9344 9345 9346 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9344 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9351 9352 9353 9354 9355 9356 9357 9358 9359 9360 9361 9362 9363 9364 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9351 def update!(**args) @category_id = args[:category_id] if args.key?(:category_id) @channel_id = args[:channel_id] if args.key?(:channel_id) @channel_title = args[:channel_title] if args.key?(:channel_title) @default_audio_language = args[:default_audio_language] if args.key?(:default_audio_language) @default_language = args[:default_language] if args.key?(:default_language) @description = args[:description] if args.key?(:description) @live_broadcast_content = args[:live_broadcast_content] if args.key?(:live_broadcast_content) @localized = args[:localized] if args.key?(:localized) @published_at = args[:published_at] if args.key?(:published_at) @tags = args[:tags] if args.key?(:tags) @thumbnails = args[:thumbnails] if args.key?(:thumbnails) @title = args[:title] if args.key?(:title) end |