Class: Google::Apis::YoutubeV3::VideoSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video, including title, description, uploader, thumbnails and category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoSnippet

Returns a new instance of VideoSnippet.



9318
9319
9320
# File 'lib/google/apis/youtube_v3/classes.rb', line 9318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idString

The YouTube video category associated with the video. Corresponds to the JSON property categoryId

Returns:

  • (String)


9258
9259
9260
# File 'lib/google/apis/youtube_v3/classes.rb', line 9258

def category_id
  @category_id
end

#channel_idString

The ID that YouTube uses to uniquely identify the channel that the video was uploaded to. Corresponds to the JSON property channelId

Returns:

  • (String)


9264
9265
9266
# File 'lib/google/apis/youtube_v3/classes.rb', line 9264

def channel_id
  @channel_id
end

#channel_titleString

Channel title for the channel that the video belongs to. Corresponds to the JSON property channelTitle

Returns:

  • (String)


9269
9270
9271
# File 'lib/google/apis/youtube_v3/classes.rb', line 9269

def channel_title
  @channel_title
end

#default_audio_languageString

The default_audio_language property specifies the language spoken in the video' s default audio track. Corresponds to the JSON property defaultAudioLanguage

Returns:

  • (String)


9275
9276
9277
# File 'lib/google/apis/youtube_v3/classes.rb', line 9275

def default_audio_language
  @default_audio_language
end

#default_languageString

The language of the videos's default snippet. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/youtube_v3/classes.rb', line 9280

def default_language
  @default_language
end

#descriptionString

The video's description. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property description

Returns:

  • (String)


9285
9286
9287
# File 'lib/google/apis/youtube_v3/classes.rb', line 9285

def description
  @description
end

#live_broadcast_contentString

Indicates if the video is an upcoming/active live broadcast. Or it's "none" if the video is not an upcoming/active live broadcast. Corresponds to the JSON property liveBroadcastContent

Returns:

  • (String)


9291
9292
9293
# File 'lib/google/apis/youtube_v3/classes.rb', line 9291

def live_broadcast_content
  @live_broadcast_content
end

#localizedGoogle::Apis::YoutubeV3::VideoLocalization

Localized versions of certain video properties (e.g. title). Corresponds to the JSON property localized



9296
9297
9298
# File 'lib/google/apis/youtube_v3/classes.rb', line 9296

def localized
  @localized
end

#published_atDateTime

The date and time when the video was uploaded. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


9301
9302
9303
# File 'lib/google/apis/youtube_v3/classes.rb', line 9301

def published_at
  @published_at
end

#tagsArray<String>

A list of keyword tags associated with the video. Tags may contain spaces. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


9306
9307
9308
# File 'lib/google/apis/youtube_v3/classes.rb', line 9306

def tags
  @tags
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



9311
9312
9313
# File 'lib/google/apis/youtube_v3/classes.rb', line 9311

def thumbnails
  @thumbnails
end

#titleString

The video's title. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property title

Returns:

  • (String)


9316
9317
9318
# File 'lib/google/apis/youtube_v3/classes.rb', line 9316

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9323
9324
9325
9326
9327
9328
9329
9330
9331
9332
9333
9334
9335
9336
# File 'lib/google/apis/youtube_v3/classes.rb', line 9323

def update!(**args)
  @category_id = args[:category_id] if args.key?(:category_id)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @default_audio_language = args[:default_audio_language] if args.key?(:default_audio_language)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @live_broadcast_content = args[:live_broadcast_content] if args.key?(:live_broadcast_content)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @tags = args[:tags] if args.key?(:tags)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end