Class: Google::Apis::YoutubeV3::VideoSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video, including title, description, uploader, thumbnails and category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoSnippet

Returns a new instance of VideoSnippet.



9065
9066
9067
# File 'lib/google/apis/youtube_v3/classes.rb', line 9065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_idString

The YouTube video category associated with the video. Corresponds to the JSON property categoryId

Returns:

  • (String)


9005
9006
9007
# File 'lib/google/apis/youtube_v3/classes.rb', line 9005

def category_id
  @category_id
end

#channel_idString

The ID that YouTube uses to uniquely identify the channel that the video was uploaded to. Corresponds to the JSON property channelId

Returns:

  • (String)


9011
9012
9013
# File 'lib/google/apis/youtube_v3/classes.rb', line 9011

def channel_id
  @channel_id
end

#channel_titleString

Channel title for the channel that the video belongs to. Corresponds to the JSON property channelTitle

Returns:

  • (String)


9016
9017
9018
# File 'lib/google/apis/youtube_v3/classes.rb', line 9016

def channel_title
  @channel_title
end

#default_audio_languageString

The default_audio_language property specifies the language spoken in the video' s default audio track. Corresponds to the JSON property defaultAudioLanguage

Returns:

  • (String)


9022
9023
9024
# File 'lib/google/apis/youtube_v3/classes.rb', line 9022

def default_audio_language
  @default_audio_language
end

#default_languageString

The language of the videos's default snippet. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


9027
9028
9029
# File 'lib/google/apis/youtube_v3/classes.rb', line 9027

def default_language
  @default_language
end

#descriptionString

The video's description. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property description

Returns:

  • (String)


9032
9033
9034
# File 'lib/google/apis/youtube_v3/classes.rb', line 9032

def description
  @description
end

#live_broadcast_contentString

Indicates if the video is an upcoming/active live broadcast. Or it's "none" if the video is not an upcoming/active live broadcast. Corresponds to the JSON property liveBroadcastContent

Returns:

  • (String)


9038
9039
9040
# File 'lib/google/apis/youtube_v3/classes.rb', line 9038

def live_broadcast_content
  @live_broadcast_content
end

#localizedGoogle::Apis::YoutubeV3::VideoLocalization

Localized versions of certain video properties (e.g. title). Corresponds to the JSON property localized



9043
9044
9045
# File 'lib/google/apis/youtube_v3/classes.rb', line 9043

def localized
  @localized
end

#published_atDateTime

The date and time when the video was uploaded. Corresponds to the JSON property publishedAt

Returns:

  • (DateTime)


9048
9049
9050
# File 'lib/google/apis/youtube_v3/classes.rb', line 9048

def published_at
  @published_at
end

#tagsArray<String>

A list of keyword tags associated with the video. Tags may contain spaces. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


9053
9054
9055
# File 'lib/google/apis/youtube_v3/classes.rb', line 9053

def tags
  @tags
end

#thumbnailsGoogle::Apis::YoutubeV3::ThumbnailDetails

Internal representation of thumbnails for a YouTube resource. Corresponds to the JSON property thumbnails



9058
9059
9060
# File 'lib/google/apis/youtube_v3/classes.rb', line 9058

def thumbnails
  @thumbnails
end

#titleString

The video's title. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property title

Returns:

  • (String)


9063
9064
9065
# File 'lib/google/apis/youtube_v3/classes.rb', line 9063

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
9080
9081
9082
9083
# File 'lib/google/apis/youtube_v3/classes.rb', line 9070

def update!(**args)
  @category_id = args[:category_id] if args.key?(:category_id)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_title = args[:channel_title] if args.key?(:channel_title)
  @default_audio_language = args[:default_audio_language] if args.key?(:default_audio_language)
  @default_language = args[:default_language] if args.key?(:default_language)
  @description = args[:description] if args.key?(:description)
  @live_broadcast_content = args[:live_broadcast_content] if args.key?(:live_broadcast_content)
  @localized = args[:localized] if args.key?(:localized)
  @published_at = args[:published_at] if args.key?(:published_at)
  @tags = args[:tags] if args.key?(:tags)
  @thumbnails = args[:thumbnails] if args.key?(:thumbnails)
  @title = args[:title] if args.key?(:title)
end