Class: Google::Apis::YoutubeV3::VideoStat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A VideoStat resource represents a YouTube video's stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStat

Returns a new instance of VideoStat.



9381
9382
9383
# File 'lib/google/apis/youtube_v3/classes.rb', line 9381

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_detailsGoogle::Apis::YoutubeV3::VideoStatsContentDetails

Details about the content of a YouTube Video. This is a subset of the information in VideoContentDetails specifically for the Videos.stats API. Corresponds to the JSON property contentDetails



9351
9352
9353
# File 'lib/google/apis/youtube_v3/classes.rb', line 9351

def content_details
  @content_details
end

#etagString

Output only. Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


9356
9357
9358
# File 'lib/google/apis/youtube_v3/classes.rb', line 9356

def etag
  @etag
end

#idString

Output only. The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


9361
9362
9363
# File 'lib/google/apis/youtube_v3/classes.rb', line 9361

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "youtube#videoStats". Corresponds to the JSON property kind

Returns:

  • (String)


9367
9368
9369
# File 'lib/google/apis/youtube_v3/classes.rb', line 9367

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::VideoStatsSnippet

Basic details about a video. This is a subset of the information in VideoSnippet specifically for the Videos.stats API. Corresponds to the JSON property snippet



9373
9374
9375
# File 'lib/google/apis/youtube_v3/classes.rb', line 9373

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatsStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



9379
9380
9381
# File 'lib/google/apis/youtube_v3/classes.rb', line 9379

def statistics
  @statistics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9386
9387
9388
9389
9390
9391
9392
9393
# File 'lib/google/apis/youtube_v3/classes.rb', line 9386

def update!(**args)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
end