Class: Google::Apis::YoutubeV3::VideoStat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A VideoStat resource represents a YouTube video's stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStat

Returns a new instance of VideoStat.



9238
9239
9240
# File 'lib/google/apis/youtube_v3/classes.rb', line 9238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_detailsGoogle::Apis::YoutubeV3::VideoStatsContentDetails

Details about the content of a YouTube Video. This is a subset of the information in VideoContentDetails specifically for the Videos.stats API. Corresponds to the JSON property contentDetails



9208
9209
9210
# File 'lib/google/apis/youtube_v3/classes.rb', line 9208

def content_details
  @content_details
end

#etagString

Output only. Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


9213
9214
9215
# File 'lib/google/apis/youtube_v3/classes.rb', line 9213

def etag
  @etag
end

#idString

Output only. The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


9218
9219
9220
# File 'lib/google/apis/youtube_v3/classes.rb', line 9218

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "youtube#videoStats". Corresponds to the JSON property kind

Returns:

  • (String)


9224
9225
9226
# File 'lib/google/apis/youtube_v3/classes.rb', line 9224

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::VideoStatsSnippet

Basic details about a video. This is a subset of the information in VideoSnippet specifically for the Videos.stats API. Corresponds to the JSON property snippet



9230
9231
9232
# File 'lib/google/apis/youtube_v3/classes.rb', line 9230

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatsStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



9236
9237
9238
# File 'lib/google/apis/youtube_v3/classes.rb', line 9236

def statistics
  @statistics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9243
9244
9245
9246
9247
9248
9249
9250
# File 'lib/google/apis/youtube_v3/classes.rb', line 9243

def update!(**args)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
end