Class: Google::Apis::YoutubeV3::VideoStat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

A VideoStat resource represents a YouTube video's stats.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStat

Returns a new instance of VideoStat.



9205
9206
9207
# File 'lib/google/apis/youtube_v3/classes.rb', line 9205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_detailsGoogle::Apis::YoutubeV3::VideoStatsContentDetails

Details about the content of a YouTube Video. This is a subset of the information in VideoContentDetails specifically for the Videos.stats API. Corresponds to the JSON property contentDetails



9175
9176
9177
# File 'lib/google/apis/youtube_v3/classes.rb', line 9175

def content_details
  @content_details
end

#etagString

Output only. Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


9180
9181
9182
# File 'lib/google/apis/youtube_v3/classes.rb', line 9180

def etag
  @etag
end

#idString

Output only. The ID that YouTube uses to uniquely identify the video. Corresponds to the JSON property id

Returns:

  • (String)


9185
9186
9187
# File 'lib/google/apis/youtube_v3/classes.rb', line 9185

def id
  @id
end

#kindString

Output only. Identifies what kind of resource this is. Value: the fixed string "youtube#videoStats". Corresponds to the JSON property kind

Returns:

  • (String)


9191
9192
9193
# File 'lib/google/apis/youtube_v3/classes.rb', line 9191

def kind
  @kind
end

#snippetGoogle::Apis::YoutubeV3::VideoStatsSnippet

Basic details about a video. This is a subset of the information in VideoSnippet specifically for the Videos.stats API. Corresponds to the JSON property snippet



9197
9198
9199
# File 'lib/google/apis/youtube_v3/classes.rb', line 9197

def snippet
  @snippet
end

#statisticsGoogle::Apis::YoutubeV3::VideoStatsStatistics

Statistics about the video, such as the number of times the video was viewed or liked. Corresponds to the JSON property statistics



9203
9204
9205
# File 'lib/google/apis/youtube_v3/classes.rb', line 9203

def statistics
  @statistics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9210
9211
9212
9213
9214
9215
9216
9217
# File 'lib/google/apis/youtube_v3/classes.rb', line 9210

def update!(**args)
  @content_details = args[:content_details] if args.key?(:content_details)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @snippet = args[:snippet] if args.key?(:snippet)
  @statistics = args[:statistics] if args.key?(:statistics)
end