Class: Google::Apis::YoutubeV3::VideoStat
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoStat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
A VideoStat resource represents a YouTube video's stats.
Instance Attribute Summary collapse
-
#content_details ⇒ Google::Apis::YoutubeV3::VideoStatsContentDetails
Details about the content of a YouTube Video.
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#snippet ⇒ Google::Apis::YoutubeV3::VideoStatsSnippet
Basic details about a video.
-
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatsStatistics
Statistics about the video, such as the number of times the video was viewed or liked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoStat
constructor
A new instance of VideoStat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoStat
Returns a new instance of VideoStat.
9090 9091 9092 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_details ⇒ Google::Apis::YoutubeV3::VideoStatsContentDetails
Details about the content of a YouTube Video. This is a subset of the
information in VideoContentDetails specifically for the Videos.stats API.
Corresponds to the JSON property contentDetails
9060 9061 9062 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9060 def content_details @content_details end |
#etag ⇒ String
Output only. Etag of this resource.
Corresponds to the JSON property etag
9065 9066 9067 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9065 def etag @etag end |
#id ⇒ String
Output only. The ID that YouTube uses to uniquely identify the video.
Corresponds to the JSON property id
9070 9071 9072 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9070 def id @id end |
#kind ⇒ String
Output only. Identifies what kind of resource this is. Value: the fixed string
"youtube#videoStats".
Corresponds to the JSON property kind
9076 9077 9078 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9076 def kind @kind end |
#snippet ⇒ Google::Apis::YoutubeV3::VideoStatsSnippet
Basic details about a video. This is a subset of the information in
VideoSnippet specifically for the Videos.stats API.
Corresponds to the JSON property snippet
9082 9083 9084 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9082 def snippet @snippet end |
#statistics ⇒ Google::Apis::YoutubeV3::VideoStatsStatistics
Statistics about the video, such as the number of times the video was viewed
or liked.
Corresponds to the JSON property statistics
9088 9089 9090 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9088 def statistics @statistics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9095 9096 9097 9098 9099 9100 9101 9102 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9095 def update!(**args) @content_details = args[:content_details] if args.key?(:content_details) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @snippet = args[:snippet] if args.key?(:snippet) @statistics = args[:statistics] if args.key?(:statistics) end |