Class: Google::Apis::YoutubeV3::VideoStatistics
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Statistics about the video, such as the number of times the video was viewed or liked.
Instance Attribute Summary collapse
-
#comment_count ⇒ Fixnum
The number of comments for the video.
-
#dislike_count ⇒ Fixnum
The number of users who have indicated that they disliked the video by giving it a negative rating.
-
#favorite_count ⇒ Fixnum
The number of users who currently have the video marked as a favorite video.
-
#like_count ⇒ Fixnum
The number of users who have indicated that they liked the video by giving it a positive rating.
-
#view_count ⇒ Fixnum
The number of times the video has been viewed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoStatistics
constructor
A new instance of VideoStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoStatistics
Returns a new instance of VideoStatistics.
9137 9138 9139 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment_count ⇒ Fixnum
The number of comments for the video.
Corresponds to the JSON property commentCount
9113 9114 9115 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9113 def comment_count @comment_count end |
#dislike_count ⇒ Fixnum
The number of users who have indicated that they disliked the video by giving
it a negative rating.
Corresponds to the JSON property dislikeCount
9119 9120 9121 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9119 def dislike_count @dislike_count end |
#favorite_count ⇒ Fixnum
The number of users who currently have the video marked as a favorite video.
Corresponds to the JSON property favoriteCount
9124 9125 9126 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9124 def favorite_count @favorite_count end |
#like_count ⇒ Fixnum
The number of users who have indicated that they liked the video by giving it
a positive rating.
Corresponds to the JSON property likeCount
9130 9131 9132 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9130 def like_count @like_count end |
#view_count ⇒ Fixnum
The number of times the video has been viewed.
Corresponds to the JSON property viewCount
9135 9136 9137 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9135 def view_count @view_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9142 9143 9144 9145 9146 9147 9148 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9142 def update!(**args) @comment_count = args[:comment_count] if args.key?(:comment_count) @dislike_count = args[:dislike_count] if args.key?(:dislike_count) @favorite_count = args[:favorite_count] if args.key?(:favorite_count) @like_count = args[:like_count] if args.key?(:like_count) @view_count = args[:view_count] if args.key?(:view_count) end |