Class: Google::Apis::YoutubeV3::VideoStatsSnippet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video. This is a subset of the information in VideoSnippet specifically for the Videos.stats API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatsSnippet

Returns a new instance of VideoStatsSnippet.



9185
9186
9187
# File 'lib/google/apis/youtube_v3/classes.rb', line 9185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#publish_timeString

Output only. The date and time that the video was uploaded. The property value is a google.protobuf.Timestamp object. Corresponds to the JSON property publishTime

Returns:

  • (String)


9183
9184
9185
# File 'lib/google/apis/youtube_v3/classes.rb', line 9183

def publish_time
  @publish_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9190
9191
9192
# File 'lib/google/apis/youtube_v3/classes.rb', line 9190

def update!(**args)
  @publish_time = args[:publish_time] if args.key?(:publish_time)
end