Class: Google::Apis::YoutubeV3::VideoStatsStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about the video, such as the number of times the video was viewed or liked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatsStatistics

Returns a new instance of VideoStatsStatistics.



9331
9332
9333
# File 'lib/google/apis/youtube_v3/classes.rb', line 9331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comment_countFixnum

Output only. The number of comments for the video. Corresponds to the JSON property commentCount

Returns:

  • (Fixnum)


9318
9319
9320
# File 'lib/google/apis/youtube_v3/classes.rb', line 9318

def comment_count
  @comment_count
end

#like_countFixnum

Output only. The number of users who have indicated that they liked the video by giving it a positive rating. Corresponds to the JSON property likeCount

Returns:

  • (Fixnum)


9324
9325
9326
# File 'lib/google/apis/youtube_v3/classes.rb', line 9324

def like_count
  @like_count
end

#view_countFixnum

Output only. The number of times the video has been viewed. Corresponds to the JSON property viewCount

Returns:

  • (Fixnum)


9329
9330
9331
# File 'lib/google/apis/youtube_v3/classes.rb', line 9329

def view_count
  @view_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9336
9337
9338
9339
9340
# File 'lib/google/apis/youtube_v3/classes.rb', line 9336

def update!(**args)
  @comment_count = args[:comment_count] if args.key?(:comment_count)
  @like_count = args[:like_count] if args.key?(:like_count)
  @view_count = args[:view_count] if args.key?(:view_count)
end