Class: Google::Apis::YoutubeV3::VideoStatsStatistics

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Statistics about the video, such as the number of times the video was viewed or liked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatsStatistics

Returns a new instance of VideoStatsStatistics.



9216
9217
9218
# File 'lib/google/apis/youtube_v3/classes.rb', line 9216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#comment_countFixnum

Output only. The number of comments for the video. Corresponds to the JSON property commentCount

Returns:

  • (Fixnum)


9203
9204
9205
# File 'lib/google/apis/youtube_v3/classes.rb', line 9203

def comment_count
  @comment_count
end

#like_countFixnum

Output only. The number of users who have indicated that they liked the video by giving it a positive rating. Corresponds to the JSON property likeCount

Returns:

  • (Fixnum)


9209
9210
9211
# File 'lib/google/apis/youtube_v3/classes.rb', line 9209

def like_count
  @like_count
end

#view_countFixnum

Output only. The number of times the video has been viewed. Corresponds to the JSON property viewCount

Returns:

  • (Fixnum)


9214
9215
9216
# File 'lib/google/apis/youtube_v3/classes.rb', line 9214

def view_count
  @view_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9221
9222
9223
9224
9225
# File 'lib/google/apis/youtube_v3/classes.rb', line 9221

def update!(**args)
  @comment_count = args[:comment_count] if args.key?(:comment_count)
  @like_count = args[:like_count] if args.key?(:like_count)
  @view_count = args[:view_count] if args.key?(:view_count)
end