Class: Google::Apis::YoutubeV3::VideoStatus
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a video category, such as its localized title. Next Id: 19
Instance Attribute Summary collapse
-
#contains_synthetic_media ⇒ Boolean
(also: #contains_synthetic_media?)
Indicates if the video contains altered or synthetic media.
-
#embeddable ⇒ Boolean
(also: #embeddable?)
This value indicates if the video can be embedded on another website.
-
#failure_reason ⇒ String
This value explains why a video failed to upload.
-
#license ⇒ String
The video's license.
-
#made_for_kids ⇒ Boolean
(also: #made_for_kids?)
Corresponds to the JSON property
madeForKids. -
#privacy_status ⇒ String
The video's privacy status.
-
#public_stats_viewable ⇒ Boolean
(also: #public_stats_viewable?)
This value indicates if the extended video statistics on the watch page can be viewed by everyone.
-
#publish_at ⇒ DateTime
The date and time when the video is scheduled to publish.
-
#rejection_reason ⇒ String
This value explains why YouTube rejected an uploaded video.
-
#self_declared_made_for_kids ⇒ Boolean
(also: #self_declared_made_for_kids?)
Corresponds to the JSON property
selfDeclaredMadeForKids. -
#upload_status ⇒ String
The status of the uploaded video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoStatus
constructor
A new instance of VideoStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoStatus
Returns a new instance of VideoStatus.
9590 9591 9592 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains_synthetic_media ⇒ Boolean Also known as: contains_synthetic_media?
Indicates if the video contains altered or synthetic media.
Corresponds to the JSON property containsSyntheticMedia
9526 9527 9528 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9526 def contains_synthetic_media @contains_synthetic_media end |
#embeddable ⇒ Boolean Also known as: embeddable?
This value indicates if the video can be embedded on another website. @mutable
youtube.videos.insert youtube.videos.update
Corresponds to the JSON property embeddable
9533 9534 9535 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9533 def @embeddable end |
#failure_reason ⇒ String
This value explains why a video failed to upload. This property is only
present if the uploadStatus property indicates that the upload failed.
Corresponds to the JSON property failureReason
9540 9541 9542 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9540 def failure_reason @failure_reason end |
#license ⇒ String
The video's license. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property license
9545 9546 9547 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9545 def license @license end |
#made_for_kids ⇒ Boolean Also known as: made_for_kids?
Corresponds to the JSON property madeForKids
9550 9551 9552 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9550 def made_for_kids @made_for_kids end |
#privacy_status ⇒ String
The video's privacy status.
Corresponds to the JSON property privacyStatus
9556 9557 9558 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9556 def privacy_status @privacy_status end |
#public_stats_viewable ⇒ Boolean Also known as: public_stats_viewable?
This value indicates if the extended video statistics on the watch page can be
viewed by everyone. Note that the view count, likes, etc will still be visible
if this is disabled. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property publicStatsViewable
9563 9564 9565 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9563 def public_stats_viewable @public_stats_viewable end |
#publish_at ⇒ DateTime
The date and time when the video is scheduled to publish. It can be set only
if the privacy status of the video is private..
Corresponds to the JSON property publishAt
9570 9571 9572 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9570 def publish_at @publish_at end |
#rejection_reason ⇒ String
This value explains why YouTube rejected an uploaded video. This property is
only present if the uploadStatus property indicates that the upload was
rejected.
Corresponds to the JSON property rejectionReason
9577 9578 9579 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9577 def rejection_reason @rejection_reason end |
#self_declared_made_for_kids ⇒ Boolean Also known as: self_declared_made_for_kids?
Corresponds to the JSON property selfDeclaredMadeForKids
9582 9583 9584 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9582 def self_declared_made_for_kids @self_declared_made_for_kids end |
#upload_status ⇒ String
The status of the uploaded video.
Corresponds to the JSON property uploadStatus
9588 9589 9590 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9588 def upload_status @upload_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9595 9596 9597 9598 9599 9600 9601 9602 9603 9604 9605 9606 9607 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9595 def update!(**args) @contains_synthetic_media = args[:contains_synthetic_media] if args.key?(:contains_synthetic_media) @embeddable = args[:embeddable] if args.key?(:embeddable) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @license = args[:license] if args.key?(:license) @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids) @privacy_status = args[:privacy_status] if args.key?(:privacy_status) @public_stats_viewable = args[:public_stats_viewable] if args.key?(:public_stats_viewable) @publish_at = args[:publish_at] if args.key?(:publish_at) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids) @upload_status = args[:upload_status] if args.key?(:upload_status) end |