Class: Google::Apis::YoutubeV3::VideoStatus
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Basic details about a video category, such as its localized title. Next Id: 19
Instance Attribute Summary collapse
-
#contains_synthetic_media ⇒ Boolean
(also: #contains_synthetic_media?)
Indicates if the video contains altered or synthetic media.
-
#embeddable ⇒ Boolean
(also: #embeddable?)
This value indicates if the video can be embedded on another website.
-
#failure_reason ⇒ String
This value explains why a video failed to upload.
-
#license ⇒ String
The video's license.
-
#made_for_kids ⇒ Boolean
(also: #made_for_kids?)
Corresponds to the JSON property
madeForKids. -
#privacy_status ⇒ String
The video's privacy status.
-
#public_stats_viewable ⇒ Boolean
(also: #public_stats_viewable?)
This value indicates if the extended video statistics on the watch page can be viewed by everyone.
-
#publish_at ⇒ DateTime
The date and time when the video is scheduled to publish.
-
#rejection_reason ⇒ String
This value explains why YouTube rejected an uploaded video.
-
#self_declared_made_for_kids ⇒ Boolean
(also: #self_declared_made_for_kids?)
Corresponds to the JSON property
selfDeclaredMadeForKids. -
#upload_status ⇒ String
The status of the uploaded video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoStatus
constructor
A new instance of VideoStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoStatus
Returns a new instance of VideoStatus.
9586 9587 9588 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9586 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contains_synthetic_media ⇒ Boolean Also known as: contains_synthetic_media?
Indicates if the video contains altered or synthetic media.
Corresponds to the JSON property containsSyntheticMedia
9522 9523 9524 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9522 def contains_synthetic_media @contains_synthetic_media end |
#embeddable ⇒ Boolean Also known as: embeddable?
This value indicates if the video can be embedded on another website. @mutable
youtube.videos.insert youtube.videos.update
Corresponds to the JSON property embeddable
9529 9530 9531 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9529 def @embeddable end |
#failure_reason ⇒ String
This value explains why a video failed to upload. This property is only
present if the uploadStatus property indicates that the upload failed.
Corresponds to the JSON property failureReason
9536 9537 9538 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9536 def failure_reason @failure_reason end |
#license ⇒ String
The video's license. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property license
9541 9542 9543 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9541 def license @license end |
#made_for_kids ⇒ Boolean Also known as: made_for_kids?
Corresponds to the JSON property madeForKids
9546 9547 9548 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9546 def made_for_kids @made_for_kids end |
#privacy_status ⇒ String
The video's privacy status.
Corresponds to the JSON property privacyStatus
9552 9553 9554 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9552 def privacy_status @privacy_status end |
#public_stats_viewable ⇒ Boolean Also known as: public_stats_viewable?
This value indicates if the extended video statistics on the watch page can be
viewed by everyone. Note that the view count, likes, etc will still be visible
if this is disabled. @mutable youtube.videos.insert youtube.videos.update
Corresponds to the JSON property publicStatsViewable
9559 9560 9561 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9559 def public_stats_viewable @public_stats_viewable end |
#publish_at ⇒ DateTime
The date and time when the video is scheduled to publish. It can be set only
if the privacy status of the video is private..
Corresponds to the JSON property publishAt
9566 9567 9568 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9566 def publish_at @publish_at end |
#rejection_reason ⇒ String
This value explains why YouTube rejected an uploaded video. This property is
only present if the uploadStatus property indicates that the upload was
rejected.
Corresponds to the JSON property rejectionReason
9573 9574 9575 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9573 def rejection_reason @rejection_reason end |
#self_declared_made_for_kids ⇒ Boolean Also known as: self_declared_made_for_kids?
Corresponds to the JSON property selfDeclaredMadeForKids
9578 9579 9580 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9578 def self_declared_made_for_kids @self_declared_made_for_kids end |
#upload_status ⇒ String
The status of the uploaded video.
Corresponds to the JSON property uploadStatus
9584 9585 9586 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9584 def upload_status @upload_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9591 9592 9593 9594 9595 9596 9597 9598 9599 9600 9601 9602 9603 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9591 def update!(**args) @contains_synthetic_media = args[:contains_synthetic_media] if args.key?(:contains_synthetic_media) @embeddable = args[:embeddable] if args.key?(:embeddable) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @license = args[:license] if args.key?(:license) @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids) @privacy_status = args[:privacy_status] if args.key?(:privacy_status) @public_stats_viewable = args[:public_stats_viewable] if args.key?(:public_stats_viewable) @publish_at = args[:publish_at] if args.key?(:publish_at) @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason) @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids) @upload_status = args[:upload_status] if args.key?(:upload_status) end |