Class: Google::Apis::YoutubeV3::VideoStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Basic details about a video category, such as its localized title. Next Id: 19

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoStatus

Returns a new instance of VideoStatus.



9414
9415
9416
# File 'lib/google/apis/youtube_v3/classes.rb', line 9414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contains_synthetic_mediaBoolean Also known as: contains_synthetic_media?

Indicates if the video contains altered or synthetic media. Corresponds to the JSON property containsSyntheticMedia

Returns:

  • (Boolean)


9350
9351
9352
# File 'lib/google/apis/youtube_v3/classes.rb', line 9350

def contains_synthetic_media
  @contains_synthetic_media
end

#embeddableBoolean Also known as: embeddable?

This value indicates if the video can be embedded on another website. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property embeddable

Returns:

  • (Boolean)


9357
9358
9359
# File 'lib/google/apis/youtube_v3/classes.rb', line 9357

def embeddable
  @embeddable
end

#failure_reasonString

This value explains why a video failed to upload. This property is only present if the uploadStatus property indicates that the upload failed. Corresponds to the JSON property failureReason

Returns:

  • (String)


9364
9365
9366
# File 'lib/google/apis/youtube_v3/classes.rb', line 9364

def failure_reason
  @failure_reason
end

#licenseString

The video's license. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property license

Returns:

  • (String)


9369
9370
9371
# File 'lib/google/apis/youtube_v3/classes.rb', line 9369

def license
  @license
end

#made_for_kidsBoolean Also known as: made_for_kids?

Corresponds to the JSON property madeForKids

Returns:

  • (Boolean)


9374
9375
9376
# File 'lib/google/apis/youtube_v3/classes.rb', line 9374

def made_for_kids
  @made_for_kids
end

#privacy_statusString

The video's privacy status. Corresponds to the JSON property privacyStatus

Returns:

  • (String)


9380
9381
9382
# File 'lib/google/apis/youtube_v3/classes.rb', line 9380

def privacy_status
  @privacy_status
end

#public_stats_viewableBoolean Also known as: public_stats_viewable?

This value indicates if the extended video statistics on the watch page can be viewed by everyone. Note that the view count, likes, etc will still be visible if this is disabled. @mutable youtube.videos.insert youtube.videos.update Corresponds to the JSON property publicStatsViewable

Returns:

  • (Boolean)


9387
9388
9389
# File 'lib/google/apis/youtube_v3/classes.rb', line 9387

def public_stats_viewable
  @public_stats_viewable
end

#publish_atDateTime

The date and time when the video is scheduled to publish. It can be set only if the privacy status of the video is private.. Corresponds to the JSON property publishAt

Returns:

  • (DateTime)


9394
9395
9396
# File 'lib/google/apis/youtube_v3/classes.rb', line 9394

def publish_at
  @publish_at
end

#rejection_reasonString

This value explains why YouTube rejected an uploaded video. This property is only present if the uploadStatus property indicates that the upload was rejected. Corresponds to the JSON property rejectionReason

Returns:

  • (String)


9401
9402
9403
# File 'lib/google/apis/youtube_v3/classes.rb', line 9401

def rejection_reason
  @rejection_reason
end

#self_declared_made_for_kidsBoolean Also known as: self_declared_made_for_kids?

Corresponds to the JSON property selfDeclaredMadeForKids

Returns:

  • (Boolean)


9406
9407
9408
# File 'lib/google/apis/youtube_v3/classes.rb', line 9406

def self_declared_made_for_kids
  @self_declared_made_for_kids
end

#upload_statusString

The status of the uploaded video. Corresponds to the JSON property uploadStatus

Returns:

  • (String)


9412
9413
9414
# File 'lib/google/apis/youtube_v3/classes.rb', line 9412

def upload_status
  @upload_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
# File 'lib/google/apis/youtube_v3/classes.rb', line 9419

def update!(**args)
  @contains_synthetic_media = args[:contains_synthetic_media] if args.key?(:contains_synthetic_media)
  @embeddable = args[:embeddable] if args.key?(:embeddable)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @license = args[:license] if args.key?(:license)
  @made_for_kids = args[:made_for_kids] if args.key?(:made_for_kids)
  @privacy_status = args[:privacy_status] if args.key?(:privacy_status)
  @public_stats_viewable = args[:public_stats_viewable] if args.key?(:public_stats_viewable)
  @publish_at = args[:publish_at] if args.key?(:publish_at)
  @rejection_reason = args[:rejection_reason] if args.key?(:rejection_reason)
  @self_declared_made_for_kids = args[:self_declared_made_for_kids] if args.key?(:self_declared_made_for_kids)
  @upload_status = args[:upload_status] if args.key?(:upload_status)
end