Class: Google::Apis::YoutubeV3::VideoSuggestions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoSuggestions

Returns a new instance of VideoSuggestions.



9360
9361
9362
# File 'lib/google/apis/youtube_v3/classes.rb', line 9360

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editor_suggestionsArray<String>

A list of video editing operations that might improve the video quality or playback experience of the uploaded video. Corresponds to the JSON property editorSuggestions

Returns:

  • (Array<String>)


9328
9329
9330
# File 'lib/google/apis/youtube_v3/classes.rb', line 9328

def editor_suggestions
  @editor_suggestions
end

#processing_errorsArray<String>

A list of errors that will prevent YouTube from successfully processing the uploaded video video. These errors indicate that, regardless of the video's current processing status, eventually, that status will almost certainly be failed. Corresponds to the JSON property processingErrors

Returns:

  • (Array<String>)


9336
9337
9338
# File 'lib/google/apis/youtube_v3/classes.rb', line 9336

def processing_errors
  @processing_errors
end

#processing_hintsArray<String>

A list of suggestions that may improve YouTube's ability to process the video. Corresponds to the JSON property processingHints

Returns:

  • (Array<String>)


9341
9342
9343
# File 'lib/google/apis/youtube_v3/classes.rb', line 9341

def processing_hints
  @processing_hints
end

#processing_warningsArray<String>

A list of reasons why YouTube may have difficulty transcoding the uploaded video or that might result in an erroneous transcoding. These warnings are generated before YouTube actually processes the uploaded video file. In addition, they identify issues that are unlikely to cause the video processing to fail but that might cause problems such as sync issues, video artifacts, or a missing audio track. Corresponds to the JSON property processingWarnings

Returns:

  • (Array<String>)


9351
9352
9353
# File 'lib/google/apis/youtube_v3/classes.rb', line 9351

def processing_warnings
  @processing_warnings
end

#tag_suggestionsArray<Google::Apis::YoutubeV3::VideoSuggestionsTagSuggestion>

A list of keyword tags that could be added to the video's metadata to increase the likelihood that users will locate your video when searching or browsing on YouTube. Corresponds to the JSON property tagSuggestions



9358
9359
9360
# File 'lib/google/apis/youtube_v3/classes.rb', line 9358

def tag_suggestions
  @tag_suggestions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9365
9366
9367
9368
9369
9370
9371
# File 'lib/google/apis/youtube_v3/classes.rb', line 9365

def update!(**args)
  @editor_suggestions = args[:editor_suggestions] if args.key?(:editor_suggestions)
  @processing_errors = args[:processing_errors] if args.key?(:processing_errors)
  @processing_hints = args[:processing_hints] if args.key?(:processing_hints)
  @processing_warnings = args[:processing_warnings] if args.key?(:processing_warnings)
  @tag_suggestions = args[:tag_suggestions] if args.key?(:tag_suggestions)
end