Class: Google::Apis::YoutubeV3::VideoTopicDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Freebase topic information related to the video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoTopicDetails

Returns a new instance of VideoTopicDetails.



9429
9430
9431
# File 'lib/google/apis/youtube_v3/classes.rb', line 9429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#relevant_topic_idsArray<String>

Similar to topic_id, except that these topics are merely relevant to the video. These are topics that may be mentioned in, or appear in the video. You can retrieve information about each topic using Freebase Topic API. Corresponds to the JSON property relevantTopicIds

Returns:

  • (Array<String>)


9412
9413
9414
# File 'lib/google/apis/youtube_v3/classes.rb', line 9412

def relevant_topic_ids
  @relevant_topic_ids
end

#topic_categoriesArray<String>

A list of Wikipedia URLs that provide a high-level description of the video's content. Corresponds to the JSON property topicCategories

Returns:

  • (Array<String>)


9418
9419
9420
# File 'lib/google/apis/youtube_v3/classes.rb', line 9418

def topic_categories
  @topic_categories
end

#topic_idsArray<String>

A list of Freebase topic IDs that are centrally associated with the video. These are topics that are centrally featured in the video, and it can be said that the video is mainly about each of these. You can retrieve information about each topic using the < a href="http://wiki.freebase.com/wiki/Topic_API"> Freebase Topic API. Corresponds to the JSON property topicIds

Returns:

  • (Array<String>)


9427
9428
9429
# File 'lib/google/apis/youtube_v3/classes.rb', line 9427

def topic_ids
  @topic_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9434
9435
9436
9437
9438
# File 'lib/google/apis/youtube_v3/classes.rb', line 9434

def update!(**args)
  @relevant_topic_ids = args[:relevant_topic_ids] if args.key?(:relevant_topic_ids)
  @topic_categories = args[:topic_categories] if args.key?(:topic_categories)
  @topic_ids = args[:topic_ids] if args.key?(:topic_ids)
end