Class: Google::Apis::YoutubeV3::VideoTrainability
- Inherits:
-
Object
- Object
- Google::Apis::YoutubeV3::VideoTrainability
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb
Overview
Specifies who is allowed to train on the video.
Instance Attribute Summary collapse
-
#etag ⇒ String
Etag of this resource.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#permitted ⇒ Array<String>
Specifies who is allowed to train on the video.
-
#video_id ⇒ String
The ID of the video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VideoTrainability
constructor
A new instance of VideoTrainability.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VideoTrainability
Returns a new instance of VideoTrainability.
9615 9616 9617 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Etag of this resource.
Corresponds to the JSON property etag
9596 9597 9598 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9596 def etag @etag end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "youtube#
videoTrainability".
Corresponds to the JSON property kind
9602 9603 9604 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9602 def kind @kind end |
#permitted ⇒ Array<String>
Specifies who is allowed to train on the video. Valid values are: - a single
string "all" - a single string "none" - a list of allowed parties
Corresponds to the JSON property permitted
9608 9609 9610 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9608 def permitted @permitted end |
#video_id ⇒ String
The ID of the video.
Corresponds to the JSON property videoId
9613 9614 9615 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9613 def video_id @video_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9620 9621 9622 9623 9624 9625 |
# File 'lib/google/apis/youtube_v3/classes.rb', line 9620 def update!(**args) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @permitted = args[:permitted] if args.key?(:permitted) @video_id = args[:video_id] if args.key?(:video_id) end |