Class: Google::Apis::YoutubeV3::VideoTrainability

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/youtube_v3/classes.rb,
lib/google/apis/youtube_v3/representations.rb,
lib/google/apis/youtube_v3/representations.rb

Overview

Specifies who is allowed to train on the video.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoTrainability

Returns a new instance of VideoTrainability.



9467
9468
9469
# File 'lib/google/apis/youtube_v3/classes.rb', line 9467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Etag of this resource. Corresponds to the JSON property etag

Returns:

  • (String)


9448
9449
9450
# File 'lib/google/apis/youtube_v3/classes.rb', line 9448

def etag
  @etag
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "youtube# videoTrainability". Corresponds to the JSON property kind

Returns:

  • (String)


9454
9455
9456
# File 'lib/google/apis/youtube_v3/classes.rb', line 9454

def kind
  @kind
end

#permittedArray<String>

Specifies who is allowed to train on the video. Valid values are: - a single string "all" - a single string "none" - a list of allowed parties Corresponds to the JSON property permitted

Returns:

  • (Array<String>)


9460
9461
9462
# File 'lib/google/apis/youtube_v3/classes.rb', line 9460

def permitted
  @permitted
end

#video_idString

The ID of the video. Corresponds to the JSON property videoId

Returns:

  • (String)


9465
9466
9467
# File 'lib/google/apis/youtube_v3/classes.rb', line 9465

def video_id
  @video_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9472
9473
9474
9475
9476
9477
# File 'lib/google/apis/youtube_v3/classes.rb', line 9472

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @permitted = args[:permitted] if args.key?(:permitted)
  @video_id = args[:video_id] if args.key?(:video_id)
end